package Data::Password::zxcvbn::RankedDictionaries;
use strict;
use warnings;
our $VERSION = '1.0.2';

=head1 NAME

Data::Password::zxcvbn::RankedDictionaries - ranked dictionaries for common words

=head1 DESCRIPTION

This is a data file used by L<<
C<Data::Password::zxcvbn::Match::Dictionary> >>, and is generated by
the L<<
C<build-ranked-dictionaries>|https://bitbucket.org/broadbean/p5-data-password-zxcvbn/src/master/maint/build-ranked-dictionaries
>> program when building the distribution.

=cut

our %ranked_dictionaries = (
  english_wikipedia => {
                         "'aliabad"                => 26996,
                         "'best"                   => 9381,
                         "'black"                  => 17310,
                         "'blue"                   => 26339,
                         "'bout"                   => 25881,
                         "'cause"                  => 20289,
                         "'first"                  => 21522,
                         "'free"                   => 23172,
                         "'golden"                 => 24135,
                         "'good"                   => 16773,
                         "'great"                  => 19608,
                         "'green"                  => 23731,
                         "'high"                   => 22985,
                         "'home"                   => 25650,
                         "'king"                   => 22765,
                         "'little"                 => 19663,
                         "'live"                   => 25805,
                         "'love"                   => 23073,
                         "'most"                   => 23244,
                         "'national"               => 23364,
                         "'ndrangheta"             => 27426,
                         "'olya"                   => 13106,
                         "'open"                   => 27099,
                         "'outstanding"            => 29889,
                         "'people"                 => 28368,
                         "'real"                   => 22497,
                         "'right"                  => 29398,
                         "'round"                  => 21361,
                         "'special"                => 25580,
                         "'that"                   => 17910,
                         "'the"                    => 2543,
                         "'there"                  => 21951,
                         "'this"                   => 15133,
                         "'three"                  => 29786,
                         "'well"                   => 24039,
                         "'what"                   => 13839,
                         "'when"                   => 25536,
                         "'white"                  => 19601,
                         "'with"                   => 29618,
                         "'world"                  => 26581,
                         "1,000th"                 => 27351,
                         "1000m"                   => 29078,
                         "100th"                   => 6244,
                         "101st"                   => 10918,
                         "102nd"                   => 18954,
                         "103rd"                   => 18029,
                         "104th"                   => 16735,
                         "105th"                   => 18937,
                         "106th"                   => 18824,
                         "107th"                   => 18536,
                         "1080p"                   => 24359,
                         "108th"                   => 18422,
                         "109th"                   => 18235,
                         "10deg"                   => 28222,
                         "10th"                    => 2118,
                         "110th"                   => 15756,
                         "111th"                   => 16219,
                         "112th"                   => 17378,
                         "113th"                   => 14336,
                         "114th"                   => 21357,
                         "115th"                   => 21600,
                         "116th"                   => 18125,
                         "117th"                   => 21295,
                         "118th"                   => 24152,
                         "119th"                   => 24726,
                         "11th"                    => 2149,
                         "120th"                   => 22064,
                         "121st"                   => 23614,
                         "122nd"                   => 29721,
                         "124th"                   => 25867,
                         "125cc"                   => 21740,
                         "125th"                   => 14066,
                         "126th"                   => 24011,
                         "127th"                   => 25873,
                         "128th"                   => 26675,
                         "129th"                   => 28641,
                         "12th"                    => 1939,
                         "130th"                   => 26500,
                         "131st"                   => 26829,
                         "135th"                   => 25317,
                         "137th"                   => 27844,
                         "138th"                   => 27898,
                         "13th"                    => 2007,
                         "140th"                   => 27388,
                         "141st"                   => 28438,
                         "142nd"                   => 29988,
                         "145th"                   => 29058,
                         "148th"                   => 27251,
                         "149th"                   => 28837,
                         "14th"                    => 2108,
                         "1500m"                   => 21455,
                         "1500s"                   => 26442,
                         "150th"                   => 11620,
                         "1530s"                   => 28032,
                         "153rd"                   => 27130,
                         "1540s"                   => 29603,
                         "155th"                   => 29599,
                         "157th"                   => 26823,
                         "1580s"                   => 28407,
                         "1590s"                   => 28155,
                         "15th"                    => 2032,
                         "1600s"                   => 18170,
                         "160th"                   => 25527,
                         "161st"                   => 27159,
                         "1620s"                   => 24615,
                         "1630s"                   => 20123,
                         "1640s"                   => 21857,
                         "1650s"                   => 22347,
                         "1660s"                   => 22789,
                         "1670s"                   => 25582,
                         "1680s"                   => 24330,
                         "1690s"                   => 25144,
                         "16th"                    => 1793,
                         "1700s"                   => 15143,
                         "1720s"                   => 22073,
                         "1730s"                   => 19857,
                         "173rd"                   => 26801,
                         "1740s"                   => 19576,
                         "1750s"                   => 18387,
                         "175th"                   => 26104,
                         "1760s"                   => 16364,
                         "1770s"                   => 15512,
                         "1780s"                   => 14727,
                         "1790s"                   => 13210,
                         "179th"                   => 29414,
                         "17th"                    => 1701,
                         "1800s"                   => 7128,
                         "180deg"                  => 17817,
                         "180th"                   => 25053,
                         "181st"                   => 28394,
                         "1820s"                   => 8955,
                         "1830s"                   => 6838,
                         "1840s"                   => 6569,
                         "1850s"                   => 5650,
                         "1860s"                   => 5536,
                         "1870s"                   => 5222,
                         "187th"                   => 29676,
                         "1880s"                   => 4444,
                         "1890s"                   => 4757,
                         "18th"                    => 1416,
                         "1900s"                   => 5577,
                         "1910s"                   => 8799,
                         "1920s"                   => 2045,
                         "1930s"                   => 1646,
                         "1940s"                   => 2407,
                         "1950s"                   => 1273,
                         "1960s"                   => 933,
                         "1970s"                   => 855,
                         "1980s"                   => 820,
                         "1990s"                   => 912,
                         "19th"                    => 793,
                         "1up.com"                 => 24886,
                         "2/1st"                   => 27393,
                         "2000s"                   => 2808,
                         "200th"                   => 13482,
                         "2010s"                   => 9067,
                         "20deg"                   => 29926,
                         "20th"                    => 915,
                         "21st"                    => 2498,
                         "22nd"                    => 5180,
                         "23rd"                    => 5236,
                         "24th"                    => 4981,
                         "250cc"                   => 20774,
                         "250th"                   => 26147,
                         "25th"                    => 4068,
                         "26th"                    => 5533,
                         "27th"                    => 5614,
                         "300th"                   => 18680,
                         "30deg"                   => 22234,
                         "30th"                    => 4946,
                         "360deg"                  => 17764,
                         "36ers"                   => 28146,
                         "400th"                   => 21231,
                         "45deg"                   => 18988,
                         "4kids"                   => 25537,
                         "4x100"                   => 9148,
                         "4x100m"                  => 21899,
                         "4x200"                   => 17074,
                         "4x400"                   => 18443,
                         "500cc"                   => 22550,
                         "500th"                   => 19383,
                         "509th"                   => 27402,
                         "50th"                    => 4866,
                         "60deg"                   => 21802,
                         "76ers"                   => 12014,
                         "90deg"                   => 14423,
                         "`abdu'l"                 => 17563,
                         "a.f.c"                   => 12816,
                         "a.k.a"                   => 7158,
                         "a.m."                    => 4280,
                         "aachen"                  => 9686,
                         "aacsb"                   => 28890,
                         "aagpbl"                  => 22986,
                         "aalto"                   => 19458,
                         "aamir"                   => 20281,
                         "aarau"                   => 28053,
                         "aargau"                  => 20689,
                         "aarhus"                  => 10916,
                         "aarti"                   => 26784,
                         "ababa"                   => 12225,
                         "abacetus"                => 20258,
                         "abacha"                  => 27860,
                         "abalone"                 => 23825,
                         "abandoned"               => 1485,
                         "abandonment"             => 7733,
                         "abandons"                => 14244,
                         "abated"                  => 27597,
                         "abatement"               => 24494,
                         "abbas"                   => 6468,
                         "abbasabad"               => 23257,
                         "abbasi"                  => 21067,
                         "abbasid"                 => 11616,
                         "abbasids"                => 23233,
                         "abbess"                  => 12531,
                         "abbeville"               => 16581,
                         "abbeys"                  => 17709,
                         "abbot"                   => 4645,
                         "abbots"                  => 13562,
                         "abbotsford"              => 15874,
                         "abbottabad"              => 21963,
                         "abbreviated"             => 3998,
                         "abbreviation"            => 6990,
                         "abbreviations"           => 12716,
                         "abdel"                   => 10036,
                         "abdicate"                => 17512,
                         "abdicated"               => 13580,
                         "abdication"              => 12311,
                         "abdomen"                 => 6743,
                         "abdomina"                => 18305,
                         "abducts"                 => 29944,
                         "abdulaziz"               => 14444,
                         "abdullahi"               => 25146,
                         "abdur"                   => 17646,
                         "abdus"                   => 24952,
                         "abelard"                 => 29189,
                         "abelian"                 => 11073,
                         "abellio"                 => 22383,
                         "abenaki"                 => 21327,
                         "abercorn"                => 27440,
                         "abercromby"              => 26314,
                         "aberdare"                => 15971,
                         "aberdeenshire"           => 12027,
                         "abergavenny"             => 20674,
                         "aberrations"             => 22633,
                         "aberystwyth"             => 13200,
                         "abeyance"                => 20772,
                         "abhay"                   => 25669,
                         "abidjan"                 => 18406,
                         "abies"                   => 21411,
                         "abilene"                 => 13249,
                         "abilities"               => 2879,
                         "ability"                 => 1022,
                         "abingdon"                => 12288,
                         "abington"                => 19589,
                         "abitibi"                 => 27092,
                         "abitur"                  => 20814,
                         "abkhaz"                  => 18152,
                         "abkhazia"                => 10384,
                         "abkhazian"               => 23929,
                         "ablation"                => 18879,
                         "ablative"                => 28721,
                         "ablaze"                  => 18405,
                         "ablett"                  => 28517,
                         "abnormalities"           => 9623,
                         "abode"                   => 11760,
                         "abolish"                 => 9707,
                         "abolished"               => 3047,
                         "abolishing"              => 13496,
                         "abolishment"             => 24368,
                         "abolition"               => 5313,
                         "abolitionist"            => 9742,
                         "abolitionists"           => 17025,
                         "aboriginal"              => 3525,
                         "aboriginals"             => 19185,
                         "aborigines"              => 10284,
                         "abortions"               => 11212,
                         "abortive"                => 13671,
                         "abounded"                => 28590,
                         "abounds"                 => 28744,
                         "about.com"               => 16763,
                         "above"                   => 484,
                         "abrahamic"               => 21852,
                         "abramoff"                => 19011,
                         "abramovich"              => 28243,
                         "abrasion"                => 20698,
                         "abrasive"                => 13851,
                         "abridged"                => 13377,
                         "abroad"                  => 2240,
                         "abrogated"               => 24548,
                         "abruptly"                => 6977,
                         "abruzzo"                 => 15891,
                         "abscess"                 => 20292,
                         "absence"                 => 2325,
                         "absent"                  => 4029,
                         "absentia"                => 15389,
                         "absolutism"              => 23939,
                         "absolutist"              => 26318,
                         "absorbed"                => 3556,
                         "absorber"                => 21026,
                         "absorbers"               => 19993,
                         "absorbing"               => 8646,
                         "absorbs"                 => 13169,
                         "absorption"              => 5774,
                         "abstained"               => 17039,
                         "abstaining"              => 25185,
                         "abstention"              => 23732,
                         "abstentions"             => 24999,
                         "abstract"                => 3722,
                         "abstracted"              => 11318,
                         "abstracting"             => 12928,
                         "abstraction"             => 8307,
                         "abstractions"            => 19648,
                         "abstracts"               => 12742,
                         "absurdist"               => 27153,
                         "abteilung"               => 26157,
                         "abu'l"                   => 19834,
                         "abubakar"                => 21006,
                         "abuja"                   => 16411,
                         "abundance"               => 5480,
                         "abundances"              => 27430,
                         "abundant"                => 4630,
                         "abuse"                   => 2442,
                         "abusers"                 => 24444,
                         "abuses"                  => 7182,
                         "abutment"                => 26167,
                         "abutments"               => 18989,
                         "abuts"                   => 24242,
                         "abutting"                => 24116,
                         "abwehr"                  => 21033,
                         "abyss"                   => 9747,
                         "abyssinia"               => 19345,
                         "abyssinian"              => 21046,
                         "ac/dc"                   => 12851,
                         "academia"                => 6155,
                         "academic"                => 853,
                         "academica"               => 21526,
                         "academical"              => 16853,
                         "academically"            => 9354,
                         "academician"             => 12521,
                         "academicians"            => 21630,
                         "academics"               => 3979,
                         "academie"                => 7767,
                         "academies"               => 7091,
                         "academy"                 => 475,
                         "acadian"                 => 12773,
                         "acadians"                => 14666,
                         "accademia"               => 11569,
                         "accede"                  => 24393,
                         "acceded"                 => 15760,
                         "accelerate"              => 8294,
                         "accelerated"             => 5771,
                         "accelerates"             => 19014,
                         "accelerating"            => 10798,
                         "acceleration"            => 5902,
                         "accelerator"             => 9676,
                         "accelerators"            => 17775,
                         "accented"                => 15924,
                         "accentuated"             => 20031,
                         "accenture"               => 26429,
                         "acceptability"           => 26390,
                         "acceptance"              => 3812,
                         "accepted"                => 1081,
                         "acceptor"                => 14235,
                         "accepts"                 => 4814,
                         "accessed"                => 4426,
                         "accesses"                => 18121,
                         "accessibility"           => 7873,
                         "accessible"              => 2634,
                         "accessing"               => 10108,
                         "accession"               => 5813,
                         "accessories"             => 5975,
                         "accion"                  => 26436,
                         "accipitridae"            => 27889,
                         "acclaim"                 => 3662,
                         "acclaimed"               => 3332,
                         "acclamation"             => 18439,
                         "accolade"                => 13373,
                         "accolades"               => 6592,
                         "accommodate"             => 3106,
                         "accommodated"            => 9589,
                         "accommodates"            => 13049,
                         "accommodation"           => 4013,
                         "accompanied"             => 1856,
                         "accompanies"             => 9820,
                         "accompaniment"           => 7899,
                         "accompanist"             => 16312,
                         "accompany"               => 5238,
                         "accompanying"            => 4097,
                         "accomplishments"         => 5552,
                         "accordance"              => 3738,
                         "accorded"                => 9663,
                         "according"               => 216,
                         "accordingly"             => 4320,
                         "accordion"               => 9102,
                         "accordionist"            => 27450,
                         "accords"                 => 10880,
                         "account"                 => 1132,
                         "accountability"          => 6205,
                         "accountancy"             => 12771,
                         "accounted"               => 5339,
                         "accounting"              => 3434,
                         "accounts"                => 1991,
                         "accra"                   => 11097,
                         "accreditation"           => 4634,
                         "accredited"              => 3768,
                         "accrediting"             => 14840,
                         "accretion"               => 17561,
                         "accrington"              => 13620,
                         "accrue"                  => 21947,
                         "accrued"                 => 16087,
                         "accumulate"              => 9193,
                         "accumulated"             => 5557,
                         "accumulates"             => 16916,
                         "accumulating"            => 11735,
                         "accumulation"            => 7142,
                         "accumulations"           => 23344,
                         "accumulator"             => 20682,
                         "accuracy"                => 3790,
                         "accurate"                => 3030,
                         "accurately"              => 5308,
                         "accusative"              => 16294,
                         "accused"                 => 1795,
                         "acetaldehyde"            => 29281,
                         "acetic"                  => 15621,
                         "acetone"                 => 20486,
                         "acetyl"                  => 16467,
                         "acetylation"             => 29997,
                         "acetylcholine"           => 15916,
                         "acetylene"               => 21845,
                         "acetyltransferase"       => 28060,
                         "achaea"                  => 17644,
                         "achaean"                 => 27645,
                         "achaemenid"              => 16274,
                         "acharya"                 => 12095,
                         "achievable"              => 17591,
                         "achieve"                 => 1994,
                         "achieved"                => 1257,
                         "achievement"             => 2258,
                         "achievements"            => 3025,
                         "achievers"               => 26963,
                         "achieves"                => 10611,
                         "achieving"               => 3840,
                         "acid"                    => 1778,
                         "acidic"                  => 8353,
                         "acidification"           => 25072,
                         "acidity"                 => 14016,
                         "acids"                   => 4526,
                         "acknowledged"            => 3507,
                         "acknowledgement"         => 13228,
                         "acknowledges"            => 9363,
                         "acknowledging"           => 9318,
                         "acknowledgment"          => 15780,
                         "acland"                  => 18602,
                         "acleris"                 => 26891,
                         "acolytes"                => 24670,
                         "acorn"                   => 10758,
                         "acoustic"                => 2969,
                         "acoustical"              => 19546,
                         "acoustically"            => 23181,
                         "acoustics"               => 11051,
                         "acquiesced"              => 25121,
                         "acquire"                 => 3652,
                         "acquired"                => 911,
                         "acquires"                => 11449,
                         "acquiring"               => 4996,
                         "acquisition"             => 2561,
                         "acquisitions"            => 6355,
                         "acquitted"               => 6462,
                         "acraea"                  => 23128,
                         "acre"                    => 3995,
                         "acreage"                 => 15628,
                         "acres"                   => 2591,
                         "acrimonious"             => 19241,
                         "acrobatic"               => 14321,
                         "acrobatics"              => 20276,
                         "acrocercops"             => 22926,
                         "acrolophus"              => 29800,
                         "acronym"                 => 6374,
                         "acronyms"                => 23424,
                         "acropolis"               => 12873,
                         "across"                  => 419,
                         "acrylic"                 => 12006,
                         "act"                     => 303,
                         "actions"                 => 1382,
                         "activated"               => 3607,
                         "activates"               => 10524,
                         "activating"              => 11481,
                         "activation"              => 4944,
                         "active"                  => 571,
                         "actively"                => 2995,
                         "activision"              => 15259,
                         "activism"                => 5062,
                         "activist"                => 2771,
                         "activists"               => 3515,
                         "activities"              => 623,
                         "activity"                => 1001,
                         "actor"                   => 775,
                         "actors"                  => 1832,
                         "actress"                 => 1094,
                         "actresses"               => 6898,
                         "acts"                    => 1251,
                         "actual"                  => 1603,
                         "actuaries"               => 27137,
                         "actuated"                => 20078,
                         "actuator"                => 20870,
                         "actuators"               => 19481,
                         "acuity"                  => 19796,
                         "acumen"                  => 17482,
                         "acute"                   => 4307,
                         "acutely"                 => 19818,
                         "acyclic"                 => 25342,
                         "adalbert"                => 15347,
                         "adamantly"               => 25914,
                         "adamawa"                 => 28120,
                         "adana"                   => 12961,
                         "adapt"                   => 5930,
                         "adaptability"            => 22869,
                         "adaptable"               => 15340,
                         "adaptation"              => 2248,
                         "adaptations"             => 4798,
                         "adapted"                 => 1978,
                         "adapter"                 => 10796,
                         "adapting"                => 8733,
                         "adaption"                => 12618,
                         "adaptive"                => 6748,
                         "adaptor"                 => 22541,
                         "adapts"                  => 18333,
                         "adare"                   => 27432,
                         "adarsh"                  => 22231,
                         "added"                   => 505,
                         "adder"                   => 19563,
                         "adding"                  => 2016,
                         "addition"                => 377,
                         "additional"              => 658,
                         "additionally"            => 1719,
                         "additions"               => 4721,
                         "additive"                => 9213,
                         "additives"               => 12669,
                         "addressed"               => 3151,
                         "addresses"               => 4241,
                         "addressing"              => 5039,
                         "adds"                    => 4139,
                         "adelphi"                 => 16380,
                         "adenauer"                => 20729,
                         "adenine"                 => 23583,
                         "adenosine"               => 17055,
                         "adept"                   => 10517,
                         "adequacy"                => 22877,
                         "adequate"                => 4319,
                         "adequately"              => 8392,
                         "adhere"                  => 8467,
                         "adhered"                 => 11624,
                         "adherence"               => 9491,
                         "adherent"                => 17334,
                         "adherents"               => 8101,
                         "adheres"                 => 15298,
                         "adhering"                => 14200,
                         "adhesion"                => 10664,
                         "adhesives"               => 20624,
                         "adiabatic"               => 20608,
                         "adige"                   => 27999,
                         "adipose"                 => 19477,
                         "adirondack"              => 12939,
                         "aditi"                   => 26830,
                         "adiyaman"                => 24190,
                         "adjacent"                => 1660,
                         "adjectival"              => 23465,
                         "adjective"               => 8375,
                         "adjectives"              => 9990,
                         "adjoined"                => 22469,
                         "adjoining"               => 5130,
                         "adjoins"                 => 15892,
                         "adjoint"                 => 15904,
                         "adjournment"             => 28566,
                         "adjudged"                => 19029,
                         "adjudicated"             => 25067,
                         "adjudication"            => 20280,
                         "adjudicator"             => 27747,
                         "adjunct"                 => 7305,
                         "adjustable"              => 9086,
                         "adjusted"                => 5044,
                         "adjusts"                 => 21007,
                         "adjutant"                => 7423,
                         "adjuvant"                => 27557,
                         "administered"            => 2884,
                         "administering"           => 9588,
                         "administers"             => 9413,
                         "administracion"          => 21418,
                         "administrated"           => 17825,
                         "administration"          => 676,
                         "administrations"         => 8990,
                         "administrative"          => 782,
                         "administratively"        => 7466,
                         "administrator"           => 3368,
                         "administrators"          => 5377,
                         "admiral"                 => 2034,
                         "admirals"                => 11042,
                         "admiralty"               => 5151,
                         "admission"               => 3465,
                         "admissions"              => 6344,
                         "admits"                  => 5194,
                         "admitted"                => 1841,
                         "admixture"               => 19280,
                         "adnan"                   => 13692,
                         "adobe"                   => 6419,
                         "adolescents"             => 9092,
                         "adolf"                   => 4487,
                         "adolphe"                 => 11938,
                         "adolphus"                => 13375,
                         "adoor"                   => 24807,
                         "adopted"                 => 1068,
                         "adopters"                => 28371,
                         "adopting"                => 5754,
                         "adopts"                  => 10057,
                         "adorn"                   => 16697,
                         "adorned"                 => 8260,
                         "adorning"                => 28487,
                         "adornment"               => 28367,
                         "adorns"                  => 27774,
                         "adrenergic"              => 20145,
                         "adriaan"                 => 22212,
                         "adriaen"                 => 29813,
                         "adrianople"              => 20020,
                         "adriatic"                => 7991,
                         "adsorption"              => 17493,
                         "adult"                   => 1359,
                         "adulterous"              => 24466,
                         "adulthood"               => 7277,
                         "adults"                  => 1984,
                         "advaita"                 => 17480,
                         "advance"                 => 1589,
                         "advanced"                => 1002,
                         "advancement"             => 4749,
                         "advancements"            => 12662,
                         "advances"                => 4133,
                         "advancing"               => 4082,
                         "advani"                  => 29295,
                         "advantageous"            => 10507,
                         "advantages"              => 4173,
                         "adventist"               => 8064,
                         "adventists"              => 16021,
                         "adventurer"              => 10434,
                         "adventurers"             => 12819,
                         "adventures"              => 2749,
                         "adverb"                  => 26378,
                         "adverbs"                 => 20268,
                         "adversarial"             => 22751,
                         "adverse"                 => 5264,
                         "adversely"               => 11647,
                         "advert"                  => 12404,
                         "advertised"              => 6240,
                         "advertisement"           => 5518,
                         "advertisements"          => 4984,
                         "advertiser"              => 9854,
                         "advertisers"             => 10558,
                         "advertising"             => 2013,
                         "adverts"                 => 14203,
                         "advised"                 => 3731,
                         "adviser"                 => 4420,
                         "advisers"                => 8238,
                         "advises"                 => 8567,
                         "advisor"                 => 3188,
                         "advisories"              => 16305,
                         "advisors"                => 6708,
                         "advisory"                => 2484,
                         "advocacy"                => 4144,
                         "advocate"                => 2883,
                         "advocated"               => 4131,
                         "advocates"               => 4509,
                         "advocating"              => 7119,
                         "aechmea"                 => 20850,
                         "aegean"                  => 8769,
                         "aegis"                   => 10875,
                         "aegon"                   => 20411,
                         "aemilius"                => 27727,
                         "aeneas"                  => 15111,
                         "aeneid"                  => 21406,
                         "aeolian"                 => 18932,
                         "aerial"                  => 3315,
                         "aerials"                 => 24520,
                         "aerobatic"               => 15975,
                         "aerobatics"              => 22908,
                         "aerobic"                 => 12782,
                         "aerodrome"               => 7364,
                         "aerodynamic"             => 8984,
                         "aerodynamics"            => 13596,
                         "aeroflot"                => 21513,
                         "aeronautica"             => 19007,
                         "aeronautical"            => 8499,
                         "aeronautics"             => 9094,
                         "aeronautique"            => 24282,
                         "aeroplane"               => 11536,
                         "aeroplanes"              => 19016,
                         "aeros"                   => 20855,
                         "aerosols"                => 24099,
                         "aerospace"               => 4977,
                         "aerospatiale"            => 29458,
                         "aeschylus"               => 21531,
                         "aesop"                   => 17447,
                         "aesthetic"               => 4702,
                         "aesthetically"           => 13724,
                         "aesthetics"              => 7368,
                         "aethelred"               => 20162,
                         "aethelstan"              => 26128,
                         "aether"                  => 19046,
                         "aetna"                   => 28595,
                         "affairs"                 => 1020,
                         "affected"                => 1756,
                         "affecting"               => 4729,
                         "affectionately"          => 10911,
                         "affective"               => 14155,
                         "afferent"                => 24800,
                         "affiliate"               => 2902,
                         "affiliated"              => 2181,
                         "affiliates"              => 5859,
                         "affiliation"             => 4328,
                         "affiliations"            => 7513,
                         "affine"                  => 11478,
                         "affinis"                 => 22221,
                         "affinities"              => 15557,
                         "affinity"                => 6323,
                         "affirmation"             => 14071,
                         "affirmed"                => 7288,
                         "affirming"               => 13575,
                         "affirms"                 => 16935,
                         "affix"                   => 25949,
                         "affixed"                 => 13127,
                         "affixes"                 => 21110,
                         "afflicted"               => 10735,
                         "affluence"               => 22002,
                         "affluent"                => 7581,
                         "affordability"           => 19656,
                         "affordable"              => 5465,
                         "afforded"                => 8676,
                         "affording"               => 21097,
                         "affords"                 => 14678,
                         "afghan"                  => 4400,
                         "afghanistan"             => 2232,
                         "afghans"                 => 13709,
                         "aficionados"             => 22132,
                         "afield"                  => 13367,
                         "afire"                   => 26668,
                         "afonso"                  => 10821,
                         "aforementioned"          => 6188,
                         "aforesaid"               => 22471,
                         "afoul"                   => 24763,
                         "africa"                  => 562,
                         "african"                 => 529,
                         "africana"                => 19044,
                         "africans"                => 6390,
                         "africanus"               => 18983,
                         "afridi"                  => 25319,
                         "afrikaans"               => 9818,
                         "afrikaner"               => 17490,
                         "afrikaners"              => 29592,
                         "afshar"                  => 27631,
                         "aftab"                   => 20519,
                         "after"                   => 30,
                         "aftermarket"             => 16641,
                         "aftermath"               => 2597,
                         "aftershock"              => 27770,
                         "aftershocks"             => 23213,
                         "afterward"               => 4414,
                         "afterwards"              => 1821,
                         "afterword"               => 23480,
                         "afzal"                   => 22447,
                         "against"                 => 101,
                         "agama"                   => 27893,
                         "agaricus"                => 25579,
                         "agassiz"                 => 17745,
                         "agave"                   => 19915,
                         "agder"                   => 16990,
                         "age"                     => 140,
                         "aged"                    => 1524,
                         "ageing"                  => 10613,
                         "agence"                  => 21545,
                         "agencies"                => 2131,
                         "agency"                  => 1039,
                         "agents"                  => 2165,
                         "ages"                    => 1753,
                         "agglomeration"           => 13983,
                         "aggregate"               => 3246,
                         "aggregated"              => 14948,
                         "aggregates"              => 13138,
                         "aggregating"             => 21248,
                         "aggregation"             => 10226,
                         "aggregations"            => 27011,
                         "aggregator"              => 10413,
                         "aggression"              => 6080,
                         "aggressively"            => 9230,
                         "aggressiveness"          => 20505,
                         "aggrieved"               => 25993,
                         "agile"                   => 10599,
                         "agility"                 => 11041,
                         "agincourt"               => 20834,
                         "aging"                   => 4794,
                         "agios"                   => 16399,
                         "agitating"               => 27754,
                         "agitation"               => 9461,
                         "agnostic"                => 10971,
                         "agong"                   => 24106,
                         "agonist"                 => 12162,
                         "agonists"                => 17582,
                         "agonopterix"             => 27967,
                         "agora"                   => 18482,
                         "agrarian"                => 7716,
                         "agreement"               => 985,
                         "agreements"              => 3690,
                         "agrees"                  => 3789,
                         "agribusiness"            => 18916,
                         "agricole"                => 27847,
                         "agricultural"            => 1376,
                         "agriculturally"          => 29117,
                         "agriculture"             => 1526,
                         "agrippa"                 => 16289,
                         "agrippina"               => 23837,
                         "agronomist"              => 29087,
                         "agronomy"                => 23573,
                         "aground"                 => 9446,
                         "aguascalientes"          => 21094,
                         "agulhas"                 => 29337,
                         "agung"                   => 25501,
                         "aharon"                  => 19416,
                         "ahmadabad"               => 17221,
                         "ahmadinejad"             => 14195,
                         "ahmadiyya"               => 15125,
                         "ahmedabad"               => 9377,
                         "ahmednagar"              => 21415,
                         "ahmet"                   => 13016,
                         "ahvaz"                   => 22591,
                         "aichi"                   => 11467,
                         "aicte"                   => 20310,
                         "aided"                   => 4059,
                         "ailerons"                => 14815,
                         "ailing"                  => 11462,
                         "ailments"                => 13099,
                         "ailsa"                   => 25911,
                         "aimed"                   => 2409,
                         "aiming"                  => 6283,
                         "aims"                    => 2864,
                         "aintree"                 => 20895,
                         "air"                     => 207,
                         "airasia"                 => 26755,
                         "airbase"                 => 12247,
                         "aircraft"                => 460,
                         "aircrew"                 => 12495,
                         "aircrews"                => 17814,
                         "airdate"                 => 13275,
                         "airdrie"                 => 16095,
                         "airdrieonians"           => 28870,
                         "aired"                   => 1325,
                         "aires"                   => 3270,
                         "airfield"                => 3231,
                         "airfields"               => 7988,
                         "airflow"                 => 12959,
                         "airfoil"                 => 17232,
                         "airframe"                => 11164,
                         "airframes"               => 19468,
                         "airing"                  => 3518,
                         "airings"                 => 21442,
                         "airlift"                 => 7527,
                         "airline"                 => 2764,
                         "airliner"                => 11429,
                         "airliners"               => 15209,
                         "airlines"                => 2375,
                         "airmen"                  => 9121,
                         "airpark"                 => 27939,
                         "airplay"                 => 5088,
                         "airport"                 => 599,
                         "airports"                => 4370,
                         "airs"                    => 4902,
                         "airship"                 => 9696,
                         "airships"                => 15417,
                         "airshow"                 => 18453,
                         "airspeed"                => 15411,
                         "airstrike"               => 19719,
                         "airstrikes"              => 14507,
                         "airstrips"               => 28638,
                         "airtel"                  => 20752,
                         "airtime"                 => 16615,
                         "airways"                 => 4560,
                         "airworthiness"           => 26421,
                         "airworthy"               => 27877,
                         "aisles"                  => 9943,
                         "aisne"                   => 13301,
                         "ajaccio"                 => 21042,
                         "ajith"                   => 22644,
                         "ajmer"                   => 17234,
                         "akademi"                 => 12047,
                         "akademie"                => 17409,
                         "akali"                   => 23762,
                         "akash"                   => 22006,
                         "akb48"                   => 20677,
                         "akbar"                   => 7260,
                         "akershus"                => 18071,
                         "akhenaten"               => 19516,
                         "akhil"                   => 28177,
                         "akhtar"                  => 13322,
                         "akiba"                   => 29165,
                         "akita"                   => 14089,
                         "akiva"                   => 19430,
                         "akkadian"                => 14469,
                         "akram"                   => 18480,
                         "akron"                   => 7667,
                         "aksaray"                 => 29253,
                         "alagoas"                 => 27962,
                         "alamein"                 => 17279,
                         "alamos"                  => 12349,
                         "aland"                   => 8621,
                         "alanine"                 => 23280,
                         "alans"                   => 27907,
                         "alappuzha"               => 21835,
                         "alasdair"                => 19023,
                         "alaskan"                 => 10123,
                         "alauddin"                => 24911,
                         "alava"                   => 18612,
                         "albacete"                => 19864,
                         "albania"                 => 3767,
                         "albanian"                => 3669,
                         "albanians"               => 9639,
                         "albans"                  => 8734,
                         "albarn"                  => 20562,
                         "albatrosses"             => 26132,
                         "albay"                   => 29502,
                         "albedo"                  => 15071,
                         "albeit"                  => 4602,
                         "albemarle"               => 12743,
                         "alberni"                 => 29209,
                         "albertus"                => 26206,
                         "albertville"             => 23258,
                         "albini"                  => 22495,
                         "albinism"                => 28165,
                         "albinus"                 => 28027,
                         "alborz"                  => 20676,
                         "album"                   => 97,
                         "albumin"                 => 23090,
                         "albums"                  => 873,
                         "albuquerque"             => 7110,
                         "alcalde"                 => 16340,
                         "alcan"                   => 29540,
                         "alchemical"              => 21748,
                         "alchemist"               => 13740,
                         "alchemists"              => 28198,
                         "alcibiades"              => 23316,
                         "alcoa"                   => 18202,
                         "alcoholism"              => 8367,
                         "alcohols"                => 14794,
                         "aldeburgh"               => 22605,
                         "aldehyde"                => 16809,
                         "aldehydes"               => 21854,
                         "alderley"                => 27901,
                         "aldermen"                => 11922,
                         "alderney"                => 20502,
                         "aldershot"               => 10216,
                         "aldgate"                 => 28841,
                         "aldwych"                 => 26316,
                         "alegre"                  => 11882,
                         "alekhine"                => 22281,
                         "aleksandar"              => 12260,
                         "aleksandrovich"          => 17185,
                         "aleksandrow"             => 28099,
                         "alemannic"               => 28958,
                         "alentejo"                => 26173,
                         "aleph"                   => 23981,
                         "aleppo"                  => 8134,
                         "alerts"                  => 11778,
                         "alesi"                   => 20349,
                         "alessandria"             => 18868,
                         "alesund"                 => 21296,
                         "aleut"                   => 24869,
                         "aleutian"                => 13906,
                         "aleutians"               => 28419,
                         "alexandrian"             => 17451,
                         "alexandrine"             => 27554,
                         "alexandrov"              => 25655,
                         "alexandrovich"           => 20580,
                         "alexios"                 => 13771,
                         "alexius"                 => 25775,
                         "alfreton"                => 23712,
                         "algae"                   => 6537,
                         "algal"                   => 17212,
                         "algarve"                 => 15043,
                         "algebra"                 => 3987,
                         "algebraic"               => 6005,
                         "algebraically"           => 23853,
                         "algebras"                => 10055,
                         "algeciras"               => 20434,
                         "algeria"                 => 4179,
                         "algerian"                => 6044,
                         "algiers"                 => 8046,
                         "algol"                   => 16805,
                         "algoma"                  => 19801,
                         "algonquian"              => 15032,
                         "algonquin"               => 13270,
                         "algorithm"               => 3290,
                         "algorithmic"             => 16888,
                         "algorithms"              => 4896,
                         "alhaji"                  => 24638,
                         "aliabad"                 => 13763,
                         "aliasing"                => 23541,
                         "alienation"              => 11134,
                         "aligarh"                 => 15321,
                         "alighieri"               => 26087,
                         "align"                   => 5643,
                         "aligned"                 => 4924,
                         "aligning"                => 16152,
                         "alignment"               => 4168,
                         "alignments"              => 15267,
                         "aligns"                  => 24197,
                         "aliphatic"               => 28974,
                         "alister"                 => 27591,
                         "alitalia"                => 29111,
                         "alito"                   => 23249,
                         "aliyev"                  => 17599,
                         "alkali"                  => 11549,
                         "alkaloid"                => 19410,
                         "alkaloids"               => 15632,
                         "alkene"                  => 23166,
                         "alkenes"                 => 23164,
                         "alkmaar"                 => 20592,
                         "alkyl"                   => 15439,
                         "alkylation"              => 29939,
                         "allahabad"               => 9976,
                         "allama"                  => 24192,
                         "allegany"                => 18060,
                         "allegation"              => 10627,
                         "allegations"             => 3415,
                         "allege"                  => 16301,
                         "alleged"                 => 2197,
                         "allegedly"               => 3212,
                         "alleges"                 => 13576,
                         "allegheny"               => 6774,
                         "allegiance"              => 5641,
                         "alleging"                => 7932,
                         "allegorical"             => 11283,
                         "allegories"              => 24954,
                         "allegory"                => 11420,
                         "allele"                  => 11669,
                         "alleles"                 => 13274,
                         "allendale"               => 25323,
                         "allentown"               => 11278,
                         "allerton"                => 21041,
                         "alleviate"               => 8760,
                         "alleviated"              => 22038,
                         "alleviating"             => 22942,
                         "alleviation"             => 22160,
                         "alleyn"                  => 26824,
                         "allgau"                  => 29271,
                         "allgemeine"              => 17699,
                         "alliance"                => 1336,
                         "alliances"               => 7309,
                         "allied"                  => 1811,
                         "allier"                  => 22480,
                         "allies"                  => 2256,
                         "allium"                  => 16110,
                         "allmusic"                => 3876,
                         "alloa"                   => 18758,
                         "allocate"                => 12703,
                         "allocated"               => 3944,
                         "allocates"               => 25854,
                         "allocating"              => 17215,
                         "allocation"              => 5740,
                         "allocations"             => 15566,
                         "allophones"              => 28466,
                         "allosteric"              => 24474,
                         "allotment"               => 12777,
                         "allotments"              => 15479,
                         "allotted"                => 8565,
                         "allow"                   => 902,
                         "allowable"               => 16430,
                         "allowed"                 => 633,
                         "allowing"                => 1293,
                         "allows"                  => 1173,
                         "alloy"                   => 6249,
                         "alloys"                  => 9124,
                         "allround"                => 20846,
                         "allsvenskan"             => 12051,
                         "allude"                  => 19607,
                         "alluded"                 => 12130,
                         "alludes"                 => 11714,
                         "alluding"                => 14564,
                         "allusion"                => 11096,
                         "allusions"               => 11337,
                         "alluvial"                => 10503,
                         "alluvium"                => 23969,
                         "allying"                 => 24383,
                         "almagro"                 => 19050,
                         "almanac"                 => 11633,
                         "almanack"                => 23684,
                         "almaty"                  => 15040,
                         "almeria"                 => 14148,
                         "almirante"               => 22284,
                         "almohad"                 => 29929,
                         "almshouse"               => 29075,
                         "almshouses"              => 19617,
                         "alnus"                   => 28882,
                         "alnwick"                 => 22109,
                         "aloft"                   => 15518,
                         "alois"                   => 14978,
                         "along"                   => 179,
                         "alongside"               => 1119,
                         "alouettes"               => 12407,
                         "alpes"                   => 10559,
                         "alphabetic"              => 18247,
                         "alphabetical"            => 8544,
                         "alphabetically"          => 11181,
                         "alphabets"               => 14627,
                         "alphanumeric"            => 21744,
                         "alpini"                  => 27348,
                         "alps"                    => 4761,
                         "alsace"                  => 8022,
                         "alsatian"                => 21574,
                         "also"                    => 22,
                         "alstom"                  => 16933,
                         "altai"                   => 14014,
                         "altamont"                => 24313,
                         "altan"                   => 26682,
                         "altarpiece"              => 10472,
                         "altarpieces"             => 20648,
                         "altars"                  => 11242,
                         "altay"                   => 29693,
                         "alter"                   => 4498,
                         "alteration"              => 8761,
                         "alterations"             => 6239,
                         "altered"                 => 3316,
                         "alternate"               => 2568,
                         "alternated"              => 11344,
                         "alternately"             => 8418,
                         "alternates"              => 13062,
                         "alternating"             => 5609,
                         "alternation"             => 17160,
                         "alternative"             => 1206,
                         "alternatively"           => 4706,
                         "alternatives"            => 5588,
                         "although"                => 184,
                         "altimeter"               => 27139,
                         "altitude"                => 2754,
                         "altitudes"               => 7433,
                         "alto"                    => 5192,
                         "altona"                  => 15563,
                         "altoona"                 => 16038,
                         "altos"                   => 16649,
                         "altrincham"              => 15508,
                         "altstadt"                => 29014,
                         "altus"                   => 28340,
                         "alumina"                 => 19977,
                         "aluminium"               => 5108,
                         "aluminum"                => 4920,
                         "alumna"                  => 20106,
                         "alumnae"                 => 19975,
                         "alumni"                  => 2793,
                         "alumnus"                 => 6887,
                         "alveolar"                => 12555,
                         "alwar"                   => 28412,
                         "alzheimer"               => 7791,
                         "am/fm"                   => 29022,
                         "amadou"                  => 24430,
                         "amalfi"                  => 23464,
                         "amalgamate"              => 24457,
                         "amalgamated"             => 6138,
                         "amalgamation"            => 7252,
                         "amalgamations"           => 27805,
                         "amalie"                  => 18120,
                         "amalric"                 => 28239,
                         "amami"                   => 24245,
                         "amanita"                 => 20813,
                         "amarna"                  => 17323,
                         "amass"                   => 20924,
                         "amassed"                 => 7551,
                         "amassing"                => 14262,
                         "amasya"                  => 21492,
                         "amata"                   => 24746,
                         "amateurliga"             => 25474,
                         "amaury"                  => 29598,
                         "amazon.com"              => 10786,
                         "amazonia"                => 27465,
                         "amazonian"               => 17213,
                         "amazons"                 => 15294,
                         "ambala"                  => 25290,
                         "ambassador"              => 2068,
                         "ambassadors"             => 6755,
                         "ambedkar"                => 16764,
                         "amberley"                => 28084,
                         "ambient"                 => 6377,
                         "ambiguities"             => 22529,
                         "ambiguity"               => 8996,
                         "ambiguous"               => 7040,
                         "ambika"                  => 27306,
                         "ambit"                   => 29799,
                         "ambitions"               => 7184,
                         "ambivalent"              => 15836,
                         "ambon"                   => 21070,
                         "amboy"                   => 17107,
                         "ambroise"                => 25591,
                         "ambulatory"              => 17166,
                         "ambushes"                => 17463,
                         "amedeo"                  => 21166,
                         "ameer"                   => 25298,
                         "ameliorate"              => 27670,
                         "amend"                   => 9269,
                         "amended"                 => 4936,
                         "amending"                => 14860,
                         "amendment"               => 2456,
                         "amendments"              => 5639,
                         "amenhotep"               => 20098,
                         "amenities"               => 5819,
                         "amenity"                 => 20681,
                         "american"                => 76,
                         "americana"               => 9292,
                         "americanism"             => 27151,
                         "americans"               => 1360,
                         "americanus"              => 28092,
                         "americas"                => 3802,
                         "americo"                 => 28621,
                         "amerindian"              => 16296,
                         "amerindians"             => 24782,
                         "amersfoort"              => 26237,
                         "amery"                   => 27664,
                         "amesbury"                => 26650,
                         "amhara"                  => 18878,
                         "amharic"                 => 18066,
                         "amherst"                 => 6934,
                         "amicably"                => 19545,
                         "amicus"                  => 16480,
                         "amide"                   => 19989,
                         "amidships"               => 15847,
                         "amidst"                  => 7134,
                         "amiens"                  => 10757,
                         "amigaos"                 => 25471,
                         "amine"                   => 13280,
                         "amines"                  => 18012,
                         "amino"                   => 4851,
                         "amirabad"                => 22505,
                         "amitabh"                 => 16226,
                         "amity"                   => 15970,
                         "amjad"                   => 23698,
                         "amlaib"                  => 28481,
                         "amman"                   => 9048,
                         "ammar"                   => 27980,
                         "ammonia"                 => 8597,
                         "ammonian"                => 25996,
                         "ammonite"                => 23860,
                         "ammonites"               => 25840,
                         "ammonium"                => 11152,
                         "ammunition"              => 3389,
                         "amnesty"                 => 5661,
                         "among"                   => 227,
                         "amongst"                 => 1905,
                         "amorphous"               => 13587,
                         "amory"                   => 21187,
                         "amount"                  => 1010,
                         "amounted"                => 6753,
                         "amounting"               => 10481,
                         "amounts"                 => 2838,
                         "amphetamine"             => 17067,
                         "amphibian"               => 12994,
                         "amphibians"              => 9145,
                         "amphibious"              => 5525,
                         "amphitheater"            => 11275,
                         "amphitheatre"            => 10989,
                         "amphoe"                  => 14876,
                         "amplification"           => 10862,
                         "amplified"               => 10930,
                         "amplifier"               => 7687,
                         "amplifiers"              => 8930,
                         "amplify"                 => 16929,
                         "amplifying"              => 26110,
                         "amplitude"               => 7892,
                         "amplitudes"              => 20869,
                         "amputated"               => 15548,
                         "amputee"                 => 26284,
                         "amravati"                => 27926,
                         "amrit"                   => 27549,
                         "amritsar"                => 13285,
                         "amstrad"                 => 18328,
                         "amtrak"                  => 6327,
                         "amuro"                   => 21790,
                         "amusements"              => 22866,
                         "amygdala"                => 18095,
                         "amyloid"                 => 18155,
                         "amyotrophic"             => 28862,
                         "an"                      => 16,
                         "an/fps"                  => 17424,
                         "anabaptist"              => 25742,
                         "anabaptists"             => 29194,
                         "anachronistic"           => 20253,
                         "anacostia"               => 17475,
                         "anadolu"                 => 28519,
                         "anaerobic"               => 12363,
                         "anaesthesia"             => 21091,
                         "anaheim"                 => 7005,
                         "analgesia"               => 29810,
                         "analgesic"               => 16928,
                         "analog"                  => 3881,
                         "analogies"               => 19995,
                         "analogous"               => 6527,
                         "analogously"             => 29357,
                         "analogs"                 => 19339,
                         "analogue"                => 7116,
                         "analogues"               => 15930,
                         "analyse"                 => 14137,
                         "analysed"                => 10982,
                         "analyses"                => 5938,
                         "analysing"               => 15751,
                         "analysis"                => 1040,
                         "analyst"                 => 5001,
                         "analysts"                => 6434,
                         "analyte"                 => 25027,
                         "analytic"                => 7950,
                         "analytical"              => 6635,
                         "analytically"            => 26098,
                         "analytics"               => 9274,
                         "analyzed"                => 6175,
                         "analyzer"                => 16994,
                         "analyzers"               => 28114,
                         "analyzes"                => 13024,
                         "anambra"                 => 26545,
                         "anamorphic"              => 20910,
                         "anand"                   => 7549,
                         "anant"                   => 26130,
                         "anarchic"                => 25477,
                         "anarchism"               => 10052,
                         "anarchist"               => 6015,
                         "anarchists"              => 9848,
                         "anarcho"                 => 13030,
                         "anare"                   => 28319,
                         "anastasius"              => 23703,
                         "anatolia"                => 7695,
                         "anatolian"               => 12694,
                         "anatoly"                 => 12741,
                         "anatomic"                => 26679,
                         "anatomical"              => 9179,
                         "anatomist"               => 18969,
                         "anatomy"                 => 4909,
                         "anbar"                   => 17584,
                         "ancaster"                => 27144,
                         "ancestor"                => 4737,
                         "ancestors"               => 4121,
                         "ancestral"               => 5414,
                         "ancestries"              => 29097,
                         "ancestry"                => 3825,
                         "anchor"                  => 3232,
                         "anchorage"               => 7386,
                         "anchored"                => 5491,
                         "anchoring"               => 12925,
                         "anchors"                 => 8399,
                         "ancien"                  => 19006,
                         "ancient"                 => 798,
                         "ancients"                => 14566,
                         "ancillary"               => 12293,
                         "and"                     => 3,
                         "and/or"                  => 2265,
                         "andalucia"               => 20812,
                         "andalus"                 => 16835,
                         "andalusia"               => 10081,
                         "andalusian"              => 14166,
                         "andaman"                 => 12660,
                         "andante"                 => 25284,
                         "andean"                  => 10347,
                         "anderlecht"              => 14499,
                         "andersson"               => 10509,
                         "andesite"                => 23136,
                         "andhra"                  => 4816,
                         "andorra"                 => 10422,
                         "andorran"                => 29729,
                         "andreu"                  => 26936,
                         "androgen"                => 18358,
                         "androgynous"             => 21718,
                         "android"                 => 4848,
                         "androids"                => 22144,
                         "andromedae"              => 26420,
                         "andronicus"              => 26514,
                         "andronikos"              => 17256,
                         "anecdotal"               => 14621,
                         "anecdotes"               => 11120,
                         "anemones"                => 25363,
                         "angara"                  => 26887,
                         "angeles"                 => 687,
                         "angelicum"               => 29731,
                         "angelis"                 => 23838,
                         "angelou"                 => 15781,
                         "angered"                 => 7179,
                         "angering"                => 22413,
                         "angevin"                 => 20587,
                         "angiogenesis"            => 20406,
                         "angiography"             => 28103,
                         "angiosperms"             => 27383,
                         "angiotensin"             => 23548,
                         "angkor"                  => 16893,
                         "anglais"                 => 27015,
                         "angled"                  => 10545,
                         "anglers"                 => 14175,
                         "angles"                  => 5023,
                         "anglesey"                => 11825,
                         "anglia"                  => 8056,
                         "anglian"                 => 13647,
                         "anglican"                => 3236,
                         "anglicanism"             => 19414,
                         "anglicans"               => 14941,
                         "anglicised"              => 15503,
                         "anglicized"              => 15560,
                         "anglo"                   => 2524,
                         "anglophone"              => 15205,
                         "angola"                  => 4850,
                         "angolan"                 => 11039,
                         "angouleme"               => 18512,
                         "angra"                   => 19082,
                         "angrily"                 => 9332,
                         "angular"                 => 6202,
                         "anhalt"                  => 8376,
                         "anheuser"                => 19593,
                         "anhui"                   => 11973,
                         "anhydride"               => 23873,
                         "anhydrous"               => 21682,
                         "aniline"                 => 26865,
                         "animals"                 => 1225,
                         "animated"                => 2288,
                         "animating"               => 25041,
                         "animation"               => 2635,
                         "animations"              => 10533,
                         "animator"                => 9197,
                         "animators"               => 12686,
                         "animatronic"             => 25304,
                         "animax"                  => 26385,
                         "animism"                 => 28296,
                         "anion"                   => 13528,
                         "anionic"                 => 28730,
                         "anions"                  => 18862,
                         "anisotropic"             => 24088,
                         "anisotropy"              => 23208,
                         "anjou"                   => 10764,
                         "annales"                 => 16802,
                         "annals"                  => 6768,
                         "annam"                   => 27478,
                         "annan"                   => 11606,
                         "annandale"               => 17342,
                         "annapolis"               => 8077,
                         "annapurna"               => 23201,
                         "annealing"               => 22772,
                         "annecy"                  => 22190,
                         "annenberg"               => 19678,
                         "annesley"                => 23272,
                         "annex"                   => 6528,
                         "annexation"              => 6375,
                         "annexe"                  => 23907,
                         "annexed"                 => 4544,
                         "annexes"                 => 25852,
                         "annexing"                => 19961,
                         "annibale"                => 28431,
                         "annihilated"             => 14177,
                         "annihilation"            => 11731,
                         "anniston"                => 27284,
                         "anniversary"             => 1712,
                         "annotated"               => 11901,
                         "annotation"              => 17454,
                         "annotations"             => 14816,
                         "announced"               => 356,
                         "announcements"           => 8749,
                         "announcer"               => 5586,
                         "announcers"              => 12369,
                         "announces"               => 7437,
                         "announcing"              => 5386,
                         "annual"                  => 636,
                         "annually"                => 2008,
                         "annuals"                 => 18508,
                         "annuities"               => 21877,
                         "annuity"                 => 13644,
                         "annular"                 => 16196,
                         "annulus"                 => 25125,
                         "annum"                   => 9305,
                         "annunciation"            => 13010,
                         "anode"                   => 13055,
                         "anointing"               => 22206,
                         "anomalies"               => 11535,
                         "anomalous"               => 14837,
                         "anorthosis"              => 22429,
                         "another"                 => 176,
                         "anoxic"                  => 29479,
                         "anquetil"                => 29796,
                         "ansaldo"                 => 29804,
                         "ansar"                   => 14984,
                         "ansbach"                 => 19797,
                         "anschluss"               => 19197,
                         "ansett"                  => 23005,
                         "ansgar"                  => 26188,
                         "anstruther"              => 26740,
                         "answerable"              => 24986,
                         "antagonism"              => 16239,
                         "antagonist"              => 6626,
                         "antagonists"             => 10239,
                         "antalya"                 => 13598,
                         "antananarivo"            => 21243,
                         "antarctic"               => 3657,
                         "antarctica"              => 4783,
                         "antebellum"              => 13818,
                         "antecedent"              => 16545,
                         "antecedents"             => 16524,
                         "antena"                  => 26848,
                         "antenna"                 => 4768,
                         "antennae"                => 10302,
                         "antennas"                => 8741,
                         "anterior"                => 5483,
                         "anteriorly"              => 17090,
                         "anthem"                  => 4359,
                         "anthemic"                => 25612,
                         "anthems"                 => 12690,
                         "anthers"                 => 20322,
                         "anthologies"             => 8002,
                         "anthologized"            => 23711,
                         "anthology"               => 3899,
                         "anthracite"              => 17970,
                         "anthropogenic"           => 17130,
                         "anthropological"         => 9766,
                         "anthropologist"          => 7845,
                         "anthropologists"         => 11491,
                         "anthropology"            => 4796,
                         "anthropomorphic"         => 11868,
                         "anti"                    => 702,
                         "antiaircraft"            => 15702,
                         "antibacterial"           => 20647,
                         "antibody"                => 9201,
                         "antic"                   => 23303,
                         "anticancer"              => 28562,
                         "anticipated"             => 4779,
                         "anticipates"             => 21654,
                         "anticline"               => 27531,
                         "antidepressant"          => 18038,
                         "antifungal"              => 25615,
                         "antigen"                 => 9353,
                         "antigens"                => 13445,
                         "antigonish"              => 28657,
                         "antigonus"               => 20455,
                         "antillean"               => 28249,
                         "antilles"                => 8917,
                         "antimatter"              => 20508,
                         "antimicrobial"           => 15176,
                         "antimony"                => 17481,
                         "antioch"                 => 6810,
                         "antiochus"               => 13726,
                         "antioquia"               => 17038,
                         "antioxidant"             => 18011,
                         "antioxidants"            => 24348,
                         "antipater"               => 29041,
                         "antipathy"               => 21498,
                         "antipope"                => 23161,
                         "antipsychotic"           => 24184,
                         "antipsychotics"          => 26799,
                         "antiqua"                 => 29010,
                         "antiquarian"             => 10397,
                         "antiquaries"             => 16666,
                         "antiquary"               => 17477,
                         "antiquities"             => 7808,
                         "antiquity"               => 5621,
                         "antiretroviral"          => 26134,
                         "antisemitic"             => 11465,
                         "antisemitism"            => 9945,
                         "antisense"               => 29427,
                         "antisubmarine"           => 13135,
                         "antitank"                => 24191,
                         "antithesis"              => 19343,
                         "antitrust"               => 10985,
                         "antiviral"               => 19575,
                         "antiwar"                 => 24252,
                         "antofagasta"             => 23477,
                         "antonescu"               => 18023,
                         "antonin"                 => 12455,
                         "antonine"                => 26658,
                         "antoninus"               => 22483,
                         "antonis"                 => 25602,
                         "antrim"                  => 8008,
                         "antti"                   => 23046,
                         "antwerp"                 => 5291,
                         "anuradhapura"            => 18397,
                         "anurag"                  => 28935,
                         "anxiolytic"              => 29670,
                         "anyang"                  => 21818,
                         "anzac"                   => 9501,
                         "anzio"                   => 21786,
                         "aomori"                  => 16470,
                         "aortic"                  => 13618,
                         "aosta"                   => 17326,
                         "aoyama"                  => 21905,
                         "apaches"                 => 16807,
                         "apalachicola"            => 26875,
                         "apartheid"               => 6162,
                         "apartments"              => 3466,
                         "apeldoorn"               => 29749,
                         "apennines"               => 23789,
                         "apertura"                => 11004,
                         "aperture"                => 6945,
                         "apertures"               => 23447,
                         "apex"                    => 5351,
                         "aphasia"                 => 20203,
                         "aphid"                   => 23986,
                         "aphids"                  => 19270,
                         "aphorisms"               => 24849,
                         "aphrodite"               => 13346,
                         "apical"                  => 9934,
                         "apnea"                   => 20873,
                         "apocalyptic"             => 9775,
                         "apocrypha"               => 22590,
                         "apocryphal"              => 14674,
                         "apocynaceae"             => 26556,
                         "apoel"                   => 16006,
                         "apolitical"              => 21020,
                         "apollinaire"             => 26170,
                         "apollonia"               => 26802,
                         "apollonius"              => 21459,
                         "apologetics"             => 22816,
                         "apologised"              => 13655,
                         "apologises"              => 24315,
                         "apologist"               => 26583,
                         "apologists"              => 29841,
                         "apoplexy"                => 27820,
                         "apoptosis"               => 10847,
                         "apoptotic"               => 23193,
                         "apostasy"                => 16804,
                         "apostate"                => 22448,
                         "apostle"                 => 7343,
                         "apostles"                => 6801,
                         "apostolate"              => 24331,
                         "apostolic"               => 4712,
                         "apothecaries"            => 28683,
                         "apotheosis"              => 29891,
                         "appalachia"              => 17927,
                         "appalachian"             => 6742,
                         "appalachians"            => 22145,
                         "apparatus"               => 5551,
                         "apparel"                 => 8850,
                         "apparent"                => 2387,
                         "apparitions"             => 18447,
                         "appeal"                  => 1775,
                         "appealed"                => 4415,
                         "appeals"                 => 3102,
                         "appear"                  => 938,
                         "appearance"              => 688,
                         "appearances"             => 900,
                         "appeared"                => 355,
                         "appearing"               => 1981,
                         "appears"                 => 821,
                         "appeasement"             => 21372,
                         "appellant"               => 18018,
                         "appellate"               => 7638,
                         "appellation"             => 11393,
                         "appendages"              => 14891,
                         "appended"                => 13846,
                         "appendices"              => 24091,
                         "appenzell"               => 26324,
                         "appian"                  => 28372,
                         "applauded"               => 12132,
                         "appliances"              => 8265,
                         "applicability"           => 15905,
                         "applicable"              => 5547,
                         "applicant"               => 8305,
                         "applicants"              => 6052,
                         "application"             => 1258,
                         "applications"            => 1322,
                         "applied"                 => 1078,
                         "applies"                 => 4268,
                         "apply"                   => 2264,
                         "applying"                => 4240,
                         "appoint"                 => 6029,
                         "appointed"               => 409,
                         "appointee"               => 17253,
                         "appointees"              => 15967,
                         "appointing"              => 9022,
                         "appoints"                => 11005,
                         "appomattox"              => 15527,
                         "apportioned"             => 17793,
                         "apportionment"           => 17961,
                         "appraisal"               => 11077,
                         "appraisals"              => 28504,
                         "appreciable"             => 21013,
                         "apprentice"              => 5229,
                         "apprenticed"             => 9517,
                         "apprentices"             => 12526,
                         "apprenticeship"          => 7000,
                         "apprenticeships"         => 22286,
                         "approach"                => 1072,
                         "approachable"            => 25525,
                         "approached"              => 2756,
                         "approaches"              => 2819,
                         "approbation"             => 27910,
                         "appropriated"            => 9421,
                         "appropriately"           => 8530,
                         "appropriateness"         => 23989,
                         "appropriating"           => 27661,
                         "appropriation"           => 9591,
                         "appropriations"          => 7735,
                         "approval"                => 2316,
                         "approvals"               => 18407,
                         "approved"                => 1432,
                         "approving"               => 12374,
                         "approx"                  => 7926,
                         "approximant"             => 29524,
                         "approximate"             => 5632,
                         "approximated"            => 13448,
                         "approximately"           => 514,
                         "approximates"            => 22176,
                         "approximating"           => 22552,
                         "approximation"           => 6759,
                         "approximations"          => 15641,
                         "apses"                   => 29321,
                         "apuestas"                => 24014,
                         "apulia"                  => 13545,
                         "aqaba"                   => 23951,
                         "aquabats"                => 29761,
                         "aquaculture"             => 11249,
                         "aquaria"                 => 21618,
                         "aquarii"                 => 28391,
                         "aquarium"                => 6171,
                         "aquariums"               => 16980,
                         "aquatic"                 => 4626,
                         "aquatics"                => 7095,
                         "aqueduct"                => 7834,
                         "aqueducts"               => 18752,
                         "aqueous"                 => 10220,
                         "aquifer"                 => 12963,
                         "aquifers"                => 19047,
                         "aquileia"                => 20376,
                         "aquinas"                 => 9661,
                         "aquitaine"               => 9672,
                         "arab"                    => 1637,
                         "arabesque"               => 26760,
                         "arabi"                   => 17787,
                         "arabia"                  => 3404,
                         "arabian"                 => 5095,
                         "arabic"                  => 2260,
                         "arabica"                 => 29894,
                         "arabidopsis"             => 26432,
                         "arable"                  => 9991,
                         "arabs"                   => 5016,
                         "arafat"                  => 13729,
                         "aragonese"               => 14082,
                         "arakan"                  => 18866,
                         "aramaic"                 => 9087,
                         "araneta"                 => 23896,
                         "arapaho"                 => 19578,
                         "arapahoe"                => 29694,
                         "aravind"                 => 29969,
                         "arbitrage"               => 20690,
                         "arbitrarily"             => 11710,
                         "arbitrary"               => 5464,
                         "arbitration"             => 6402,
                         "arbitrators"             => 27897,
                         "arbitron"                => 24013,
                         "arbor"                   => 7205,
                         "arborea"                 => 23111,
                         "arboreal"                => 12915,
                         "arboretum"               => 8131,
                         "arbroath"                => 16378,
                         "arbuthnot"               => 19304,
                         "arcade"                  => 3905,
                         "arcades"                 => 11125,
                         "arch"                    => 3125,
                         "archaea"                 => 18965,
                         "archaeological"          => 2527,
                         "archaeologically"        => 29113,
                         "archaeologist"           => 6970,
                         "archaeologists"          => 6594,
                         "archaeology"             => 4260,
                         "archaic"                 => 6981,
                         "archangels"              => 29654,
                         "archbishop"              => 2274,
                         "archbishopric"           => 12144,
                         "archbishops"             => 12282,
                         "archdeacon"              => 7985,
                         "archdeaconry"            => 15838,
                         "archdiocesan"            => 25237,
                         "archdiocese"             => 4488,
                         "archduchess"             => 19034,
                         "archduke"                => 9678,
                         "arched"                  => 7008,
                         "archelaus"               => 29207,
                         "archeological"           => 7174,
                         "archeologist"            => 20287,
                         "archeologists"           => 18928,
                         "archeology"              => 14205,
                         "archeparchy"             => 29857,
                         "archers"                 => 9383,
                         "arches"                  => 5392,
                         "archetypal"              => 15273,
                         "archetype"               => 14527,
                         "archetypes"              => 18600,
                         "archiepiscopal"          => 26389,
                         "archimandrite"           => 26521,
                         "archimedean"             => 27741,
                         "archimedes"              => 15270,
                         "arching"                 => 28312,
                         "archipelago"             => 4843,
                         "architect"               => 1480,
                         "architects"              => 2845,
                         "architectural"           => 2111,
                         "architecturally"         => 12089,
                         "architecture"            => 1047,
                         "architectures"           => 10833,
                         "archiv"                  => 17579,
                         "archival"                => 8150,
                         "archive"                 => 3580,
                         "archived"                => 11497,
                         "archives"                => 3003,
                         "archiving"               => 17450,
                         "archivist"               => 13799,
                         "archivists"              => 28209,
                         "archpriest"              => 29368,
                         "arcot"                   => 22585,
                         "arcseconds"              => 27190,
                         "arctic"                  => 3649,
                         "arctiidae"               => 6922,
                         "arcuate"                 => 29608,
                         "ardabil"                 => 11572,
                         "ardahan"                 => 29124,
                         "ardashir"                => 26712,
                         "ardeche"                 => 23121,
                         "ardeidae"                => 26602,
                         "ardennes"                => 11939,
                         "ardent"                  => 9042,
                         "ardrossan"               => 25234,
                         "arduous"                 => 14250,
                         "are"                     => 18,
                         "area"                    => 98,
                         "areal"                   => 27471,
                         "areas"                   => 357,
                         "arecibo"                 => 21331,
                         "arena"                   => 1650,
                         "arenabowl"               => 24505,
                         "arendal"                 => 25113,
                         "arequipa"                => 20186,
                         "arete"                   => 29985,
                         "areva"                   => 26086,
                         "arezzo"                  => 19235,
                         "argentina"               => 1787,
                         "argentine"               => 2820,
                         "argentinean"             => 27181,
                         "argentines"              => 21373,
                         "argentinian"             => 10809,
                         "argentino"               => 16121,
                         "argentinos"              => 22537,
                         "arges"                   => 24987,
                         "arginine"                => 19188,
                         "argonauts"               => 9989,
                         "argonne"                 => 15605,
                         "argos"                   => 12509,
                         "argosy"                  => 26974,
                         "arguably"                => 5237,
                         "argued"                  => 1689,
                         "argues"                  => 3186,
                         "argumentation"           => 21986,
                         "arguments"               => 3646,
                         "argus"                   => 10500,
                         "argyll"                  => 9275,
                         "aria"                    => 5026,
                         "arianism"                => 27796,
                         "ariege"                  => 25046,
                         "arima"                   => 26195,
                         "arion"                   => 21456,
                         "arise"                   => 4979,
                         "arisen"                  => 10008,
                         "arises"                  => 6567,
                         "arising"                 => 6425,
                         "arista"                  => 12834,
                         "aristide"                => 16793,
                         "aristides"               => 27699,
                         "aristocracy"             => 7721,
                         "aristocrat"              => 11219,
                         "aristocratic"            => 6959,
                         "aristocrats"             => 11702,
                         "aristophanes"            => 20728,
                         "aristotelian"            => 15957,
                         "aristotle"               => 6368,
                         "arithmetic"              => 6919,
                         "arjun"                   => 10040,
                         "arjuna"                  => 12801,
                         "arkansas"                => 2025,
                         "arkhangelsk"             => 15706,
                         "arkwright"               => 21375,
                         "arles"                   => 13997,
                         "arlington"               => 4967,
                         "armadale"                => 25037,
                         "armagh"                  => 8225,
                         "armagnac"                => 27019,
                         "armament"                => 5360,
                         "armaments"               => 11831,
                         "armature"                => 22453,
                         "armband"                 => 24367,
                         "armbar"                  => 25005,
                         "armed"                   => 1264,
                         "armee"                   => 12729,
                         "armenia"                 => 3638,
                         "armenian"                => 2640,
                         "armenians"               => 6718,
                         "armia"                   => 24673,
                         "armidale"                => 20914,
                         "armies"                  => 3080,
                         "armin"                   => 14659,
                         "arminius"                => 29788,
                         "armistice"               => 6523,
                         "armor"                   => 3770,
                         "armored"                 => 4218,
                         "armorial"                => 21417,
                         "armory"                  => 8800,
                         "armoured"                => 3952,
                         "armoury"                 => 18448,
                         "army"                    => 214,
                         "arnaldo"                 => 24306,
                         "arnaz"                   => 25111,
                         "arnulf"                  => 18805,
                         "aromanian"               => 29522,
                         "aromas"                  => 27630,
                         "aromatic"                => 8656,
                         "aroostook"               => 25438,
                         "arose"                   => 3784,
                         "arousal"                 => 13518,
                         "arpad"                   => 20010,
                         "arpanet"                 => 28498,
                         "arran"                   => 14314,
                         "arranged"                => 1938,
                         "arrangement"             => 2511,
                         "arranger"                => 7758,
                         "arrangers"               => 27276,
                         "arranges"                => 9357,
                         "arras"                   => 12500,
                         "array"                   => 3356,
                         "arrayed"                 => 23996,
                         "arrays"                  => 8887,
                         "arrears"                 => 18444,
                         "arrests"                 => 6061,
                         "arrhythmias"             => 27880,
                         "arrival"                 => 1845,
                         "arrivals"                => 9565,
                         "arrived"                 => 920,
                         "arrives"                 => 3063,
                         "arriving"                => 2539,
                         "arrondissement"          => 6676,
                         "arrondissements"         => 20350,
                         "arrowheads"              => 24148,
                         "arsenals"                => 29779,
                         "arsene"                  => 20818,
                         "arsenio"                 => 23352,
                         "arshad"                  => 27635,
                         "art"                     => 253,
                         "artaxerxes"              => 24562,
                         "artefacts"               => 8805,
                         "artemisia"               => 16078,
                         "arterial"                => 8388,
                         "artes"                   => 11326,
                         "artesian"                => 24420,
                         "arthritis"               => 9710,
                         "arthropod"               => 23331,
                         "arthropods"              => 12530,
                         "arthurian"               => 15098,
                         "article"                 => 843,
                         "articled"                => 20053,
                         "articles"                => 1281,
                         "articular"               => 20409,
                         "articulated"             => 7456,
                         "articulates"             => 26294,
                         "articulating"            => 24334,
                         "articulation"            => 10025,
                         "artifacts"               => 3869,
                         "artificial"              => 2893,
                         "artificially"            => 10192,
                         "artigas"                 => 24844,
                         "artillery"               => 1600,
                         "artin"                   => 24178,
                         "artisan"                 => 12061,
                         "artisanal"               => 22420,
                         "artisans"                => 8767,
                         "artist"                  => 597,
                         "artiste"                 => 16415,
                         "artistes"                => 13509,
                         "artistic"                => 1883,
                         "artistically"            => 14351,
                         "artistry"                => 12198,
                         "artists"                 => 644,
                         "artois"                  => 15469,
                         "arts"                    => 448,
                         "artvin"                  => 29730,
                         "artwork"                 => 3171,
                         "artworks"                => 8053,
                         "aruna"                   => 22736,
                         "arunachal"               => 14283,
                         "arundel"                 => 9598,
                         "arundell"                => 22094,
                         "arusha"                  => 22730,
                         "arvid"                   => 23320,
                         "aryeh"                   => 24798,
                         "as"                      => 8,
                         "asahi"                   => 12117,
                         "asami"                   => 28135,
                         "asana"                   => 29995,
                         "asansol"                 => 24734,
                         "asante"                  => 19585,
                         "asaph"                   => 21428,
                         "ascap"                   => 13439,
                         "ascend"                  => 11292,
                         "ascendancy"              => 15650,
                         "ascendant"               => 25719,
                         "ascended"                => 7956,
                         "ascending"               => 8160,
                         "ascends"                 => 15868,
                         "ascenso"                 => 22984,
                         "ascent"                  => 6454,
                         "ascents"                 => 15581,
                         "ascertained"             => 17260,
                         "ascetic"                 => 13149,
                         "asceticism"              => 22013,
                         "ascetics"                => 26941,
                         "aschaffenburg"           => 24822,
                         "ascii"                   => 10813,
                         "ascoli"                  => 18261,
                         "ascomycota"              => 27603,
                         "ascot"                   => 9660,
                         "ascribe"                 => 23435,
                         "ascribed"                => 8794,
                         "ascribes"                => 26119,
                         "asean"                   => 9815,
                         "asesoria"                => 24493,
                         "asexual"                 => 16775,
                         "asghar"                  => 23941,
                         "ashbourne"               => 22558,
                         "ashburnham"              => 27883,
                         "ashburton"               => 18058,
                         "ashbury"                 => 26789,
                         "ashdod"                  => 21199,
                         "ashdown"                 => 19256,
                         "asheville"               => 11307,
                         "ashfield"                => 16651,
                         "ashgabat"                => 29064,
                         "ashikaga"                => 19336,
                         "ashina"                  => 21316,
                         "ashkelon"                => 22614,
                         "ashkenazi"               => 11540,
                         "ashland"                 => 9216,
                         "ashlar"                  => 14022,
                         "ashok"                   => 10390,
                         "ashoka"                  => 13565,
                         "ashore"                  => 6096,
                         "ashot"                   => 27755,
                         "ashraf"                  => 13173,
                         "ashram"                  => 10548,
                         "ashtabula"               => 24803,
                         "ashur"                   => 26456,
                         "asia"                    => 996,
                         "asia/oceania"            => 22826,
                         "asian"                   => 928,
                         "asiatic"                 => 8509,
                         "asistencia"              => 22455,
                         "asker"                   => 20485,
                         "asociacion"              => 15442,
                         "aspartate"               => 26256,
                         "aspect"                  => 2882,
                         "aspects"                 => 1837,
                         "asperger"                => 21826,
                         "aspergillus"             => 19313,
                         "asphalt"                 => 7045,
                         "aspinall"                => 23060,
                         "aspirated"               => 13532,
                         "aspiration"              => 12385,
                         "aspirations"             => 8045,
                         "aspired"                 => 15466,
                         "aspires"                 => 20159,
                         "aspiring"                => 7749,
                         "asquith"                 => 14142,
                         "assad"                   => 9475,
                         "assailants"              => 16428,
                         "assailed"                => 29408,
                         "assam"                   => 5711,
                         "assamese"                => 11800,
                         "assange"                 => 23663,
                         "assassinate"             => 8885,
                         "assassinated"            => 5866,
                         "assassinating"           => 23717,
                         "assassination"           => 3506,
                         "assassinations"          => 13060,
                         "assault"                 => 2251,
                         "assaults"                => 7965,
                         "assay"                   => 11684,
                         "assays"                  => 16704,
                         "assemblage"              => 12022,
                         "assemblages"             => 20022,
                         "assembled"               => 3448,
                         "assembles"               => 20134,
                         "assemblies"              => 6025,
                         "assembling"              => 10722,
                         "assembly"                => 643,
                         "assemblyman"             => 13625,
                         "assemblymen"             => 23578,
                         "assen"                   => 26071,
                         "assent"                  => 9946,
                         "assert"                  => 7388,
                         "asserted"                => 4925,
                         "asserting"               => 9118,
                         "assertion"               => 8181,
                         "assertions"              => 12301,
                         "asserts"                 => 6794,
                         "assess"                  => 5703,
                         "assessed"                => 5319,
                         "assesses"                => 18498,
                         "assessing"               => 8681,
                         "assessment"              => 2687,
                         "assessments"             => 7264,
                         "assessor"                => 14528,
                         "assessors"               => 25745,
                         "asset"                   => 4255,
                         "assets"                  => 2372,
                         "assigned"                => 1059,
                         "assigns"                 => 8537,
                         "assimilate"              => 16111,
                         "assimilated"             => 9595,
                         "assimilating"            => 29019,
                         "assimilation"            => 8830,
                         "assiniboine"             => 20499,
                         "assis"                   => 27518,
                         "assisi"                  => 13158,
                         "assist"                  => 2261,
                         "assistance"              => 1743,
                         "assistant"               => 877,
                         "assistants"              => 6628,
                         "assisted"                => 2402,
                         "assisting"               => 5171,
                         "assistive"               => 26189,
                         "assists"                 => 3053,
                         "assize"                  => 25958,
                         "assizes"                 => 23197,
                         "associacao"              => 17322,
                         "associate"               => 1819,
                         "associated"              => 655,
                         "associates"              => 3295,
                         "association"             => 286,
                         "associations"            => 2935,
                         "associative"             => 12696,
                         "associazione"            => 21870,
                         "assortment"              => 10733,
                         "assumed"                 => 1838,
                         "assumes"                 => 5936,
                         "assumption"              => 4321,
                         "assur"                   => 28542,
                         "assyria"                 => 12434,
                         "assyrian"                => 6854,
                         "assyrians"               => 11968,
                         "asteraceae"              => 16586,
                         "asterisk"                => 13122,
                         "asterism"                => 24170,
                         "astern"                  => 20828,
                         "asteroid"                => 5717,
                         "asteroids"               => 10257,
                         "astley"                  => 13693,
                         "astonishingly"           => 29296,
                         "astor"                   => 9252,
                         "astragalus"              => 21495,
                         "astrakhan"               => 18087,
                         "astride"                 => 20579,
                         "astrocytes"              => 28306,
                         "astrodome"               => 26779,
                         "astrolabe"               => 26437,
                         "astrologer"              => 16712,
                         "astrologers"             => 21842,
                         "astrological"            => 14821,
                         "astrology"               => 9436,
                         "astronautics"            => 21237,
                         "astronomer"              => 6381,
                         "astronomers"             => 8988,
                         "astronomical"            => 4956,
                         "astronomy"               => 4508,
                         "astrophysical"           => 19152,
                         "astrophysicist"          => 22973,
                         "astrophysics"            => 11591,
                         "asturian"                => 18838,
                         "asturias"                => 8742,
                         "asuka"                   => 18391,
                         "asura"                   => 18174,
                         "aswan"                   => 24149,
                         "asylum"                  => 4407,
                         "asylums"                 => 21888,
                         "asymmetric"              => 10061,
                         "asymmetrical"            => 12655,
                         "asymmetry"               => 15861,
                         "asymptomatic"            => 18216,
                         "asymptotic"              => 14953,
                         "asymptotically"          => 23267,
                         "asynchronous"            => 14136,
                         "at"                      => 13,
                         "atacama"                 => 20825,
                         "atalanta"                => 15910,
                         "atari"                   => 6648,
                         "ataturk"                 => 13345,
                         "ataxia"                  => 19543,
                         "atelier"                 => 13071,
                         "ateliers"                => 29327,
                         "ateneo"                  => 11193,
                         "athabasca"               => 17251,
                         "athabaskan"              => 24198,
                         "athanasius"              => 15653,
                         "atheism"                 => 12030,
                         "atheist"                 => 7878,
                         "atheistic"               => 26150,
                         "athenaeum"               => 14168,
                         "athenian"                => 8899,
                         "athenians"               => 13102,
                         "athenry"                 => 29450,
                         "athens"                  => 2548,
                         "atherosclerosis"         => 21902,
                         "athlete"                 => 2924,
                         "athletes"                => 2377,
                         "athletic"                => 1460,
                         "athleticism"             => 23649,
                         "athletics"               => 1482,
                         "athlone"                 => 16825,
                         "athol"                   => 19874,
                         "atholl"                  => 19486,
                         "atlante"                 => 26301,
                         "atlantean"               => 28943,
                         "atlantic"                => 1168,
                         "atlantica"               => 29614,
                         "atlantique"              => 20072,
                         "atlantiques"             => 22000,
                         "atlas"                   => 4614,
                         "atlases"                 => 25419,
                         "atletico"                => 5986,
                         "atman"                   => 20798,
                         "atmosphere"              => 2713,
                         "atmospheres"             => 16943,
                         "atmospheric"             => 4522,
                         "atoll"                   => 7130,
                         "atolls"                  => 18690,
                         "atom"                    => 5082,
                         "atoms"                   => 4672,
                         "atonement"               => 13113,
                         "atop"                    => 5060,
                         "atpase"                  => 19021,
                         "atria"                   => 25077,
                         "atrial"                  => 15963,
                         "atrium"                  => 10050,
                         "atrocities"              => 8302,
                         "atsushi"                 => 23020,
                         "attache"                 => 10332,
                         "attached"                => 1751,
                         "attaches"                => 12250,
                         "attaching"               => 11958,
                         "attachment"              => 5453,
                         "attack"                  => 533,
                         "attacked"                => 1399,
                         "attackers"               => 7586,
                         "attacking"               => 2963,
                         "attacks"                 => 1227,
                         "attain"                  => 6606,
                         "attainable"              => 22249,
                         "attainder"               => 23127,
                         "attained"                => 4402,
                         "attaining"               => 8492,
                         "attainment"              => 11972,
                         "attains"                 => 14561,
                         "attempt"                 => 842,
                         "attempted"               => 1389,
                         "attempting"              => 2690,
                         "attempts"                => 1318,
                         "attenborough"            => 15575,
                         "attend"                  => 1762,
                         "attendance"              => 2702,
                         "attendances"             => 12722,
                         "attended"                => 606,
                         "attendee"                => 27981,
                         "attendees"               => 7190,
                         "attending"               => 2367,
                         "attends"                 => 7928,
                         "attentional"             => 25455,
                         "attenuated"              => 19120,
                         "attenuation"             => 15382,
                         "attestation"             => 23332,
                         "attested"                => 6502,
                         "attesting"               => 25683,
                         "attests"                 => 22343,
                         "attire"                  => 9185,
                         "attitudes"               => 5034,
                         "attlee"                  => 20077,
                         "attock"                  => 26315,
                         "attract"                 => 3734,
                         "attracting"              => 5570,
                         "attraction"              => 3257,
                         "attractions"             => 3760,
                         "attractiveness"          => 16008,
                         "attracts"                => 6014,
                         "attributable"            => 12278,
                         "attribute"               => 6580,
                         "attributed"              => 2332,
                         "attributes"              => 4360,
                         "attributing"             => 15858,
                         "attribution"             => 8299,
                         "attributions"            => 22216,
                         "attrition"               => 12596,
                         "atypical"                => 11530,
                         "auchinleck"              => 29053,
                         "auckland"                => 3184,
                         "auctioned"               => 10419,
                         "auctions"                => 10888,
                         "audacious"               => 18364,
                         "audax"                   => 28228,
                         "auden"                   => 18410,
                         "audible"                 => 11772,
                         "audience"                => 1285,
                         "audiences"               => 3259,
                         "audiencia"               => 18611,
                         "audio"                   => 1906,
                         "audiobook"               => 16317,
                         "audiobooks"              => 21252,
                         "audiovisual"             => 14123,
                         "audit"                   => 5821,
                         "auditing"                => 12673,
                         "auditioned"              => 7489,
                         "auditor"                 => 7438,
                         "auditorium"              => 4367,
                         "auditoriums"             => 25301,
                         "auditors"                => 13841,
                         "auditory"                => 9114,
                         "audits"                  => 14218,
                         "audley"                  => 17661,
                         "audubon"                 => 11596,
                         "augment"                 => 11798,
                         "augmentation"            => 15694,
                         "augmented"               => 6828,
                         "augmenting"              => 22342,
                         "augsburg"                => 8206,
                         "august"                  => 161,
                         "augustan"                => 23667,
                         "augustana"               => 25918,
                         "augustinian"             => 10793,
                         "augustinians"            => 23829,
                         "augustow"                => 26177,
                         "aulus"                   => 25130,
                         "aural"                   => 18727,
                         "aurangabad"              => 16484,
                         "aurangzeb"               => 14059,
                         "aurel"                   => 26473,
                         "aurelian"                => 21571,
                         "aureus"                  => 17335,
                         "aurobindo"               => 20286,
                         "auschwitz"               => 8372,
                         "auspices"                => 6792,
                         "auspicious"              => 13255,
                         "austen"                  => 9316,
                         "austere"                 => 13546,
                         "austerity"               => 12013,
                         "austerlitz"              => 25970,
                         "austral"                 => 18347,
                         "australasia"             => 10440,
                         "australasian"            => 9909,
                         "australia"               => 328,
                         "australian"              => 403,
                         "australians"             => 5361,
                         "australis"               => 12852,
                         "austria"                 => 1555,
                         "austrian"                => 1960,
                         "austrians"               => 8926,
                         "austro"                  => 6012,
                         "austronesian"            => 14202,
                         "authentically"           => 29026,
                         "authenticated"           => 18545,
                         "authentication"          => 9366,
                         "authenticity"            => 7406,
                         "author"                  => 656,
                         "authored"                => 3070,
                         "authoring"               => 12856,
                         "authorisation"           => 15773,
                         "authorise"               => 26654,
                         "authorised"              => 6791,
                         "authorising"             => 22849,
                         "authoritarian"           => 8878,
                         "authoritarianism"        => 22510,
                         "authoritative"           => 8852,
                         "authorities"             => 1284,
                         "authority"               => 860,
                         "authorized"              => 3247,
                         "authorizing"             => 12400,
                         "authors"                 => 1891,
                         "authorship"              => 7870,
                         "autism"                  => 6889,
                         "autistic"                => 13085,
                         "auto"                    => 3029,
                         "autobiographical"        => 6414,
                         "autobiographies"         => 22960,
                         "autobiography"           => 3879,
                         "autobots"                => 10129,
                         "autocephalous"           => 27087,
                         "autochthonous"           => 27282,
                         "autocracy"               => 27609,
                         "autocratic"              => 16210,
                         "autodesk"                => 22005,
                         "autodromo"               => 22163,
                         "autofocus"               => 22621,
                         "autoimmune"              => 12646,
                         "automaker"               => 18518,
                         "automakers"              => 19602,
                         "automata"                => 15634,
                         "automate"                => 18706,
                         "automated"               => 4687,
                         "automatic"               => 2449,
                         "automatically"           => 3361,
                         "automation"              => 6826,
                         "automaton"               => 14261,
                         "automobile"              => 3330,
                         "automobiles"             => 6428,
                         "automorphism"            => 18287,
                         "automorphisms"           => 29602,
                         "automotive"              => 4554,
                         "autonoma"                => 17894,
                         "autonomic"               => 16875,
                         "autonomist"              => 26476,
                         "autonomous"              => 2780,
                         "autonomously"            => 20084,
                         "autonomy"                => 4461,
                         "autoroute"               => 14614,
                         "autos"                   => 25172,
                         "autosomal"               => 12115,
                         "autosport"               => 28962,
                         "autovia"                 => 26052,
                         "auvergne"                => 13886,
                         "auxerre"                 => 17573,
                         "auxiliaries"             => 14170,
                         "auxiliary"               => 3733,
                         "avail"                   => 9942,
                         "availability"            => 3724,
                         "available"               => 397,
                         "avalanches"              => 20228,
                         "avars"                   => 18978,
                         "avatars"                 => 15117,
                         "aveiro"                  => 25331,
                         "avellino"                => 20568,
                         "avengers"                => 5921,
                         "avenida"                 => 12870,
                         "avenue"                  => 976,
                         "avenues"                 => 7391,
                         "average"                 => 351,
                         "averaged"                => 4110,
                         "averages"                => 6811,
                         "averaging"               => 5208,
                         "avesta"                  => 27418,
                         "avestan"                 => 23077,
                         "aveyron"                 => 24398,
                         "avian"                   => 11133,
                         "aviation"                => 1824,
                         "aviators"                => 12517,
                         "avicenna"                => 20919,
                         "avicii"                  => 28428,
                         "avignon"                 => 11174,
                         "avionics"                => 12810,
                         "aviv"                    => 4912,
                         "avoca"                   => 22081,
                         "avocets"                 => 27463,
                         "avoidance"               => 8961,
                         "avoided"                 => 4344,
                         "avoids"                  => 9119,
                         "avonmouth"               => 27879,
                         "avowed"                  => 22274,
                         "avraham"                 => 15915,
                         "avram"                   => 28148,
                         "awadh"                   => 24248,
                         "awaited"                 => 9227,
                         "awakening"               => 7414,
                         "awakens"                 => 11893,
                         "awami"                   => 16056,
                         "award"                   => 255,
                         "awarded"                 => 517,
                         "awardee"                 => 25828,
                         "awardees"                => 23212,
                         "awarding"                => 7285,
                         "awards"                  => 396,
                         "awareness"               => 2630,
                         "awash"                   => 26215,
                         "awlaki"                  => 27800,
                         "axial"                   => 9192,
                         "axillary"                => 20977,
                         "axils"                   => 23190,
                         "axiom"                   => 10042,
                         "axiomatic"               => 22384,
                         "axioms"                  => 10607,
                         "axis"                    => 2821,
                         "axles"                   => 10884,
                         "axonal"                  => 26338,
                         "axons"                   => 15177,
                         "ayacucho"                => 23849,
                         "ayatollah"               => 12283,
                         "ayckbourn"               => 29912,
                         "aydin"                   => 15192,
                         "aykroyd"                 => 23609,
                         "aylesbury"               => 12257,
                         "aylmer"                  => 18093,
                         "ayman"                   => 25208,
                         "aymara"                  => 15220,
                         "ayodhya"                 => 19013,
                         "ayrshire"                => 9604,
                         "ayumi"                   => 19344,
                         "ayurveda"                => 16505,
                         "ayurvedic"               => 17098,
                         "ayutthaya"               => 15454,
                         "ayyavazhi"               => 27881,
                         "ayyubid"                 => 22917,
                         "azadegan"                => 22956,
                         "azarenka"                => 19917,
                         "azaria"                  => 29909,
                         "azerbaijan"              => 2844,
                         "azerbaijani"             => 7344,
                         "azerbaijanis"            => 22998,
                         "azeri"                   => 14833,
                         "azeris"                  => 29617,
                         "azhar"                   => 15134,
                         "aznar"                   => 28025,
                         "azores"                  => 8846,
                         "azuma"                   => 26912,
                         "azusa"                   => 20099,
                         "b'nai"                   => 18852,
                         "b.i.g"                   => 28742,
                         "b.o.b"                   => 24890,
                         "b.tech"                  => 22945,
                         "b/hip"                   => 8169,
                         "b/soul"                  => 28871,
                         "b0d3fb"                  => 23994,
                         "ba'al"                   => 29092,
                         "ba'ath"                  => 14466,
                         "ba'athist"               => 27848,
                         "baba"                    => 5331,
                         "babangida"               => 28534,
                         "babar"                   => 19815,
                         "babbage"                 => 24347,
                         "babbler"                 => 21794,
                         "babol"                   => 23871,
                         "babur"                   => 17327,
                         "babylonia"               => 16709,
                         "babylonian"              => 8662,
                         "babylonians"             => 23102,
                         "bacau"                   => 27892,
                         "baccalaureat"            => 28206,
                         "baccalaureate"           => 8577,
                         "bacharach"               => 18703,
                         "bachata"                 => 26461,
                         "bachchan"                => 13264,
                         "bachelor"                => 1642,
                         "bacillus"                => 17047,
                         "backa"                   => 18375,
                         "backbench"               => 22983,
                         "backbencher"             => 27637,
                         "backcountry"             => 18671,
                         "backdrop"                => 7304,
                         "backdrops"               => 24046,
                         "backed"                  => 2936,
                         "backend"                 => 27219,
                         "backfield"               => 18516,
                         "background"              => 700,
                         "backgrounds"             => 5463,
                         "backhouse"               => 29348,
                         "backing"                 => 3117,
                         "backstory"               => 12723,
                         "backstretch"             => 29685,
                         "backstroke"              => 8198,
                         "backward"                => 6593,
                         "backwaters"              => 26095,
                         "bacolod"                 => 21795,
                         "bacteria"                => 3706,
                         "bacterial"               => 6215,
                         "bacteriology"            => 23133,
                         "bacterium"               => 9987,
                         "bactria"                 => 24793,
                         "bactrian"                => 24127,
                         "badajoz"                 => 16413,
                         "badakhshan"              => 22887,
                         "badami"                  => 28547,
                         "badawi"                  => 25122,
                         "baddeley"                => 29596,
                         "baden"                   => 4445,
                         "badged"                  => 17815,
                         "badging"                 => 29659,
                         "badminton"               => 5837,
                         "badri"                   => 29302,
                         "baekje"                  => 16678,
                         "baerum"                  => 21551,
                         "baffin"                  => 17933,
                         "bafta"                   => 7946,
                         "bagan"                   => 15089,
                         "baghdad"                 => 5048,
                         "baghdadi"                => 22863,
                         "bagmati"                 => 29563,
                         "bagot"                   => 22723,
                         "bagram"                  => 24535,
                         "bagrat"                  => 25557,
                         "bagration"               => 21715,
                         "baguio"                  => 18501,
                         "baha'i"                  => 6654,
                         "baha'is"                 => 9876,
                         "baha'u'llah"             => 14909,
                         "bahadur"                 => 8167,
                         "bahamian"                => 17455,
                         "bahasa"                  => 28572,
                         "bahawalpur"              => 22412,
                         "bahia"                   => 7912,
                         "bahini"                  => 28184,
                         "bahman"                  => 25354,
                         "bahn"                    => 5741,
                         "bahnhof"                 => 23347,
                         "bahrain"                 => 5528,
                         "bahraini"                => 14067,
                         "bahru"                   => 18729,
                         "baikonur"                => 22872,
                         "bailiwick"               => 21527,
                         "bainimarama"             => 23607,
                         "baits"                   => 29121,
                         "bajaj"                   => 22174,
                         "bajnoksag"               => 17202,
                         "bakar"                   => 21071,
                         "bakeries"                => 16093,
                         "bakersfield"             => 9967,
                         "bakhsh"                  => 15578,
                         "bakhtiari"               => 16727,
                         "bakri"                   => 26070,
                         "bakufu"                  => 24965,
                         "bakunin"                 => 24543,
                         "balaclava"               => 28975,
                         "balad"                   => 27138,
                         "balaji"                  => 16177,
                         "balakrishnan"            => 28156,
                         "balan"                   => 19037,
                         "balanced"                => 5028,
                         "balances"                => 11762,
                         "balanchine"              => 17907,
                         "balancing"               => 8287,
                         "balconies"               => 13273,
                         "balearic"                => 14770,
                         "balikpapan"              => 25936,
                         "balinese"                => 14895,
                         "balkan"                  => 6177,
                         "balkans"                 => 6796,
                         "balked"                  => 27795,
                         "balkh"                   => 24157,
                         "ballad"                  => 4322,
                         "ballade"                 => 29978,
                         "ballads"                 => 6536,
                         "ballarat"                => 10151,
                         "ballast"                 => 9582,
                         "ballet"                  => 2583,
                         "ballets"                 => 11064,
                         "ballina"                 => 27918,
                         "balliol"                 => 11834,
                         "ballo"                   => 26030,
                         "ballooning"              => 27208,
                         "ballot"                  => 3696,
                         "balloting"               => 15827,
                         "ballots"                 => 5388,
                         "ballymena"               => 20254,
                         "balmain"                 => 13540,
                         "baloch"                  => 13725,
                         "balochi"                 => 29739,
                         "balochistan"             => 10377,
                         "baloncesto"              => 22057,
                         "balsa"                   => 23434,
                         "balthasar"               => 19396,
                         "balti"                   => 24358,
                         "baltic"                  => 3891,
                         "baltimore"               => 1948,
                         "baltistan"               => 20050,
                         "balto"                   => 25003,
                         "baluchestan"             => 12759,
                         "baluchistan"             => 21137,
                         "balustrade"              => 15576,
                         "balustrades"             => 27710,
                         "bamako"                  => 18796,
                         "bambara"                 => 29665,
                         "bamberg"                 => 13004,
                         "bampton"                 => 28070,
                         "banaras"                 => 23580,
                         "banat"                   => 12880,
                         "banbury"                 => 13494,
                         "banca"                   => 18728,
                         "banco"                   => 9635,
                         "bancorp"                 => 26999,
                         "band"                    => 155,
                         "bandai"                  => 12571,
                         "bandar"                  => 10376,
                         "bandaranaike"            => 24757,
                         "bande"                   => 26822,
                         "banded"                  => 9362,
                         "banding"                 => 15483,
                         "bandini"                 => 25006,
                         "bandits"                 => 7637,
                         "bandleader"              => 11392,
                         "bandmaster"              => 29622,
                         "bandmate"                => 13293,
                         "bandmates"               => 13478,
                         "bando"                   => 29907,
                         "bandon"                  => 23140,
                         "bandra"                  => 20183,
                         "bands"                   => 1342,
                         "bandstand"               => 14182,
                         "bandura"                 => 23828,
                         "bandwidth"               => 6793,
                         "banff"                   => 12240,
                         "banga"                   => 27223,
                         "bangalore"               => 4957,
                         "bangla"                  => 14026,
                         "bangladesh"              => 2529,
                         "bangladeshi"             => 8587,
                         "bangladeshis"            => 27626,
                         "bangor"                  => 7556,
                         "bangui"                  => 25150,
                         "banishment"              => 16237,
                         "banja"                   => 14551,
                         "banjo"                   => 7825,
                         "bank"                    => 498,
                         "banka"                   => 23977,
                         "banked"                  => 15461,
                         "bankers"                 => 8779,
                         "banking"                 => 2797,
                         "banknote"                => 14949,
                         "banknotes"               => 9101,
                         "bankruptcy"              => 3542,
                         "banksia"                 => 9948,
                         "bankstown"               => 14653,
                         "banksy"                  => 29732,
                         "bankura"                 => 27716,
                         "banned"                  => 2684,
                         "banners"                 => 8818,
                         "bannock"                 => 28821,
                         "bannockburn"             => 27093,
                         "banovina"                => 23820,
                         "banque"                  => 15660,
                         "banqueting"              => 27043,
                         "banquets"                => 18557,
                         "banshees"                => 22115,
                         "banska"                  => 16867,
                         "bantamweight"            => 10579,
                         "banten"                  => 27702,
                         "bantu"                   => 10574,
                         "baoding"                 => 29206,
                         "baptised"                => 9310,
                         "baptismal"               => 13311,
                         "baptisms"                => 19573,
                         "baptist"                 => 2464,
                         "baptistery"              => 25297,
                         "baptists"                => 10305,
                         "barack"                  => 4862,
                         "barangay"                => 8076,
                         "barangays"               => 8554,
                         "baranja"                 => 28950,
                         "barat"                   => 22454,
                         "barbadian"               => 19709,
                         "barbarism"               => 26580,
                         "barbarossa"              => 11019,
                         "barbarous"               => 29008,
                         "barbary"                 => 13429,
                         "barbed"                  => 10449,
                         "barberini"               => 19972,
                         "barbet"                  => 27513,
                         "barbettes"               => 29556,
                         "barbican"                => 15438,
                         "barbuda"                 => 13359,
                         "barbus"                  => 19752,
                         "barda"                   => 22774,
                         "bardhaman"               => 24071,
                         "bardic"                  => 27419,
                         "bards"                   => 19618,
                         "bardstown"               => 29769,
                         "bareilly"                => 21505,
                         "barenaked"               => 28678,
                         "barents"                 => 21990,
                         "barges"                  => 9272,
                         "baring"                  => 14882,
                         "barisal"                 => 17177,
                         "barisan"                 => 18786,
                         "barium"                  => 15450,
                         "barnabas"                => 13397,
                         "barnacles"               => 29527,
                         "barnegat"                => 27069,
                         "barnet"                  => 8901,
                         "barneveld"               => 23487,
                         "barnsley"                => 8033,
                         "barnstable"              => 20060,
                         "barnstaple"              => 15846,
                         "barnstormers"            => 27167,
                         "baroda"                  => 14804,
                         "barometric"              => 18210,
                         "baroness"                => 7890,
                         "baronet"                 => 3418,
                         "baronetage"              => 9628,
                         "baronetcies"             => 27277,
                         "baronetcy"               => 7625,
                         "baronets"                => 8422,
                         "baronial"                => 19358,
                         "baronies"                => 18922,
                         "barons"                  => 7248,
                         "barony"                  => 6427,
                         "baroque"                 => 3778,
                         "barque"                  => 17570,
                         "barrack"                 => 19146,
                         "barracks"                => 4000,
                         "barrages"                => 28057,
                         "barranquilla"            => 21129,
                         "barred"                  => 6475,
                         "barrels"                 => 6420,
                         "barrens"                 => 21945,
                         "barrichello"             => 15416,
                         "barrier"                 => 3748,
                         "barriers"                => 5456,
                         "barrio"                  => 8798,
                         "barrister"               => 6956,
                         "barristers"              => 17483,
                         "barrymore"               => 11585,
                         "barthes"                 => 28818,
                         "bartin"                  => 26384,
                         "bartoli"                 => 21700,
                         "barua"                   => 27028,
                         "baruch"                  => 13242,
                         "barwon"                  => 28855,
                         "barzani"                 => 26336,
                         "basal"                   => 5118,
                         "basalt"                  => 9251,
                         "basaltic"                => 16127,
                         "basalts"                 => 24117,
                         "bascule"                 => 26404,
                         "base"                    => 501,
                         "based"                   => 125,
                         "basel"                   => 5391,
                         "baseline"                => 8748,
                         "baseman"                 => 6258,
                         "basemen"                 => 25621,
                         "bases"                   => 2589,
                         "basescu"                 => 23579,
                         "bashar"                  => 17631,
                         "bashkortostan"           => 21972,
                         "basho"                   => 29110,
                         "basic"                   => 1097,
                         "basidia"                 => 28722,
                         "basie"                   => 15252,
                         "basilan"                 => 21065,
                         "basildon"                => 22045,
                         "basilica"                => 4966,
                         "basilicas"               => 29144,
                         "basilicata"              => 25956,
                         "basin"                   => 2082,
                         "basingstoke"             => 14383,
                         "basins"                  => 7654,
                         "basis"                   => 960,
                         "basketball"              => 711,
                         "basque"                  => 4914,
                         "basques"                 => 19685,
                         "basra"                   => 12312,
                         "bassa"                   => 28820,
                         "bassano"                 => 22298,
                         "basse"                   => 15092,
                         "bassist"                 => 3386,
                         "bassists"                => 23243,
                         "bassoons"                => 20783,
                         "basti"                   => 25443,
                         "bastia"                  => 18625,
                         "bastion"                 => 10286,
                         "bastions"                => 15989,
                         "bataan"                  => 14425,
                         "bataille"                => 26269,
                         "bataillon"               => 27695,
                         "batang"                  => 24047,
                         "batangas"                => 16626,
                         "batavia"                 => 9732,
                         "batavian"                => 19743,
                         "batches"                 => 13154,
                         "bathhouse"               => 18596,
                         "bathurst"                => 7769,
                         "batik"                   => 25425,
                         "batley"                  => 20767,
                         "baton"                   => 5762,
                         "batons"                  => 22113,
                         "bats"                    => 3997,
                         "batsman"                 => 4421,
                         "batsmen"                 => 9656,
                         "battalion"               => 1332,
                         "battalions"              => 3749,
                         "batted"                  => 3947,
                         "battenberg"              => 29245,
                         "batters"                 => 7907,
                         "battersea"               => 14012,
                         "battery"                 => 2195,
                         "batticaloa"              => 24034,
                         "batting"                 => 2850,
                         "battle"                  => 339,
                         "battlecruiser"           => 15510,
                         "battlecruisers"          => 15630,
                         "battled"                 => 7616,
                         "battlefield"             => 4229,
                         "battlefields"            => 15686,
                         "battlements"             => 20564,
                         "battleship"              => 5955,
                         "battleships"             => 7186,
                         "battlestar"              => 15338,
                         "batumi"                  => 25796,
                         "bautzen"                 => 27509,
                         "bauxite"                 => 18616,
                         "bavaria"                 => 3923,
                         "bavarian"                => 5422,
                         "bay"                     => 532,
                         "bayan"                   => 13390,
                         "bayburt"                 => 29401,
                         "bayerische"              => 26230,
                         "bayernliga"              => 25059,
                         "bayesian"                => 13472,
                         "bayeux"                  => 21098,
                         "bayezid"                 => 23714,
                         "bayfield"                => 28425,
                         "bayonet"                 => 11889,
                         "bayonets"                => 18402,
                         "bayonne"                 => 12930,
                         "bayou"                   => 9177,
                         "bayreuth"                => 12926,
                         "bayswater"               => 24885,
                         "bazaar"                  => 8136,
                         "bazaars"                 => 29201,
                         "bazar"                   => 10781,
                         "bbwaa"                   => 25806,
                         "be'er"                   => 25446,
                         "beachhead"               => 17314,
                         "beacons"                 => 14295,
                         "beaconsfield"            => 20178,
                         "beaked"                  => 21022,
                         "beams"                   => 6272,
                         "beano"                   => 22957,
                         "bearers"                 => 9629,
                         "bearing"                 => 2915,
                         "bearn"                   => 20984,
                         "bears"                   => 2075,
                         "beaten"                  => 3101,
                         "beatification"           => 15825,
                         "beatified"               => 16082,
                         "beatrix"                 => 14130,
                         "beatz"                   => 24450,
                         "beaufort"                => 8251,
                         "beauharnais"             => 28289,
                         "beautification"          => 20487,
                         "beauvoir"                => 21997,
                         "beaux"                   => 7601,
                         "beaverbrook"             => 26295,
                         "beaverton"               => 22715,
                         "became"                  => 82,
                         "beckenham"               => 23982,
                         "become"                  => 278,
                         "becomes"                 => 1110,
                         "becoming"                => 732,
                         "bedchamber"              => 20691,
                         "bedfordshire"            => 8876,
                         "bedouin"                 => 11257,
                         "bedouins"                => 25009,
                         "bedser"                  => 29585,
                         "beechcraft"              => 18253,
                         "beeching"                => 15715,
                         "beefheart"               => 27700,
                         "beehives"                => 28493,
                         "beekeeping"              => 24239,
                         "been"                    => 37,
                         "beerbohm"                => 29235,
                         "beermen"                 => 21382,
                         "beersheba"               => 15677,
                         "beeston"                 => 18883,
                         "beetles"                 => 5841,
                         "befell"                  => 26200,
                         "before"                  => 89,
                         "befriended"              => 7919,
                         "befriending"             => 22635,
                         "befriends"               => 10453,
                         "began"                   => 144,
                         "beginner"                => 13967,
                         "beginners"               => 12701,
                         "beginning"               => 540,
                         "beginnings"              => 5029,
                         "begins"                  => 1207,
                         "begum"                   => 11498,
                         "begun"                   => 2158,
                         "behalf"                  => 2385,
                         "behavioral"              => 5204,
                         "behaviors"               => 5626,
                         "behaviour"               => 3148,
                         "behavioural"             => 12386,
                         "behaviours"              => 12945,
                         "beheaded"                => 10088,
                         "behest"                  => 9885,
                         "beijing"                 => 2414,
                         "being"                   => 86,
                         "beinn"                   => 24189,
                         "beira"                   => 16607,
                         "beirut"                  => 5807,
                         "beitar"                  => 18987,
                         "beiyang"                 => 29284,
                         "belafonte"               => 22335,
                         "belarus"                 => 4760,
                         "belarusian"              => 6441,
                         "belarusians"             => 25616,
                         "belatedly"               => 22427,
                         "belchatow"               => 23148,
                         "belediyespor"            => 29677,
                         "belem"                   => 19048,
                         "belenenses"              => 28520,
                         "belfast"                 => 3651,
                         "belfort"                 => 17878,
                         "belfry"                  => 12616,
                         "belgaum"                 => 14473,
                         "belge"                   => 26395,
                         "belgian"                 => 2307,
                         "belgians"                => 15002,
                         "belgique"                => 25962,
                         "belgium"                 => 1875,
                         "belgrade"                => 3857,
                         "belgrano"                => 13772,
                         "belichick"               => 26663,
                         "belief"                  => 2326,
                         "beliefs"                 => 3090,
                         "believed"                => 808,
                         "believers"               => 7360,
                         "belisarius"              => 22978,
                         "belizean"                => 22575,
                         "bellarmine"              => 26207,
                         "bellary"                 => 26259,
                         "bellator"                => 11253,
                         "bellefonte"              => 25541,
                         "belleville"              => 11717,
                         "belleza"                 => 18213,
                         "bellflower"              => 29920,
                         "bellingham"              => 13152,
                         "bellinzona"              => 26831,
                         "bellona"                 => 27577,
                         "belonged"                => 2438,
                         "belonging"               => 2585,
                         "belorussian"             => 23223,
                         "below"                   => 582,
                         "belsen"                  => 24570,
                         "beltline"                => 29825,
                         "beltway"                 => 13144,
                         "belvidere"               => 23638,
                         "belvoir"                 => 19019,
                         "bemidji"                 => 25649,
                         "benares"                 => 24708,
                         "benaud"                  => 27220,
                         "benazir"                 => 17968,
                         "bencher"                 => 22237,
                         "benches"                 => 8936,
                         "benchmark"               => 9771,
                         "benchmarking"            => 22279,
                         "benchmarks"              => 16911,
                         "bendigo"                 => 11853,
                         "benedictine"             => 6995,
                         "benedictines"            => 23034,
                         "benediction"             => 24709,
                         "benefactors"             => 14912,
                         "benefice"                => 14971,
                         "benefices"               => 25468,
                         "beneficial"              => 5580,
                         "beneficiaries"           => 10934,
                         "benefited"               => 6869,
                         "benefiting"              => 12411,
                         "benefits"                => 2168,
                         "benefitted"              => 18266,
                         "benefitting"             => 29855,
                         "benelux"                 => 16483,
                         "bengal"                  => 3015,
                         "bengali"                 => 4611,
                         "bengalis"                => 27925,
                         "bengaluru"               => 15540,
                         "benghazi"                => 13603,
                         "bengt"                   => 20616,
                         "benin"                   => 7317,
                         "bentham"                 => 15251,
                         "benthic"                 => 14587,
                         "bentinck"                => 19253,
                         "benue"                   => 25070,
                         "benzene"                 => 13631,
                         "benzodiazepine"          => 20095,
                         "benzodiazepines"         => 15672,
                         "bequeathed"              => 8989,
                         "bequest"                 => 12136,
                         "bequests"                => 23120,
                         "berar"                   => 25532,
                         "berat"                   => 24092,
                         "berates"                 => 24593,
                         "berber"                  => 9160,
                         "berbers"                 => 17273,
                         "berchtesgaden"           => 28929,
                         "berdych"                 => 26942,
                         "berea"                   => 21058,
                         "berengar"                => 23628,
                         "berenger"                => 29109,
                         "berets"                  => 18736,
                         "berezovsky"              => 26435,
                         "bergamo"                 => 12744,
                         "bergson"                 => 25559,
                         "berhad"                  => 18297,
                         "beria"                   => 23312,
                         "bering"                  => 12028,
                         "berio"                   => 28141,
                         "berisha"                 => 26153,
                         "berkeley"                => 2977,
                         "berkhamsted"             => 25791,
                         "berklee"                 => 13826,
                         "berks"                   => 13679,
                         "berkshire"               => 5398,
                         "berle"                   => 22868,
                         "berlioz"                 => 15018,
                         "berlusconi"              => 12222,
                         "bermondsey"              => 21344,
                         "bermudian"               => 20344,
                         "bernadotte"              => 19669,
                         "bernd"                   => 14041,
                         "berne"                   => 13020,
                         "berners"                 => 22809,
                         "bernese"                 => 15327,
                         "bernini"                 => 18043,
                         "bernoulli"               => 15319,
                         "bernt"                   => 29737,
                         "berri"                   => 29446,
                         "bertelsmann"             => 29278,
                         "berth"                   => 6584,
                         "berthe"                  => 29032,
                         "berthed"                 => 18238,
                         "berthier"                => 26558,
                         "berthing"                => 23306,
                         "berths"                  => 11845,
                         "bertolt"                 => 21414,
                         "berwickshire"            => 25495,
                         "berwyn"                  => 26961,
                         "besancon"                => 16541,
                         "besant"                  => 23926,
                         "besar"                   => 16891,
                         "beset"                   => 14683,
                         "besiege"                 => 20250,
                         "besieged"                => 6254,
                         "besiegers"               => 27000,
                         "besieging"               => 15120,
                         "bespoke"                 => 16123,
                         "bessarabia"              => 13673,
                         "bessarabian"             => 28448,
                         "bessel"                  => 22768,
                         "bessemer"                => 18427,
                         "best"                    => 162,
                         "besting"                 => 27835,
                         "bestowed"                => 6384,
                         "bestowing"               => 25117,
                         "bestows"                 => 27030,
                         "bests"                   => 14436,
                         "bestseller"              => 8237,
                         "bestsellers"             => 20754,
                         "bestselling"             => 11192,
                         "beta"                    => 3091,
                         "betel"                   => 22315,
                         "bethesda"                => 10849,
                         "bethlehem"               => 7033,
                         "bethnal"                 => 20593,
                         "bethpage"                => 28142,
                         "betis"                   => 18399,
                         "betjeman"                => 25927,
                         "betrothal"               => 21552,
                         "betrothed"               => 14309,
                         "bettered"                => 19222,
                         "betterment"              => 17376,
                         "betula"                  => 21595,
                         "between"                 => 57,
                         "beverages"               => 7226,
                         "bevin"                   => 27586,
                         "bexar"                   => 18425,
                         "bexley"                  => 17672,
                         "bezalel"                 => 28143,
                         "beziers"                 => 25795,
                         "bezirksliga"             => 22546,
                         "bhadra"                  => 25972,
                         "bhagalpur"               => 28546,
                         "bhagat"                  => 18091,
                         "bhagavad"                => 19768,
                         "bhagavata"               => 21839,
                         "bhagwan"                 => 24126,
                         "bhakti"                  => 14703,
                         "bhamo"                   => 28865,
                         "bhangra"                 => 26054,
                         "bharata"                 => 20769,
                         "bharathi"                => 22441,
                         "bharati"                 => 15444,
                         "bharatiya"               => 10706,
                         "bharatpur"               => 26033,
                         "bharti"                  => 20334,
                         "bhasa"                   => 26303,
                         "bhaskar"                 => 17506,
                         "bhattacharya"            => 16527,
                         "bhavan"                  => 15342,
                         "bhawan"                  => 28578,
                         "bhima"                   => 19121,
                         "bhiwani"                 => 28723,
                         "bhojpuri"                => 21876,
                         "bhopal"                  => 10208,
                         "bhosle"                  => 27735,
                         "bhubaneswar"             => 15188,
                         "bhumibol"                => 24621,
                         "bhushan"                 => 16029,
                         "bhutan"                  => 6415,
                         "bhutanese"               => 16918,
                         "bhutto"                  => 9651,
                         "biafra"                  => 18531,
                         "biala"                   => 13440,
                         "bialystok"               => 9004,
                         "biannual"                => 17890,
                         "biases"                  => 14406,
                         "biathlete"               => 22118,
                         "biathlon"                => 10669,
                         "bible"                   => 2153,
                         "biblical"                => 3499,
                         "bibliographic"           => 17898,
                         "bibliographical"         => 25574,
                         "bibliography"            => 4478,
                         "biblioteca"              => 16890,
                         "bibliotheca"             => 20029,
                         "bibliotheque"            => 14229,
                         "bicameral"               => 15948,
                         "bicarbonate"             => 18738,
                         "bicentenary"             => 25861,
                         "bicester"                => 23535,
                         "bickerton"               => 27584,
                         "bicol"                   => 21665,
                         "bicolor"                 => 18581,
                         "bicycles"                => 7170,
                         "bicycling"               => 17786,
                         "bicyclists"              => 25673,
                         "bidar"                   => 24733,
                         "bidders"                 => 18627,
                         "bideford"                => 21643,
                         "biden"                   => 13263,
                         "bidirectional"           => 19702,
                         "bielefeld"               => 16279,
                         "bielsk"                  => 25711,
                         "bielsko"                 => 21773,
                         "biennale"                => 8921,
                         "biennial"                => 7880,
                         "biennially"              => 28765,
                         "bienville"               => 29436,
                         "bifurcated"              => 28587,
                         "bifurcation"             => 20625,
                         "biggar"                  => 26410,
                         "bight"                   => 14613,
                         "bihar"                   => 5757,
                         "bihari"                  => 18046,
                         "bijapur"                 => 16431,
                         "bijar"                   => 28264,
                         "bijelo"                  => 26426,
                         "bikaner"                 => 20024,
                         "biking"                  => 9630,
                         "bikram"                  => 25636,
                         "bilaspur"                => 23287,
                         "bilateral"               => 6157,
                         "bilayer"                 => 23376,
                         "bilbao"                  => 8755,
                         "biliary"                 => 27524,
                         "bilinear"                => 22687,
                         "bilingual"               => 6347,
                         "bilingualism"            => 20512,
                         "billboard"               => 1330,
                         "bille"                   => 27066,
                         "billed"                  => 5297,
                         "billets"                 => 28760,
                         "billiards"               => 12355,
                         "billion"                 => 1347,
                         "billiton"                => 28673,
                         "bimonthly"               => 15704,
                         "binaries"                => 21024,
                         "binary"                  => 4481,
                         "binders"                 => 29441,
                         "binding"                 => 2991,
                         "bindings"                => 17315,
                         "binds"                   => 7649,
                         "binet"                   => 28235,
                         "bingen"                  => 20044,
                         "binghamton"              => 10511,
                         "bingley"                 => 21145,
                         "binocular"               => 21214,
                         "binomial"                => 11855,
                         "bioavailability"         => 23581,
                         "biochemical"             => 10445,
                         "biochemist"              => 18286,
                         "biochemistry"            => 8129,
                         "biodiesel"               => 15167,
                         "biodiversity"            => 6170,
                         "bioengineering"          => 27081,
                         "biofilm"                 => 29885,
                         "biofuel"                 => 18212,
                         "biofuels"                => 15210,
                         "biogas"                  => 24010,
                         "biogenesis"              => 27806,
                         "biogeographic"           => 28302,
                         "biogeography"            => 25533,
                         "biograph"                => 28350,
                         "biographer"              => 5956,
                         "biographers"             => 14396,
                         "biographical"            => 6189,
                         "biographies"             => 7416,
                         "biography"               => 785,
                         "bioinformatics"          => 13925,
                         "biologist"               => 8197,
                         "biologists"              => 11795,
                         "biology"                 => 2535,
                         "biomarker"               => 26628,
                         "biomarkers"              => 22771,
                         "biomass"                 => 9108,
                         "biome"                   => 22970,
                         "biomechanics"            => 27333,
                         "biomedical"              => 7655,
                         "biophysical"             => 26762,
                         "biophysics"              => 17789,
                         "biopic"                  => 13743,
                         "bioscience"              => 28018,
                         "biosciences"             => 26930,
                         "biosphere"               => 10379,
                         "biosynthesis"            => 11532,
                         "biosynthetic"            => 29743,
                         "biota"                   => 21766,
                         "biotechnology"           => 7461,
                         "biotic"                  => 22130,
                         "biotin"                  => 29664,
                         "bipartite"               => 19590,
                         "bipedal"                 => 21752,
                         "biplane"                 => 9100,
                         "biplanes"                => 22722,
                         "bipolar"                 => 9832,
                         "birding"                 => 20483,
                         "birdlife"                => 14188,
                         "birds"                   => 1461,
                         "birdwatching"            => 24449,
                         "birger"                  => 20117,
                         "birkbeck"                => 20204,
                         "birkenau"                => 24783,
                         "birkenfeld"              => 22254,
                         "birkenhead"              => 11581,
                         "birkin"                  => 26253,
                         "birla"                   => 17174,
                         "birmingham"              => 2041,
                         "birth"                   => 1174,
                         "birthdate"               => 27799,
                         "birthplace"              => 4942,
                         "births"                  => 6653,
                         "biscay"                  => 12258,
                         "bisected"                => 16785,
                         "bisects"                 => 22156,
                         "bisexuality"             => 22829,
                         "bishopric"               => 7263,
                         "bishoprics"              => 21392,
                         "bishops"                 => 3007,
                         "bishopsgate"             => 27778,
                         "bismuth"                 => 18198,
                         "bison"                   => 7817,
                         "bisons"                  => 15871,
                         "bissau"                  => 11619,
                         "bistrica"                => 25974,
                         "bistrita"                => 23763,
                         "biswas"                  => 21872,
                         "bitcoin"                 => 16118,
                         "bithynia"                => 23075,
                         "bitmap"                  => 21338,
                         "bitola"                  => 21136,
                         "bitrate"                 => 29705,
                         "bitterly"                => 11475,
                         "bittern"                 => 25453,
                         "bitterns"                => 24337,
                         "bittorrent"              => 19204,
                         "bitumen"                 => 16818,
                         "bituminous"              => 20666,
                         "bivalve"                 => 16659,
                         "bivalves"                => 21500,
                         "biweekly"                => 20623,
                         "bizerte"                 => 27720,
                         "bizet"                   => 18641,
                         "bjelke"                  => 23539,
                         "bjorn"                   => 8910,
                         "blackadder"              => 18717,
                         "blackbirds"              => 26886,
                         "blackfoot"               => 17164,
                         "blackfriars"             => 16840,
                         "blackhawks"              => 9705,
                         "blackheath"              => 16848,
                         "blackish"                => 8424,
                         "blacklist"               => 16850,
                         "blacklisted"             => 16518,
                         "blackmails"              => 21109,
                         "blackmun"                => 29055,
                         "blackpool"               => 5581,
                         "blackrock"               => 16150,
                         "blacksburg"              => 26775,
                         "blacksmith"              => 7967,
                         "blacksmiths"             => 18395,
                         "blacktown"               => 23900,
                         "blackwall"               => 26178,
                         "bladed"                  => 12942,
                         "blaenau"                 => 28816,
                         "blagoevgrad"             => 22401,
                         "blagojevich"             => 22014,
                         "blamey"                  => 26883,
                         "blantyre"                => 23150,
                         "blasts"                  => 11036,
                         "blavatsky"               => 22037,
                         "blaxploitation"          => 29843,
                         "blazon"                  => 11248,
                         "blended"                 => 8226,
                         "blending"                => 9031,
                         "blends"                  => 10165,
                         "blenny"                  => 19285,
                         "bleriot"                 => 21751,
                         "bletchley"               => 16388,
                         "blige"                   => 15683,
                         "bligh"                   => 14307,
                         "blighted"                => 22201,
                         "blimps"                  => 29765,
                         "blistering"              => 19946,
                         "blizzards"               => 28778,
                         "bloc"                    => 5429,
                         "block"                   => 1122,
                         "blockade"                => 5374,
                         "blockaded"               => 16998,
                         "blockades"               => 28300,
                         "blockading"              => 14005,
                         "blockbuster"             => 8932,
                         "blockers"                => 18104,
                         "blockhouse"              => 17156,
                         "blocks"                  => 2222,
                         "blocs"                   => 22910,
                         "bloemfontein"            => 16512,
                         "blog"                    => 3537,
                         "blogger"                 => 9398,
                         "bloggers"                => 12101,
                         "blogging"                => 14546,
                         "blogs"                   => 7444,
                         "blois"                   => 15307,
                         "blomfield"               => 26685,
                         "bloodiest"               => 22618,
                         "bloodlines"              => 22560,
                         "bloodstock"              => 29256,
                         "bloomberg"               => 8103,
                         "bloomington"             => 9130,
                         "blooms"                  => 13048,
                         "bloomsburg"              => 22456,
                         "bloomsbury"              => 13089,
                         "bloor"                   => 16675,
                         "blotch"                  => 16495,
                         "blotches"                => 18507,
                         "bluebeard"               => 28653,
                         "bluefield"               => 27349,
                         "bluegrass"               => 7606,
                         "bluestone"               => 21594,
                         "bluesy"                  => 24650,
                         "bluetooth"               => 11103,
                         "bluffs"                  => 10537,
                         "bluffton"                => 28594,
                         "bluish"                  => 11804,
                         "blurring"                => 19791,
                         "blyth"                   => 11929,
                         "blyton"                  => 27060,
                         "board"                   => 335,
                         "boarders"                => 13759,
                         "boardings"               => 22801,
                         "boards"                  => 2903,
                         "boars"                   => 21147,
                         "boasted"                 => 8807,
                         "boasting"                => 13867,
                         "boasts"                  => 6840,
                         "boaters"                 => 21259,
                         "boats"                   => 2086,
                         "boatswain"               => 21444,
                         "boavista"                => 24602,
                         "boban"                   => 27237,
                         "bobsledder"              => 20789,
                         "bobsleigh"               => 14754,
                         "bocage"                  => 29610,
                         "boccaccio"               => 22465,
                         "bocelli"                 => 23830,
                         "bodhisattva"             => 17784,
                         "bodied"                  => 7678,
                         "bodies"                  => 1621,
                         "bodil"                   => 29471,
                         "bodleian"                => 18158,
                         "bodmin"                  => 18345,
                         "body"                    => 401,
                         "bodybuilder"             => 18767,
                         "bodybuilding"            => 12650,
                         "bodywork"                => 12552,
                         "boehner"                 => 29519,
                         "boeotia"                 => 25898,
                         "boers"                   => 14825,
                         "bofors"                  => 17006,
                         "bogdanov"                => 27415,
                         "bogdanovich"             => 26415,
                         "bognor"                  => 27503,
                         "bogor"                   => 25833,
                         "bohdan"                  => 23593,
                         "boheme"                  => 16441,
                         "bohemia"                 => 5879,
                         "bohemian"                => 6184,
                         "bohemians"               => 14622,
                         "bohemond"                => 23933,
                         "bohme"                   => 28649,
                         "bohol"                   => 17394,
                         "bohra"                   => 29391,
                         "bohun"                   => 27119,
                         "boilermakers"            => 19588,
                         "boilers"                 => 6987,
                         "boise"                   => 8023,
                         "boisterous"              => 24054,
                         "bojan"                   => 22784,
                         "bolagh"                  => 17941,
                         "bold"                    => 3559,
                         "boldface"                => 20678,
                         "boldklub"                => 23063,
                         "boldly"                  => 15332,
                         "boldness"                => 24217,
                         "boleslav"                => 23780,
                         "boleslaw"                => 10705,
                         "boletus"                 => 24193,
                         "boleyn"                  => 15006,
                         "bolingbroke"             => 23003,
                         "bolivarian"              => 19279,
                         "bolivia"                 => 4292,
                         "bolivian"                => 8406,
                         "bollywood"               => 5426,
                         "bolshevik"               => 7936,
                         "bolsheviks"              => 9064,
                         "bolshevism"              => 22991,
                         "bolshoi"                 => 15652,
                         "bolstered"               => 13747,
                         "boltzmann"               => 16012,
                         "bolzano"                 => 19246,
                         "bombarded"               => 10895,
                         "bombardment"             => 4134,
                         "bombardments"            => 19579,
                         "bombastic"               => 25358,
                         "bombing"                 => 2951,
                         "bombings"                => 6693,
                         "bombs"                   => 3901,
                         "bombus"                  => 29372,
                         "bonaventure"             => 14640,
                         "boneh"                   => 22411,
                         "bonfires"                => 24240,
                         "bonheur"                 => 29652,
                         "boniface"                => 9783,
                         "bonnaroo"                => 27435,
                         "bonne"                   => 19844,
                         "bonnier"                 => 27772,
                         "bonus"                   => 2663,
                         "bonuses"                 => 10130,
                         "booed"                   => 18227,
                         "book"                    => 211,
                         "bookings"                => 16663,
                         "booklet"                 => 7090,
                         "booklist"                => 21678,
                         "bookmaker"               => 24642,
                         "bookmakers"              => 21257,
                         "books"                   => 468,
                         "bookseller"              => 12908,
                         "booksellers"             => 14748,
                         "bookshop"                => 14154,
                         "boolean"                 => 11187,
                         "boomed"                  => 19074,
                         "booms"                   => 17392,
                         "boonton"                 => 29834,
                         "boosted"                 => 9488,
                         "boosting"                => 12956,
                         "booting"                 => 24114,
                         "bootle"                  => 23057,
                         "bootlegging"             => 25817,
                         "bootstrap"               => 22382,
                         "borac"                   => 24928,
                         "boras"                   => 25452,
                         "borax"                   => 24207,
                         "borbon"                  => 28800,
                         "borde"                   => 29180,
                         "border"                  => 845,
                         "bordered"                => 4071,
                         "bordering"               => 6769,
                         "borderland"              => 27318,
                         "borderlands"             => 19282,
                         "boreal"                  => 12854,
                         "borehole"                => 24102,
                         "borgo"                   => 19460,
                         "born"                    => 80,
                         "borne"                   => 5516,
                         "borneo"                  => 6227,
                         "bornholm"                => 21717,
                         "borno"                   => 25647,
                         "boron"                   => 11618,
                         "borough"                 => 1522,
                         "boroughs"                => 6749,
                         "borromeo"                => 17628,
                         "borrower"                => 14407,
                         "borrowers"               => 13910,
                         "borrowings"              => 19739,
                         "borrows"                 => 14237,
                         "boscawen"                => 28339,
                         "boscombe"                => 26834,
                         "bosna"                   => 27273,
                         "bosnia"                  => 3266,
                         "bosniak"                 => 15745,
                         "bosniaks"                => 17943,
                         "bosnian"                 => 5718,
                         "boson"                   => 19255,
                         "bosons"                  => 21819,
                         "bosphorus"               => 20576,
                         "bossier"                 => 16948,
                         "botanic"                 => 9438,
                         "botanical"               => 4682,
                         "botanist"                => 6243,
                         "botanists"               => 15562,
                         "botany"                  => 6379,
                         "botev"                   => 20583,
                         "both"                    => 88,
                         "botha"                   => 15478,
                         "botolph"                 => 28480,
                         "botswana"                => 7021,
                         "bottleneck"              => 15127,
                         "bottlenecks"             => 25294,
                         "bottlenose"              => 24389,
                         "bottling"                => 12946,
                         "botvinnik"               => 28759,
                         "bouches"                 => 28291,
                         "bouchet"                 => 19909,
                         "bougainville"            => 13195,
                         "bouillon"                => 23372,
                         "boulders"                => 10447,
                         "boulevard"               => 2940,
                         "boulevards"              => 17339,
                         "boulez"                  => 21501,
                         "boulogne"                => 10569,
                         "boult"                   => 24631,
                         "boundaries"              => 2401,
                         "boundary"                => 1937,
                         "bounded"                 => 3974,
                         "bounding"                => 20235,
                         "bourbons"                => 24204,
                         "bourchier"               => 22310,
                         "bourgeoisie"             => 12713,
                         "bourges"                 => 17623,
                         "bourgogne"               => 18754,
                         "bournemouth"             => 7658,
                         "bourse"                  => 27675,
                         "boutiques"               => 14981,
                         "bouts"                   => 8239,
                         "bowed"                   => 11832,
                         "bowery"                  => 14433,
                         "bowl"                    => 1392,
                         "bowled"                  => 6371,
                         "bowlers"                 => 9051,
                         "bowls"                   => 6484,
                         "boxset"                  => 22421,
                         "boyaca"                  => 25829,
                         "boyar"                   => 23451,
                         "boyars"                  => 21649,
                         "boyband"                 => 25944,
                         "boycott"                 => 6081,
                         "boycotted"               => 12406,
                         "boycotts"                => 18889,
                         "boyhood"                 => 12862,
                         "boylston"                => 24456,
                         "boys/girls"              => 21606,
                         "bozorg"                  => 23813,
                         "braathens"               => 23492,
                         "brabant"                 => 9657,
                         "brabazon"                => 29426,
                         "braced"                  => 12590,
                         "brachiopods"             => 27013,
                         "bracket"                 => 7508,
                         "bracketed"               => 20195,
                         "brackets"                => 7452,
                         "brackish"                => 12645,
                         "bracknell"               => 20949,
                         "bracts"                  => 16618,
                         "bradenton"               => 20185,
                         "bradman"                 => 11331,
                         "braganca"                => 27573,
                         "braganza"                => 16526,
                         "brahe"                   => 21528,
                         "brahma"                  => 9356,
                         "brahman"                 => 11753,
                         "brahmana"                => 25759,
                         "brahmaputra"             => 17220,
                         "brahmi"                  => 22074,
                         "brahmin"                 => 8723,
                         "brahmins"                => 10218,
                         "brahmo"                  => 22753,
                         "braille"                 => 9456,
                         "brainchild"              => 15068,
                         "brainstem"               => 22027,
                         "braintree"               => 16207,
                         "braking"                 => 8320,
                         "bramall"                 => 22173,
                         "bramley"                 => 21222,
                         "brampton"                => 10974,
                         "branagh"                 => 23987,
                         "branched"                => 7835,
                         "branches"                => 2009,
                         "branching"               => 8095,
                         "brand"                   => 1312,
                         "branded"                 => 4140,
                         "brandeis"                => 11987,
                         "branding"                => 5836,
                         "brandishing"             => 28400,
                         "brands"                  => 3287,
                         "brandywine"              => 15445,
                         "braniff"                 => 20714,
                         "branko"                  => 16645,
                         "brankovic"               => 24894,
                         "brantford"               => 16235,
                         "braque"                  => 23927,
                         "brasenose"               => 20091,
                         "brasileira"              => 23895,
                         "brasileiro"              => 12347,
                         "brasiliensis"            => 26769,
                         "brasov"                  => 15727,
                         "brassey"                 => 29315,
                         "bratianu"                => 29251,
                         "bratislava"              => 8071,
                         "brattleboro"             => 26492,
                         "braunfels"               => 27353,
                         "braunschweig"            => 12242,
                         "bravery"                 => 5783,
                         "brazilian"               => 1941,
                         "brazilians"              => 13168,
                         "brazo"                   => 29250,
                         "brazos"                  => 17045,
                         "brazzaville"             => 16707,
                         "breaches"                => 12154,
                         "breaching"               => 14869,
                         "breadth"                 => 9321,
                         "breakage"                => 21799,
                         "breakaway"               => 8420,
                         "breakbeat"               => 27944,
                         "breakout"                => 8536,
                         "breakthrough"            => 4463,
                         "breakwater"              => 14829,
                         "bream"                   => 18292,
                         "breastfeeding"           => 15519,
                         "breaststroke"            => 8078,
                         "breccia"                 => 27155,
                         "brechin"                 => 18083,
                         "brecker"                 => 26947,
                         "breckinridge"            => 14611,
                         "brecon"                  => 14676,
                         "bred"                    => 5170,
                         "breda"                   => 11345,
                         "breech"                  => 11108,
                         "breeches"                => 19457,
                         "breed"                   => 3219,
                         "breeder"                 => 10655,
                         "breeders"                => 7195,
                         "breeding"                => 2660,
                         "breeds"                  => 5430,
                         "brega"                   => 26401,
                         "breguet"                 => 21245,
                         "breisgau"                => 22466,
                         "bremerhaven"             => 19771,
                         "bremerton"               => 17715,
                         "brentano"                => 27160,
                         "brentford"               => 8450,
                         "brentwood"               => 11447,
                         "brera"                   => 23995,
                         "breslau"                 => 10572,
                         "bresson"                 => 27566,
                         "brethren"                => 7171,
                         "bretton"                 => 19512,
                         "breuning"                => 13365,
                         "breve"                   => 29051,
                         "brevet"                  => 10925,
                         "breviary"                => 27378,
                         "brevis"                  => 19825,
                         "brevity"                 => 19041,
                         "breweries"               => 9437,
                         "brewers"                 => 6816,
                         "brewery"                 => 4183,
                         "brewing"                 => 6144,
                         "brezhnev"                => 15350,
                         "briain"                  => 27406,
                         "briarcliff"              => 23351,
                         "brick"                   => 2036,
                         "bricklayer"              => 24997,
                         "brickwork"               => 14491,
                         "brickworks"              => 20001,
                         "brickyard"               => 20188,
                         "bridge"                  => 512,
                         "bridged"                 => 16674,
                         "bridgehead"              => 12905,
                         "bridgend"                => 16334,
                         "bridgeport"              => 8937,
                         "bridgestone"             => 20200,
                         "bridgeton"               => 27804,
                         "bridgetown"              => 20921,
                         "bridging"                => 10907,
                         "bridgnorth"              => 24144,
                         "bridgwater"              => 16984,
                         "bridle"                  => 17365,
                         "bridlington"             => 23549,
                         "bridport"                => 23038,
                         "brief"                   => 1680,
                         "briefly"                 => 1653,
                         "brienne"                 => 23528,
                         "brigade"                 => 1248,
                         "brigades"                => 5156,
                         "brigadier"               => 3817,
                         "brigands"                => 26683,
                         "brigantine"              => 25221,
                         "brightly"                => 9490,
                         "brightness"              => 8935,
                         "brigs"                   => 26552,
                         "brine"                   => 13160,
                         "brinsley"                => 29965,
                         "brisbane"                => 2659,
                         "bristles"                => 16451,
                         "britain"                 => 832,
                         "britannia"               => 8357,
                         "britannica"              => 11197,
                         "british"                 => 164,
                         "briton"                  => 15151,
                         "britons"                 => 11207,
                         "britpop"                 => 22748,
                         "brixton"                 => 13235,
                         "broad"                   => 1738,
                         "broadband"               => 6494,
                         "broadcast"               => 814,
                         "broadcaster"             => 4358,
                         "broadcasters"            => 6069,
                         "broadcasting"            => 1361,
                         "broadcasts"              => 2841,
                         "broadened"               => 11266,
                         "broadening"              => 15074,
                         "broader"                 => 4510,
                         "broadest"                => 17595,
                         "broadleaf"               => 19521,
                         "broadly"                 => 5346,
                         "broadmoor"               => 23892,
                         "broadsheet"              => 17453,
                         "broadside"               => 12634,
                         "broadsides"              => 22943,
                         "broadview"               => 27690,
                         "broadway"                => 1932,
                         "brocade"                 => 25451,
                         "broch"                   => 22460,
                         "brockton"                => 21256,
                         "brockville"              => 23932,
                         "broglie"                 => 23674,
                         "brokerage"               => 10933,
                         "brokered"                => 14639,
                         "brome"                   => 21745,
                         "bromeliad"               => 25637,
                         "bromide"                 => 14641,
                         "bromine"                 => 19301,
                         "brompton"                => 15348,
                         "bromsgrove"              => 21809,
                         "bromwich"                => 8505,
                         "bronfman"                => 26003,
                         "bronislaw"               => 24625,
                         "bronx"                   => 5262,
                         "bronze"                  => 1341,
                         "bronzes"                 => 14319,
                         "broodmare"               => 15689,
                         "broods"                  => 22001,
                         "brookfield"              => 13032,
                         "brookhaven"              => 18088,
                         "brookings"               => 15059,
                         "brooklands"              => 17877,
                         "brookville"              => 26902,
                         "brookwood"               => 22067,
                         "bros."                   => 4300,
                         "brothels"                => 13237,
                         "brotherhood"             => 5092,
                         "brotherhoods"            => 29811,
                         "brothers"                => 841,
                         "broward"                 => 13788,
                         "browed"                  => 27632,
                         "brownian"                => 21824,
                         "brownish"                => 7067,
                         "brownsville"             => 11268,
                         "browser"                 => 5829,
                         "browsers"                => 10938,
                         "bruford"                 => 26365,
                         "bruges"                  => 11765,
                         "brugge"                  => 15608,
                         "bruhl"                   => 27581,
                         "brumbies"                => 25400,
                         "brunei"                  => 7148,
                         "brunel"                  => 13034,
                         "brunswick"               => 2992,
                         "brussels"                => 3573,
                         "brutalist"               => 28042,
                         "bruxelles"               => 19138,
                         "bryansk"                 => 21860,
                         "brythonic"               => 25703,
                         "brzeg"                   => 28389,
                         "bskyb"                   => 22468,
                         "buble"                   => 23095,
                         "bubonic"                 => 22063,
                         "buccal"                  => 26491,
                         "buccaneer"               => 19057,
                         "buccaneers"              => 7146,
                         "buccleuch"               => 27464,
                         "bucculatrix"             => 24940,
                         "bucharest"               => 5235,
                         "buchenwald"              => 19418,
                         "buckethead"              => 22832,
                         "buckinghamshire"         => 7213,
                         "buckminster"             => 29798,
                         "bucuresti"               => 12106,
                         "buddhas"                 => 18430,
                         "buddhism"                => 3862,
                         "buddhist"                => 2714,
                         "buddhists"               => 9904,
                         "budding"                 => 11551,
                         "buddleja"                => 18343,
                         "budejovice"              => 19754,
                         "budget"                  => 1495,
                         "budgetary"               => 12318,
                         "budgeted"                => 16304,
                         "budgeting"               => 17340,
                         "budgets"                 => 8557,
                         "budokan"                 => 23310,
                         "buducnost"               => 25054,
                         "buenos"                  => 3277,
                         "buffaloes"               => 13675,
                         "buffered"                => 29106,
                         "buffering"               => 24203,
                         "buffers"                 => 15708,
                         "buganda"                 => 21283,
                         "bugis"                   => 29012,
                         "bugle"                   => 11960,
                         "buhari"                  => 29249,
                         "build"                   => 1011,
                         "builders"                => 5920,
                         "building"                => 191,
                         "buildings"               => 569,
                         "builds"                  => 6220,
                         "buildup"                 => 10444,
                         "built"                   => 175,
                         "bukhara"                 => 17304,
                         "bukhari"                 => 18486,
                         "bukidnon"                => 28090,
                         "bukit"                   => 10425,
                         "bukovina"                => 18148,
                         "bulacan"                 => 16456,
                         "bulawayo"                => 18169,
                         "bulbophyllum"            => 7668,
                         "bulbous"                 => 17390,
                         "bulbul"                  => 20356,
                         "bulgaria"                => 2810,
                         "bulgarian"               => 2852,
                         "bulgarians"              => 10166,
                         "bulgars"                 => 22544,
                         "bulge"                   => 10944,
                         "bulges"                  => 28614,
                         "bulk"                    => 3617,
                         "bulkeley"                => 24748,
                         "bulkhead"                => 16913,
                         "bulkheads"               => 20437,
                         "bulletins"               => 10956,
                         "bullfighting"            => 21973,
                         "bullpen"                 => 11675,
                         "bullying"                => 6762,
                         "bulwark"                 => 19772,
                         "bulwer"                  => 26168,
                         "bunbury"                 => 16473,
                         "bundaberg"               => 21002,
                         "bundesautobahn"          => 27867,
                         "bundesbahn"              => 24628,
                         "bundesliga"              => 5099,
                         "bundesstrasse"           => 17295,
                         "bundestag"               => 13218,
                         "bundeswehr"              => 14849,
                         "bundled"                 => 10375,
                         "bundles"                 => 9920,
                         "bungalows"               => 16097,
                         "bunkers"                 => 11063,
                         "bunko"                   => 29090,
                         "bunuel"                  => 21844,
                         "buoyancy"                => 12955,
                         "buoyant"                 => 18344,
                         "buoyed"                  => 23957,
                         "buoys"                   => 18821,
                         "burdensome"              => 29698,
                         "burdwan"                 => 25270,
                         "bureau"                  => 1345,
                         "bureaucracy"             => 8954,
                         "bureaucratic"            => 10262,
                         "bureaus"                 => 13751,
                         "buren"                   => 9758,
                         "burgas"                  => 16743,
                         "burgenland"              => 23516,
                         "burgeoning"              => 10404,
                         "burgesses"               => 17208,
                         "burgh"                   => 9355,
                         "burghers"                => 19542,
                         "burghley"                => 22890,
                         "burghs"                  => 15227,
                         "burgundian"              => 14944,
                         "burgundians"             => 26855,
                         "burgundy"                => 6849,
                         "burial"                  => 3115,
                         "burials"                 => 7564,
                         "buried"                  => 1210,
                         "burkina"                 => 7409,
                         "burkinabe"               => 26050,
                         "burlesque"               => 10288,
                         "burlington"              => 5597,
                         "burmese"                 => 5479,
                         "burnaby"                 => 14698,
                         "burne"                   => 21730,
                         "burnet"                  => 13560,
                         "burnie"                  => 19078,
                         "burra"                   => 25104,
                         "burrard"                 => 27202,
                         "burrowing"               => 15104,
                         "bursa"                   => 14765,
                         "bursaries"               => 25975,
                         "bursary"                 => 22371,
                         "burslem"                 => 21332,
                         "bursts"                  => 9405,
                         "burundi"                 => 9401,
                         "burwood"                 => 22127,
                         "busan"                   => 10190,
                         "buses"                   => 2465,
                         "bushehr"                 => 17474,
                         "bushels"                 => 24812,
                         "bushfire"                => 22669,
                         "bushfires"               => 20025,
                         "bushland"                => 20093,
                         "busiest"                 => 6872,
                         "business"                => 269,
                         "businesses"              => 1664,
                         "businessman"             => 2504,
                         "businessmen"             => 6309,
                         "businesspeople"          => 25262,
                         "businessperson"          => 21325,
                         "businessweek"            => 17951,
                         "busing"                  => 24267,
                         "buskerud"                => 24669,
                         "busko"                   => 28965,
                         "busoni"                  => 22434,
                         "bustling"                => 15876,
                         "busway"                  => 18523,
                         "butte"                   => 8508,
                         "buttes"                  => 24370,
                         "buttress"                => 17969,
                         "buttresses"              => 12595,
                         "butyl"                   => 26665,
                         "buuren"                  => 29948,
                         "buyout"                  => 10919,
                         "buzau"                   => 27287,
                         "buzzcocks"               => 23443,
                         "by"                      => 11,
                         "bycatch"                 => 26845,
                         "bydgoszcz"               => 10998,
                         "byelection"              => 29369,
                         "bygone"                  => 25698,
                         "bylaw"                   => 26866,
                         "bypass"                  => 4194,
                         "bypassed"                => 9581,
                         "bypasses"                => 14115,
                         "bypassing"               => 10807,
                         "byproduct"               => 16270,
                         "byproducts"              => 22059,
                         "byrds"                   => 13297,
                         "bystrica"                => 17062,
                         "bytes"                   => 9429,
                         "bytom"                   => 27592,
                         "bytow"                   => 22582,
                         "byung"                   => 24565,
                         "byway"                   => 13632,
                         "byzantine"               => 2905,
                         "byzantines"              => 9367,
                         "byzantium"               => 11090,
                         "caballeros"              => 25590,
                         "cabaret"                 => 7104,
                         "cabildo"                 => 22841,
                         "cabinet"                 => 1692,
                         "cabins"                  => 7843,
                         "cable"                   => 1770,
                         "cables"                  => 5750,
                         "cablevision"             => 19248,
                         "cabling"                 => 22119,
                         "cabrillo"                => 26797,
                         "cabriolet"               => 22345,
                         "cacak"                   => 27552,
                         "cacao"                   => 18579,
                         "cache"                   => 6620,
                         "caches"                  => 16072,
                         "caching"                 => 21052,
                         "cacti"                   => 18366,
                         "cadastral"               => 17974,
                         "cadbury"                 => 13147,
                         "caddo"                   => 15798,
                         "cadell"                  => 28677,
                         "cadet"                   => 4639,
                         "cadets"                  => 5343,
                         "cadfael"                 => 26262,
                         "cadre"                   => 10458,
                         "cadres"                  => 13887,
                         "caernarfon"              => 20695,
                         "caerphilly"              => 22503,
                         "caesarea"                => 14478,
                         "caesarean"               => 25349,
                         "caesars"                 => 15424,
                         "caesium"                 => 18326,
                         "caetano"                 => 17119,
                         "cafe"                    => 3134,
                         "cafes"                   => 8151,
                         "cafeterias"              => 29192,
                         "caffe"                   => 23804,
                         "cagayan"                 => 13916,
                         "cagliari"                => 12324,
                         "caguas"                  => 28613,
                         "cahiers"                 => 26710,
                         "caicos"                  => 16544,
                         "caird"                   => 27712,
                         "cairn"                   => 11769,
                         "cairo"                   => 4146,
                         "caisson"                 => 27719,
                         "caithness"               => 15226,
                         "caius"                   => 16690,
                         "cajon"                   => 21607,
                         "calabar"                 => 23169,
                         "calabria"                => 9528,
                         "calabrian"               => 29263,
                         "calais"                  => 7851,
                         "calamities"              => 24964,
                         "calatrava"               => 23857,
                         "calaveras"               => 25099,
                         "calcareous"              => 13674,
                         "calcite"                 => 17393,
                         "calcium"                 => 4899,
                         "calculate"               => 6709,
                         "calculated"              => 3798,
                         "calculates"              => 16680,
                         "calculation"             => 6089,
                         "calculations"            => 6196,
                         "calculators"             => 15142,
                         "calculus"                => 6879,
                         "calcutta"                => 4974,
                         "caldas"                  => 17348,
                         "caledon"                 => 22485,
                         "caledonia"               => 7073,
                         "caledonian"              => 8690,
                         "calendar"                => 2517,
                         "calendars"               => 11566,
                         "calibers"                => 21827,
                         "calibration"             => 11506,
                         "calibre"                 => 10276,
                         "calicut"                 => 13854,
                         "calif."                  => 23319,
                         "california"              => 321,
                         "californian"             => 11763,
                         "californians"            => 23983,
                         "californica"             => 22858,
                         "calinescu"               => 24421,
                         "calipers"                => 27163,
                         "caliph"                  => 7587,
                         "caliphate"               => 9081,
                         "caliphs"                 => 20238,
                         "callao"                  => 17749,
                         "called"                  => 116,
                         "calligrapher"            => 21960,
                         "calligraphic"            => 26877,
                         "calligraphy"             => 10770,
                         "calliostoma"             => 21685,
                         "callsign"                => 10742,
                         "callus"                  => 22737,
                         "caloptilia"              => 23207,
                         "caloric"                 => 25321,
                         "caltech"                 => 13741,
                         "calthorpe"               => 28987,
                         "caltrans"                => 26100,
                         "calum"                   => 26248,
                         "calumet"                 => 13442,
                         "calvados"                => 17242,
                         "calvinism"               => 17302,
                         "calvinist"               => 11741,
                         "calvinistic"             => 25848,
                         "calvinists"              => 22060,
                         "calyx"                   => 17663,
                         "camanachd"               => 29979,
                         "camarines"               => 21102,
                         "camas"                   => 25563,
                         "camberley"               => 22799,
                         "camberwell"              => 14990,
                         "cambodia"                => 4648,
                         "cambodian"               => 8124,
                         "cambodians"              => 28180,
                         "camborne"                => 29262,
                         "cambrai"                 => 14523,
                         "cambrian"                => 9217,
                         "cambridge"               => 1507,
                         "cambridgeshire"          => 8111,
                         "cameo"                   => 4873,
                         "cameos"                  => 12436,
                         "cameramen"               => 29489,
                         "camerata"                => 25462,
                         "cameroon"                => 5096,
                         "cameroonian"             => 14693,
                         "camillus"                => 26012,
                         "cammell"                 => 24079,
                         "camogie"                 => 11421,
                         "camorra"                 => 24172,
                         "camouflage"              => 8551,
                         "camouflaged"             => 18154,
                         "camp"                    => 788,
                         "campaign"                => 500,
                         "campaigned"              => 5636,
                         "campaigner"              => 12046,
                         "campaigners"             => 17364,
                         "campaigning"             => 6348,
                         "campaigns"               => 2486,
                         "campania"                => 12457,
                         "campanian"               => 23256,
                         "campanile"               => 23445,
                         "campbells"               => 27295,
                         "campbelltown"            => 20771,
                         "campeche"                => 17880,
                         "campeonato"              => 7401,
                         "camperdown"              => 24006,
                         "campground"              => 10361,
                         "campgrounds"             => 17106,
                         "camphor"                 => 23904,
                         "campinas"                => 22263,
                         "camps"                   => 2648,
                         "campsites"               => 13793,
                         "campus"                  => 819,
                         "campuses"                => 4343,
                         "campy"                   => 26541,
                         "camshaft"                => 14716,
                         "camshafts"               => 26918,
                         "camus"                   => 16800,
                         "canaan"                  => 11050,
                         "canaanite"               => 19429,
                         "canadair"                => 29649,
                         "canadensis"              => 20883,
                         "canadian"                => 467,
                         "canadians"               => 5715,
                         "canadiens"               => 7060,
                         "canal"                   => 1429,
                         "canal+"                  => 20424,
                         "canals"                  => 6043,
                         "canandaigua"             => 24519,
                         "canara"                  => 23353,
                         "canaria"                 => 19442,
                         "canarian"                => 25846,
                         "canaveral"               => 15852,
                         "canberra"                => 4907,
                         "cancellara"              => 28161,
                         "cancellation"            => 5513,
                         "cancelled"               => 2806,
                         "cancerous"               => 18041,
                         "cancers"                 => 8776,
                         "cancion"                 => 25991,
                         "candidacy"               => 6212,
                         "candidate"               => 1051,
                         "candidates"              => 1548,
                         "candidature"             => 19847,
                         "candido"                 => 16718,
                         "caney"                   => 29764,
                         "canis"                   => 14365,
                         "canisius"                => 24649,
                         "canna"                   => 29442,
                         "cannabinoid"             => 25472,
                         "cannes"                  => 5382,
                         "cannibalism"             => 13937,
                         "cannibalistic"           => 29818,
                         "cannock"                 => 25307,
                         "cannonball"              => 13057,
                         "cannonballs"             => 29835,
                         "cannons"                 => 6544,
                         "canoe"                   => 5553,
                         "canoeing"                => 9525,
                         "canoeist"                => 16691,
                         "canoer"                  => 11485,
                         "canoes"                  => 10653,
                         "canola"                  => 29910,
                         "canonical"               => 6245,
                         "canonically"             => 25827,
                         "canonization"            => 16039,
                         "canonized"               => 13981,
                         "canons"                  => 7528,
                         "canopies"                => 17733,
                         "canopy"                  => 6464,
                         "canso"                   => 27715,
                         "cantabria"               => 16326,
                         "cantabrian"              => 24220,
                         "cantal"                  => 28787,
                         "cantata"                 => 9798,
                         "cantatas"                => 15119,
                         "canteen"                 => 11796,
                         "canterbury"              => 3562,
                         "cantilever"              => 11657,
                         "cantilevered"            => 22278,
                         "canton"                  => 2892,
                         "cantonal"                => 12957,
                         "cantonese"               => 7915,
                         "cantonment"              => 11783,
                         "cantons"                 => 9334,
                         "cantus"                  => 25605,
                         "canute"                  => 21164,
                         "canvas"                  => 5373,
                         "canvases"                => 13444,
                         "canwest"                 => 23630,
                         "canyon"                  => 3050,
                         "canyons"                 => 11513,
                         "capabilities"            => 3430,
                         "capability"              => 3764,
                         "capablanca"              => 26129,
                         "capacitance"             => 13271,
                         "capacities"              => 7172,
                         "capacitive"              => 22123,
                         "capacitor"               => 10951,
                         "capacitors"              => 11451,
                         "capacity"                => 998,
                         "cape"                    => 1442,
                         "capensis"                => 25186,
                         "capes"                   => 17369,
                         "capillary"               => 13911,
                         "capistrano"              => 23519,
                         "capita"                  => 2423,
                         "capitaine"               => 29134,
                         "capital"                 => 474,
                         "capitalisation"          => 26849,
                         "capitalise"              => 21597,
                         "capitalised"             => 29099,
                         "capitalism"              => 6006,
                         "capitalist"              => 6895,
                         "capitalists"             => 14662,
                         "capitalization"          => 13592,
                         "capitalized"             => 12740,
                         "capitalizing"            => 22260,
                         "capitol"                 => 3524,
                         "capitoline"              => 28707,
                         "capitulated"             => 15997,
                         "capitulation"            => 11457,
                         "cappadocia"              => 17204,
                         "capped"                  => 5077,
                         "cappella"                => 8703,
                         "capping"                 => 16861,
                         "caproni"                 => 24196,
                         "caps"                    => 3616,
                         "capsid"                  => 26727,
                         "capsized"                => 14660,
                         "capstone"                => 20345,
                         "capsule"                 => 6800,
                         "captaincy"               => 9171,
                         "captained"               => 5370,
                         "captaining"              => 14843,
                         "captains"                => 5933,
                         "caption"                 => 13350,
                         "captions"                => 18619,
                         "captives"                => 8349,
                         "captivity"               => 5777,
                         "captor"                  => 29860,
                         "captors"                 => 13312,
                         "capture"                 => 1728,
                         "captured"                => 1083,
                         "captures"                => 7207,
                         "capturing"               => 4369,
                         "capua"                   => 16221,
                         "capuchin"                => 15467,
                         "carabidae"               => 13802,
                         "carabinieri"             => 26022,
                         "carabus"                 => 28565,
                         "caracalla"               => 24923,
                         "caragiale"               => 21303,
                         "carapace"                => 15309,
                         "caravans"                => 15499,
                         "carbide"                 => 13230,
                         "carbines"                => 21625,
                         "carbohydrate"            => 13224,
                         "carbohydrates"           => 13182,
                         "carbon"                  => 2044,
                         "carbonate"               => 8580,
                         "carbonated"              => 19583,
                         "carbonates"              => 24717,
                         "carbondale"              => 17834,
                         "carbonic"                => 26735,
                         "carboniferous"           => 11353,
                         "carbons"                 => 24526,
                         "carbonyl"                => 14074,
                         "carboxyl"                => 29680,
                         "carboxylic"              => 17578,
                         "carburetors"             => 23051,
                         "carburettor"             => 24317,
                         "carburettors"            => 29558,
                         "carcasses"               => 17133,
                         "carcassonne"             => 22426,
                         "carcetti"                => 29443,
                         "carcinogen"              => 24867,
                         "carcinogenic"            => 19594,
                         "carcinoma"               => 11356,
                         "carcinomas"              => 28757,
                         "cardamom"                => 22873,
                         "cardiff"                 => 3519,
                         "cardinalate"             => 23373,
                         "cardinality"             => 19592,
                         "cardinals"               => 3181,
                         "carding"                 => 27826,
                         "cardiomyopathy"          => 22350,
                         "cardiothoracic"          => 28894,
                         "cardiovascular"          => 7979,
                         "career"                  => 119,
                         "careers"                 => 3799,
                         "caregivers"              => 15300,
                         "carell"                  => 20946,
                         "carers"                  => 22248,
                         "caretaker"               => 6906,
                         "caretakers"              => 20181,
                         "carex"                   => 18502,
                         "cargo"                   => 2342,
                         "cargoes"                 => 16403,
                         "carib"                   => 23391,
                         "caribbean"               => 2360,
                         "cariboo"                 => 18747,
                         "caricature"              => 12594,
                         "caricatures"             => 14350,
                         "caricaturist"            => 28508,
                         "caricom"                 => 23523,
                         "caries"                  => 28775,
                         "carillon"                => 15757,
                         "carinae"                 => 14810,
                         "carinthia"               => 12737,
                         "carinthian"              => 26507,
                         "carlist"                 => 14634,
                         "carlists"                => 29417,
                         "carlsson"                => 18849,
                         "carmarthen"              => 14428,
                         "carmarthenshire"         => 15435,
                         "carmelite"               => 14541,
                         "carmelites"              => 20537,
                         "carnarvon"               => 19108,
                         "carnatic"                => 10580,
                         "carnation"               => 17526,
                         "carnaval"                => 19729,
                         "carne"                   => 18535,
                         "carnegie"                => 3965,
                         "carneiro"                => 28598,
                         "carniola"                => 9668,
                         "carnivals"               => 18705,
                         "carnivores"              => 16598,
                         "carnivorous"             => 10993,
                         "carnot"                  => 20433,
                         "carolinas"               => 13405,
                         "carolingian"             => 12105,
                         "carolla"                 => 28605,
                         "carotene"                => 26266,
                         "carpark"                 => 23494,
                         "carpathian"              => 12802,
                         "carpathians"             => 16487,
                         "carpets"                 => 10141,
                         "carpi"                   => 21559,
                         "carre"                   => 16133,
                         "carrefour"               => 22749,
                         "carriages"               => 6692,
                         "carriageway"             => 9789,
                         "carrickfergus"           => 22860,
                         "carried"                 => 837,
                         "carriers"                => 3875,
                         "carries"                 => 2736,
                         "carrollton"              => 15470,
                         "carronades"              => 28439,
                         "cars"                    => 1034,
                         "carstairs"               => 27992,
                         "cartan"                  => 22214,
                         "cartels"                 => 16907,
                         "carteret"                => 19217,
                         "cartesian"               => 11204,
                         "carthaginian"            => 13654,
                         "carthaginians"           => 17780,
                         "carthusian"              => 25159,
                         "cartilage"               => 11321,
                         "cartilaginous"           => 25739,
                         "cartographer"            => 15682,
                         "cartographers"           => 18372,
                         "cartographic"            => 22577,
                         "cartography"             => 16661,
                         "cartooning"              => 21829,
                         "cartoonish"              => 29871,
                         "cartoonist"              => 6845,
                         "cartoonists"             => 13378,
                         "cartridge"               => 5278,
                         "cartridges"              => 7744,
                         "carts"                   => 10777,
                         "carved"                  => 3421,
                         "carvings"                => 8438,
                         "casal"                   => 26560,
                         "casals"                  => 23096,
                         "cascades"                => 10466,
                         "cascadia"                => 29780,
                         "cascading"               => 18976,
                         "casco"                   => 19272,
                         "casein"                  => 28316,
                         "casemate"                => 23290,
                         "casemates"               => 17110,
                         "casement"                => 17965,
                         "cases"                   => 773,
                         "cashel"                  => 16149,
                         "casimir"                 => 9132,
                         "casks"                   => 23092,
                         "caspase"                 => 24074,
                         "caspian"                 => 9018,
                         "cassation"               => 22775,
                         "cassava"                 => 12138,
                         "cassavetes"              => 26576,
                         "cassette"                => 5752,
                         "cassettes"               => 13272,
                         "cassia"                  => 20750,
                         "cassini"                 => 15489,
                         "cassino"                 => 17407,
                         "cast"                    => 834,
                         "castaways"               => 23953,
                         "caste"                   => 5126,
                         "castel"                  => 13358,
                         "castellan"               => 20468,
                         "castelo"                 => 16689,
                         "castes"                  => 8619,
                         "castiel"                 => 27783,
                         "castile"                 => 5403,
                         "castilian"               => 11319,
                         "casting"                 => 3501,
                         "castings"                => 15842,
                         "castle"                  => 715,
                         "castleford"              => 12553,
                         "castlemaine"             => 22521,
                         "castlereagh"             => 21904,
                         "castles"                 => 5601,
                         "castleton"               => 19202,
                         "castletown"              => 22665,
                         "castra"                  => 23470,
                         "castration"              => 21122,
                         "castrum"                 => 23068,
                         "casts"                   => 8711,
                         "casualties"              => 2861,
                         "casualty"                => 7160,
                         "cataclysm"               => 28159,
                         "catalans"                => 18072,
                         "catalog"                 => 4713,
                         "cataloged"               => 24372,
                         "catalogue"               => 4410,
                         "catalogued"              => 14563,
                         "catalonia"               => 6118,
                         "catalunya"               => 12874,
                         "catalyses"               => 15610,
                         "catalysis"               => 15158,
                         "catalyst"                => 6082,
                         "catalysts"               => 12171,
                         "catalytic"               => 8674,
                         "catalyze"                => 19377,
                         "catalyzed"               => 13837,
                         "catalyzes"               => 9964,
                         "catamaran"               => 20472,
                         "catamarca"               => 25330,
                         "catapulted"              => 19999,
                         "catapults"               => 24665,
                         "cataract"                => 15982,
                         "catastrophes"            => 26647,
                         "catastrophic"            => 8512,
                         "catawba"                 => 16742,
                         "catchers"                => 16276,
                         "catchment"               => 7232,
                         "catchphrase"             => 12572,
                         "catchphrases"            => 25188,
                         "catechism"               => 12114,
                         "categoria"               => 27873,
                         "categorical"             => 15585,
                         "categories"              => 2238,
                         "categorised"             => 14729,
                         "categorization"          => 14966,
                         "categorize"              => 17889,
                         "categorized"             => 6790,
                         "categorizes"             => 29013,
                         "categorizing"            => 29283,
                         "category"                => 1337,
                         "catena"                  => 29888,
                         "catenary"                => 22318,
                         "catenin"                 => 27878,
                         "caterpillar"             => 10369,
                         "caterpillars"            => 12674,
                         "caters"                  => 10039,
                         "catesby"                 => 28217,
                         "cathal"                  => 19408,
                         "catharina"               => 19491,
                         "catharines"              => 15484,
                         "cathedral"               => 1478,
                         "cathedrals"              => 10214,
                         "cathode"                 => 10787,
                         "catholic"                => 598,
                         "catholicism"             => 5260,
                         "catholicos"              => 16330,
                         "catholics"               => 3624,
                         "catholique"              => 23114,
                         "cation"                  => 13990,
                         "cationic"                => 27443,
                         "cations"                 => 16846,
                         "catocala"                => 25310,
                         "catolica"                => 16947,
                         "catshark"                => 23388,
                         "catskill"                => 15277,
                         "cattaraugus"             => 25999,
                         "catterick"               => 29070,
                         "cattle"                  => 2444,
                         "cauca"                   => 19329,
                         "caucasians"              => 25353,
                         "caucasus"                => 5940,
                         "cauchy"                  => 13963,
                         "caucus"                  => 5903,
                         "caucuses"                => 15939,
                         "caudal"                  => 11066,
                         "causa"                   => 13701,
                         "causal"                  => 9290,
                         "causality"               => 15899,
                         "causation"               => 16090,
                         "causative"               => 15848,
                         "caused"                  => 738,
                         "causes"                  => 1577,
                         "causeway"                => 7868,
                         "causing"                 => 1663,
                         "cautioned"               => 15534,
                         "cautions"                => 17500,
                         "cauvery"                 => 29244,
                         "cavaliers"               => 8925,
                         "cavalli"                 => 23685,
                         "cavalry"                 => 1927,
                         "cavalrymen"              => 19158,
                         "cavan"                   => 11827,
                         "cavendish"               => 8605,
                         "cavernous"               => 27177,
                         "caverns"                 => 12971,
                         "caversham"               => 25619,
                         "caves"                   => 4350,
                         "cavitation"              => 28927,
                         "cavite"                  => 12012,
                         "cavities"                => 12053,
                         "cavity"                  => 6067,
                         "cavour"                  => 25890,
                         "caxias"                  => 25460,
                         "caxton"                  => 23324,
                         "cayley"                  => 17527,
                         "cbeebies"                => 29634,
                         "cd+dvd"                  => 28097,
                         "cd/dvd"                  => 18576,
                         "ceara"                   => 17688,
                         "ceased"                  => 2436,
                         "ceasefire"               => 8317,
                         "ceasing"                 => 14858,
                         "ceausescu"               => 15902,
                         "cebuano"                 => 22652,
                         "cedar"                   => 4249,
                         "ceded"                   => 6695,
                         "ceding"                  => 20759,
                         "ceiba"                   => 28462,
                         "ceilings"                => 8950,
                         "celebes"                 => 27956,
                         "celebi"                  => 25682,
                         "celebrant"               => 28434,
                         "celebrated"              => 1980,
                         "celebrates"              => 7481,
                         "celebrations"            => 4128,
                         "celebrities"             => 4355,
                         "celebrity"               => 3284,
                         "celestial"               => 6697,
                         "celje"                   => 18389,
                         "cellars"                 => 12747,
                         "celle"                   => 16554,
                         "cellist"                 => 10268,
                         "cello"                   => 6225,
                         "cellos"                  => 24513,
                         "cells"                   => 1260,
                         "cellular"                => 4570,
                         "celluloid"               => 21096,
                         "cellulose"               => 11413,
                         "celsius"                 => 10438,
                         "celta"                   => 20440,
                         "celts"                   => 13521,
                         "cemented"                => 10194,
                         "cementing"               => 19984,
                         "cements"                 => 25420,
                         "cemeteries"              => 6090,
                         "cemetery"                => 1252,
                         "cenel"                   => 21073,
                         "cenotaph"                => 17778,
                         "cenozoic"                => 19052,
                         "censored"                => 9540,
                         "censoring"               => 26106,
                         "censors"                 => 12317,
                         "censorship"              => 5195,
                         "census"                  => 368,
                         "censuses"                => 11202,
                         "cent"                    => 3394,
                         "centaurs"                => 25646,
                         "centaurus"               => 26713,
                         "centenary"               => 6408,
                         "centennial"              => 5507,
                         "center"                  => 238,
                         "centered"                => 3178,
                         "centering"               => 13956,
                         "centerline"              => 19262,
                         "centerpiece"             => 10846,
                         "centers"                 => 1928,
                         "centerville"             => 17650,
                         "centimeters"             => 6140,
                         "centimetre"              => 29330,
                         "centimetres"             => 12068,
                         "centipede"               => 22944,
                         "central"                 => 218,
                         "centrale"                => 16962,
                         "centralia"               => 22684,
                         "centralised"             => 14399,
                         "centrality"              => 20175,
                         "centralization"          => 19446,
                         "centralized"             => 7471,
                         "centrally"               => 8286,
                         "centre"                  => 411,
                         "centred"                 => 5667,
                         "centrepiece"             => 18337,
                         "centres"                 => 2945,
                         "centreville"             => 23118,
                         "centric"                 => 10651,
                         "centrifugal"             => 12757,
                         "centrifuge"              => 22676,
                         "centrist"                => 12793,
                         "centro"                  => 7229,
                         "centrum"                 => 18267,
                         "centuries"               => 1404,
                         "centurions"              => 19226,
                         "century"                 => 154,
                         "cephalopod"              => 25001,
                         "cephalopods"             => 17125,
                         "cerambycidae"            => 5569,
                         "ceramic"                 => 5776,
                         "ceramics"                => 6385,
                         "cercle"                  => 12882,
                         "cereals"                 => 11461,
                         "cerebellar"              => 19603,
                         "cerebral"                => 6839,
                         "cerebrospinal"           => 22999,
                         "ceredigion"              => 17569,
                         "ceremonial"              => 4637,
                         "ceremonially"            => 23802,
                         "ceremonies"              => 3813,
                         "ceres"                   => 13252,
                         "cerevisiae"              => 21912,
                         "cerium"                  => 29833,
                         "cerrado"                 => 27077,
                         "cerro"                   => 8497,
                         "certain"                 => 727,
                         "certificate"             => 2994,
                         "certificates"            => 6438,
                         "certification"           => 3635,
                         "certifications"          => 10564,
                         "certified"               => 2396,
                         "certifies"               => 27472,
                         "certify"                 => 16155,
                         "certifying"              => 13691,
                         "certiorari"              => 17622,
                         "cervical"                => 9512,
                         "cesaro"                  => 27636,
                         "ceska"                   => 28530,
                         "ceske"                   => 17952,
                         "cesky"                   => 29879,
                         "cessation"               => 9857,
                         "cession"                 => 15594,
                         "cetaceans"               => 19766,
                         "cetinje"                 => 23689,
                         "ceuta"                   => 18004,
                         "ceylon"                  => 5894,
                         "ceylonese"               => 27086,
                         "cezanne"                 => 16555,
                         "ch'uan"                  => 24662,
                         "chabad"                  => 13822,
                         "chabahar"                => 29793,
                         "chaco"                   => 13409,
                         "chadian"                 => 17238,
                         "chafee"                  => 29399,
                         "chagall"                 => 22043,
                         "chagatai"                => 25128,
                         "chagos"                  => 25986,
                         "chagrin"                 => 14184,
                         "chahar"                  => 15783,
                         "chaharmahal"             => 19149,
                         "chaim"                   => 11588,
                         "chain"                   => 1553,
                         "chaining"                => 24464,
                         "chains"                  => 4035,
                         "chainz"                  => 29823,
                         "chaired"                 => 4279,
                         "chairing"                => 18851,
                         "chairlift"               => 22120,
                         "chairman"                => 790,
                         "chairmanship"            => 10236,
                         "chairmen"                => 11700,
                         "chairperson"             => 7363,
                         "chairwoman"              => 14075,
                         "chaitanya"               => 19286,
                         "chakraborty"             => 16412,
                         "chakri"                  => 28911,
                         "chalcedon"               => 19274,
                         "chalcolithic"            => 28624,
                         "chaldean"                => 15931,
                         "chalice"                 => 14734,
                         "challenge"               => 1295,
                         "challenged"              => 3100,
                         "challenger"              => 4531,
                         "challengers"             => 10616,
                         "challenges"              => 2746,
                         "challenging"             => 4080,
                         "chalon"                  => 24690,
                         "chalons"                 => 29692,
                         "chalukya"                => 19212,
                         "chalukyas"               => 21578,
                         "chama"                   => 29525,
                         "chamber"                 => 1559,
                         "chambered"               => 11612,
                         "chambersburg"            => 23799,
                         "chambery"                => 28676,
                         "chambre"                 => 20369,
                         "chameleon"               => 12300,
                         "chameleons"              => 29901,
                         "chamfered"               => 27810,
                         "champaign"               => 9455,
                         "championed"              => 9013,
                         "championing"             => 18714,
                         "championnat"             => 13865,
                         "champions"               => 1125,
                         "championship"            => 290,
                         "championships"           => 570,
                         "champlain"               => 10366,
                         "chancel"                 => 5638,
                         "chancellery"             => 16613,
                         "chancellor"              => 2528,
                         "chancellors"             => 13732,
                         "chancellorship"          => 27676,
                         "chancellorsville"        => 20232,
                         "chancery"                => 9926,
                         "chand"                   => 11368,
                         "chandan"                 => 21511,
                         "chandi"                  => 28652,
                         "chandigarh"              => 12157,
                         "chandni"                 => 29986,
                         "chandos"                 => 19209,
                         "chandragupta"            => 23379,
                         "chandran"                => 24437,
                         "chandrasekhar"           => 22422,
                         "chang'an"                => 9814,
                         "changchun"               => 17833,
                         "changeable"              => 25680,
                         "changeling"              => 27590,
                         "changeover"              => 21236,
                         "changers"                => 26862,
                         "changes"                 => 705,
                         "changeup"                => 25630,
                         "changi"                  => 17820,
                         "changsha"                => 15522,
                         "chania"                  => 25141,
                         "channel"                 => 581,
                         "channelled"              => 27536,
                         "channels"                => 2187,
                         "chanson"                 => 17182,
                         "chansons"                => 20479,
                         "chanted"                 => 14039,
                         "chanter"                 => 26305,
                         "chantilly"               => 17035,
                         "chantry"                 => 19677,
                         "chants"                  => 10713,
                         "chaotic"                 => 8058,
                         "chaparral"               => 13680,
                         "chapbook"                => 28981,
                         "chapel"                  => 1501,
                         "chapelle"                => 12556,
                         "chapels"                 => 7852,
                         "chaplain"                => 5177,
                         "chaplaincy"              => 21016,
                         "chaplains"               => 11836,
                         "chapter"                 => 1627,
                         "chapters"                => 3067,
                         "chapultepec"             => 25223,
                         "character"               => 418,
                         "characterisation"        => 15644,
                         "characterise"            => 24226,
                         "characterised"           => 5901,
                         "characteristic"          => 2693,
                         "characteristically"      => 13233,
                         "characteristics"         => 2017,
                         "characterization"        => 7745,
                         "characterizations"       => 20130,
                         "characterize"            => 9626,
                         "characterized"           => 2358,
                         "characterizes"           => 12597,
                         "characterizing"          => 15790,
                         "characters"              => 659,
                         "charadriiformesfamily"   => 14711,
                         "charan"                  => 15659,
                         "charaxes"                => 23697,
                         "charcoal"                => 8106,
                         "charcot"                 => 20599,
                         "charente"                => 14110,
                         "charentes"               => 24296,
                         "charged"                 => 1798,
                         "charing"                 => 14032,
                         "chariots"                => 14088,
                         "charismatic"             => 8293,
                         "charitable"              => 3847,
                         "charities"               => 5257,
                         "charlemagne"             => 8641,
                         "charleroi"               => 14954,
                         "charleston"              => 3978,
                         "charlestown"             => 13174,
                         "charleville"             => 24112,
                         "charlevoix"              => 24386,
                         "charlottenburg"          => 22373,
                         "charlottesville"         => 12392,
                         "charlottetown"           => 14710,
                         "chart"                   => 739,
                         "charted"                 => 4217,
                         "charter"                 => 1861,
                         "chartered"               => 4348,
                         "charterhouse"            => 14269,
                         "chartering"              => 29009,
                         "charteris"               => 22129,
                         "charters"                => 8043,
                         "charting"                => 5980,
                         "chartist"                => 28337,
                         "chartres"                => 15084,
                         "charts"                  => 1702,
                         "chasers"                 => 17363,
                         "chasseurs"               => 19988,
                         "chassis"                 => 4187,
                         "chastised"               => 26497,
                         "chateau"                 => 4291,
                         "chateaux"                => 25393,
                         "chatelet"                => 22134,
                         "chater"                  => 28764,
                         "chatillon"               => 21195,
                         "chatsworth"              => 16409,
                         "chattahoochee"           => 17854,
                         "chattanooga"             => 7849,
                         "chatterjee"              => 12797,
                         "chattopadhyay"           => 27612,
                         "chaudhary"               => 17638,
                         "chaumont"                => 26038,
                         "chautauqua"              => 14900,
                         "chauvel"                 => 26016,
                         "chaux"                   => 28861,
                         "chavo"                   => 22934,
                         "cheaply"                 => 14575,
                         "chebyshev"               => 28208,
                         "chechen"                 => 9708,
                         "chechens"                => 21315,
                         "chechnya"                => 12579,
                         "checkerboard"            => 27002,
                         "checkpoints"             => 13054,
                         "checksum"                => 25596,
                         "chedi"                   => 29868,
                         "cheeked"                 => 25755,
                         "cheerfully"              => 27725,
                         "cheeses"                 => 14327,
                         "cheetahs"                => 16790,
                         "cheil"                   => 17575,
                         "cheka"                   => 28484,
                         "chekhov"                 => 13578,
                         "chelan"                  => 27241,
                         "chelm"                   => 18313,
                         "chelmno"                 => 25266,
                         "chelmsford"              => 11208,
                         "cheltenham"              => 6470,
                         "chelyabinsk"             => 17517,
                         "chemical"                => 1514,
                         "chemically"              => 10323,
                         "chemicals"               => 4538,
                         "chemin"                  => 17259,
                         "chemins"                 => 23174,
                         "chemistry"               => 2284,
                         "chemists"                => 12557,
                         "chemnitz"                => 18130,
                         "chemotherapy"            => 9117,
                         "chemung"                 => 27731,
                         "chenango"                => 25283,
                         "chenar"                  => 22424,
                         "chengde"                 => 24811,
                         "chengdu"                 => 10283,
                         "chennai"                 => 4372,
                         "chepstow"                => 22171,
                         "chequered"               => 24085,
                         "chera"                   => 23135,
                         "cherbourg"               => 13430,
                         "chernigov"               => 29777,
                         "chernihiv"               => 26372,
                         "chernivtsi"              => 26490,
                         "chernobyl"               => 13769,
                         "cherokees"               => 23576,
                         "chert"                   => 21807,
                         "chertsey"                => 22334,
                         "cherwell"                => 25092,
                         "chesapeake"              => 6858,
                         "chesham"                 => 20819,
                         "cheshmeh"                => 11570,
                         "chess"                   => 2598,
                         "chesterfield"            => 7561,
                         "chetnik"                 => 18709,
                         "chetniks"                => 17414,
                         "chettiar"                => 29681,
                         "chetwynd"                => 26620,
                         "chevrons"                => 23307,
                         "chhatrapati"             => 27890,
                         "chhattisgarh"            => 13044,
                         "chiapas"                 => 11170,
                         "chiaroscuro"             => 28414,
                         "chiba"                   => 9780,
                         "chicagoland"             => 27032,
                         "chicane"                 => 19699,
                         "chichester"              => 8047,
                         "chickamauga"             => 16622,
                         "chickasaw"               => 13614,
                         "chicopee"                => 29482,
                         "chicoutimi"              => 29808,
                         "chidambaram"             => 19305,
                         "chief"                   => 407,
                         "chiefdom"                => 22270,
                         "chiefdoms"               => 26924,
                         "chiefly"                 => 5354,
                         "chieftain"               => 9619,
                         "chieftains"              => 11649,
                         "chievo"                  => 19798,
                         "chihuahua"               => 9941,
                         "chikara"                 => 17719,
                         "chilcotin"               => 29255,
                         "childcare"               => 15153,
                         "childe"                  => 24528,
                         "childhood"               => 1971,
                         "childless"               => 9059,
                         "children"                => 201,
                         "chile"                   => 2336,
                         "chilean"                 => 4091,
                         "chileans"                => 22543,
                         "chillicothe"             => 20761,
                         "chilliwack"              => 21389,
                         "chiloe"                  => 24579,
                         "chiltern"                => 14861,
                         "chimneys"                => 10175,
                         "chimpanzees"             => 13486,
                         "china"                   => 453,
                         "chine"                   => 26123,
                         "chinensis"               => 25289,
                         "chinese"                 => 516,
                         "chionodes"               => 28076,
                         "chios"                   => 19247,
                         "chipmunks"               => 17558,
                         "chippenham"              => 19928,
                         "chippewa"                => 11358,
                         "chipset"                 => 16307,
                         "chipsets"                => 22150,
                         "chirac"                  => 16488,
                         "chiral"                  => 12988,
                         "chiranjeevi"             => 26811,
                         "chiropractic"            => 13986,
                         "chishti"                 => 25823,
                         "chisinau"                => 13256,
                         "chiswick"                => 16744,
                         "chita"                   => 21762,
                         "chitral"                 => 22504,
                         "chittagong"              => 10254,
                         "chittoor"                => 28176,
                         "chivalric"               => 22940,
                         "chiyoda"                 => 27380,
                         "chloride"                => 6358,
                         "chlorides"               => 27076,
                         "chlorinated"             => 27039,
                         "chlorine"                => 9955,
                         "chlorophyll"             => 17464,
                         "chloroplast"             => 23432,
                         "chloroplasts"            => 21966,
                         "choctaw"                 => 10468,
                         "choir"                   => 2469,
                         "choirmaster"             => 22670,
                         "choirs"                  => 8182,
                         "choiseul"                => 26900,
                         "chojnice"                => 24819,
                         "chola"                   => 8914,
                         "cholas"                  => 18048,
                         "cholera"                 => 8759,
                         "choline"                 => 25983,
                         "cholmondeley"            => 24366,
                         "chongqing"               => 10322,
                         "chopra"                  => 10118,
                         "choral"                  => 5314,
                         "chorale"                 => 10267,
                         "chord"                   => 5179,
                         "chords"                  => 7074,
                         "choreographed"           => 8081,
                         "choreographer"           => 6962,
                         "choreographers"          => 15879,
                         "choreographic"           => 24454,
                         "choreography"            => 7149,
                         "chorister"               => 25548,
                         "choristers"              => 21883,
                         "chorley"                 => 15565,
                         "chorlton"                => 27634,
                         "chorus"                  => 3031,
                         "choruses"                => 12133,
                         "chosen"                  => 1224,
                         "choshu"                  => 27268,
                         "chota"                   => 26863,
                         "chowk"                   => 17050,
                         "christchurch"            => 5764,
                         "christendom"             => 18350,
                         "christened"              => 9633,
                         "christgau"               => 14451,
                         "christiania"             => 15730,
                         "christianity"            => 2546,
                         "christianization"        => 19926,
                         "christianized"           => 26063,
                         "christians"              => 2708,
                         "christology"             => 26108,
                         "christoph"               => 8686,
                         "christus"                => 27373,
                         "chroma"                  => 20963,
                         "chromatic"               => 10222,
                         "chromatin"               => 16865,
                         "chromatography"          => 13866,
                         "chromosomal"             => 15001,
                         "chromosome"              => 6086,
                         "chromosomes"             => 8874,
                         "chronicle"               => 3429,
                         "chronicled"              => 11260,
                         "chronicler"              => 10551,
                         "chroniclers"             => 16642,
                         "chronicles"              => 4656,
                         "chronicling"             => 15102,
                         "chronicon"               => 22219,
                         "chronological"           => 7051,
                         "chronologically"         => 12664,
                         "chronology"              => 7610,
                         "chrysalis"               => 16669,
                         "chrysanthemum"           => 23740,
                         "chrysostom"              => 20247,
                         "chukchi"                 => 23640,
                         "chukotka"                => 29820,
                         "chulalongkorn"           => 20042,
                         "church"                  => 147,
                         "churches"                => 1403,
                         "churchmen"               => 24839,
                         "churchyard"              => 6946,
                         "chuvash"                 => 21882,
                         "ciaran"                  => 17088,
                         "cibernetico"             => 23083,
                         "cicada"                  => 26732,
                         "cichlids"                => 25142,
                         "ciconiiformesfamily"     => 27985,
                         "cidade"                  => 24392,
                         "ciechanow"               => 24915,
                         "cielo"                   => 18167,
                         "ciencias"                => 25244,
                         "cieszyn"                 => 14915,
                         "cilia"                   => 15197,
                         "ciliary"                 => 29803,
                         "cilicia"                 => 13940,
                         "cilla"                   => 23298,
                         "cimarron"                => 18141,
                         "cincinnati"              => 2616,
                         "cinema"                  => 1985,
                         "cinemas"                 => 6724,
                         "cinemascope"             => 23571,
                         "cinematheque"            => 28068,
                         "cinematic"               => 7632,
                         "cinematographer"         => 7463,
                         "cinematographers"        => 19922,
                         "cinematographic"         => 29712,
                         "cinematography"          => 7019,
                         "cineplex"                => 25654,
                         "cinerama"                => 28883,
                         "cinerea"                 => 27734,
                         "cingulate"               => 27582,
                         "ciphers"                 => 17939,
                         "ciphertext"              => 21546,
                         "circa"                   => 4745,
                         "circadian"               => 15427,
                         "circassian"              => 18839,
                         "circassians"             => 22932,
                         "circe"                   => 19453,
                         "circle"                  => 1740,
                         "circuit"                 => 1425,
                         "circuitous"              => 27345,
                         "circuitry"               => 12586,
                         "circuits"                => 4854,
                         "circular"                => 3069,
                         "circulated"              => 6248,
                         "circulates"              => 25049,
                         "circulating"             => 8060,
                         "circulation"             => 3065,
                         "circumflex"              => 29935,
                         "circumnavigation"        => 17199,
                         "circumpolar"             => 26878,
                         "circumscribed"           => 17822,
                         "circumscription"         => 26290,
                         "circumvent"              => 14048,
                         "circumvented"            => 26559,
                         "circuses"                => 20274,
                         "cirencester"             => 19434,
                         "cisse"                   => 28072,
                         "cistercian"              => 11024,
                         "cistercians"             => 26018,
                         "cistern"                 => 18069,
                         "cisterns"                => 21410,
                         "citation"                => 4048,
                         "citations"               => 6866,
                         "cited"                   => 2098,
                         "cites"                   => 5778,
                         "cities"                  => 760,
                         "citigroup"               => 17398,
                         "citing"                  => 3166,
                         "citizen"                 => 2470,
                         "citizenry"               => 18005,
                         "citizens"                => 1272,
                         "citizenship"             => 3214,
                         "citrate"                 => 21922,
                         "citric"                  => 22396,
                         "citta"                   => 15403,
                         "city"                    => 54,
                         "cityscape"               => 17765,
                         "citytv"                  => 24818,
                         "ciudad"                  => 7651,
                         "civet"                   => 25207,
                         "civic"                   => 2897,
                         "civil"                   => 463,
                         "civilian"                => 2241,
                         "civilians"               => 3378,
                         "civilisation"            => 12075,
                         "civilisations"           => 25997,
                         "civilizations"           => 8688,
                         "civita"                  => 28261,
                         "civitas"                 => 21381,
                         "clackamas"               => 22680,
                         "clacton"                 => 29802,
                         "cladding"                => 15579,
                         "clade"                   => 7640,
                         "clades"                  => 17684,
                         "cladistic"               => 21550,
                         "cladogram"               => 16836,
                         "claes"                   => 20371,
                         "claim"                   => 1282,
                         "claimant"                => 10727,
                         "claimants"               => 11824,
                         "claimed"                 => 802,
                         "claiming"                => 2315,
                         "claims"                  => 1149,
                         "clairvaux"               => 26729,
                         "clan"                    => 2279,
                         "clandestine"             => 8724,
                         "clandestinely"           => 23568,
                         "clann"                   => 20882,
                         "clans"                   => 5887,
                         "clapboard"               => 17421,
                         "clapham"                 => 12422,
                         "claremont"               => 8222,
                         "clarendon"               => 11267,
                         "clarified"               => 8780,
                         "clarifies"               => 23374,
                         "clarin"                  => 28332,
                         "clarinetist"             => 16828,
                         "clarinets"               => 17183,
                         "clarksburg"              => 25381,
                         "clarksville"             => 15951,
                         "clash"                   => 4985,
                         "clashed"                 => 8192,
                         "clashes"                 => 6198,
                         "clasico"                 => 26261,
                         "clasps"                  => 22196,
                         "class"                   => 284,
                         "classed"                 => 8683,
                         "classes"                 => 1140,
                         "classical"               => 1201,
                         "classically"             => 11556,
                         "classicism"              => 15529,
                         "classicist"              => 18547,
                         "classification"          => 1917,
                         "classifications"         => 8128,
                         "classified"              => 2006,
                         "classifier"              => 19878,
                         "classifiers"             => 24009,
                         "classifies"              => 13278,
                         "classify"                => 9144,
                         "classifying"             => 12890,
                         "classmate"               => 9106,
                         "classroom"               => 3972,
                         "classrooms"              => 4371,
                         "claudius"                => 8719,
                         "clause"                  => 3913,
                         "clauses"                 => 7955,
                         "clausura"                => 11904,
                         "clays"                   => 15420,
                         "cleanly"                 => 21913,
                         "clearances"              => 15724,
                         "clearest"                => 25415,
                         "clearfield"              => 19833,
                         "clearinghouse"           => 23002,
                         "clearings"               => 21841,
                         "clearwater"              => 10193,
                         "cleave"                  => 18275,
                         "cleaved"                 => 19944,
                         "cleburne"                => 23534,
                         "cleese"                  => 19948,
                         "cleethorpes"             => 29301,
                         "cleeve"                  => 29380,
                         "cleft"                   => 13153,
                         "clemenceau"              => 23469,
                         "cleon"                   => 28934,
                         "clerestory"              => 17239,
                         "clergy"                  => 3941,
                         "clergyman"               => 7582,
                         "clergymen"               => 14801,
                         "clerical"                => 7929,
                         "clerics"                 => 10157,
                         "clerked"                 => 24792,
                         "clerkenwell"             => 25404,
                         "clermont"                => 9769,
                         "clevedon"                => 28597,
                         "cleves"                  => 17096,
                         "cliched"                 => 23363,
                         "cliches"                 => 14760,
                         "cliffs"                  => 5357,
                         "cliftonville"            => 29029,
                         "clijsters"               => 21810,
                         "climactic"               => 14958,
                         "climate"                 => 1166,
                         "climates"                => 8135,
                         "climatic"                => 8765,
                         "climatology"             => 27869,
                         "climbers"                => 9566,
                         "climbs"                  => 7566,
                         "clinch"                  => 9790,
                         "clinched"                => 8622,
                         "clinching"               => 14808,
                         "clinical"                => 2116,
                         "clinician"               => 17741,
                         "clinicians"              => 14152,
                         "clinics"                 => 6298,
                         "clinker"                 => 25048,
                         "clique"                  => 11466,
                         "cliques"                 => 24069,
                         "clitheroe"               => 23052,
                         "clive"                   => 6158,
                         "clivina"                 => 21613,
                         "cloaks"                  => 28522,
                         "clockmaker"              => 29354,
                         "clockwise"               => 7784,
                         "cloister"                => 11028,
                         "cloisters"               => 19976,
                         "clonal"                  => 26135,
                         "clones"                  => 8907,
                         "clonmel"                 => 25623,
                         "clontarf"                => 23028,
                         "closed"                  => 683,
                         "closely"                 => 1571,
                         "clostridium"             => 23844,
                         "closure"                 => 2801,
                         "closures"                => 11214,
                         "cloth"                   => 4442,
                         "clothing"                => 2480,
                         "cloverdale"              => 29063,
                         "cloverleaf"              => 14995,
                         "cloyne"                  => 29177,
                         "club"                    => 131,
                         "clube"                   => 7440,
                         "clubs"                   => 971,
                         "clumps"                  => 16253,
                         "cluny"                   => 17116,
                         "cluster"                 => 3637,
                         "clustered"               => 11009,
                         "clustering"              => 12964,
                         "clusters"                => 4717,
                         "clwyd"                   => 22261,
                         "clydebank"               => 19320,
                         "coach"                   => 466,
                         "coached"                 => 2869,
                         "coachella"               => 16051,
                         "coaches"                 => 2501,
                         "coaching"                => 2097,
                         "coadjutor"               => 15705,
                         "coagulation"             => 18661,
                         "coahuila"                => 13984,
                         "coal"                    => 1575,
                         "coalesce"                => 23769,
                         "coalesced"               => 22599,
                         "coalfield"               => 14508,
                         "coalfields"              => 22104,
                         "coaling"                 => 27763,
                         "coalition"               => 1914,
                         "coalitions"              => 13181,
                         "coarse"                  => 8491,
                         "coarser"                 => 24989,
                         "coast"                   => 507,
                         "coastal"                 => 1759,
                         "coastline"               => 5492,
                         "coastlines"              => 18812,
                         "coasts"                  => 6844,
                         "coatbridge"              => 23773,
                         "coated"                  => 7150,
                         "coating"                 => 7496,
                         "coatings"                => 11454,
                         "coauthor"                => 26285,
                         "coauthored"              => 19309,
                         "coaxial"                 => 15225,
                         "cobbled"                 => 21930,
                         "cobbles"                 => 29952,
                         "cobblestone"             => 20491,
                         "cobden"                  => 22705,
                         "cobham"                  => 14159,
                         "cobol"                   => 26407,
                         "cobourg"                 => 28645,
                         "coburg"                  => 10431,
                         "cochabamba"              => 19360,
                         "cochin"                  => 9617,
                         "cochlea"                 => 28990,
                         "cochlear"                => 20862,
                         "cockatoo"                => 19244,
                         "cockerell"               => 22556,
                         "cocking"                 => 27023,
                         "cockpit"                 => 5890,
                         "cockpits"                => 21368,
                         "cocos"                   => 18537,
                         "code"                    => 887,
                         "codec"                   => 15832,
                         "codecs"                  => 21306,
                         "codeine"                 => 22795,
                         "codename"                => 12575,
                         "codenamed"               => 11621,
                         "codes"                   => 3317,
                         "codeshare"               => 26913,
                         "codex"                   => 5618,
                         "codice_1"                => 9061,
                         "codice_10"               => 28827,
                         "codice_2"                => 12576,
                         "codice_3"                => 15497,
                         "codice_4"                => 17144,
                         "codice_5"                => 19876,
                         "codice_6"                => 21724,
                         "codice_7"                => 23661,
                         "codice_8"                => 25196,
                         "codice_9"                => 27098,
                         "codices"                 => 19361,
                         "codification"            => 18684,
                         "codified"                => 10112,
                         "coding"                  => 6201,
                         "codon"                   => 20390,
                         "codrington"              => 25209,
                         "coeducational"           => 9677,
                         "coefficient"             => 6666,
                         "coefficients"            => 7199,
                         "coenzyme"                => 22208,
                         "coercive"                => 15617,
                         "coetzee"                 => 22739,
                         "coeur"                   => 12118,
                         "coexisted"               => 28071,
                         "coexistence"             => 15802,
                         "cofactor"                => 18514,
                         "cofounded"               => 23053,
                         "cofounder"               => 21349,
                         "cognate"                 => 12077,
                         "cognates"                => 23099,
                         "cognition"               => 9195,
                         "cognitive"               => 3772,
                         "cognomen"                => 25540,
                         "cohabitation"            => 22257,
                         "coherence"               => 12259,
                         "coherent"                => 7905,
                         "cohesion"                => 11130,
                         "cohesive"                => 11512,
                         "cohomology"              => 13460,
                         "cohort"                  => 10843,
                         "cohorts"                 => 16956,
                         "coiled"                  => 13950,
                         "coils"                   => 11107,
                         "coimbatore"              => 10947,
                         "coimbra"                 => 11550,
                         "coin"                    => 3809,
                         "coinage"                 => 8232,
                         "coincide"                => 6758,
                         "coincided"               => 6451,
                         "coincident"              => 24068,
                         "coincidentally"          => 8822,
                         "coincides"               => 11044,
                         "coinciding"              => 10131,
                         "coined"                  => 4449,
                         "coining"                 => 16385,
                         "coins"                   => 2888,
                         "coking"                  => 27029,
                         "col."                    => 5167,
                         "colborne"                => 26344,
                         "colchester"              => 6699,
                         "coldest"                 => 12241,
                         "coldfield"               => 22282,
                         "coldstream"              => 18789,
                         "coldwater"               => 17664,
                         "colegio"                 => 10104,
                         "coleophora"              => 10353,
                         "coleophoridae"           => 18724,
                         "coleoptera"              => 27296,
                         "coleraine"               => 16996,
                         "coleridge"               => 10357,
                         "colima"                  => 19496,
                         "coliseum"                => 6814,
                         "collaborate"             => 7275,
                         "collaborated"            => 2978,
                         "collaborates"            => 12069,
                         "collaborating"           => 6960,
                         "collaboration"           => 1885,
                         "collaborationist"        => 24179,
                         "collaborations"          => 5454,
                         "collaborative"           => 4588,
                         "collaboratively"         => 18582,
                         "collaborator"            => 6696,
                         "collaborators"           => 7192,
                         "collagen"                => 12230,
                         "collages"                => 18271,
                         "collapse"                => 2868,
                         "collapses"               => 9590,
                         "collapsible"             => 25423,
                         "collated"                => 17233,
                         "colle"                   => 20985,
                         "colleagues"              => 3197,
                         "collectable"             => 27051,
                         "collected"               => 1688,
                         "collectible"             => 12085,
                         "collectibles"            => 17989,
                         "collecting"              => 3572,
                         "collection"              => 602,
                         "collections"             => 1955,
                         "collective"              => 2602,
                         "collectively"            => 4728,
                         "collectives"             => 21454,
                         "collectivization"        => 22372,
                         "collector"               => 3759,
                         "collectors"              => 4905,
                         "collects"                => 7605,
                         "college"                 => 137,
                         "colleges"                => 1926,
                         "collegiate"              => 3006,
                         "collegiately"            => 17886,
                         "collegio"                => 26630,
                         "collegium"               => 14969,
                         "collided"                => 7986,
                         "collider"                => 20023,
                         "colliding"               => 15777,
                         "collieries"              => 13947,
                         "colliers"                => 24833,
                         "colliery"                => 6777,
                         "collingwood"             => 7202,
                         "collision"               => 4669,
                         "collisions"              => 9255,
                         "colloidal"               => 26299,
                         "colloquial"              => 10044,
                         "colloquially"            => 7785,
                         "colloquium"              => 26204,
                         "colmar"                  => 22322,
                         "colne"                   => 18295,
                         "cologne"                 => 4577,
                         "colombian"               => 4835,
                         "colombians"              => 26835,
                         "colonels"                => 10292,
                         "colonia"                 => 10636,
                         "colonial"                => 1565,
                         "colonialism"             => 10174,
                         "colonials"               => 17777,
                         "colonies"                => 2798,
                         "colonisation"            => 13555,
                         "colonised"               => 20897,
                         "colonist"                => 18424,
                         "colonists"               => 5501,
                         "colonization"            => 6388,
                         "colonize"                => 16185,
                         "colonized"               => 12428,
                         "colonizers"              => 22675,
                         "colonizing"              => 23716,
                         "colony"                  => 1755,
                         "colophon"                => 25429,
                         "color"                   => 1025,
                         "coloration"              => 9012,
                         "coloratura"              => 26928,
                         "colorectal"              => 18184,
                         "colored"                 => 3187,
                         "colorless"               => 14475,
                         "colour"                  => 2047,
                         "colouration"             => 15690,
                         "coloured"                => 4272,
                         "colourful"               => 8282,
                         "colouring"               => 14223,
                         "colourless"              => 21753,
                         "colours"                 => 3245,
                         "colquhoun"               => 23898,
                         "colspan=12"              => 19081,
                         "colspan=3|total"         => 10988,
                         "colspan=3|turnout"       => 21333,
                         "colspan=9"               => 10400,
                         "colspan=9|"              => 13384,
                         "colt"                    => 5166,
                         "colts"                   => 5043,
                         "columba"                 => 13404,
                         "columbia"                => 978,
                         "columbian"               => 8245,
                         "columbine"               => 17441,
                         "columella"               => 16997,
                         "column"                  => 2054,
                         "columnar"                => 21805,
                         "columnist"               => 4775,
                         "columns"                 => 2792,
                         "colwyn"                  => 24902,
                         "comarca"                 => 12350,
                         "combat"                  => 1216,
                         "combatant"               => 10072,
                         "combatants"              => 9204,
                         "combating"               => 11607,
                         "combats"                 => 23625,
                         "combe"                   => 14091,
                         "combination"             => 1682,
                         "combinations"            => 5405,
                         "combinatorial"           => 13935,
                         "combinatorics"           => 19154,
                         "combine"                 => 4184,
                         "combined"                => 1066,
                         "combines"                => 4730,
                         "combining"               => 4031,
                         "combos"                  => 20720,
                         "combustion"              => 5826,
                         "comdr"                   => 18841,
                         "comeback"                => 4495,
                         "comedian"                => 3900,
                         "comedians"               => 8240,
                         "comedic"                 => 7342,
                         "comedie"                 => 18655,
                         "comedienne"              => 22128,
                         "comedies"                => 7329,
                         "comedy"                  => 1030,
                         "comercio"                => 29791,
                         "comic"                   => 1436,
                         "comical"                 => 11590,
                         "comically"               => 21946,
                         "comics"                  => 1638,
                         "comilla"                 => 25792,
                         "comintern"               => 12776,
                         "comique"                 => 15070,
                         "comitatus"               => 29968,
                         "comite"                  => 17318,
                         "comix"                   => 21287,
                         "command"                 => 607,
                         "commandant"              => 5874,
                         "commanded"               => 2314,
                         "commander"               => 856,
                         "commanders"              => 3986,
                         "commandery"              => 14472,
                         "commanding"              => 2939,
                         "commandos"               => 8672,
                         "commands"                => 4423,
                         "commedia"                => 20032,
                         "commemorate"             => 4765,
                         "commemorated"            => 6543,
                         "commemorates"            => 8298,
                         "commemorating"           => 7215,
                         "commemoration"           => 7547,
                         "commemorations"          => 16408,
                         "commemorative"           => 6351,
                         "commenced"               => 2887,
                         "commencement"            => 7295,
                         "commences"               => 15095,
                         "commencing"              => 8550,
                         "commendation"            => 9080,
                         "commendations"           => 21983,
                         "commended"               => 8264,
                         "commending"              => 26060,
                         "commends"                => 28163,
                         "commentaries"            => 7191,
                         "commentary"              => 3110,
                         "commentated"             => 24606,
                         "commentating"            => 25821,
                         "commentator"             => 4511,
                         "commentators"            => 5451,
                         "commented"               => 2536,
                         "commenting"              => 5646,
                         "comments"                => 2968,
                         "commerce"                => 2064,
                         "commercial"              => 613,
                         "commercialization"       => 13306,
                         "commercialize"           => 25189,
                         "commercialized"          => 16452,
                         "commercially"            => 3723,
                         "commercials"             => 4244,
                         "commissar"               => 13716,
                         "commissariat"            => 17819,
                         "commissars"              => 23219,
                         "commissary"              => 15146,
                         "commission"              => 609,
                         "commissioned"            => 1353,
                         "commissioner"            => 1949,
                         "commissioners"           => 4206,
                         "commissioning"           => 6979,
                         "commissions"             => 4512,
                         "commitments"             => 6393,
                         "commits"                 => 9534,
                         "committee"               => 436,
                         "committeeman"            => 26320,
                         "committees"              => 3177,
                         "commodities"             => 7468,
                         "commodity"               => 6901,
                         "commodore"               => 4654,
                         "commodores"              => 14095,
                         "common"                  => 342,
                         "commonalities"           => 27476,
                         "commonality"             => 21261,
                         "commoners"               => 12920,
                         "commonly"                => 944,
                         "commonplace"             => 9370,
                         "commons"                 => 2461,
                         "commonwealth"            => 1686,
                         "communal"                => 5440,
                         "communally"              => 29378,
                         "communaute"              => 20124,
                         "commune"                 => 1552,
                         "communes"                => 5655,
                         "communicable"            => 25000,
                         "communicated"            => 9487,
                         "communicates"            => 14133,
                         "communication"           => 1516,
                         "communications"          => 1384,
                         "communicative"           => 17136,
                         "communicators"           => 27540,
                         "communion"               => 5746,
                         "communis"                => 27851,
                         "communism"               => 5333,
                         "communist"               => 1266,
                         "communists"              => 4416,
                         "communities"             => 1024,
                         "community"               => 226,
                         "commutation"             => 20387,
                         "commutative"             => 12018,
                         "commutator"              => 25465,
                         "commuted"                => 8100,
                         "commuter"                => 4941,
                         "commuters"               => 9482,
                         "commutes"                => 24823,
                         "commuting"               => 12359,
                         "comoros"                 => 13522,
                         "comox"                   => 29326,
                         "compact"                 => 3297,
                         "compacted"               => 19951,
                         "compaction"              => 24425,
                         "compactness"             => 27025,
                         "compagnie"               => 12480,
                         "compania"                => 19356,
                         "companies"               => 621,
                         "companion"               => 3210,
                         "companions"              => 5625,
                         "company"                 => 113,
                         "comparable"              => 4257,
                         "comparably"              => 28949,
                         "comparative"             => 4698,
                         "comparatively"           => 6833,
                         "compared"                => 1109,
                         "compares"                => 7801,
                         "comparison"              => 2653,
                         "comparisons"             => 6233,
                         "compasses"               => 26192,
                         "compatibility"           => 7120,
                         "compatible"              => 4226,
                         "compatriot"              => 11681,
                         "compatriots"             => 15776,
                         "compendium"              => 11002,
                         "compensate"              => 7007,
                         "compensates"             => 28150,
                         "compensation"            => 3346,
                         "compensatory"            => 17452,
                         "compete"                 => 1675,
                         "competed"                => 929,
                         "competence"              => 7960,
                         "competences"             => 23658,
                         "competencies"            => 15477,
                         "competency"              => 13190,
                         "competes"                => 4895,
                         "competing"               => 2141,
                         "competition"             => 481,
                         "competitions"            => 1945,
                         "competitive"             => 2196,
                         "competitively"           => 15720,
                         "competitiveness"         => 10028,
                         "competitor"              => 4457,
                         "competitors"             => 3423,
                         "compilation"             => 2096,
                         "compilations"            => 7109,
                         "compile"                 => 9799,
                         "compiled"                => 3054,
                         "compiler"                => 7384,
                         "compilers"               => 13209,
                         "compiles"                => 18471,
                         "compiling"               => 7614,
                         "complainant"             => 26162,
                         "complained"              => 4750,
                         "complaints"              => 3981,
                         "complement"              => 4953,
                         "complementary"           => 7154,
                         "complemented"            => 10045,
                         "complementing"           => 19068,
                         "complements"             => 14201,
                         "complete"                => 667,
                         "completed"               => 473,
                         "completeness"            => 14999,
                         "completes"               => 9998,
                         "completing"              => 2606,
                         "completion"              => 2070,
                         "completions"             => 15457,
                         "complex"                 => 704,
                         "complexes"               => 5421,
                         "complexities"            => 14257,
                         "complexity"              => 4076,
                         "compliance"              => 4650,
                         "compliant"               => 8685,
                         "complicity"              => 14460,
                         "complied"                => 11154,
                         "complies"                => 17403,
                         "complutense"             => 27688,
                         "comply"                  => 5435,
                         "complying"               => 17541,
                         "component"               => 2235,
                         "components"              => 1892,
                         "compose"                 => 6674,
                         "composed"                => 824,
                         "composer"                => 1422,
                         "composers"               => 3309,
                         "composes"                => 16501,
                         "composing"               => 5906,
                         "composite"               => 4451,
                         "composites"              => 13433,
                         "compositing"             => 26241,
                         "composition"             => 1551,
                         "compositional"           => 11320,
                         "compositions"            => 2928,
                         "compostela"              => 15014,
                         "composting"              => 20402,
                         "compound"                => 2765,
                         "compounded"              => 11218,
                         "compounding"             => 16533,
                         "compounds"               => 3406,
                         "comprehensible"          => 25457,
                         "comprehensive"           => 2454,
                         "comprehensively"         => 17593,
                         "compressed"              => 6308,
                         "compresses"              => 29499,
                         "compressing"             => 23561,
                         "compression"             => 4838,
                         "compressive"             => 21409,
                         "compressor"              => 10161,
                         "compressors"             => 17336,
                         "comprise"                => 5140,
                         "comprised"               => 4083,
                         "comprises"               => 2772,
                         "comprising"              => 3308,
                         "comptroller"             => 9803,
                         "compulsory"              => 5193,
                         "compuserve"              => 28236,
                         "computable"              => 19911,
                         "computation"             => 7622,
                         "computational"           => 5506,
                         "computationally"         => 18642,
                         "computations"            => 15128,
                         "computed"                => 7696,
                         "computerised"            => 24663,
                         "computerized"            => 11087,
                         "computers"               => 2650,
                         "computes"                => 21532,
                         "computing"               => 3402,
                         "comte"                   => 7255,
                         "comune"                  => 6516,
                         "comuni"                  => 29495,
                         "comyn"                   => 21637,
                         "conakry"                 => 26994,
                         "conall"                  => 29233,
                         "concacaf"                => 7970,
                         "concatenation"           => 28603,
                         "concave"                 => 8999,
                         "conceals"                => 24234,
                         "conceded"                => 7014,
                         "concedes"                => 24294,
                         "conceding"               => 10648,
                         "conceicao"               => 22547,
                         "conceit"                 => 24718,
                         "conceived"               => 3610,
                         "concentrated"            => 3202,
                         "concentrates"            => 11054,
                         "concentration"           => 2376,
                         "concentrations"          => 4954,
                         "concentric"              => 11376,
                         "concept"                 => 1013,
                         "conceptions"             => 13682,
                         "concepts"                => 2832,
                         "conceptual"              => 6048,
                         "conceptualization"       => 25707,
                         "conceptualized"          => 17173,
                         "conceptually"            => 14783,
                         "concerning"              => 2460,
                         "concerns"                => 1968,
                         "concert"                 => 1113,
                         "concerted"               => 12784,
                         "concertgebouw"           => 23655,
                         "concerti"                => 26625,
                         "concertina"              => 29877,
                         "concertmaster"           => 21011,
                         "concerto"                => 4805,
                         "concertos"               => 10966,
                         "concerts"                => 2085,
                         "concession"              => 6481,
                         "concessions"             => 7041,
                         "conciliation"            => 17143,
                         "conciliatory"            => 19841,
                         "concise"                 => 12352,
                         "conclave"                => 10513,
                         "conclude"                => 6341,
                         "concluded"               => 1815,
                         "concludes"               => 5251,
                         "concluding"              => 6127,
                         "conclusion"              => 2571,
                         "concomitant"             => 20393,
                         "concordance"             => 23215,
                         "concordat"               => 17588,
                         "concordia"               => 8511,
                         "concours"                => 20715,
                         "concourse"               => 9721,
                         "concourses"              => 28386,
                         "concubine"               => 12091,
                         "concubines"              => 17301,
                         "concurred"               => 14625,
                         "concurrence"             => 18228,
                         "concurrency"             => 8042,
                         "concurrent"              => 5852,
                         "concurrently"            => 6223,
                         "concurring"              => 18931,
                         "condemnation"            => 9166,
                         "condemned"               => 3775,
                         "condemns"                => 18113,
                         "condensate"              => 20152,
                         "condensation"            => 11201,
                         "condense"                => 24689,
                         "condensed"               => 9060,
                         "condenser"               => 17405,
                         "condensing"              => 21638,
                         "condita"                 => 20845,
                         "conditional"             => 6733,
                         "conditionally"           => 25855,
                         "conditioned"             => 8228,
                         "conditions"              => 884,
                         "condoleezza"             => 23564,
                         "condominium"             => 11329,
                         "condominiums"            => 12651,
                         "condorcet"               => 24064,
                         "condors"                 => 25197,
                         "conducive"               => 13199,
                         "conduct"                 => 2065,
                         "conductance"             => 19764,
                         "conducted"               => 1060,
                         "conducting"              => 3323,
                         "conduction"              => 11285,
                         "conductive"              => 12540,
                         "conductivity"            => 10356,
                         "conductor"               => 3071,
                         "conductors"              => 7604,
                         "conducts"                => 6219,
                         "conduits"                => 24950,
                         "conestoga"               => 22856,
                         "confection"              => 29037,
                         "confectionery"           => 14092,
                         "confederacion"           => 28029,
                         "confederacy"             => 6317,
                         "confederate"             => 2612,
                         "confederates"            => 7881,
                         "confederation"           => 3841,
                         "confederations"          => 13321,
                         "conference"              => 511,
                         "conferences"             => 3066,
                         "conferencing"            => 17257,
                         "conferred"               => 5514,
                         "conferring"              => 17011,
                         "confers"                 => 16209,
                         "confesses"               => 7763,
                         "confessions"             => 8164,
                         "confessor"               => 12223,
                         "confidently"             => 18607,
                         "configurable"            => 23801,
                         "configuration"           => 3304,
                         "configurations"          => 7434,
                         "configure"               => 19853,
                         "configured"              => 8707,
                         "confined"                => 4752,
                         "confinement"             => 8063,
                         "confirmed"               => 1356,
                         "confiscated"             => 6353,
                         "confiscation"            => 13331,
                         "conflagration"           => 26280,
                         "conflated"               => 23315,
                         "conflict"                => 1314,
                         "conflicting"             => 7209,
                         "conflicts"               => 3320,
                         "confluence"              => 4995,
                         "conform"                 => 8037,
                         "conformal"               => 16605,
                         "conformance"             => 24924,
                         "conformation"            => 12275,
                         "conformational"          => 17916,
                         "conformed"               => 19283,
                         "conforming"              => 14656,
                         "conformist"              => 21118,
                         "conformity"              => 10826,
                         "conforms"                => 19063,
                         "confounding"             => 26938,
                         "confraternity"           => 20573,
                         "confrontation"           => 5395,
                         "confrontations"          => 12499,
                         "confronts"               => 6114,
                         "confucian"               => 10272,
                         "confucianism"            => 13710,
                         "confucius"               => 12440,
                         "confusingly"             => 18853,
                         "confusion"               => 3372,
                         "congenital"              => 9220,
                         "congested"               => 13125,
                         "congestion"              => 6841,
                         "congestive"              => 19484,
                         "congke"                  => 27498,
                         "conglomerate"            => 7948,
                         "conglomerates"           => 17429,
                         "congo"                   => 3244,
                         "congolese"               => 10163,
                         "congratulatory"          => 27614,
                         "congregants"             => 25052,
                         "congregate"              => 17668,
                         "congregated"             => 27954,
                         "congregation"            => 2624,
                         "congregational"          => 6971,
                         "congregationalist"       => 20302,
                         "congregations"           => 5532,
                         "congress"                => 731,
                         "congresses"              => 7369,
                         "congressional"           => 2614,
                         "congreve"                => 25660,
                         "congruence"              => 20558,
                         "congruent"               => 17431,
                         "conic"                   => 17161,
                         "conical"                 => 8223,
                         "conidae"                 => 19644,
                         "conidia"                 => 27863,
                         "conifer"                 => 14207,
                         "coniferous"              => 12623,
                         "conifers"                => 15398,
                         "coniston"                => 25992,
                         "conjecture"              => 7503,
                         "conjectured"             => 14323,
                         "conjectures"             => 18506,
                         "conjugate"               => 11104,
                         "conjugated"              => 16050,
                         "conjugation"             => 13156,
                         "conjunction"             => 3280,
                         "conjunctions"            => 25428,
                         "conjunto"                => 28307,
                         "conmebol"                => 17600,
                         "connacht"                => 8964,
                         "connaught"               => 12799,
                         "connected"               => 1211,
                         "connecticut"             => 1876,
                         "connecting"              => 2475,
                         "connections"             => 2437,
                         "connective"              => 13593,
                         "connectivity"            => 7161,
                         "connector"               => 6667,
                         "connectors"              => 10217,
                         "connects"                => 3013,
                         "connemara"               => 25506,
                         "connexion"               => 20362,
                         "connoisseurs"            => 26870,
                         "connotation"             => 14809,
                         "connotations"            => 11974,
                         "conor"                   => 12420,
                         "conquered"               => 3948,
                         "conqueror"               => 9044,
                         "conquerors"              => 17216,
                         "conquest"                => 3145,
                         "conquests"               => 10016,
                         "conquistador"            => 19777,
                         "conquistadors"           => 19257,
                         "conscript"               => 25201,
                         "conscripted"             => 13400,
                         "conscription"            => 8435,
                         "conscripts"              => 15082,
                         "consecrate"              => 26661,
                         "consecrated"             => 4500,
                         "consecration"            => 7963,
                         "consecrators"            => 16134,
                         "consecutive"             => 1614,
                         "consecutively"           => 11806,
                         "conseil"                 => 13088,
                         "consejo"                 => 14661,
                         "consensus"               => 3815,
                         "consent"                 => 3674,
                         "consents"                => 25254,
                         "consequence"             => 3416,
                         "consequent"              => 10238,
                         "consequential"           => 23302,
                         "consequently"            => 2947,
                         "conservancy"             => 9261,
                         "conservation"            => 1698,
                         "conservationist"         => 16587,
                         "conservationists"        => 19259,
                         "conservatism"            => 10835,
                         "conservative"            => 1223,
                         "conservatively"          => 28039,
                         "conservatives"           => 4022,
                         "conservatoire"           => 9667,
                         "conservator"             => 20621,
                         "conservatories"          => 23050,
                         "conservatorio"           => 28460,
                         "conservatorium"          => 18802,
                         "conservators"            => 26333,
                         "conservatory"            => 4145,
                         "conserved"               => 7043,
                         "conserving"              => 16389,
                         "considerable"            => 1924,
                         "considerably"            => 3489,
                         "considerations"          => 5882,
                         "considered"              => 340,
                         "considers"               => 3835,
                         "consigned"               => 20776,
                         "consignment"             => 22693,
                         "consist"                 => 2881,
                         "consisted"               => 1434,
                         "consistency"             => 6557,
                         "consistent"              => 2853,
                         "consistently"            => 3711,
                         "consisting"              => 1613,
                         "consistory"              => 14757,
                         "consists"                => 813,
                         "console"                 => 4203,
                         "consoles"                => 7583,
                         "consolidate"             => 8290,
                         "consolidated"            => 3777,
                         "consolidating"           => 11720,
                         "consolidation"           => 5873,
                         "consonant"               => 6747,
                         "consonants"              => 6683,
                         "consort"                 => 5325,
                         "consortia"               => 26659,
                         "consortium"              => 4312,
                         "consorts"                => 16018,
                         "conspecific"             => 22397,
                         "conspicuous"             => 7418,
                         "conspicuously"           => 18800,
                         "conspirators"            => 9891,
                         "constables"              => 11790,
                         "constabulary"            => 9247,
                         "constancy"               => 28475,
                         "constant"                => 1871,
                         "constanta"               => 17476,
                         "constantia"              => 27814,
                         "constantin"              => 9748,
                         "constantinople"          => 4009,
                         "constantius"             => 16440,
                         "constants"               => 9445,
                         "constellation"           => 5409,
                         "consternation"           => 18984,
                         "constituencies"          => 4438,
                         "constituency"            => 1455,
                         "constituent"             => 4518,
                         "constituents"            => 8010,
                         "constitute"              => 4123,
                         "constituted"             => 4395,
                         "constitutes"             => 6342,
                         "constituting"            => 10562,
                         "constitution"            => 1188,
                         "constitutional"          => 2066,
                         "constitutionality"       => 12522,
                         "constitutionally"        => 12511,
                         "constitutions"           => 10489,
                         "constitutive"            => 18249,
                         "constrain"               => 22750,
                         "constrained"             => 9335,
                         "constraint"              => 8729,
                         "constraints"             => 5219,
                         "constricted"             => 23271,
                         "constriction"            => 21881,
                         "construct"               => 3282,
                         "constructed"             => 892,
                         "constructing"            => 5585,
                         "construction"            => 393,
                         "constructions"           => 7394,
                         "constructivism"          => 21383,
                         "constructivist"          => 20381,
                         "constructor"             => 13588,
                         "constructors"            => 12164,
                         "constructs"              => 9610,
                         "consul"                  => 4738,
                         "consular"                => 10748,
                         "consulates"              => 14430,
                         "consuls"                 => 13643,
                         "consulship"              => 14651,
                         "consultancy"             => 7982,
                         "consultant"              => 3267,
                         "consultants"             => 7567,
                         "consultation"            => 5916,
                         "consultations"           => 11903,
                         "consultative"            => 9580,
                         "consulted"               => 6721,
                         "consulting"              => 3751,
                         "consume"                 => 7100,
                         "consumerism"             => 18284,
                         "consumers"               => 3642,
                         "consuming"               => 6924,
                         "consumption"             => 2906,
                         "contactless"             => 26651,
                         "contador"                => 17823,
                         "contagion"               => 22704,
                         "contain"                 => 1685,
                         "contained"               => 1469,
                         "container"               => 4965,
                         "containers"              => 6600,
                         "containing"              => 1387,
                         "contains"                => 671,
                         "contaminant"             => 23452,
                         "contaminants"            => 12431,
                         "contamination"           => 6673,
                         "contemplated"            => 12252,
                         "contemplates"            => 21592,
                         "contemplation"           => 13619,
                         "contemplative"           => 15488,
                         "contemporain"            => 28102,
                         "contemporaneous"         => 12447,
                         "contemporaries"          => 5651,
                         "contemporary"            => 935,
                         "contemptuous"            => 28940,
                         "contend"                 => 9655,
                         "contended"               => 9442,
                         "contender"               => 6925,
                         "contenders"              => 8614,
                         "contending"              => 15803,
                         "contends"                => 12060,
                         "content"                 => 1118,
                         "contention"              => 6630,
                         "contentious"             => 9319,
                         "contents"                => 3645,
                         "contest"                 => 1462,
                         "contestant"              => 4434,
                         "contestants"             => 3744,
                         "contested"               => 2364,
                         "contests"                => 5345,
                         "context"                 => 1893,
                         "contexts"                => 6264,
                         "contextual"              => 13646,
                         "contiguous"              => 8196,
                         "continent"               => 3621,
                         "continental"             => 2216,
                         "continents"              => 6292,
                         "contingent"              => 5692,
                         "contingents"             => 15821,
                         "continual"               => 9567,
                         "continually"             => 5515,
                         "continuation"            => 4766,
                         "continuations"           => 29501,
                         "continue"                => 965,
                         "continued"               => 337,
                         "continues"               => 1082,
                         "continuing"              => 1911,
                         "continuity"              => 4735,
                         "continuo"                => 16025,
                         "continuous"              => 2357,
                         "continuously"            => 3842,
                         "continuum"               => 8208,
                         "contours"                => 14144,
                         "contrabass"              => 27850,
                         "contraception"           => 13197,
                         "contraceptive"           => 16726,
                         "contract"                => 637,
                         "contracted"              => 3956,
                         "contracting"             => 7739,
                         "contractor"              => 5227,
                         "contractors"             => 6053,
                         "contracts"               => 2912,
                         "contractual"             => 9068,
                         "contractually"           => 25179,
                         "contradicted"            => 12035,
                         "contradiction"           => 9698,
                         "contradictions"          => 12601,
                         "contradictory"           => 9476,
                         "contradicts"             => 16013,
                         "contraindicated"         => 27865,
                         "contraindications"       => 24961,
                         "contralto"               => 20986,
                         "contrapuntal"            => 25578,
                         "contras"                 => 23551,
                         "contrast"                => 1786,
                         "contrasted"              => 7752,
                         "contrasting"             => 7802,
                         "contrasts"               => 7799,
                         "contravention"           => 23834,
                         "contre"                  => 21697,
                         "contribute"              => 3199,
                         "contributed"             => 1476,
                         "contributes"             => 5800,
                         "contributing"            => 2732,
                         "contribution"            => 2271,
                         "contributions"           => 1831,
                         "contributor"             => 4366,
                         "contributors"            => 5537,
                         "contributory"            => 21312,
                         "contrived"               => 15816,
                         "control"                 => 332,
                         "controllable"            => 18867,
                         "controlled"              => 1415,
                         "controller"              => 4339,
                         "controllers"             => 7374,
                         "controls"                => 2870,
                         "controversial"           => 2033,
                         "controversially"         => 10584,
                         "controversies"           => 5622,
                         "controversy"             => 1631,
                         "conurbation"             => 17066,
                         "conus"                   => 11135,
                         "convair"                 => 16803,
                         "convalescence"           => 27135,
                         "convalescent"            => 21660,
                         "convection"              => 7589,
                         "convective"              => 15513,
                         "convened"                => 6728,
                         "convener"                => 22717,
                         "conveniences"            => 26183,
                         "convening"               => 19271,
                         "convenor"                => 23159,
                         "convent"                 => 4231,
                         "convention"              => 1240,
                         "conventional"            => 2420,
                         "conventionally"          => 11291,
                         "conventions"             => 4185,
                         "convents"                => 16264,
                         "converge"                => 9368,
                         "converged"               => 15475,
                         "convergence"             => 6664,
                         "convergent"              => 12224,
                         "converges"               => 14343,
                         "converging"              => 15701,
                         "conversely"              => 6476,
                         "conversion"              => 2410,
                         "conversions"             => 8533,
                         "convert"                 => 3705,
                         "converted"               => 1443,
                         "converter"               => 9384,
                         "converters"              => 14714,
                         "converting"              => 5728,
                         "converts"                => 6773,
                         "convex"                  => 6560,
                         "convey"                  => 6865,
                         "conveyance"              => 18836,
                         "conveyed"                => 8205,
                         "conveying"               => 13151,
                         "conveys"                 => 13276,
                         "convicts"                => 8738,
                         "convinces"               => 6643,
                         "convincingly"            => 14706,
                         "convocation"             => 12435,
                         "convolution"             => 18855,
                         "convoy"                  => 3254,
                         "convoys"                 => 7392,
                         "conwy"                   => 17061,
                         "conyngham"               => 25165,
                         "cooch"                   => 24273,
                         "cookery"                 => 14215,
                         "cookware"                => 29266,
                         "coolant"                 => 13703,
                         "cooled"                  => 5912,
                         "cooling"                 => 4425,
                         "cooperated"              => 10336,
                         "cooperates"              => 17544,
                         "cooperation"             => 2308,
                         "cooperative"             => 3872,
                         "cooperatively"           => 21433,
                         "cooperatives"            => 10259,
                         "cooperstown"             => 19923,
                         "coordinate"              => 4833,
                         "coordinated"             => 5205,
                         "coordinates"             => 3846,
                         "coordinating"            => 7131,
                         "coordination"            => 4704,
                         "coordinator"             => 4109,
                         "coordinators"            => 17108,
                         "coorg"                   => 26136,
                         "coosa"                   => 29846,
                         "coote"                   => 19941,
                         "copa"                    => 4271,
                         "copacabana"              => 24365,
                         "copan"                   => 26614,
                         "copelatus"               => 17503,
                         "copenhagen"              => 3488,
                         "copepods"                => 23466,
                         "copies"                  => 1370,
                         "copious"                 => 16054,
                         "coppi"                   => 29669,
                         "copra"                   => 25648,
                         "copse"                   => 28502,
                         "coptic"                  => 8796,
                         "copts"                   => 26790,
                         "copula"                  => 23305,
                         "copulation"              => 18861,
                         "copying"                 => 8677,
                         "copyist"                 => 27297,
                         "copyright"               => 3419,
                         "copyrighted"             => 11850,
                         "copyrights"              => 14131,
                         "copywriter"              => 23764,
                         "coquille"                => 28580,
                         "coquitlam"               => 19214,
                         "coraciiformesfamily"     => 26796,
                         "corals"                  => 12009,
                         "corba"                   => 29510,
                         "corbels"                 => 28916,
                         "corbet"                  => 15945,
                         "corbusier"               => 16612,
                         "cordillera"              => 11047,
                         "core"                    => 1378,
                         "corelli"                 => 25884,
                         "cores"                   => 8795,
                         "corfu"                   => 12439,
                         "corinth"                 => 9637,
                         "corinthian"              => 10526,
                         "corinthians"             => 10591,
                         "coriolis"                => 23843,
                         "cork"                    => 3040,
                         "cormorant"               => 17581,
                         "cormorants"              => 18119,
                         "corneal"                 => 15397,
                         "corneille"               => 25599,
                         "cornelis"                => 11745,
                         "cornerback"              => 9503,
                         "cornerstone"             => 7671,
                         "cornerstones"            => 27738,
                         "cornhill"                => 25704,
                         "cornhuskers"             => 13760,
                         "cornice"                 => 9962,
                         "cornices"                => 20684,
                         "cornwall"                => 3599,
                         "corollary"               => 18409,
                         "coromandel"              => 20396,
                         "coronal"                 => 21506,
                         "coronation"              => 4605,
                         "corot"                   => 25977,
                         "corp."                   => 6615,
                         "corpora"                 => 29452,
                         "corporate"               => 1863,
                         "corporation"             => 896,
                         "corporations"            => 3963,
                         "corps"                   => 890,
                         "corpus"                  => 5017,
                         "correctional"            => 6954,
                         "corrections"             => 7545,
                         "corrective"              => 12474,
                         "correctness"             => 14079,
                         "corrects"                => 24360,
                         "corregidor"              => 20154,
                         "corregimiento"           => 28558,
                         "correlate"               => 13031,
                         "correlated"              => 8244,
                         "correlates"              => 14328,
                         "correlation"             => 5992,
                         "correlations"            => 13474,
                         "correspond"              => 5898,
                         "corresponded"            => 8962,
                         "correspondence"          => 3999,
                         "correspondences"         => 19178,
                         "correspondent"           => 4087,
                         "correspondents"          => 11148,
                         "corresponding"           => 2619,
                         "correspondingly"         => 15276,
                         "corresponds"             => 5175,
                         "correze"                 => 27662,
                         "corridor"                => 3655,
                         "corridors"               => 8585,
                         "corrientes"              => 20330,
                         "corroborated"            => 16532,
                         "corrosion"               => 8184,
                         "corrugated"              => 11384,
                         "corruption"              => 2747,
                         "corsairs"                => 21289,
                         "corsican"                => 15977,
                         "corte"                   => 18329,
                         "cortex"                  => 6077,
                         "cortical"                => 11595,
                         "corticosteroids"         => 24588,
                         "cortisol"                => 18923,
                         "cortona"                 => 28327,
                         "coruna"                  => 14277,
                         "corus"                   => 19537,
                         "corvallis"               => 18915,
                         "corvettes"               => 12933,
                         "corvinus"                => 20902,
                         "corydon"                 => 28596,
                         "cosimo"                  => 14705,
                         "cosine"                  => 19826,
                         "cosmas"                  => 24601,
                         "cosmodrome"              => 20741,
                         "cosmological"            => 13436,
                         "cosmology"               => 9811,
                         "cosmonaut"               => 17186,
                         "cosmonauts"              => 21916,
                         "cosmopolitan"            => 8583,
                         "cosmopterigidae"         => 15896,
                         "cosmopterix"             => 28711,
                         "cosplay"                 => 24379,
                         "cossack"                 => 10115,
                         "cossacks"                => 9568,
                         "cossidae"                => 18255,
                         "cost"                    => 767,
                         "costal"                  => 10493,
                         "costliest"               => 28901,
                         "costly"                  => 6088,
                         "costs"                   => 1620,
                         "costumed"                => 15026,
                         "cotabato"                => 20317,
                         "coterminous"             => 26297,
                         "cotes"                   => 16465,
                         "cotonou"                 => 28851,
                         "cotswold"                => 18354,
                         "cottages"                => 6885,
                         "cottbus"                 => 20473,
                         "cottonwood"              => 13503,
                         "coulee"                  => 21254,
                         "coulomb"                 => 18460,
                         "coulthard"               => 14127,
                         "council"                 => 247,
                         "councillor"              => 4507,
                         "councillors"             => 4748,
                         "councilors"              => 14258,
                         "councils"                => 3743,
                         "counsellors"             => 22632,
                         "counsels"                => 21478,
                         "countable"               => 16528,
                         "counted"                 => 4008,
                         "counter"                 => 2127,
                         "counteract"              => 12706,
                         "counterattack"           => 9178,
                         "counterattacked"         => 22061,
                         "counterattacks"          => 18559,
                         "counterbalance"          => 21281,
                         "counterclockwise"        => 20773,
                         "counterculture"          => 15662,
                         "countered"               => 9551,
                         "countering"              => 16169,
                         "counterinsurgency"       => 21693,
                         "countermeasure"          => 26642,
                         "countermeasures"         => 13638,
                         "counteroffensive"        => 20427,
                         "counterpart"             => 4903,
                         "counterparts"            => 5131,
                         "counterpoint"            => 11463,
                         "counters"                => 9694,
                         "counterterrorism"        => 19869,
                         "counterweight"           => 20911,
                         "countess"                => 4839,
                         "counties"                => 1674,
                         "countries"               => 479,
                         "country"                 => 219,
                         "countryside"             => 4170,
                         "countrywide"             => 20575,
                         "county"                  => 105,
                         "countywide"              => 14752,
                         "coup"                    => 2872,
                         "coupe"                   => 5668,
                         "coupes"                  => 18569,
                         "coupled"                 => 4066,
                         "coupler"                 => 21370,
                         "couplers"                => 23386,
                         "couples"                 => 1801,
                         "couplet"                 => 18007,
                         "couplets"                => 19193,
                         "coupling"                => 7001,
                         "couplings"               => 20709,
                         "coups"                   => 17080,
                         "courant"                 => 16365,
                         "courbet"                 => 22405,
                         "courland"                => 17751,
                         "cours"                   => 19933,
                         "coursed"                 => 28700,
                         "courses"                 => 1484,
                         "coursework"              => 12704,
                         "court"                   => 244,
                         "courtauld"               => 25220,
                         "courtenay"               => 11209,
                         "courtesan"               => 19811,
                         "courthouses"             => 19767,
                         "courtier"                => 12907,
                         "courtiers"               => 14744,
                         "courtland"               => 29686,
                         "courtly"                 => 16903,
                         "courts"                  => 1630,
                         "courtyard"               => 5348,
                         "courtyards"              => 15520,
                         "coutinho"                => 24521,
                         "covalent"                => 15051,
                         "covalently"              => 24424,
                         "covariance"              => 16079,
                         "covariant"               => 19135,
                         "cove"                    => 4393,
                         "covenant"                => 6214,
                         "covenanters"             => 22949,
                         "covenants"               => 15809,
                         "covent"                  => 9163,
                         "cover"                   => 725,
                         "coverage"                => 1923,
                         "covered"                 => 866,
                         "covering"                => 1947,
                         "coverings"               => 20027,
                         "covers"                  => 1289,
                         "coverts"                 => 19519,
                         "coves"                   => 26396,
                         "coveted"                 => 9053,
                         "cowdenbeath"             => 21897,
                         "cowes"                   => 19401,
                         "cowichan"                => 28381,
                         "cowper"                  => 15402,
                         "cowries"                 => 26312,
                         "cowry"                   => 28044,
                         "coxae"                   => 17412,
                         "coxed"                   => 18730,
                         "coxeter"                 => 16323,
                         "coxless"                 => 20172,
                         "coxswain"                => 20781,
                         "cpusa"                   => 24465,
                         "crackdown"               => 11239,
                         "cracow"                  => 19386,
                         "cradock"                 => 24723,
                         "crafted"                 => 7580,
                         "crafting"                => 14302,
                         "crafts"                  => 5106,
                         "craftsman"               => 9346,
                         "craftsmen"               => 8582,
                         "crags"                   => 17804,
                         "craigie"                 => 22230,
                         "craigslist"              => 26979,
                         "craiova"                 => 18484,
                         "crambidae"               => 6338,
                         "cranbrook"               => 16591,
                         "cranial"                 => 12284,
                         "crankcase"               => 22366,
                         "crankshaft"              => 12992,
                         "crassus"                 => 17386,
                         "crataegus"               => 25770,
                         "crater"                  => 3565,
                         "craters"                 => 7842,
                         "creamery"                => 18603,
                         "create"                  => 742,
                         "created"                 => 293,
                         "creates"                 => 3099,
                         "creating"                => 1323,
                         "creation"                => 1096,
                         "creationism"             => 16574,
                         "creationist"             => 22808,
                         "creationists"            => 28732,
                         "creativity"              => 5629,
                         "creator"                 => 3203,
                         "creators"                => 6174,
                         "credential"              => 18806,
                         "creditable"              => 25450,
                         "credited"                => 1808,
                         "crediting"               => 20719,
                         "creditor"                => 13519,
                         "creditors"               => 7811,
                         "credits"                 => 2046,
                         "creek"                   => 829,
                         "creeks"                  => 8477,
                         "crematoria"              => 29485,
                         "cremona"                 => 14006,
                         "creole"                  => 7486,
                         "creoles"                 => 19586,
                         "crest"                   => 4180,
                         "crested"                 => 10275,
                         "creston"                 => 27280,
                         "crests"                  => 13561,
                         "crestwood"               => 24409,
                         "cretaceous"              => 6279,
                         "cretan"                  => 14055,
                         "crete"                   => 6703,
                         "creuse"                  => 26681,
                         "crevices"                => 16481,
                         "crew"                    => 1006,
                         "crewe"                   => 7861,
                         "crewed"                  => 18006,
                         "crewmembers"             => 20146,
                         "crewmen"                 => 12024,
                         "cricketer"               => 2930,
                         "cricketers"              => 9819,
                         "cricketing"              => 16170,
                         "crimea"                  => 7613,
                         "crimean"                 => 7054,
                         "criminality"             => 20822,
                         "criminalized"            => 29640,
                         "criminology"             => 13061,
                         "criollo"                 => 28684,
                         "criollos"                => 29196,
                         "crises"                  => 8607,
                         "crisis"                  => 1643,
                         "crispa"                  => 25921,
                         "cristoforo"              => 29462,
                         "criteria"                => 3123,
                         "criterion"               => 6634,
                         "criterium"               => 19788,
                         "critic"                  => 2022,
                         "critical"                => 894,
                         "criticality"             => 27128,
                         "critically"              => 3904,
                         "criticised"              => 3697,
                         "criticises"              => 21821,
                         "criticising"             => 13108,
                         "criticism"               => 1713,
                         "criticisms"              => 5732,
                         "criticized"              => 2035,
                         "criticizes"              => 11851,
                         "criticizing"             => 7597,
                         "critics"                 => 1150,
                         "critique"                => 6038,
                         "critiqued"               => 18047,
                         "critiques"               => 11355,
                         "croat"                   => 13415,
                         "croatia"                 => 2759,
                         "croatian"                => 2781,
                         "croats"                  => 8657,
                         "crocodiles"              => 11583,
                         "crocodilians"            => 25491,
                         "crohn"                   => 21738,
                         "croix"                   => 7404,
                         "cromarty"                => 26734,
                         "cromwellian"             => 28383,
                         "cronenberg"              => 25167,
                         "cronulla"                => 14176,
                         "crookes"                 => 29204,
                         "crop"                    => 3892,
                         "cropland"                => 29388,
                         "cropping"                => 18392,
                         "crops"                   => 2942,
                         "crore"                   => 10822,
                         "crores"                  => 15369,
                         "crossbar"                => 16559,
                         "crosse"                  => 13536,
                         "crosses"                 => 2757,
                         "crossing"                => 1746,
                         "crossings"               => 6986,
                         "crossover"               => 5899,
                         "crossovers"              => 17914,
                         "crossrail"               => 23774,
                         "crossroad"               => 24969,
                         "crossroads"              => 6405,
                         "crosstown"               => 16138,
                         "croton"                  => 17169,
                         "crowdfunding"            => 16549,
                         "crowds"                  => 5415,
                         "crowdsourcing"           => 24735,
                         "crown"                   => 1298,
                         "crowne"                  => 29864,
                         "crowned"                 => 3684,
                         "crowns"                  => 8538,
                         "croydon"                 => 7328,
                         "crucial"                 => 3755,
                         "crucially"               => 20721,
                         "cruciate"                => 15046,
                         "crucible"                => 14358,
                         "crucifixion"             => 10270,
                         "cruciform"               => 15731,
                         "crucis"                  => 29290,
                         "crude"                   => 5635,
                         "cruised"                 => 12893,
                         "cruisers"                => 6028,
                         "cruiserweight"           => 15258,
                         "cruises"                 => 7774,
                         "crumlin"                 => 26232,
                         "crusade"                 => 5904,
                         "crusaders"               => 6595,
                         "crusades"                => 11559,
                         "crusading"               => 26031,
                         "crustacean"              => 22157,
                         "crustaceans"             => 10198,
                         "crustal"                 => 21427,
                         "cruyff"                  => 28848,
                         "cruzeiro"                => 16791,
                         "crvena"                  => 26480,
                         "cryogenic"               => 16761,
                         "cryptanalysis"           => 24377,
                         "cryptographic"           => 13131,
                         "cryptography"            => 11873,
                         "crystalline"             => 9006,
                         "crystallization"         => 17861,
                         "crystallized"            => 20582,
                         "crystallographic"        => 24159,
                         "crystallography"         => 16444,
                         "crystals"                => 6007,
                         "csiro"                   => 20142,
                         "ctesiphon"               => 23321,
                         "cuando"                  => 27904,
                         "cuatro"                  => 20663,
                         "cuauhtemoc"              => 22359,
                         "cuba"                    => 2508,
                         "cuban"                   => 3335,
                         "cubic"                   => 5270,
                         "cubism"                  => 15147,
                         "cubist"                  => 17358,
                         "cubitt"                  => 25519,
                         "cuckoos"                 => 19398,
                         "cuddalore"               => 23086,
                         "cuernavaca"              => 25021,
                         "cuisine"                 => 4152,
                         "cuisines"                => 14268,
                         "culled"                  => 18930,
                         "culling"                 => 23269,
                         "culloden"                => 22259,
                         "culminate"               => 18659,
                         "culminated"              => 5706,
                         "culminates"              => 13923,
                         "culminating"             => 5747,
                         "culmination"             => 10048,
                         "culpeper"                => 20101,
                         "culprits"                => 22008,
                         "cult"                    => 3044,
                         "cultivar"                => 10345,
                         "cultivars"               => 9131,
                         "cultivate"               => 9905,
                         "cultivated"              => 4663,
                         "cultivation"             => 3990,
                         "cultivators"             => 19726,
                         "cults"                   => 11637,
                         "cultura"                 => 15789,
                         "cultural"                => 703,
                         "culturally"              => 6958,
                         "culture"                 => 547,
                         "cultured"                => 11525,
                         "cultures"                => 2916,
                         "culvert"                 => 20110,
                         "culverts"                => 26185,
                         "cuman"                   => 29033,
                         "cumann"                  => 23179,
                         "cumans"                  => 22760,
                         "cumberland"              => 4191,
                         "cumbernauld"             => 27900,
                         "cumbersome"              => 15726,
                         "cumbia"                  => 20226,
                         "cumbria"                 => 8273,
                         "cumulative"              => 7773,
                         "cunard"                  => 14356,
                         "cundinamarca"            => 29781,
                         "cuneiform"               => 14448,
                         "cunxu"                   => 21018,
                         "cup"                     => 267,
                         "cupen"                   => 28985,
                         "cupertino"               => 28074,
                         "cupola"                  => 10860,
                         "curacao"                 => 11534,
                         "curacies"                => 27326,
                         "curacy"                  => 17756,
                         "curate"                  => 9058,
                         "curated"                 => 7783,
                         "curative"                => 20753,
                         "curator"                 => 5390,
                         "curatorial"              => 19646,
                         "curators"                => 14387,
                         "curbing"                 => 27650,
                         "curia"                   => 12339,
                         "curiae"                  => 24262,
                         "curiosities"             => 19846,
                         "curiously"               => 13819,
                         "curler"                  => 17300,
                         "curling"                 => 5698,
                         "curragh"                 => 19332,
                         "currencies"              => 10756,
                         "currency"                => 3327,
                         "current"                 => 369,
                         "currently"               => 318,
                         "currents"                => 5713,
                         "curricula"               => 10615,
                         "curricular"              => 8712,
                         "curriculum"              => 2716,
                         "cursive"                 => 17488,
                         "cursor"                  => 16561,
                         "curtail"                 => 18351,
                         "curtailed"               => 11615,
                         "curvature"               => 8316,
                         "curve"                   => 3456,
                         "curved"                  => 4676,
                         "curves"                  => 4911,
                         "curvilinear"             => 22375,
                         "curving"                 => 11014,
                         "curzon"                  => 12938,
                         "cusco"                   => 17210,
                         "cusps"                   => 21491,
                         "custodians"              => 24676,
                         "customarily"             => 16355,
                         "customary"               => 6222,
                         "customers"               => 2148,
                         "customised"              => 24307,
                         "customizable"            => 17461,
                         "customization"           => 15260,
                         "customize"               => 16024,
                         "customized"              => 9157,
                         "customs"                 => 2976,
                         "custos"                  => 24284,
                         "cutaneous"               => 14112,
                         "cutoff"                  => 12569,
                         "cutscenes"               => 21943,
                         "cuttack"                 => 18336,
                         "cuttings"                => 13281,
                         "cuttlefish"              => 24998,
                         "cutty"                   => 26707,
                         "cuvier"                  => 21774,
                         "cuyahoga"                => 16167,
                         "cuzco"                   => 23604,
                         "cyanobacteria"           => 19065,
                         "cyathea"                 => 29487,
                         "cybele"                  => 27213,
                         "cybermen"                => 19535,
                         "cybernetic"              => 17875,
                         "cybernetics"             => 17872,
                         "cyberpunk"               => 19508,
                         "cybersecurity"           => 25083,
                         "cybertron"               => 13091,
                         "cyborgs"                 => 27666,
                         "cyclades"                => 28108,
                         "cyclase"                 => 27642,
                         "cycle"                   => 1651,
                         "cycled"                  => 22770,
                         "cycles"                  => 4824,
                         "cyclic"                  => 7806,
                         "cyclical"                => 16896,
                         "cyclin"                  => 18927,
                         "cycling"                 => 3354,
                         "cyclist"                 => 4938,
                         "cycliste"                => 27054,
                         "cyclists"                => 6737,
                         "cyclo"                   => 18749,
                         "cyclonic"                => 19660,
                         "cygni"                   => 29742,
                         "cylinder"                => 2920,
                         "cylinders"               => 6752,
                         "cylindrical"             => 6669,
                         "cymbals"                 => 12995,
                         "cymru"                   => 11933,
                         "cynon"                   => 29153,
                         "cyprinid"                => 29115,
                         "cyprinidae"              => 27188,
                         "cypriot"                 => 7028,
                         "cypriots"                => 14788,
                         "cyprus"                  => 3403,
                         "cyrenaica"               => 20460,
                         "cyrene"                  => 25139,
                         "cyrillic"                => 6500,
                         "cysteine"                => 15064,
                         "cystic"                  => 15288,
                         "cysts"                   => 15712,
                         "cytochrome"              => 13381,
                         "cytokine"                => 19072,
                         "cytokines"               => 16421,
                         "cytoplasm"               => 12788,
                         "cytoplasmic"             => 14024,
                         "cytosine"                => 28270,
                         "cytoskeleton"            => 23506,
                         "cytosol"                 => 23348,
                         "cytosolic"               => 26371,
                         "cytotoxic"               => 20488,
                         "czech"                   => 1788,
                         "czechoslovak"            => 7291,
                         "czechoslovakia"          => 4525,
                         "czechs"                  => 13823,
                         "czeslaw"                 => 25787,
                         "czestochowa"             => 16740,
                         "d'affaires"              => 17456,
                         "d'amato"                 => 22592,
                         "d'amico"                 => 26758,
                         "d'amore"                 => 18369,
                         "d'annunzio"              => 29746,
                         "d'arc"                   => 26001,
                         "d'armor"                 => 29964,
                         "d'art"                   => 13790,
                         "d'arte"                  => 27059,
                         "d'automne"               => 28668,
                         "d'auvergne"              => 27317,
                         "d'azur"                  => 18875,
                         "d'estaing"               => 23720,
                         "d'este"                  => 17187,
                         "d'etat"                  => 6629,
                         "d'etudes"                => 18693,
                         "d'histoire"              => 21356,
                         "d'hondt"                 => 20198,
                         "d'honneur"               => 11015,
                         "d'italia"                => 10013,
                         "d'ivoire"                => 9153,
                         "d'orleans"               => 16232,
                         "d'oro"                   => 21687,
                         "d'orsay"                 => 25097,
                         "d'oyly"                  => 14777,
                         "d'souza"                 => 19935,
                         "d'une"                   => 29836,
                         "d.c."                    => 2395,
                         "d.c.."                   => 12445,
                         "dabrowa"                 => 17031,
                         "dabrowka"                => 27477,
                         "dacian"                  => 14872,
                         "dacians"                 => 25758,
                         "dacre"                   => 20165,
                         "daegu"                   => 13677,
                         "daejeon"                 => 21925,
                         "dafydd"                  => 18051,
                         "dagbladet"               => 23788,
                         "dagenham"                => 12986,
                         "dahomey"                 => 18441,
                         "daigo"                   => 22100,
                         "daihatsu"                => 24436,
                         "daiichi"                 => 26310,
                         "daily"                   => 875,
                         "daimler"                 => 9500,
                         "daimyo"                  => 11412,
                         "dairies"                 => 22228,
                         "dairy"                   => 4259,
                         "daizong"                 => 28643,
                         "dakar"                   => 10015,
                         "dakshina"                => 23375,
                         "dalarna"                 => 28387,
                         "dalek"                   => 13704,
                         "daleks"                  => 11055,
                         "dalhousie"               => 12078,
                         "dalian"                  => 12334,
                         "dalit"                   => 15356,
                         "dalits"                  => 21051,
                         "dalkeith"                => 29338,
                         "dallara"                 => 25080,
                         "dallas/fort"             => 27161,
                         "dalles"                  => 23706,
                         "dalmatia"                => 10158,
                         "dalmatian"               => 14699,
                         "daltrey"                 => 21163,
                         "damage"                  => 1155,
                         "damaged"                 => 1854,
                         "damages"                 => 4465,
                         "damascus"                => 5607,
                         "dame"                    => 3124,
                         "dammed"                  => 14736,
                         "damming"                 => 19278,
                         "damodar"                 => 20578,
                         "dampers"                 => 21933,
                         "damping"                 => 14911,
                         "dams"                    => 5697,
                         "damselfly"               => 25116,
                         "danby"                   => 21525,
                         "danceable"               => 29122,
                         "dancefloor"              => 23747,
                         "dancehall"               => 14635,
                         "dancers"                 => 4027,
                         "dances"                  => 4246,
                         "dandenong"               => 16347,
                         "danish"                  => 1803,
                         "dannebrog"               => 29454,
                         "danse"                   => 17966,
                         "dansk"                   => 25690,
                         "danske"                  => 25809,
                         "danube"                  => 5694,
                         "danubian"                => 21982,
                         "danville"                => 10510,
                         "danza"                   => 22152,
                         "daoist"                  => 22262,
                         "daraa"                   => 28945,
                         "darbar"                  => 27103,
                         "darbhanga"               => 25296,
                         "dardanelles"             => 15451,
                         "daredevils"              => 27480,
                         "darfur"                  => 11486,
                         "dargah"                  => 20104,
                         "darjeeling"              => 13742,
                         "darke"                   => 27126,
                         "darkening"               => 23675,
                         "darker"                  => 4921,
                         "darkly"                  => 17368,
                         "darko"                   => 19513,
                         "darkseid"                => 19427,
                         "darlington"              => 6891,
                         "darmstadt"               => 9645,
                         "darna"                   => 27841,
                         "darpa"                   => 16115,
                         "darreh"                  => 9687,
                         "darshan"                 => 17298,
                         "darters"                 => 24917,
                         "dartford"                => 14476,
                         "dartmoor"                => 16901,
                         "dartmouth"               => 5943,
                         "darts"                   => 6949,
                         "darul"                   => 18521,
                         "darwen"                  => 19789,
                         "darya"                   => 17981,
                         "dashes"                  => 19787,
                         "dasht"                   => 12107,
                         "dassault"                => 16552,
                         "data"                    => 528,
                         "database"                => 2733,
                         "databases"               => 6367,
                         "dataset"                 => 16991,
                         "datasets"                => 18468,
                         "dated"                   => 2099,
                         "dates"                   => 1584,
                         "dative"                  => 18322,
                         "datong"                  => 28196,
                         "datuk"                   => 16595,
                         "datum"                   => 18414,
                         "daugava"                 => 22166,
                         "daugavpils"              => 27420,
                         "daughters"               => 1929,
                         "dauntless"               => 22902,
                         "davao"                   => 11444,
                         "daventry"                => 23794,
                         "daviess"                 => 27852,
                         "davos"                   => 16061,
                         "dawla"                   => 15449,
                         "day"                     => 126,
                         "dayak"                   => 26069,
                         "dayal"                   => 21620,
                         "days"                    => 323,
                         "daytime"                 => 4453,
                         "deaconess"               => 28876,
                         "deactivation"            => 19861,
                         "deadliest"               => 11586,
                         "deadlocked"              => 24350,
                         "deadpan"                 => 26953,
                         "deafness"                => 16085,
                         "dealerships"             => 14723,
                         "deanery"                 => 9971,
                         "death"                   => 196,
                         "deathmatch"              => 23329,
                         "deaths"                  => 2346,
                         "deathstroke"             => 29513,
                         "deauville"               => 21089,
                         "debarge"                 => 28405,
                         "debate"                  => 1886,
                         "debated"                 => 6100,
                         "debater"                 => 29305,
                         "debates"                 => 4972,
                         "debian"                  => 16099,
                         "debit"                   => 13383,
                         "debre"                   => 27647,
                         "debrecen"                => 18098,
                         "debris"                  => 5053,
                         "debtor"                  => 12654,
                         "debtors"                 => 16681,
                         "debug"                   => 24391,
                         "debugging"               => 17678,
                         "debunked"                => 29675,
                         "debussy"                 => 13112,
                         "debut"                   => 412,
                         "debutant"                => 15831,
                         "debuted"                 => 1848,
                         "debuting"                => 7977,
                         "debuts"                  => 9254,
                         "debye"                   => 28485,
                         "decadal"                 => 27048,
                         "decade"                  => 1645,
                         "decades"                 => 1550,
                         "decal"                   => 28872,
                         "decals"                  => 23610,
                         "decarboxylase"           => 27293,
                         "decathlon"               => 12805,
                         "decay"                   => 4934,
                         "decayed"                 => 14333,
                         "decays"                  => 16664,
                         "decca"                   => 8720,
                         "deccan"                  => 10441,
                         "deceased"                => 3983,
                         "deceleration"            => 22566,
                         "december"                => 174,
                         "decentralised"           => 29361,
                         "decentralization"        => 16011,
                         "decentralized"           => 12341,
                         "decepticon"              => 13801,
                         "decepticons"             => 11708,
                         "decided"                 => 558,
                         "decider"                 => 9845,
                         "decides"                 => 2452,
                         "deciduous"               => 7803,
                         "decile"                  => 28924,
                         "decimated"               => 12202,
                         "decimation"              => 29306,
                         "decisive"                => 4733,
                         "decisively"              => 10797,
                         "decius"                  => 27535,
                         "deckers"                 => 21053,
                         "decking"                 => 25405,
                         "decks"                   => 7634,
                         "declaration"             => 2848,
                         "declarations"            => 11261,
                         "declarative"             => 19086,
                         "declaratory"             => 29850,
                         "declared"                => 1101,
                         "declarer"                => 28321,
                         "declares"                => 7058,
                         "declaring"               => 5041,
                         "declassified"            => 16970,
                         "declension"              => 17893,
                         "declination"             => 21865,
                         "decline"                 => 2019,
                         "declined"                => 2093,
                         "declines"                => 8678,
                         "declining"               => 4937,
                         "decoders"                => 28892,
                         "decoding"                => 12711,
                         "decolonization"          => 25065,
                         "decommissioned"          => 4872,
                         "decommissioning"         => 9288,
                         "decomposes"              => 21120,
                         "decomposition"           => 7558,
                         "decompression"           => 12919,
                         "decor"                   => 11445,
                         "decorated"               => 2783,
                         "decoration"              => 4230,
                         "decorations"             => 4928,
                         "decorative"              => 4383,
                         "decrease"                => 3492,
                         "decreased"               => 3792,
                         "decreases"               => 6314,
                         "decreasing"              => 6018,
                         "decree"                  => 3695,
                         "decreed"                 => 9695,
                         "decrees"                 => 9395,
                         "decried"                 => 18677,
                         "decrypt"                 => 27238,
                         "dedekind"                => 25057,
                         "dedicated"               => 1005,
                         "dedicates"               => 21082,
                         "dedicating"              => 16256,
                         "dedication"              => 4539,
                         "dedications"             => 23137,
                         "deduced"                 => 11977,
                         "deduces"                 => 20966,
                         "deducted"                => 13847,
                         "deeded"                  => 16706,
                         "deemed"                  => 3019,
                         "deeming"                 => 19183,
                         "deepa"                   => 25584,
                         "deepen"                  => 16966,
                         "deepened"                => 14296,
                         "deepening"               => 14715,
                         "deepwater"               => 13485,
                         "deer"                    => 3382,
                         "deerfield"               => 13755,
                         "defamation"              => 9014,
                         "defamatory"              => 21847,
                         "defaulted"               => 18890,
                         "defaults"                => 22459,
                         "defeat"                  => 1085,
                         "defeated"                => 648,
                         "defeating"               => 2050,
                         "defeats"                 => 5284,
                         "defecation"              => 28875,
                         "defect"                  => 7588,
                         "defected"                => 8801,
                         "defecting"               => 24093,
                         "defection"               => 12487,
                         "defections"              => 21950,
                         "defectors"               => 18669,
                         "defects"                 => 6597,
                         "defence"                 => 1374,
                         "defenceman"              => 9159,
                         "defencemen"              => 27225,
                         "defences"                => 6011,
                         "defendants"              => 5862,
                         "defended"                => 2855,
                         "defenders"               => 4411,
                         "defends"                 => 10943,
                         "defense"                 => 870,
                         "defensed"                => 26792,
                         "defenseman"              => 13447,
                         "defensemen"              => 28005,
                         "defenses"                => 5460,
                         "defensible"              => 20378,
                         "defensive"               => 1804,
                         "defensively"             => 17605,
                         "defensor"                => 27301,
                         "deferred"                => 10278,
                         "defiance"                => 8642,
                         "deficiencies"            => 10182,
                         "deficiency"              => 6722,
                         "deficient"               => 10107,
                         "deficit"                 => 5244,
                         "deficits"                => 10105,
                         "definable"               => 26693,
                         "define"                  => 3353,
                         "defined"                 => 1156,
                         "defines"                 => 4063,
                         "defining"                => 4573,
                         "definition"              => 1763,
                         "definitions"             => 4754,
                         "definitive"              => 5680,
                         "definitively"            => 12175,
                         "deflation"               => 22085,
                         "deflected"               => 13543,
                         "deflection"              => 13641,
                         "deflections"             => 25396,
                         "deforestation"           => 9574,
                         "deform"                  => 29439,
                         "deformation"             => 9425,
                         "deformations"            => 25507,
                         "deformities"             => 21388,
                         "defunct"                 => 3943,
                         "degc"                    => 3671,
                         "degeneracy"              => 27191,
                         "degenerated"             => 16765,
                         "degeneration"            => 12515,
                         "degeneres"               => 16508,
                         "degli"                   => 13118,
                         "degradation"             => 5958,
                         "degraded"                => 8510,
                         "degrades"                => 22711,
                         "degree"                  => 518,
                         "degrees"                 => 1656,
                         "dehestan"                => 11837,
                         "dehradun"                => 17538,
                         "dehydrogenase"           => 9740,
                         "deified"                 => 23460,
                         "deild"                   => 28536,
                         "deism"                   => 28355,
                         "deities"                 => 5702,
                         "deity"                   => 4646,
                         "dejan"                   => 16923,
                         "dejected"                => 27186,
                         "dekalb"                  => 12668,
                         "delamere"                => 27947,
                         "delaunay"                => 22172,
                         "delaware"                => 2748,
                         "delayed"                 => 3039,
                         "delays"                  => 5163,
                         "delegate"                => 4236,
                         "delegated"               => 10354,
                         "delegates"               => 3660,
                         "delegation"              => 3827,
                         "delegations"             => 10666,
                         "deleted"                 => 6610,
                         "deleterious"             => 19017,
                         "deleting"                => 20109,
                         "deletion"                => 10877,
                         "deletions"               => 22381,
                         "deleuze"                 => 24232,
                         "delft"                   => 12653,
                         "delgada"                 => 26193,
                         "delhi"                   => 2317,
                         "deliberated"             => 28182,
                         "deliberation"            => 13435,
                         "deliberations"           => 14766,
                         "deliberative"            => 22708,
                         "delimitation"            => 13668,
                         "delimited"               => 19192,
                         "delineate"               => 27578,
                         "delineated"              => 14946,
                         "delineation"             => 24492,
                         "delinquency"             => 15814,
                         "delisted"                => 14793,
                         "delius"                  => 23282,
                         "delivered"               => 1849,
                         "delivers"                => 6521,
                         "dell'arte"               => 24674,
                         "delle"                   => 10298,
                         "dello"                   => 19932,
                         "deloitte"                => 16610,
                         "delos"                   => 21636,
                         "delved"                  => 27042,
                         "delves"                  => 22408,
                         "demand"                  => 1661,
                         "demanded"                => 3255,
                         "demands"                 => 2814,
                         "demarcated"              => 21593,
                         "demarcation"             => 14488,
                         "dementieva"              => 26976,
                         "demerara"                => 26002,
                         "demersal"                => 25882,
                         "demesne"                 => 19987,
                         "demetrios"               => 25153,
                         "demilitarized"           => 21583,
                         "demise"                  => 4780,
                         "demobilisation"          => 23648,
                         "demobilised"             => 26575,
                         "demobilization"          => 18909,
                         "demobilized"             => 15688,
                         "democracies"             => 14282,
                         "democracy"               => 2391,
                         "democrat"                => 2592,
                         "democratic"              => 756,
                         "democratically"          => 13225,
                         "democratique"            => 29709,
                         "democratization"         => 17473,
                         "democrats"               => 2686,
                         "demographic"             => 5368,
                         "demographics"            => 1683,
                         "demography"              => 8994,
                         "demolish"                => 10929,
                         "demolished"              => 2400,
                         "demolishing"             => 16023,
                         "demolition"              => 4361,
                         "demonstrate"             => 3918,
                         "demonstrated"            => 2604,
                         "demonstrates"            => 6187,
                         "demonstrating"           => 5856,
                         "demonstration"           => 3836,
                         "demonstrations"          => 4651,
                         "demonstrative"           => 20864,
                         "demonstrator"            => 14772,
                         "demonstrators"           => 8979,
                         "demoralized"             => 22349,
                         "demos"                   => 6448,
                         "demosthenes"             => 20905,
                         "demoted"                 => 8756,
                         "demotic"                 => 26730,
                         "demotion"                => 18634,
                         "dempo"                   => 29003,
                         "denbigh"                 => 19755,
                         "denbighshire"            => 18123,
                         "dench"                   => 22844,
                         "dendrites"               => 23395,
                         "dendritic"               => 15922,
                         "dengeki"                 => 21548,
                         "dengue"                  => 21811,
                         "denied"                  => 2206,
                         "denizens"                => 23806,
                         "denmark"                 => 1834,
                         "denominated"             => 17129,
                         "denomination"            => 5833,
                         "denominational"          => 9688,
                         "denominations"           => 5657,
                         "denote"                  => 6509,
                         "denoted"                 => 6558,
                         "denotes"                 => 5969,
                         "denoting"                => 10178,
                         "denouement"              => 29917,
                         "denounce"                => 15322,
                         "denounced"               => 6154,
                         "denounces"               => 24943,
                         "denouncing"              => 12364,
                         "dense"                   => 3894,
                         "densely"                 => 6806,
                         "denser"                  => 15250,
                         "densest"                 => 28746,
                         "densities"               => 10093,
                         "density"                 => 951,
                         "dentate"                 => 14077,
                         "denticles"               => 28049,
                         "dentistry"               => 9037,
                         "dentition"               => 19432,
                         "denunciation"            => 20686,
                         "denys"                   => 13809,
                         "denzil"                  => 29960,
                         "depart"                  => 7447,
                         "departed"                => 2665,
                         "departement"             => 9352,
                         "departements"            => 26573,
                         "departing"               => 5959,
                         "department"              => 294,
                         "departmental"            => 9289,
                         "departments"             => 2413,
                         "departs"                 => 9808,
                         "departure"               => 2225,
                         "departures"              => 10010,
                         "dependence"              => 6417,
                         "dependencies"            => 9606,
                         "dependency"              => 8195,
                         "dependent"               => 2658,
                         "dependents"              => 16251,
                         "depending"               => 1836,
                         "depict"                  => 6047,
                         "depicted"                => 2824,
                         "depicting"               => 3945,
                         "depiction"               => 5602,
                         "depictions"              => 6706,
                         "depicts"                 => 4051,
                         "depleted"                => 8126,
                         "depleting"               => 25034,
                         "depletion"               => 10909,
                         "deplored"                => 23791,
                         "deploy"                  => 7459,
                         "deployable"              => 22416,
                         "deployed"                => 2443,
                         "deploying"               => 10264,
                         "deployment"              => 3680,
                         "deployments"             => 9424,
                         "deploys"                 => 23937,
                         "depolarization"          => 23416,
                         "depopulated"             => 15976,
                         "depopulation"            => 22982,
                         "deportation"             => 7924,
                         "deportations"            => 15391,
                         "deported"                => 6328,
                         "deportees"               => 25194,
                         "deportes"                => 13917,
                         "deportiva"               => 20614,
                         "deportivo"               => 8039,
                         "deposed"                 => 6211,
                         "deposited"               => 5567,
                         "depositing"              => 19242,
                         "depositors"              => 23453,
                         "deposits"                => 3495,
                         "depot"                   => 2990,
                         "depots"                  => 9684,
                         "deprecated"              => 20364,
                         "depreciation"            => 17357,
                         "depredations"            => 27785,
                         "depression"              => 1983,
                         "depressions"             => 12234,
                         "deprivation"             => 10117,
                         "deptford"                => 14505,
                         "depth"                   => 2031,
                         "deputation"              => 21277,
                         "deputies"                => 4467,
                         "deputy"                  => 1198,
                         "derailment"              => 17509,
                         "derbies"                 => 24426,
                         "derby"                   => 2426,
                         "derbyshire"              => 5037,
                         "derecho"                 => 24781,
                         "deregulated"             => 28831,
                         "deregulation"            => 12850,
                         "dereham"                 => 27367,
                         "derelict"                => 9910,
                         "derided"                 => 16205,
                         "derivation"              => 8158,
                         "derivations"             => 20726,
                         "derivative"              => 4725,
                         "derivatives"             => 5727,
                         "derive"                  => 6281,
                         "derived"                 => 1398,
                         "derives"                 => 4004,
                         "deriving"                => 10926,
                         "derleth"                 => 29512,
                         "dermal"                  => 18183,
                         "dermatitis"              => 17052,
                         "dermatology"             => 17324,
                         "dermot"                  => 14892,
                         "derrida"                 => 16445,
                         "derulo"                  => 26971,
                         "derwent"                 => 12269,
                         "deryni"                  => 29606,
                         "desalination"            => 16944,
                         "desam"                   => 28284,
                         "descartes"               => 12328,
                         "descend"                 => 8159,
                         "descendant"              => 4482,
                         "descendants"             => 2794,
                         "descended"               => 4186,
                         "descendent"              => 16238,
                         "descendents"             => 12846,
                         "descending"              => 6383,
                         "descends"                => 8085,
                         "descent"                 => 2355,
                         "descentralizado"         => 25722,
                         "descents"                => 28753,
                         "deschutes"               => 27372,
                         "described"               => 350,
                         "describes"               => 1640,
                         "describing"              => 2745,
                         "description"             => 1038,
                         "descriptions"            => 4810,
                         "descriptive"             => 7805,
                         "descriptor"              => 19527,
                         "descriptors"             => 22896,
                         "desegregation"           => 14093,
                         "deseret"                 => 17391,
                         "deserters"               => 16482,
                         "desertification"         => 22020,
                         "deserts"                 => 9570,
                         "deshmukh"                => 22865,
                         "deshpande"               => 27363,
                         "desiccation"             => 28179,
                         "design"                  => 324,
                         "designate"               => 8052,
                         "designated"              => 1106,
                         "designates"              => 14643,
                         "designating"             => 12778,
                         "designation"             => 2721,
                         "designations"            => 7840,
                         "designator"              => 21627,
                         "designed"                => 435,
                         "designers"               => 3919,
                         "designing"               => 4562,
                         "designs"                 => 1705,
                         "desirability"            => 22688,
                         "desirable"               => 6166,
                         "desired"                 => 3530,
                         "desiring"                => 15236,
                         "desirous"                => 29856,
                         "desktops"                => 22370,
                         "despatch"                => 20370,
                         "despatched"              => 17746,
                         "despatches"              => 13165,
                         "despenser"               => 29139,
                         "despite"                 => 434,
                         "despot"                  => 17274,
                         "despotate"               => 28569,
                         "despotic"                => 27643,
                         "despotism"               => 28735,
                         "dessau"                  => 15505,
                         "destabilizing"           => 29199,
                         "destination"             => 2970,
                         "destinations"            => 4161,
                         "destino"                 => 26469,
                         "destitute"               => 12833,
                         "destroyed"               => 1042,
                         "destroyer"               => 3453,
                         "destroyers"              => 4826,
                         "destruction"             => 2175,
                         "detachable"              => 15699,
                         "detached"                => 5089,
                         "detachment"              => 4580,
                         "detachments"             => 9773,
                         "detailed"                => 2257,
                         "detailing"               => 6534,
                         "detained"                => 5471,
                         "detainee"                => 16897,
                         "detainees"               => 8635,
                         "detect"                  => 4610,
                         "detectable"              => 14243,
                         "detected"                => 4379,
                         "detecting"               => 9174,
                         "detection"               => 3926,
                         "detects"                 => 14326,
                         "deter"                   => 10732,
                         "detergents"              => 22539,
                         "deteriorated"            => 6998,
                         "deteriorates"            => 27671,
                         "deteriorating"           => 9371,
                         "deterioration"           => 8745,
                         "determinant"             => 11993,
                         "determinants"            => 16497,
                         "determination"           => 4165,
                         "determinations"          => 21081,
                         "determine"               => 1842,
                         "determined"              => 1435,
                         "determines"              => 5851,
                         "determining"             => 4375,
                         "determinism"             => 15943,
                         "deterministic"           => 12151,
                         "deterred"                => 20560,
                         "deterrence"              => 16404,
                         "detested"                => 24872,
                         "dethroned"               => 20671,
                         "detmold"                 => 28992,
                         "detonated"               => 10410,
                         "detoxification"          => 27292,
                         "detractors"              => 13954,
                         "detrimental"             => 9706,
                         "detritus"                => 18943,
                         "deuterium"               => 18084,
                         "deuteronomy"             => 18248,
                         "deutsche"                => 4568,
                         "deutschen"               => 16976,
                         "deutscher"               => 12464,
                         "deutsches"               => 15349,
                         "deutz"                   => 28600,
                         "devaluation"             => 18403,
                         "devalued"                => 26376,
                         "devanagari"              => 16033,
                         "devarajan"               => 27497,
                         "devas"                   => 19893,
                         "develop"                 => 1202,
                         "developed"               => 373,
                         "developer"               => 3452,
                         "developers"              => 3395,
                         "developing"              => 1424,
                         "development"             => 224,
                         "developmental"           => 5061,
                         "developmentally"         => 24591,
                         "developments"            => 2734,
                         "develops"                => 4105,
                         "deventer"                => 25625,
                         "devi"                    => 5653,
                         "deviance"                => 27955,
                         "deviates"                => 21507,
                         "deviating"               => 28204,
                         "deviation"               => 8162,
                         "deviations"              => 12362,
                         "device"                  => 1622,
                         "devices"                 => 1806,
                         "devised"                 => 5329,
                         "devises"                 => 24675,
                         "devizes"                 => 20494,
                         "devoid"                  => 10344,
                         "devolution"              => 14172,
                         "devolved"                => 12333,
                         "devonian"                => 10488,
                         "devonport"               => 12152,
                         "devonshire"              => 10802,
                         "devoted"                 => 2499,
                         "devotee"                 => 12375,
                         "devotees"                => 7332,
                         "devotes"                 => 17054,
                         "devotional"              => 9697,
                         "devotions"               => 19996,
                         "devout"                  => 8871,
                         "dewsbury"                => 16246,
                         "dexterity"               => 18701,
                         "dezful"                  => 29689,
                         "dezong"                  => 17179,
                         "dhabi"                   => 8297,
                         "dhaka"                   => 6337,
                         "dhamma"                  => 23278,
                         "dhanbad"                 => 29264,
                         "dhanush"                 => 28937,
                         "dharmendra"              => 29052,
                         "dharwad"                 => 20737,
                         "dhawan"                  => 24571,
                         "dhivehi"                 => 25780,
                         "dhoni"                   => 27369,
                         "dhruva"                  => 28004,
                         "diabetes"                => 5230,
                         "diacritic"               => 23026,
                         "diacritics"              => 18561,
                         "diadem"                  => 25508,
                         "diaghilev"               => 24533,
                         "diagnosed"               => 4113,
                         "diagnoses"               => 15401,
                         "diagnostic"              => 5830,
                         "diagnostics"             => 13599,
                         "diagonal"                => 7350,
                         "diagonally"              => 13807,
                         "diagonals"               => 23538,
                         "diagram"                 => 5845,
                         "diagrams"                => 8886,
                         "dialect"                 => 3156,
                         "dialectal"               => 20615,
                         "dialectic"               => 18000,
                         "dialectical"             => 17037,
                         "dialects"                => 4061,
                         "dialogue"                => 2981,
                         "dialogues"               => 8814,
                         "diameter"                => 2371,
                         "diameters"               => 14230,
                         "diamondback"             => 29486,
                         "diamondbacks"            => 10957,
                         "diaries"                 => 7052,
                         "diario"                  => 16381,
                         "diarist"                 => 21894,
                         "diarmait"                => 27846,
                         "diarmuid"                => 27764,
                         "diarrhoea"               => 27838,
                         "diaspora"                => 6426,
                         "diatoms"                 => 25493,
                         "diatonic"                => 16416,
                         "dibrugarh"               => 27593,
                         "dichomeris"              => 16433,
                         "dichotomy"               => 15392,
                         "dictated"                => 8785,
                         "dictator"                => 7548,
                         "dictatorial"             => 16499,
                         "dictatorship"            => 6631,
                         "diction"                 => 18017,
                         "dictionaries"            => 9830,
                         "dictionary"              => 3634,
                         "dictionnaire"            => 26860,
                         "dictum"                  => 27354,
                         "didactic"                => 15626,
                         "didcot"                  => 27757,
                         "diddley"                 => 20688,
                         "diderot"                 => 19639,
                         "didsbury"                => 28515,
                         "died"                    => 210,
                         "dielectric"              => 11816,
                         "diels"                   => 26766,
                         "diemen"                  => 17380,
                         "dieppe"                  => 14485,
                         "diesels"                 => 17465,
                         "dietary"                 => 7882,
                         "diets"                   => 10921,
                         "differ"                  => 3824,
                         "differed"                => 6735,
                         "differences"             => 1818,
                         "different"               => 237,
                         "differentiable"          => 15108,
                         "differential"            => 4052,
                         "differentials"           => 21149,
                         "differentiate"           => 7228,
                         "differentiated"          => 8146,
                         "differentiates"          => 17921,
                         "differentiating"         => 15422,
                         "differentiation"         => 7036,
                         "differing"               => 5876,
                         "differs"                 => 4337,
                         "difficulties"            => 2728,
                         "difficulty"              => 2896,
                         "diffraction"             => 10424,
                         "diffuse"                 => 9800,
                         "diffused"                => 19658,
                         "diffuser"                => 28283,
                         "diffusion"               => 6662,
                         "digestive"               => 10402,
                         "diggings"                => 28172,
                         "digipak"                 => 24719,
                         "digit"                   => 5502,
                         "digitally"               => 6573,
                         "digitisation"            => 26512,
                         "digitised"               => 24271,
                         "digitization"            => 24121,
                         "digitized"               => 14533,
                         "digits"                  => 6183,
                         "dignitaries"             => 9400,
                         "digraph"                 => 25735,
                         "digraphs"                => 26539,
                         "dihedral"                => 18229,
                         "dijkstra"                => 28113,
                         "dijon"                   => 13247,
                         "dilapidated"             => 11352,
                         "dilemmas"                => 18755,
                         "diliman"                 => 22847,
                         "dilip"                   => 17957,
                         "dilute"                  => 14904,
                         "diluted"                 => 13985,
                         "dilution"                => 15655,
                         "dimensional"             => 3073,
                         "dimensionality"          => 26914,
                         "dimensionless"           => 19571,
                         "dimensions"              => 3483,
                         "dimer"                   => 18720,
                         "dimers"                  => 28591,
                         "dimethyl"                => 23587,
                         "diminished"              => 6099,
                         "diminishes"              => 21787,
                         "diminishing"             => 11128,
                         "diminutive"              => 10149,
                         "dimitar"                 => 19566,
                         "dimitrie"                => 26702,
                         "dimitrios"               => 19564,
                         "dimitrov"                => 17524,
                         "dimorphic"               => 20454,
                         "dimorphism"              => 15053,
                         "dinajpur"                => 28954,
                         "dinar"                   => 18848,
                         "dinars"                  => 27412,
                         "dinas"                   => 27455,
                         "dindigul"                => 29821,
                         "dingoes"                 => 26525,
                         "dinos"                   => 27942,
                         "diocesan"                => 6817,
                         "diocese"                 => 1784,
                         "dioceses"                => 7981,
                         "diocletian"              => 13892,
                         "diode"                   => 12194,
                         "diodes"                  => 15333,
                         "diodorus"                => 18672,
                         "dioecious"               => 22786,
                         "diogo"                   => 16783,
                         "diomedes"                => 28333,
                         "dionysius"               => 12016,
                         "dioramas"                => 29875,
                         "diouf"                   => 29407,
                         "dioxide"                 => 5073,
                         "dioxin"                  => 29708,
                         "diphosphate"             => 17499,
                         "diphthong"               => 24408,
                         "diphthongs"              => 16925,
                         "diplo"                   => 26409,
                         "diploid"                 => 16520,
                         "diploma"                 => 3666,
                         "diplomacy"               => 6386,
                         "diplomas"                => 11156,
                         "diplomat"                => 4210,
                         "diplomatic"              => 2627,
                         "diplomatically"          => 29363,
                         "diplomats"               => 7961,
                         "dipole"                  => 11810,
                         "diptera"                 => 22410,
                         "dirac"                   => 12751,
                         "direct"                  => 848,
                         "direct3d"                => 29770,
                         "directed"                => 493,
                         "directing"               => 3663,
                         "direction"               => 1035,
                         "directional"             => 7326,
                         "directive"               => 6032,
                         "directives"              => 11786,
                         "directly"                => 906,
                         "director"                => 291,
                         "directorate"             => 5871,
                         "directorates"            => 22779,
                         "directorial"             => 7698,
                         "directories"             => 12815,
                         "directors"               => 1655,
                         "directorship"            => 13630,
                         "directory"               => 5350,
                         "directs"                 => 8191,
                         "directv"                 => 13308,
                         "directx"                 => 21275,
                         "dirge"                   => 27523,
                         "dirichlet"               => 17041,
                         "disabilities"            => 5102,
                         "disability"              => 4692,
                         "disabled"                => 3701,
                         "disables"                => 28153,
                         "disabling"               => 15642,
                         "disadvantage"            => 7514,
                         "disadvantaged"           => 9057,
                         "disadvantages"           => 8252,
                         "disaffected"             => 18101,
                         "disagreed"               => 7294,
                         "disagreements"           => 7794,
                         "disallowed"              => 14431,
                         "disambiguation"          => 1488,
                         "disapproval"             => 10358,
                         "disapproved"             => 11812,
                         "disarmament"             => 9918,
                         "disassembled"            => 15864,
                         "disassembly"             => 28532,
                         "disasters"               => 6670,
                         "disband"                 => 11953,
                         "disbanded"               => 2934,
                         "disbanding"              => 10333,
                         "disbandment"             => 13094,
                         "disbursed"               => 29379,
                         "disc"                    => 1954,
                         "discal"                  => 11313,
                         "discard"                 => 14040,
                         "discarded"               => 7020,
                         "discarding"              => 18946,
                         "discards"                => 25459,
                         "discern"                 => 15506,
                         "discerned"               => 20448,
                         "discernible"             => 15687,
                         "discharge"               => 4338,
                         "discharged"              => 5406,
                         "discharges"              => 11183,
                         "disciple"                => 6532,
                         "disciples"               => 6095,
                         "disciplinarian"          => 26528,
                         "disciplinary"            => 6395,
                         "discipline"              => 3306,
                         "disciplines"             => 4213,
                         "disclaimer"              => 18628,
                         "disclose"                => 9519,
                         "disclosed"               => 7670,
                         "discloses"               => 27147,
                         "disclosing"              => 18191,
                         "disclosures"             => 16521,
                         "discography"             => 3256,
                         "disconnection"           => 27843,
                         "discontent"              => 9478,
                         "discontented"            => 25667,
                         "discontinuation"         => 14342,
                         "discontinued"            => 3138,
                         "discontinuing"           => 24053,
                         "discontinuities"         => 28293,
                         "discontinuity"           => 18809,
                         "discontinuous"           => 15956,
                         "discounted"              => 10330,
                         "discounts"               => 12813,
                         "discourages"             => 23559,
                         "discourse"               => 5788,
                         "discourses"              => 11986,
                         "discovered"              => 905,
                         "discoverer"              => 12710,
                         "discoverers"             => 26214,
                         "discoveries"             => 5719,
                         "discovering"             => 5675,
                         "discovers"               => 3220,
                         "discovery"               => 1715,
                         "discredited"             => 12884,
                         "discrete"                => 5734,
                         "discretionary"           => 14525,
                         "discriminant"            => 25849,
                         "discriminate"            => 13669,
                         "discriminated"           => 14239,
                         "discrimination"          => 3276,
                         "discriminatory"          => 10391,
                         "discs"                   => 5608,
                         "discursive"              => 26692,
                         "discusses"               => 5804,
                         "discussions"             => 3727,
                         "discworld"               => 20459,
                         "disease"                 => 1184,
                         "diseases"                => 2725,
                         "disembark"               => 21831,
                         "disembarked"             => 14317,
                         "disembarking"            => 24679,
                         "disembodied"             => 22726,
                         "disenchanted"            => 18265,
                         "disenfranchised"         => 19240,
                         "disengagement"           => 20325,
                         "disestablished"          => 17736,
                         "disestablishment"        => 24081,
                         "disguising"              => 22346,
                         "disheartened"            => 27551,
                         "disinfection"            => 25761,
                         "disintegration"          => 12469,
                         "disjoint"                => 16450,
                         "disjointed"              => 22301,
                         "disjunct"                => 24185,
                         "disk"                    => 3545,
                         "disliked"                => 7519,
                         "dislocation"             => 16870,
                         "dislocations"            => 24701,
                         "dismantled"              => 6167,
                         "dismantling"             => 12315,
                         "dismay"                  => 10041,
                         "dismayed"                => 15047,
                         "dismembered"             => 19786,
                         "dismissal"               => 5733,
                         "dismissals"              => 20716,
                         "dismissed"               => 2639,
                         "dismisses"               => 13202,
                         "dismounted"              => 14632,
                         "disobedience"            => 11166,
                         "disorder"                => 3135,
                         "disordered"              => 18649,
                         "disorders"               => 3849,
                         "disparaged"              => 29862,
                         "disparate"               => 10965,
                         "disparities"             => 14875,
                         "disparity"               => 11524,
                         "dispatched"              => 5450,
                         "dispatches"              => 10885,
                         "dispatching"             => 17973,
                         "dispel"                  => 21305,
                         "dispensary"              => 14442,
                         "dispensation"            => 15371,
                         "dispensed"               => 15359,
                         "dispersal"               => 9002,
                         "disperse"                => 10021,
                         "dispersed"               => 5772,
                         "dispersing"              => 19832,
                         "dispersion"              => 9555,
                         "displaced"               => 4696,
                         "displacement"            => 4968,
                         "displacements"           => 20670,
                         "displaces"               => 28526,
                         "displacing"              => 14027,
                         "display"                 => 1466,
                         "displayed"               => 2455,
                         "displaying"              => 6022,
                         "displays"                => 3068,
                         "disposals"               => 18725,
                         "disposed"                => 8277,
                         "dispositions"            => 19165,
                         "dispossessed"            => 19062,
                         "disproportionate"        => 13025,
                         "disproportionately"      => 14850,
                         "disproved"               => 20957,
                         "disputation"             => 28178,
                         "dispute"                 => 2417,
                         "disputed"                => 3935,
                         "disputes"                => 4006,
                         "disqualification"        => 9419,
                         "disqualified"            => 6938,
                         "disregarded"             => 14049,
                         "disregarding"            => 18686,
                         "disrepair"               => 9056,
                         "disrepute"               => 29520,
                         "disrupted"               => 7347,
                         "disruption"              => 7380,
                         "disruptions"             => 15947,
                         "disruptive"              => 12467,
                         "dissatisfaction"         => 9330,
                         "dissatisfied"            => 8784,
                         "disseminate"             => 13848,
                         "disseminated"            => 12836,
                         "disseminating"           => 16852,
                         "dissemination"           => 9262,
                         "dissension"              => 20398,
                         "dissent"                 => 7829,
                         "dissented"               => 18699,
                         "dissenters"              => 14414,
                         "dissenting"              => 10484,
                         "dissertation"            => 5760,
                         "dissertations"           => 18831,
                         "dissident"               => 9681,
                         "dissidents"              => 11244,
                         "dissipated"              => 8820,
                         "dissipating"             => 15573,
                         "dissipation"             => 15217,
                         "dissociated"             => 29422,
                         "dissociation"            => 14312,
                         "dissolution"             => 4171,
                         "dissolved"               => 3032,
                         "dissolves"               => 16158,
                         "dissolving"              => 12796,
                         "dissonance"              => 16695,
                         "dissonant"               => 22367,
                         "dissuaded"               => 23085,
                         "distal"                  => 9729,
                         "distance"                => 963,
                         "distanced"               => 12837,
                         "distances"               => 4324,
                         "distant"                 => 3476,
                         "distantly"               => 14616,
                         "distillation"            => 11363,
                         "distilled"               => 12003,
                         "distilleries"            => 19842,
                         "distillers"              => 20740,
                         "distillery"              => 8447,
                         "distilling"              => 20336,
                         "distinct"                => 1776,
                         "distinction"             => 2516,
                         "distinctions"            => 7904,
                         "distinctive"             => 2654,
                         "distinctively"           => 14259,
                         "distinctiveness"         => 25171,
                         "distinguish"             => 3758,
                         "distinguishable"         => 12322,
                         "distinguished"           => 1595,
                         "distinguishes"           => 8564,
                         "distinguishing"          => 6788,
                         "distorted"               => 8080,
                         "distorting"              => 22695,
                         "distortion"              => 7377,
                         "distortions"             => 15314,
                         "distribute"              => 5693,
                         "distributed"             => 1647,
                         "distributes"             => 9631,
                         "distributing"            => 6933,
                         "distribution"            => 883,
                         "distributions"           => 6821,
                         "distributive"            => 18712,
                         "distributor"             => 6105,
                         "distributors"            => 7518,
                         "district"                => 104,
                         "districts"               => 1126,
                         "distrito"                => 18371,
                         "distrusted"              => 22226,
                         "disturbances"            => 8257,
                         "disulfide"               => 15494,
                         "disuse"                  => 12732,
                         "disused"                 => 8684,
                         "ditches"                 => 10495,
                         "ditko"                   => 28476,
                         "ditton"                  => 24344,
                         "diurnal"                 => 12563,
                         "divan"                   => 22203,
                         "divas"                   => 13022,
                         "dived"                   => 17521,
                         "diverge"                 => 15622,
                         "diverged"                => 12188,
                         "divergence"              => 9760,
                         "divergent"               => 10485,
                         "diverges"                => 18722,
                         "diverging"               => 18042,
                         "diverse"                 => 2433,
                         "diversification"         => 12119,
                         "diversified"             => 7897,
                         "diversifying"            => 24732,
                         "diversity"               => 3149,
                         "diverted"                => 6882,
                         "diverts"                 => 26648,
                         "divested"                => 16814,
                         "divestment"              => 25079,
                         "divide"                  => 4254,
                         "divided"                 => 959,
                         "dividend"                => 11640,
                         "dividends"               => 11842,
                         "divides"                 => 6903,
                         "dividing"                => 5834,
                         "divination"              => 14851,
                         "divinely"                => 21867,
                         "diving"                  => 3609,
                         "divinities"              => 28642,
                         "divinity"                => 6156,
                         "divisao"                 => 21503,
                         "divisible"               => 16955,
                         "divisie"                 => 16654,
                         "division"                => 220,
                         "divisional"              => 5273,
                         "divisione"               => 13883,
                         "divisions"               => 1652,
                         "divisive"                => 15405,
                         "divisor"                 => 17567,
                         "divisors"                => 21999,
                         "divizia"                 => 20962,
                         "divya"                   => 16387,
                         "diwali"                  => 17742,
                         "diwan"                   => 15036,
                         "dixieland"               => 20055,
                         "dixit"                   => 20489,
                         "diyarbakir"              => 21348,
                         "djibouti"                => 10848,
                         "djing"                   => 22776,
                         "djokovic"                => 12335,
                         "djurgarden"              => 23935,
                         "djurgardens"             => 21440,
                         "dmytro"                  => 23768,
                         "dnieper"                 => 15324,
                         "dniester"                => 22273,
                         "dnipro"                  => 22210,
                         "dnipropetrovsk"          => 16086,
                         "dobra"                   => 27995,
                         "dobro"                   => 25490,
                         "dobruja"                 => 24205,
                         "doc"                     => 20,
                         "docent"                  => 21777,
                         "docked"                  => 10017,
                         "docklands"               => 14435,
                         "dockyard"                => 8718,
                         "dockyards"               => 23476,
                         "doctoral"                => 4204,
                         "doctorate"               => 3334,
                         "doctorates"              => 11729,
                         "doctrinal"               => 11605,
                         "doctrine"                => 3018,
                         "doctrines"               => 7761,
                         "docudrama"               => 23409,
                         "document"                => 2132,
                         "documenta"               => 27157,
                         "documentaries"           => 5371,
                         "documentary"             => 1397,
                         "documentation"           => 4675,
                         "documented"              => 3048,
                         "documenting"             => 8017,
                         "documents"               => 1800,
                         "dodecahedron"            => 24551,
                         "dodecanese"              => 29411,
                         "dogmas"                  => 28716,
                         "dogmatic"                => 15335,
                         "dolichoderus"            => 28644,
                         "dolmen"                  => 23600,
                         "dolmens"                 => 29840,
                         "dolna"                   => 28133,
                         "dolne"                   => 27575,
                         "dolni"                   => 28051,
                         "dolny"                   => 29258,
                         "dolomites"               => 27214,
                         "domain"                  => 1936,
                         "domaine"                 => 22052,
                         "domains"                 => 4608,
                         "dome"                    => 3337,
                         "domed"                   => 10649,
                         "domes"                   => 9278,
                         "domesday"                => 7176,
                         "domestic"                => 1433,
                         "domestically"            => 8851,
                         "domesticated"            => 10146,
                         "domestication"           => 17013,
                         "domhnall"                => 27047,
                         "domiciled"               => 29370,
                         "dominance"               => 5024,
                         "dominant"                => 2518,
                         "dominate"                => 5726,
                         "dominated"               => 2174,
                         "dominates"               => 9336,
                         "dominating"              => 7734,
                         "domination"              => 6350,
                         "domingos"                => 24404,
                         "dominican"               => 3566,
                         "dominicana"              => 29625,
                         "dominicans"              => 13833,
                         "dominions"               => 11989,
                         "domitian"                => 18769,
                         "domnall"                 => 22269,
                         "domus"                   => 21540,
                         "donated"                 => 2305,
                         "donates"                 => 18394,
                         "donations"               => 3973,
                         "donau"                   => 24066,
                         "donbass"                 => 18308,
                         "doncaster"               => 6477,
                         "donegal"                 => 8170,
                         "donetsk"                 => 8918,
                         "dongguan"                => 26750,
                         "donington"               => 16782,
                         "donitz"                  => 24531,
                         "donizetti"               => 15179,
                         "donja"                   => 23270,
                         "donji"                   => 19206,
                         "donne"                   => 16107,
                         "donned"                  => 17657,
                         "donning"                 => 20941,
                         "donors"                  => 6286,
                         "doordarshan"             => 18469,
                         "dopamine"                => 10089,
                         "dopaminergic"            => 27172,
                         "doping"                  => 8013,
                         "doppler"                 => 10754,
                         "dorchester"              => 9045,
                         "dorde"                   => 24442,
                         "dordevic"                => 26450,
                         "dordogne"                => 17247,
                         "dordrecht"               => 18437,
                         "doric"                   => 10990,
                         "dorid"                   => 24608,
                         "dorje"                   => 19136,
                         "dorking"                 => 22321,
                         "dormancy"                => 22703,
                         "dormant"                 => 8466,
                         "dormer"                  => 15588,
                         "dormers"                 => 17754,
                         "dormition"               => 28489,
                         "dormitories"             => 10854,
                         "dormitory"               => 7978,
                         "doron"                   => 27964,
                         "dorsal"                  => 4601,
                         "dorsally"                => 19346,
                         "dorset"                  => 5362,
                         "dorsum"                  => 13009,
                         "doses"                   => 7725,
                         "dosing"                  => 23338,
                         "dostoevsky"              => 29955,
                         "dothan"                  => 25040,
                         "douai"                   => 17766,
                         "douala"                  => 21068,
                         "double"                  => 833,
                         "doubleheader"            => 17740,
                         "doubles"                 => 2219,
                         "doubling"                => 7499,
                         "doubs"                   => 19762,
                         "doubtless"               => 19079,
                         "douro"                   => 19229,
                         "dowager"                 => 7635,
                         "dowlatabad"              => 26807,
                         "downbeat"                => 23325,
                         "downe"                   => 28696,
                         "downed"                  => 9342,
                         "downfall"                => 7854,
                         "downfield"               => 29332,
                         "downforce"               => 26721,
                         "downgrade"               => 27882,
                         "downgraded"              => 10977,
                         "download"                => 3347,
                         "downloadable"            => 8671,
                         "downloads"               => 7470,
                         "downplayed"              => 19629,
                         "downsized"               => 22148,
                         "downstream"              => 4769,
                         "downton"                 => 20466,
                         "downtown"                => 1539,
                         "downturn"                => 10710,
                         "downward"                => 7375,
                         "downwards"               => 11409,
                         "downwind"                => 22977,
                         "dowry"                   => 9882,
                         "dr."                     => 740,
                         "draconian"               => 24212,
                         "draft"                   => 1161,
                         "drafted"                 => 2386,
                         "drafting"                => 7321,
                         "drafts"                  => 9692,
                         "draftsman"               => 16014,
                         "dragonflies"             => 21171,
                         "dragonlance"             => 23524,
                         "dragoons"                => 9535,
                         "drainage"                => 4100,
                         "drainages"               => 25269,
                         "drained"                 => 6257,
                         "draining"                => 9206,
                         "drains"                  => 6860,
                         "drama"                   => 949,
                         "dramas"                  => 5631,
                         "dramatic"                => 2425,
                         "dramatically"            => 4615,
                         "dramatised"              => 23412,
                         "dramatist"               => 10716,
                         "dramatists"              => 19000,
                         "dramatization"           => 24558,
                         "dramatized"              => 17720,
                         "dramedy"                 => 29234,
                         "drammen"                 => 18312,
                         "drapery"                 => 19775,
                         "drastically"             => 7522,
                         "draught"                 => 9462,
                         "draughts"                => 24175,
                         "draughtsman"             => 16258,
                         "draupadi"                => 26468,
                         "drava"                   => 17172,
                         "dravid"                  => 25025,
                         "dravida"                 => 15564,
                         "dravidian"               => 14386,
                         "draw"                    => 1275,
                         "drawdown"                => 25756,
                         "drawing"                 => 2090,
                         "drawings"                => 3531,
                         "drawn"                   => 1668,
                         "draws"                   => 3810,
                         "dreadnought"             => 13931,
                         "dreadnoughts"            => 20045,
                         "dreamland"               => 22101,
                         "dreamwave"               => 24187,
                         "dreamworks"              => 12253,
                         "dredd"                   => 12691,
                         "drenthe"                 => 20640,
                         "drepanidae"              => 28656,
                         "dresdner"                => 29024,
                         "dressings"               => 15624,
                         "dreux"                   => 28322,
                         "dreyfus"                 => 11142,
                         "driest"                  => 15487,
                         "drifters"                => 20419,
                         "drilled"                 => 9577,
                         "drillers"                => 25803,
                         "drilling"                => 5878,
                         "drina"                   => 23671,
                         "driven"                  => 1958,
                         "drivers"                 => 2370,
                         "drivetime"               => 28819,
                         "drivetrain"              => 21666,
                         "drogheda"                => 14663,
                         "droit"                   => 20245,
                         "drome"                   => 21234,
                         "drone"                   => 8616,
                         "drooping"                => 25217,
                         "droplet"                 => 21461,
                         "droplets"                => 13814,
                         "drosera"                 => 23776,
                         "drosophila"              => 12904,
                         "drought"                 => 5379,
                         "droughts"                => 14362,
                         "druce"                   => 23482,
                         "drum"                    => 2699,
                         "drumming"                => 9089,
                         "drums"                   => 2252,
                         "drusus"                  => 29333,
                         "druze"                   => 11948,
                         "dryandra"                => 23737,
                         "drydock"                 => 14933,
                         "dryness"                 => 25834,
                         "dual"                    => 2311,
                         "dualism"                 => 18264,
                         "dualistic"               => 29523,
                         "duality"                 => 11332,
                         "dubai"                   => 4238,
                         "dubbed"                  => 3230,
                         "dubbing"                 => 10945,
                         "dubbo"                   => 25632,
                         "dubliners"               => 25195,
                         "dubrovnik"               => 11964,
                         "dubstep"                 => 16696,
                         "ducal"                   => 10575,
                         "ducats"                  => 23797,
                         "duchies"                 => 15219,
                         "duchovny"                => 20256,
                         "duchy"                   => 3681,
                         "ductile"                 => 25359,
                         "due"                     => 183,
                         "duel"                    => 5790,
                         "duels"                   => 16321,
                         "duet"                    => 4691,
                         "duets"                   => 9992,
                         "dufferin"                => 16400,
                         "dugdale"                 => 22302,
                         "dugouts"                 => 25422,
                         "duisburg"                => 12981,
                         "dukakis"                 => 20701,
                         "dukedom"                 => 16275,
                         "dukla"                   => 20383,
                         "dulcimer"                => 26347,
                         "duller"                  => 20259,
                         "dulwich"                 => 13357,
                         "dumbarton"               => 10865,
                         "dumfries"                => 10730,
                         "dumitru"                 => 24195,
                         "dunams"                  => 16329,
                         "dunbartonshire"          => 22836,
                         "dunblane"                => 25255,
                         "dundalk"                 => 13253,
                         "dunder"                  => 26577,
                         "dunedin"                 => 7661,
                         "dunes"                   => 6740,
                         "dunfermline"             => 11398,
                         "dungannon"               => 20637,
                         "dungeness"               => 29074,
                         "dungeons"                => 6217,
                         "dunhuang"                => 26495,
                         "dunkeld"                 => 22640,
                         "dunkerque"               => 29505,
                         "dunkirk"                 => 10127,
                         "dunstable"               => 19903,
                         "dunster"                 => 27288,
                         "dunwich"                 => 25175,
                         "duodenum"                => 27361,
                         "duomo"                   => 23273,
                         "duopoly"                 => 21645,
                         "dupage"                  => 23429,
                         "duplicated"              => 11860,
                         "duplicates"              => 18378,
                         "duplicating"             => 27595,
                         "duplication"             => 11464,
                         "dupri"                   => 24411,
                         "duquesne"                => 11265,
                         "durability"              => 10128,
                         "durable"                 => 8523,
                         "durad"                   => 29982,
                         "duration"                => 3405,
                         "durations"               => 20807,
                         "durban"                  => 8368,
                         "durbar"                  => 19399,
                         "durer"                   => 17192,
                         "durga"                   => 9840,
                         "durgapur"                => 23550,
                         "during"                  => 41,
                         "durkheim"                => 20308,
                         "durrani"                 => 17145,
                         "durres"                  => 19438,
                         "duryodhana"              => 25245,
                         "dusan"                   => 12277,
                         "dushanbe"                => 24283,
                         "dusky"                   => 14337,
                         "dusseldorf"              => 7011,
                         "dutch"                   => 863,
                         "duties"                  => 1792,
                         "duvalier"                => 25274,
                         "duxbury"                 => 25987,
                         "dvina"                   => 25772,
                         "dwarf"                   => 5091,
                         "dwarfed"                 => 27336,
                         "dwarfism"                => 26549,
                         "dwarfs"                  => 11196,
                         "dwarka"                  => 26218,
                         "dwarves"                 => 12505,
                         "dwellers"                => 9496,
                         "dwelling"                => 5059,
                         "dwellings"               => 5886,
                         "dwelt"                   => 19018,
                         "dwindle"                 => 28088,
                         "dwindled"                => 11934,
                         "dwindling"               => 12453,
                         "dyfed"                   => 29530,
                         "dynamic"                 => 3083,
                         "dynamical"               => 11709,
                         "dynamically"             => 12232,
                         "dynamics"                => 4034,
                         "dynamism"                => 22479,
                         "dynamos"                 => 21009,
                         "dynastic"                => 9801,
                         "dynasties"               => 7497,
                         "dynasty"                 => 1490,
                         "dyschirius"              => 26313,
                         "dysentery"               => 15999,
                         "dysfunction"             => 9746,
                         "dysplasia"               => 17841,
                         "dystopian"               => 16912,
                         "dystrophy"               => 17124,
                         "dzogchen"                => 28349,
                         "dzong"                   => 28557,
                         "dzungar"                 => 28665,
                         "e.g."                    => 3036,
                         "e9e9e9"                  => 12145,
                         "each"                    => 124,
                         "eagerness"               => 23677,
                         "ealing"                  => 11558,
                         "eamon"                   => 14847,
                         "eamonn"                  => 17309,
                         "eared"                   => 12316,
                         "earldom"                 => 9420,
                         "earlier"                 => 642,
                         "earliest"                => 1704,
                         "early"                   => 95,
                         "earmarked"               => 13558,
                         "earned"                  => 836,
                         "earner"                  => 25038,
                         "earners"                 => 19003,
                         "earnestly"               => 26439,
                         "earning"                 => 2520,
                         "earnings"                => 5997,
                         "earns"                   => 10478,
                         "earth"                   => 722,
                         "earthbound"              => 29727,
                         "earthen"                 => 11928,
                         "earthenware"             => 18945,
                         "earthquake"              => 2778,
                         "earthquakes"             => 6123,
                         "earths"                  => 14970,
                         "earthwork"               => 17636,
                         "earthworks"              => 11522,
                         "earthworm"               => 28573,
                         "earthworms"              => 22309,
                         "eased"                   => 13215,
                         "easement"                => 19391,
                         "easements"               => 28037,
                         "easily"                  => 1583,
                         "east"                    => 138,
                         "east/west"               => 29467,
                         "eastbound"               => 8374,
                         "eastbourne"              => 11411,
                         "eastenders"              => 8276,
                         "eastern"                 => 387,
                         "easternmost"             => 10637,
                         "eastgate"                => 26114,
                         "eastlake"                => 23336,
                         "eastleigh"               => 17902,
                         "eastward"                => 6051,
                         "eastwards"               => 9453,
                         "eateries"                => 21299,
                         "eatery"                  => 29936,
                         "ebbsfleet"               => 25124,
                         "ebenezer"                => 11189,
                         "ebook"                   => 19128,
                         "ebooks"                  => 24132,
                         "ebrahim"                 => 19099,
                         "eccellenza"              => 21324,
                         "eccentricity"            => 13687,
                         "ecclesia"                => 21684,
                         "ecclesiae"               => 28785,
                         "ecclesiastic"            => 21050,
                         "ecclesiastical"          => 4126,
                         "ecclestone"              => 25062,
                         "echelons"                => 19955,
                         "echinoderms"             => 29116,
                         "echoed"                  => 9665,
                         "echoes"                  => 8637,
                         "echoing"                 => 13462,
                         "echolocation"            => 25339,
                         "ecija"                   => 20907,
                         "eclectic"                => 7155,
                         "eclecticism"             => 26416,
                         "eclipsed"                => 11703,
                         "eclipses"                => 14346,
                         "eclipsing"               => 20880,
                         "ecliptic"                => 19237,
                         "ecole"                   => 5299,
                         "ecoles"                  => 23514,
                         "ecological"              => 4422,
                         "ecologically"            => 15645,
                         "ecologist"               => 17442,
                         "ecologists"              => 22918,
                         "ecology"                 => 3762,
                         "ecommerce"               => 24512,
                         "econometric"             => 25414,
                         "econometrics"            => 22141,
                         "economic"                => 577,
                         "economical"              => 7167,
                         "economically"            => 5254,
                         "economics"               => 1782,
                         "economies"               => 6410,
                         "economist"               => 4436,
                         "economists"              => 7336,
                         "economy"                 => 1018,
                         "ecoregion"               => 11483,
                         "ecoregions"              => 18735,
                         "ecosystem"               => 6194,
                         "ecosystems"              => 7234,
                         "ecotourism"              => 17159,
                         "ecowas"                  => 25989,
                         "ecozone"                 => 16717,
                         "ecuador"                 => 3794,
                         "ecuadorian"              => 9608,
                         "ecumenical"              => 7820,
                         "ecumenism"               => 25528,
                         "edessa"                  => 17070,
                         "edgbaston"               => 17549,
                         "edge"                    => 1305,
                         "edged"                   => 6926,
                         "edges"                   => 3795,
                         "edgewater"               => 19891,
                         "edging"                  => 15386,
                         "edgware"                 => 20217,
                         "edible"                  => 7543,
                         "edict"                   => 8250,
                         "edicts"                  => 16468,
                         "edifice"                 => 11293,
                         "edifices"                => 22701,
                         "edina"                   => 22341,
                         "edinburgh"               => 2071,
                         "edirne"                  => 21365,
                         "edited"                  => 1959,
                         "editing"                 => 3647,
                         "edition"                 => 696,
                         "editions"                => 2323,
                         "editor"                  => 861,
                         "editorial"               => 2997,
                         "editorials"              => 11140,
                         "editors"                 => 3736,
                         "editorship"              => 12935,
                         "edits"                   => 11495,
                         "edmonton"                => 3611,
                         "edouard"                 => 8425,
                         "edrich"                  => 27530,
                         "edsel"                   => 21343,
                         "educacion"               => 28138,
                         "educate"                 => 6103,
                         "educated"                => 1444,
                         "educates"                => 14776,
                         "educating"               => 8482,
                         "education"               => 217,
                         "educational"             => 1164,
                         "educationalist"          => 23785,
                         "educationist"            => 19900,
                         "educations"              => 25606,
                         "educator"                => 4552,
                         "educators"               => 6651,
                         "edwardes"                => 23781,
                         "edwardian"               => 12211,
                         "edwardsville"            => 25470,
                         "eelam"                   => 18859,
                         "eerste"                  => 14124,
                         "eesti"                   => 23444,
                         "efendi"                  => 22800,
                         "effect"                  => 784,
                         "effected"                => 10370,
                         "effective"               => 1324,
                         "effectively"             => 2110,
                         "effectiveness"           => 4305,
                         "effector"                => 22200,
                         "effects"                 => 953,
                         "effendi"                 => 18239,
                         "efficacious"             => 28065,
                         "efficacy"                => 7114,
                         "efficiencies"            => 16377,
                         "efficiency"              => 2830,
                         "efficient"               => 2898,
                         "efficiently"             => 6974,
                         "effigies"                => 20859,
                         "effigy"                  => 12472,
                         "effingham"               => 20171,
                         "effluent"                => 18570,
                         "effort"                  => 1218,
                         "effortlessly"            => 19606,
                         "efforts"                 => 1012,
                         "egalitarian"             => 14394,
                         "egalitarianism"          => 28806,
                         "eglin"                   => 18294,
                         "eglinton"                => 13410,
                         "eglise"                  => 19431,
                         "egmond"                  => 29667,
                         "egmont"                  => 18273,
                         "egoism"                  => 29806,
                         "egremont"                => 25382,
                         "egress"                  => 28497,
                         "egret"                   => 24840,
                         "egrets"                  => 18272,
                         "egypt"                   => 1599,
                         "egyptian"                => 2249,
                         "egyptians"               => 7898,
                         "egyptologist"            => 20886,
                         "egyptologists"           => 23202,
                         "egyptology"              => 24002,
                         "ehime"                   => 21763,
                         "eidos"                   => 28052,
                         "eifel"                   => 20609,
                         "eigenvalue"              => 17513,
                         "eigenvalues"             => 13882,
                         "eigenvectors"            => 24585,
                         "eight"                   => 470,
                         "eighteens"               => 12756,
                         "eighteenth"              => 4929,
                         "eighth"                  => 1916,
                         "eilat"                   => 21938,
                         "eilean"                  => 21695,
                         "eilema"                  => 27686,
                         "einar"                   => 14275,
                         "eindhoven"               => 10497,
                         "einer"                   => 26756,
                         "eintracht"               => 14063,
                         "eireann"                 => 8606,
                         "eisenach"                => 17936,
                         "eisenbahn"               => 23419,
                         "eisenhower"              => 5931,
                         "eishockey"               => 21101,
                         "eisteddfod"              => 17892,
                         "ejecta"                  => 21979,
                         "ejected"                 => 8020,
                         "ejecting"                => 28459,
                         "ejection"                => 12825,
                         "ejector"                 => 27884,
                         "ejercito"                => 27453,
                         "ekiti"                   => 21088,
                         "ekstraklasa"             => 19723,
                         "elaborate"               => 3867,
                         "elaborated"              => 8726,
                         "elaborately"             => 14116,
                         "elaborates"              => 21168,
                         "elaborating"             => 23354,
                         "elaboration"             => 15384,
                         "elachista"               => 15010,
                         "elachistidae"            => 24261,
                         "elamite"                 => 29254,
                         "elapsed"                 => 15531,
                         "elastic"                 => 8446,
                         "elasticity"              => 13856,
                         "elbasan"                 => 28658,
                         "elblag"                  => 20763,
                         "elche"                   => 24506,
                         "elderly"                 => 4064,
                         "eldest"                  => 2559,
                         "eleazar"                 => 18793,
                         "elect"                   => 4195,
                         "elected"                 => 360,
                         "electing"                => 9806,
                         "election"                => 273,
                         "elections"               => 831,
                         "elective"                => 9542,
                         "electives"               => 15604,
                         "elector"                 => 7247,
                         "electoral"               => 1694,
                         "electorate"              => 4471,
                         "electorates"             => 11271,
                         "electors"                => 7296,
                         "electrical"              => 2083,
                         "electrically"            => 9263,
                         "electricity"             => 2321,
                         "electrics"               => 24208,
                         "electrification"         => 7737,
                         "electrified"             => 6741,
                         "electrifying"            => 24459,
                         "electroacoustic"         => 22891,
                         "electrochemical"         => 15738,
                         "electrocution"           => 26496,
                         "electrode"               => 9001,
                         "electrodes"              => 9847,
                         "electrodynamics"         => 22488,
                         "electrolysis"            => 19469,
                         "electrolyte"             => 12931,
                         "electrolytic"            => 19315,
                         "electromagnetic"         => 6107,
                         "electromagnetism"        => 20777,
                         "electromechanical"       => 18996,
                         "electronic"              => 1441,
                         "electronica"             => 10051,
                         "electronically"          => 9561,
                         "electronics"             => 3094,
                         "electrons"               => 5148,
                         "electrophilic"           => 26532,
                         "electrophoresis"         => 19843,
                         "electropop"              => 17983,
                         "electrostatic"           => 11962,
                         "elects"                  => 8640,
                         "elegans"                 => 12449,
                         "elegantly"               => 20717,
                         "elegiac"                 => 25593,
                         "elegies"                 => 26418,
                         "elegy"                   => 15385,
                         "elemental"               => 9468,
                         "elementary"              => 1723,
                         "elements"                => 910,
                         "elevated"                => 2894,
                         "elevating"               => 16506,
                         "elevation"               => 2115,
                         "elevations"              => 6359,
                         "eleventh"                => 4247,
                         "elfin"                   => 27115,
                         "elfman"                  => 24815,
                         "elfsborg"                => 25633,
                         "elgar"                   => 12179,
                         "eliade"                  => 22962,
                         "elicit"                  => 14669,
                         "elicited"                => 16003,
                         "eliciting"               => 27255,
                         "eliezer"                 => 15049,
                         "eligibility"             => 5802,
                         "eligible"                => 2610,
                         "elihu"                   => 23626,
                         "eliminated"              => 2198,
                         "eliminates"              => 11281,
                         "eliminating"             => 5576,
                         "elimination"             => 3534,
                         "eliminations"            => 19936,
                         "eliminator"              => 21563,
                         "eliot"                   => 6716,
                         "elisabetta"              => 28048,
                         "elite"                   => 2512,
                         "elites"                  => 9723,
                         "elitserien"              => 14334,
                         "eliya"                   => 26922,
                         "eliyahu"                 => 22365,
                         "elizabethan"             => 9744,
                         "elizabethtown"           => 18960,
                         "elkhart"                 => 18949,
                         "elkhorn"                 => 20295,
                         "ellerslie"               => 28993,
                         "ellesmere"               => 14402,
                         "ellice"                  => 24641,
                         "ellipse"                 => 16083,
                         "ellipsis"                => 28183,
                         "ellipsoid"               => 16745,
                         "elliptic"                => 9693,
                         "elliptical"              => 9116,
                         "elmhurst"                => 20539,
                         "elmwood"                 => 15800,
                         "elocution"               => 28521,
                         "elongate"                => 13033,
                         "elongated"               => 6831,
                         "elongation"              => 17637,
                         "eloquence"               => 16639,
                         "elphaba"                 => 25007,
                         "elphinstone"             => 18452,
                         "elsevier"                => 17891,
                         "elsewhere"               => 2405,
                         "elstree"                 => 21310,
                         "eltham"                  => 19337,
                         "elucidate"               => 24891,
                         "elucidated"              => 21761,
                         "elven"                   => 17395,
                         "elwes"                   => 24900,
                         "elysees"                 => 18850,
                         "elysian"                 => 29149,
                         "elytra"                  => 24496,
                         "emacs"                   => 23485,
                         "email"                   => 4694,
                         "emails"                  => 10132,
                         "emamzadeh"               => 21931,
                         "emanated"                => 29336,
                         "emanating"               => 15559,
                         "emancipation"            => 7729,
                         "embankment"              => 8566,
                         "embankments"             => 17200,
                         "embarcadero"             => 26631,
                         "embargo"                 => 10188,
                         "embarkation"             => 20011,
                         "embarked"                => 3911,
                         "embarking"               => 11297,
                         "embarks"                 => 19281,
                         "embassies"               => 9474,
                         "embassy"                 => 3010,
                         "embattled"               => 18818,
                         "embed"                   => 22516,
                         "embedded"                => 4408,
                         "embedding"               => 12503,
                         "embellished"             => 13438,
                         "embellishment"           => 27162,
                         "embellishments"          => 22312,
                         "emblazoned"              => 18568,
                         "emblem"                  => 5895,
                         "emblematic"              => 15984,
                         "emblems"                 => 12962,
                         "embodied"                => 8781,
                         "embodies"                => 14011,
                         "embody"                  => 15679,
                         "embodying"               => 22530,
                         "emboldened"              => 25107,
                         "embossed"                => 16789,
                         "embraced"                => 6479,
                         "embraces"                => 11749,
                         "embraer"                 => 17648,
                         "embroidered"             => 11162,
                         "embroidery"              => 10837,
                         "embroiled"               => 10903,
                         "embryo"                  => 9483,
                         "embryology"              => 24113,
                         "embryonic"               => 9777,
                         "emcee"                   => 18026,
                         "emden"                   => 16847,
                         "emerge"                  => 5128,
                         "emerged"                 => 2272,
                         "emergence"               => 4855,
                         "emergent"                => 12045,
                         "emerges"                 => 7278,
                         "emerging"                => 3045,
                         "emeritus"                => 4858,
                         "emigrant"                => 14294,
                         "emigrants"               => 9821,
                         "emigrate"                => 11343,
                         "emigrated"               => 3831,
                         "emigrating"              => 14498,
                         "emigration"              => 6482,
                         "emigre"                  => 14680,
                         "emigres"                 => 18893,
                         "eminent"                 => 5178,
                         "eminescu"                => 27300,
                         "emirate"                 => 11696,
                         "emirates"                => 5341,
                         "emirati"                 => 25098,
                         "emirs"                   => 26363,
                         "emissaries"              => 16519,
                         "emission"                => 5540,
                         "emissions"               => 4094,
                         "emits"                   => 14348,
                         "emitted"                 => 8810,
                         "emitter"                 => 16703,
                         "emitters"                => 27227,
                         "emitting"                => 11543,
                         "emlyn"                   => 26427,
                         "emmanuelle"              => 21746,
                         "emmeline"                => 25754,
                         "emmerdale"               => 13800,
                         "emmet"                   => 15786,
                         "emmylou"                 => 22264,
                         "emotive"                 => 19254,
                         "emperor"                 => 872,
                         "emperors"                => 6566,
                         "emphasis"                => 2675,
                         "emphasise"               => 15587,
                         "emphasised"              => 10303,
                         "emphasises"              => 17676,
                         "emphasising"             => 17712,
                         "emphasize"               => 6640,
                         "emphasized"              => 4923,
                         "emphasizes"              => 6961,
                         "emphasizing"             => 8083,
                         "empirical"               => 6131,
                         "empirically"             => 16454,
                         "empiricism"              => 22518,
                         "emplaced"                => 25539,
                         "emplacement"             => 20866,
                         "emplacements"            => 17265,
                         "employ"                  => 4578,
                         "employed"                => 1327,
                         "employees"               => 1558,
                         "employer"                => 4336,
                         "employers"               => 4318,
                         "employing"               => 5401,
                         "employment"              => 1975,
                         "employs"                 => 4429,
                         "empoli"                  => 25720,
                         "emporia"                 => 18118,
                         "empower"                 => 11502,
                         "empowered"               => 9141,
                         "empowering"              => 12803,
                         "empowerment"             => 8327,
                         "empowers"                => 22161,
                         "empresa"                 => 24257,
                         "empress"                 => 3691,
                         "empted"                  => 28847,
                         "empties"                 => 10595,
                         "emulate"                 => 10034,
                         "emulated"                => 13928,
                         "emulates"                => 28017,
                         "emulation"               => 12917,
                         "emulator"                => 15577,
                         "emulators"               => 24932,
                         "emulsion"                => 17466,
                         "enable"                  => 3374,
                         "enabled"                 => 3176,
                         "enables"                 => 4517,
                         "enabling"                => 4281,
                         "enact"                   => 10229,
                         "enacted"                 => 4119,
                         "enacting"                => 13651,
                         "enactment"               => 8306,
                         "enactments"              => 20606,
                         "enamel"                  => 9966,
                         "enantiomer"              => 29554,
                         "encamped"                => 17225,
                         "encampment"              => 11961,
                         "encampments"             => 25228,
                         "encapsulated"            => 16471,
                         "encapsulation"           => 22990,
                         "encased"                 => 14583,
                         "encephalopathy"          => 21781,
                         "encircle"                => 18185,
                         "encircled"               => 10942,
                         "encirclement"            => 14292,
                         "encircles"               => 23867,
                         "encircling"              => 15801,
                         "enclave"                 => 9558,
                         "enclaves"                => 14347,
                         "enclosed"                => 4294,
                         "encloses"                => 19673,
                         "enclosing"               => 12518,
                         "enclosure"               => 6661,
                         "enclosures"              => 12330,
                         "encode"                  => 11822,
                         "encoded"                 => 4275,
                         "encoder"                 => 19156,
                         "encodes"                 => 10824,
                         "encoding"                => 6366,
                         "encodings"               => 24103,
                         "encomienda"              => 28214,
                         "encompass"               => 8532,
                         "encompassed"             => 8454,
                         "encompasses"             => 4781,
                         "encompassing"            => 6873,
                         "encores"                 => 22796,
                         "encounter"               => 3328,
                         "encountered"             => 3283,
                         "encountering"            => 10476,
                         "encounters"              => 4273,
                         "encourage"               => 3221,
                         "encouraged"              => 2239,
                         "encourages"              => 5677,
                         "encroached"              => 23192,
                         "encroaching"             => 18911,
                         "encroachment"            => 13502,
                         "encroachments"           => 28724,
                         "encrypt"                 => 26962,
                         "encryption"              => 7844,
                         "encyclical"              => 14686,
                         "encyclopaedia"           => 9625,
                         "encyclopedia"            => 4949,
                         "encyclopedic"            => 17839,
                         "end"                     => 142,
                         "endangered"              => 3628,
                         "endeared"                => 26355,
                         "endeavored"              => 22242,
                         "endeavors"               => 9187,
                         "endeavour"               => 9155,
                         "endeavoured"             => 19184,
                         "endeavours"              => 14053,
                         "ended"                   => 649,
                         "endemic"                 => 2344,
                         "endemol"                 => 24980,
                         "enderby"                 => 23883,
                         "ending"                  => 1385,
                         "endocrine"               => 14667,
                         "endocrinology"           => 20412,
                         "endocytosis"             => 26551,
                         "endogenous"              => 13299,
                         "endometrial"             => 26548,
                         "endoplasmic"             => 21092,
                         "endorsed"                => 4215,
                         "endorsement"             => 7070,
                         "endorsements"            => 11276,
                         "endorses"                => 20795,
                         "endorsing"               => 13884,
                         "endoscopic"              => 24241,
                         "endoscopy"               => 27145,
                         "endothelial"             => 13499,
                         "endow"                   => 24914,
                         "endowed"                 => 6967,
                         "endowment"               => 5448,
                         "endowments"              => 14461,
                         "endpoint"                => 15769,
                         "endpoints"               => 17082,
                         "endurance"               => 5654,
                         "endured"                 => 7762,
                         "endures"                 => 22813,
                         "enduring"                => 6241,
                         "enemy"                   => 1328,
                         "energetic"               => 6766,
                         "energetically"           => 19722,
                         "energies"                => 7306,
                         "energon"                 => 23656,
                         "energy"                  => 573,
                         "enfeoffed"               => 24848,
                         "enforce"                 => 5924,
                         "enforceable"             => 18718,
                         "enforced"                => 5889,
                         "enforcement"             => 2474,
                         "enforcers"               => 18774,
                         "enforces"                => 19920,
                         "enforcing"               => 9096,
                         "engagements"             => 6765,
                         "engages"                 => 8107,
                         "engaging"                => 4647,
                         "engendered"              => 19896,
                         "engine"                  => 663,
                         "engined"                 => 7023,
                         "engineered"              => 5511,
                         "engineering"             => 787,
                         "engineers"               => 2192,
                         "engines"                 => 1549,
                         "england"                 => 275,
                         "englewood"               => 14471,
                         "english"                 => 221,
                         "englishmen"              => 15601,
                         "engraved"                => 6391,
                         "engraver"                => 8782,
                         "engravers"               => 19997,
                         "engraving"               => 8115,
                         "engravings"              => 9431,
                         "engulfed"                => 13869,
                         "enhance"                 => 4129,
                         "enhanced"                => 3567,
                         "enhancement"             => 7789,
                         "enhancements"            => 10804,
                         "enhances"                => 11663,
                         "enhancing"               => 7210,
                         "enigmatic"               => 12271,
                         "eniwetok"                => 13554,
                         "enjoined"                => 26233,
                         "enlai"                   => 24104,
                         "enlarge"                 => 13564,
                         "enlarged"                => 4316,
                         "enlargement"             => 10726,
                         "enlarging"               => 16974,
                         "enlightenment"           => 6098,
                         "enlil"                   => 27044,
                         "enlisted"                => 3261,
                         "enlisting"               => 13220,
                         "enlistment"              => 13198,
                         "enlists"                 => 14939,
                         "enmity"                  => 13832,
                         "ennio"                   => 21822,
                         "enniskillen"             => 20340,
                         "ennobled"                => 17982,
                         "enplanements"            => 23908,
                         "enquiry"                 => 10295,
                         "enraged"                 => 7973,
                         "enrich"                  => 13510,
                         "enriched"                => 8387,
                         "enrichment"              => 8699,
                         "enroll"                  => 8465,
                         "enrolled"                => 2805,
                         "enrolling"               => 11678,
                         "enrollment"              => 3338,
                         "enrollments"             => 23522,
                         "enrolls"                 => 15464,
                         "enrolment"               => 12734,
                         "enron"                   => 15716,
                         "enschede"                => 23274,
                         "ensemble"                => 2750,
                         "ensembles"               => 6964,
                         "enshrined"               => 10949,
                         "ensign"                  => 7225,
                         "enslaved"                => 9011,
                         "enslavement"             => 18546,
                         "ensued"                  => 6822,
                         "ensues"                  => 11460,
                         "ensuing"                 => 4771,
                         "ensure"                  => 1962,
                         "ensured"                 => 6057,
                         "ensures"                 => 7367,
                         "ensuring"                => 4910,
                         "entablature"             => 17759,
                         "entailed"                => 12583,
                         "entangled"               => 13105,
                         "entanglement"            => 17691,
                         "entebbe"                 => 29465,
                         "entente"                 => 13852,
                         "entered"                 => 694,
                         "entering"                => 1986,
                         "enters"                  => 2775,
                         "entertainer"             => 7741,
                         "entertainers"            => 10624,
                         "entertainment"           => 1019,
                         "entertainments"          => 14278,
                         "entertains"              => 27344,
                         "enthalpy"                => 20801,
                         "enthroned"               => 14477,
                         "enthronement"            => 27811,
                         "enthusiast"              => 9396,
                         "enthusiastically"        => 11732,
                         "enthusiasts"             => 6588,
                         "entirely"                => 1568,
                         "entirety"                => 5983,
                         "entities"                => 3957,
                         "entitled"                => 1234,
                         "entitlement"             => 14968,
                         "entitlements"            => 23644,
                         "entity"                  => 3307,
                         "entombed"                => 18497,
                         "entomological"           => 19862,
                         "entomologist"            => 12356,
                         "entomology"              => 14464,
                         "entrance"                => 1572,
                         "entrances"               => 7004,
                         "entrant"                 => 13657,
                         "entrants"                => 6530,
                         "entre"                   => 13246,
                         "entrenched"              => 10244,
                         "entrenchments"           => 27674,
                         "entrepreneur"            => 3937,
                         "entrepreneurial"         => 9770,
                         "entrepreneurs"           => 6228,
                         "entrepreneurship"        => 7417,
                         "entries"                 => 3779,
                         "entrusted"               => 6545,
                         "entry"                   => 1343,
                         "entryway"                => 29279,
                         "enugu"                   => 19528,
                         "enumerated"              => 13696,
                         "enumeration"             => 18166,
                         "enveloped"               => 15711,
                         "enveloping"              => 26341,
                         "enver"                   => 18702,
                         "environment"             => 1033,
                         "environmental"           => 1199,
                         "environmentalism"        => 17155,
                         "environmentalist"        => 12998,
                         "environmentalists"       => 14649,
                         "environmentally"         => 8062,
                         "environments"            => 3613,
                         "environs"                => 12476,
                         "envisaged"               => 10140,
                         "envisioned"              => 7204,
                         "envisions"               => 23512,
                         "envoy"                   => 7258,
                         "envoys"                  => 12070,
                         "enzymatic"               => 16044,
                         "enzyme"                  => 2846,
                         "enzymes"                 => 5720,
                         "enzymology"              => 12527,
                         "eocene"                  => 10834,
                         "eotvos"                  => 27568,
                         "eparchy"                 => 14862,
                         "ephemera"                => 24304,
                         "ephemeral"               => 14363,
                         "ephesus"                 => 14694,
                         "ephraim"                 => 11456,
                         "epic"                    => 3272,
                         "epicenter"               => 15542,
                         "epicentre"               => 29733,
                         "epics"                   => 12621,
                         "epidemic"                => 6033,
                         "epidemics"               => 12554,
                         "epidemiological"         => 17435,
                         "epidemiology"            => 9110,
                         "epidermal"               => 19839,
                         "epidermis"               => 17428,
                         "epigenetic"              => 16780,
                         "epigram"                 => 27949,
                         "epigrams"                => 24289,
                         "epigraph"                => 28098,
                         "epigraphic"              => 29882,
                         "epilepsy"                => 9647,
                         "epilogue"                => 10795,
                         "epiphanius"              => 29179,
                         "epiphytic"               => 27346,
                         "epirus"                  => 11374,
                         "episcopacy"              => 19117,
                         "episcopal"               => 3051,
                         "episcopalian"            => 18055,
                         "episcopate"              => 12182,
                         "episode"                 => 440,
                         "episodes"                => 1008,
                         "episodic"                => 11666,
                         "epistemic"               => 24078,
                         "epistemological"         => 19026,
                         "epistemology"            => 13508,
                         "epistle"                 => 11171,
                         "epistles"                => 12688,
                         "epistolary"              => 28343,
                         "epitaph"                 => 10979,
                         "epithelial"              => 11553,
                         "epithelium"              => 14452,
                         "epithet"                 => 7092,
                         "epithets"                => 21172,
                         "epitomized"              => 26089,
                         "epoch"                   => 8271,
                         "epochs"                  => 21784,
                         "eponym"                  => 22289,
                         "eponymous"               => 5344,
                         "epoque"                  => 29713,
                         "epsom"                   => 8643,
                         "epworth"                 => 26062,
                         "equal"                   => 1576,
                         "equaled"                 => 17781,
                         "equaling"                => 25340,
                         "equalised"               => 16570,
                         "equaliser"               => 13038,
                         "equalising"              => 25816,
                         "equality"                => 3694,
                         "equalization"            => 17209,
                         "equalize"                => 28531,
                         "equalized"               => 24228,
                         "equalled"                => 13780,
                         "equalling"               => 19912,
                         "equally"                 => 3342,
                         "equated"                 => 13523,
                         "equates"                 => 17572,
                         "equating"                => 19132,
                         "equation"                => 2807,
                         "equations"               => 3907,
                         "equator"                 => 8561,
                         "equatorial"              => 7300,
                         "equestrian"              => 6318,
                         "equidistant"             => 20510,
                         "equilateral"             => 21292,
                         "equilibria"              => 23624,
                         "equilibrium"             => 5136,
                         "equine"                  => 12885,
                         "equip"                   => 10521,
                         "equipment"               => 987,
                         "equipments"              => 22415,
                         "equipped"                => 1931,
                         "equipping"               => 15123,
                         "equitable"               => 9829,
                         "equities"                => 19252,
                         "equity"                  => 3544,
                         "equivalence"             => 8615,
                         "equivalent"              => 1797,
                         "equivalently"            => 12229,
                         "equivalents"             => 10197,
                         "equus"                   => 23726,
                         "era"                     => 743,
                         "eradicate"               => 12433,
                         "eradicated"              => 16936,
                         "eradicating"             => 26141,
                         "eradication"             => 12141,
                         "erastus"                 => 28268,
                         "erbil"                   => 27012,
                         "erdogan"                 => 14197,
                         "erdos"                   => 18530,
                         "erebidae"                => 13736,
                         "erect"                   => 6365,
                         "erected"                 => 2349,
                         "erectile"                => 21182,
                         "erecting"                => 14354,
                         "erectus"                 => 21509,
                         "eredivisie"              => 10774,
                         "eretz"                   => 24301,
                         "erfurt"                  => 13617,
                         "ergative"                => 26598,
                         "ergonomic"               => 26498,
                         "ergonomics"              => 22275,
                         "erhard"                  => 17559,
                         "erie"                    => 4532,
                         "erigeron"                => 22692,
                         "eriksson"                => 13262,
                         "erinsborough"            => 21336,
                         "eritrea"                 => 8581,
                         "eritrean"                => 14169,
                         "erlangen"                => 17685,
                         "erlewine"                => 13018,
                         "ernakulam"               => 14964,
                         "erode"                   => 13492,
                         "eroded"                  => 7949,
                         "erosion"                 => 5038,
                         "eroticism"               => 23897,
                         "erroll"                  => 28024,
                         "erroneous"               => 11378,
                         "erroneously"             => 9244,
                         "error"                   => 2707,
                         "errors"                  => 3773,
                         "erste"                   => 26216,
                         "erstwhile"               => 10049,
                         "erudite"                 => 19781,
                         "erudition"               => 24893,
                         "erupted"                 => 6642,
                         "erupting"                => 23055,
                         "eruption"                => 6297,
                         "eruptions"               => 9032,
                         "eruptive"                => 23642,
                         "erupts"                  => 20328,
                         "erythrocytes"            => 26412,
                         "erzhu"                   => 24438,
                         "erzurum"                 => 20456,
                         "escadrille"              => 21470,
                         "escalated"               => 9768,
                         "escalates"               => 28779,
                         "escalation"              => 13524,
                         "escalators"              => 16469,
                         "escapees"                => 18813,
                         "escapement"              => 22607,
                         "escapes"                 => 5036,
                         "escapist"                => 26503,
                         "escarpment"              => 9884,
                         "eschatology"             => 24321,
                         "escherichia"             => 19866,
                         "eschewed"                => 21268,
                         "eschewing"               => 27082,
                         "escondido"               => 21590,
                         "escorial"                => 27018,
                         "escorted"                => 5971,
                         "escorting"               => 8825,
                         "escuela"                 => 12608,
                         "escutcheon"              => 24697,
                         "esher"                   => 23870,
                         "eskisehir"               => 25903,
                         "eslamabad"               => 17958,
                         "esoteric"                => 9822,
                         "espanola"                => 12795,
                         "espanyol"                => 18370,
                         "especial"                => 22023,
                         "esperance"               => 16670,
                         "esperanto"               => 9872,
                         "espionage"               => 7410,
                         "espirito"                => 17553,
                         "esplanade"               => 13180,
                         "espn"                    => 4069,
                         "espn.com"                => 22958,
                         "espn2"                   => 20251,
                         "espoo"                   => 20547,
                         "esporte"                 => 15640,
                         "espouse"                 => 29849,
                         "espoused"                => 12972,
                         "espousing"               => 28253,
                         "esque"                   => 13175,
                         "esquimalt"               => 22642,
                         "essayist"                => 10282,
                         "essays"                  => 3650,
                         "essen"                   => 10334,
                         "essential"               => 2340,
                         "essentially"             => 2566,
                         "essex"                   => 3011,
                         "essonne"                 => 28464,
                         "establish"               => 1598,
                         "established"             => 254,
                         "establishes"             => 7520,
                         "establishing"            => 2427,
                         "establishment"           => 1437,
                         "establishments"          => 5977,
                         "estadio"                 => 6687,
                         "estado"                  => 13428,
                         "estate"                  => 924,
                         "estates"                 => 2967,
                         "esteghlal"               => 20096,
                         "esterhazy"               => 19444,
                         "estero"                  => 18346,
                         "estimate"                => 3636,
                         "estimated"               => 1128,
                         "estimates"               => 3396,
                         "estimating"              => 11609,
                         "estimation"              => 8826,
                         "estimations"             => 26660,
                         "estimator"               => 14797,
                         "estimators"              => 26278,
                         "estonia"                 => 3683,
                         "estonian"                => 4649,
                         "estonians"               => 20141,
                         "estoril"                 => 18252,
                         "estradiol"               => 24576,
                         "estrellas"               => 22790,
                         "estuaries"               => 12699,
                         "estuarine"               => 17379,
                         "estuary"                 => 6109,
                         "estudiantes"             => 15901,
                         "estudios"                => 24312,
                         "esztergom"               => 22446,
                         "etc."                    => 4884,
                         "etc.."                   => 21159,
                         "etcher"                  => 29595,
                         "etching"                 => 12281,
                         "etchings"                => 13955,
                         "ethanol"                 => 7439,
                         "ethereal"                => 15784,
                         "ethers"                  => 28131,
                         "ethical"                 => 4684,
                         "ethiopia"                => 3961,
                         "ethiopian"               => 5228,
                         "ethiopians"              => 19522,
                         "ethmia"                  => 22215,
                         "ethnic"                  => 1623,
                         "ethnically"              => 8692,
                         "ethnicities"             => 13542,
                         "ethnicity"               => 6168,
                         "ethniki"                 => 17283,
                         "ethnikos"                => 26563,
                         "ethno"                   => 17551,
                         "ethnographer"            => 22820,
                         "ethnographic"            => 10329,
                         "ethnography"             => 13627,
                         "ethnological"            => 22966,
                         "ethnologist"             => 24007,
                         "ethnologue"              => 22294,
                         "ethnology"               => 16283,
                         "ethnomusicology"         => 26475,
                         "ethos"                   => 10251,
                         "ethylene"                => 13248,
                         "etihad"                  => 24644,
                         "etiology"                => 18197,
                         "etobicoke"               => 17673,
                         "etruria"                 => 22562,
                         "etruscan"                => 11503,
                         "etruscans"               => 20989,
                         "etude"                   => 23529,
                         "etudes"                  => 12536,
                         "etymological"            => 17236,
                         "etymologically"          => 21834,
                         "etymologies"             => 22170,
                         "etymology"               => 3581,
                         "euboea"                  => 24901,
                         "eucalypt"                => 28064,
                         "eucalyptus"              => 9495,
                         "eucharist"               => 10693,
                         "eucharistic"             => 16187,
                         "euclidean"               => 8174,
                         "eudonia"                 => 27229,
                         "eugenics"                => 13750,
                         "eukaryotes"              => 14069,
                         "eukaryotic"              => 12215,
                         "eulima"                  => 29636,
                         "eunuchs"                 => 15157,
                         "euphemia"                => 22344,
                         "euphonium"               => 28011,
                         "euphorbia"               => 18089,
                         "euphorbiaceae"           => 24475,
                         "euphrates"               => 12614,
                         "eupithecia"              => 10371,
                         "eurasia"                 => 10544,
                         "eurasian"                => 8031,
                         "euripides"               => 18139,
                         "euro"                    => 3471,
                         "eurobasket"              => 11403,
                         "eurocopter"              => 25644,
                         "eurocup"                 => 14976,
                         "eurodance"               => 22735,
                         "eurogamer"               => 20751,
                         "euroleague"              => 9996,
                         "euromaidan"              => 27722,
                         "euronext"                => 28496,
                         "europaea"                => 29725,
                         "europe"                  => 429,
                         "europe/africa"           => 18647,
                         "european"                => 317,
                         "europeans"               => 4690,
                         "euros"                   => 7279,
                         "eurosceptic"             => 29568,
                         "eurosport"               => 25118,
                         "eurostar"                => 21681,
                         "eurovision"              => 3931,
                         "eurozone"                => 15085,
                         "eurydice"                => 23109,
                         "eurythmics"              => 27660,
                         "eusebian"                => 23719,
                         "eusebius"                => 12667,
                         "eustace"                 => 12775,
                         "euston"                  => 15126,
                         "euthanasia"              => 11906,
                         "euthanized"              => 27072,
                         "evacuated"               => 4828,
                         "evacuation"              => 5103,
                         "evacuations"             => 18739,
                         "evacuees"                => 18283,
                         "evade"                   => 10086,
                         "evaded"                  => 15186,
                         "evaluate"                => 5999,
                         "evaluated"               => 5861,
                         "evaluates"               => 13966,
                         "evaluating"              => 8377,
                         "evaluation"              => 3352,
                         "evaluations"             => 9975,
                         "evangelical"             => 3939,
                         "evangelicals"            => 16427,
                         "evangelism"              => 14288,
                         "evangelist"              => 8329,
                         "evangelistic"            => 18973,
                         "evangelists"             => 15199,
                         "evangelization"          => 18054,
                         "evanston"                => 12599,
                         "evansville"              => 10953,
                         "evaporates"              => 26701,
                         "evaporation"             => 10823,
                         "evenings"                => 6731,
                         "evenly"                  => 8089,
                         "event"                   => 382,
                         "eventing"                => 16899,
                         "events"                  => 385,
                         "eventual"                => 3268,
                         "eventually"              => 408,
                         "everard"                 => 19792,
                         "evergreen"               => 6134,
                         "everyman"                => 17362,
                         "evesham"                 => 17837,
                         "eviction"                => 8732,
                         "evictions"               => 22882,
                         "evidenced"               => 7323,
                         "evidences"               => 16217,
                         "evident"                 => 4132,
                         "evocation"               => 24836,
                         "evocative"               => 14010,
                         "evoke"                   => 11286,
                         "evoked"                  => 12582,
                         "evokes"                  => 14086,
                         "evoking"                 => 16731,
                         "evolution"               => 2186,
                         "evolutionarily"          => 23928,
                         "evolutionary"            => 4537,
                         "evolutions"              => 23646,
                         "evolve"                  => 7102,
                         "evolved"                 => 2588,
                         "evolves"                 => 14371,
                         "evolving"                => 7138,
                         "evora"                   => 21797,
                         "evreux"                  => 29214,
                         "exacerbated"             => 10009,
                         "exacted"                 => 25448,
                         "exaggerated"             => 7740,
                         "exaltation"              => 25265,
                         "examination"             => 2689,
                         "examinations"            => 5147,
                         "examined"                => 3921,
                         "examiners"               => 14567,
                         "examines"                => 7690,
                         "example"                 => 362,
                         "examples"                => 1241,
                         "exams"                   => 5114,
                         "exarch"                  => 27837,
                         "exarchate"               => 21150,
                         "excavate"                => 19734,
                         "excavated"               => 5442,
                         "excavating"              => 18608,
                         "excavation"              => 5952,
                         "excavations"             => 4867,
                         "excavator"               => 27421,
                         "excavators"              => 23105,
                         "exceed"                  => 4841,
                         "exceeded"                => 5280,
                         "exceeding"               => 6288,
                         "exceeds"                 => 7748,
                         "excel"                   => 8697,
                         "excelled"                => 7390,
                         "excellence"              => 2952,
                         "excelling"               => 22207,
                         "excelsior"               => 11869,
                         "excepting"               => 15719,
                         "exception"               => 2147,
                         "exceptional"             => 4490,
                         "exceptionally"           => 6514,
                         "exceptions"              => 4060,
                         "excerpt"                 => 11086,
                         "excerpts"                => 9084,
                         "excess"                  => 3593,
                         "excesses"                => 13861,
                         "excessive"               => 4347,
                         "excessively"             => 11956,
                         "exchange"                => 1032,
                         "exchanged"               => 5658,
                         "exchanger"               => 17930,
                         "exchangers"              => 24058,
                         "exchanges"               => 5642,
                         "exchequer"               => 9256,
                         "excise"                  => 11433,
                         "excised"                 => 21078,
                         "excision"                => 19854,
                         "excitation"              => 12641,
                         "excitatory"              => 21341,
                         "exclaim"                 => 20221,
                         "exclaimed"               => 16186,
                         "exclaiming"              => 26991,
                         "exclaims"                => 24462,
                         "exclave"                 => 17918,
                         "exclude"                 => 7962,
                         "excluded"                => 4458,
                         "excludes"                => 11361,
                         "excluding"               => 5008,
                         "exclusion"               => 6289,
                         "exclusionary"            => 28933,
                         "exclusive"               => 2554,
                         "exclusively"             => 2458,
                         "exclusivity"             => 17438,
                         "excommunicated"          => 12321,
                         "excommunication"         => 13909,
                         "excreted"                => 18256,
                         "excretion"               => 19004,
                         "excursion"               => 9849,
                         "excursions"              => 10309,
                         "executable"              => 13776,
                         "executed"                => 2166,
                         "executes"                => 15254,
                         "executing"               => 8262,
                         "execution"               => 2696,
                         "executioners"            => 27433,
                         "executions"              => 7612,
                         "executive"               => 681,
                         "executives"              => 4474,
                         "executors"               => 19700,
                         "exegesis"                => 15752,
                         "exemplar"                => 20597,
                         "exemplars"               => 28864,
                         "exemplified"             => 9026,
                         "exemplifies"             => 16042,
                         "exemplify"               => 20061,
                         "exempt"                  => 6495,
                         "exempted"                => 10778,
                         "exemption"               => 6698,
                         "exemptions"              => 11614,
                         "exercised"               => 6290,
                         "exercises"               => 3888,
                         "exerted"                 => 9864,
                         "exertions"               => 29787,
                         "exerts"                  => 19635,
                         "exeter"                  => 4636,
                         "exhaust"                 => 5846,
                         "exhaustive"              => 11123,
                         "exhibit"                 => 2988,
                         "exhibited"               => 2876,
                         "exhibiting"              => 8086,
                         "exhibition"              => 1438,
                         "exhibitions"             => 2700,
                         "exhibitor"               => 24921,
                         "exhibitors"              => 14887,
                         "exhibits"                => 3561,
                         "exhortation"             => 28755,
                         "exhorted"                => 28717,
                         "exhumed"                 => 14530,
                         "exile"                   => 2812,
                         "exiled"                  => 5150,
                         "exiles"                  => 9083,
                         "exist"                   => 1481,
                         "existed"                 => 2043,
                         "existence"               => 1367,
                         "existent"                => 9265,
                         "existentialism"          => 20857,
                         "existing"                => 1197,
                         "exists"                  => 2133,
                         "exited"                  => 9776,
                         "exiting"                 => 9285,
                         "exmoor"                  => 23154,
                         "exmouth"                 => 19907,
                         "exogenous"               => 19417,
                         "exons"                   => 20780,
                         "exoplanet"               => 26998,
                         "exoplanets"              => 28429,
                         "exoskeleton"             => 20394,
                         "exothermic"              => 29105,
                         "expand"                  => 2662,
                         "expandable"              => 22627,
                         "expanded"                => 1159,
                         "expanding"               => 3285,
                         "expands"                 => 8546,
                         "expanse"                 => 14062,
                         "expanses"                => 23526,
                         "expansion"               => 1329,
                         "expansionism"            => 28271,
                         "expansionist"            => 21555,
                         "expansions"              => 9223,
                         "expansive"               => 9782,
                         "expatriate"              => 10343,
                         "expatriates"             => 11782,
                         "expectancy"              => 10245,
                         "expectation"             => 7227,
                         "expected"                => 1163,
                         "expedition"              => 1635,
                         "expeditionary"           => 5505,
                         "expeditions"             => 5078,
                         "expelled"                => 3477,
                         "expend"                  => 26203,
                         "expended"                => 14105,
                         "expenditure"             => 7217,
                         "expenditures"            => 7779,
                         "experience"              => 803,
                         "experienced"             => 1870,
                         "experiences"             => 2135,
                         "experiential"            => 14094,
                         "experiment"              => 2743,
                         "experimental"            => 2092,
                         "experimentally"          => 11079,
                         "experimentation"         => 7554,
                         "experimented"            => 7318,
                         "experimenter"            => 19974,
                         "experimenters"           => 25341,
                         "experiments"             => 2726,
                         "expertise"               => 4207,
                         "expertly"                => 25183,
                         "experts"                 => 3004,
                         "expired"                 => 5144,
                         "expiring"                => 19452,
                         "expiry"                  => 17525,
                         "explained"               => 2102,
                         "explicit"                => 4792,
                         "explicitly"              => 4190,
                         "exploitation"            => 5206,
                         "exploitative"            => 21524,
                         "exploited"               => 6571,
                         "exploits"                => 7139,
                         "exploration"             => 3206,
                         "explorations"            => 10691,
                         "explored"                => 4015,
                         "explorers"               => 6875,
                         "explores"                => 5663,
                         "exploring"               => 4836,
                         "explosive"               => 4524,
                         "exponent"                => 9553,
                         "exponential"             => 8816,
                         "exponentially"           => 12970,
                         "exponents"               => 13495,
                         "export"                  => 3258,
                         "exportation"             => 24882,
                         "exported"                => 5387,
                         "exporter"                => 11060,
                         "exporters"               => 17387,
                         "exporting"               => 10007,
                         "exports"                 => 4871,
                         "expos"                   => 10598,
                         "exposed"                 => 2432,
                         "exposes"                 => 11399,
                         "exposition"              => 4890,
                         "expositions"             => 16827,
                         "exposure"                => 2574,
                         "exposures"               => 12015,
                         "expounded"               => 18033,
                         "expressed"               => 1592,
                         "expresses"               => 5974,
                         "expressing"              => 5317,
                         "expression"              => 1956,
                         "expressionism"           => 12203,
                         "expressionist"           => 12380,
                         "expressions"             => 5094,
                         "expressive"              => 8576,
                         "expressly"               => 10317,
                         "expressway"              => 4090,
                         "expressways"             => 15793,
                         "expropriated"            => 19191,
                         "expropriation"           => 19823,
                         "expulsion"               => 6319,
                         "expulsions"              => 20875,
                         "extant"                  => 4658,
                         "extend"                  => 2779,
                         "extended"                => 930,
                         "extender"                => 28288,
                         "extending"               => 3128,
                         "extends"                 => 3142,
                         "extensible"              => 19145,
                         "extension"               => 1617,
                         "extensional"             => 29628,
                         "extensions"              => 4918,
                         "extensive"               => 1326,
                         "extensively"             => 2558,
                         "extensor"                => 25764,
                         "extent"                  => 2231,
                         "exterior"                => 3384,
                         "exteriors"               => 18558,
                         "extermination"           => 10065,
                         "external"                => 1402,
                         "externally"              => 8942,
                         "extinct"                 => 2913,
                         "extinction"              => 5298,
                         "extinctions"             => 22253,
                         "extinguished"            => 11529,
                         "extinguishing"           => 23237,
                         "extirpated"              => 20515,
                         "extolled"                => 29566,
                         "extracellular"           => 10398,
                         "extract"                 => 5784,
                         "extracted"               => 6206,
                         "extracting"              => 11969,
                         "extraction"              => 5334,
                         "extractor"               => 25213,
                         "extracts"                => 8991,
                         "extrajudicial"           => 19506,
                         "extraliga"               => 13628,
                         "extraneous"              => 25662,
                         "extrapolated"            => 28100,
                         "extrapolation"           => 26987,
                         "extrasolar"              => 18082,
                         "extraterritorial"        => 29962,
                         "extratropical"           => 11146,
                         "extravagance"            => 22053,
                         "extremadura"             => 16535,
                         "extremes"                => 10005,
                         "extremism"               => 13920,
                         "extremist"               => 11334,
                         "extremity"               => 11139,
                         "extrinsic"               => 20802,
                         "extruded"                => 22361,
                         "extrusion"               => 21140,
                         "exuberance"              => 25357,
                         "exuberant"               => 18001,
                         "exxonmobil"              => 21012,
                         "eyalet"                  => 20397,
                         "eyewall"                 => 24990,
                         "eyewear"                 => 23738,
                         "f.c.."                   => 10838,
                         "fabaceae"                => 14008,
                         "fabius"                  => 19113,
                         "fable"                   => 11191,
                         "fables"                  => 10817,
                         "fabrica"                 => 28015,
                         "fabricated"              => 8385,
                         "fabrication"             => 8877,
                         "fabricius"               => 23224,
                         "fabrics"                 => 8894,
                         "facade"                  => 3411,
                         "facades"                 => 10030,
                         "facebook"                => 3746,
                         "faced"                   => 1499,
                         "facelift"                => 12514,
                         "facelifted"              => 25916,
                         "facet"                   => 14773,
                         "faceted"                 => 17093,
                         "facets"                  => 10326,
                         "fachhochschule"          => 12366,
                         "facie"                   => 25085,
                         "facies"                  => 19855,
                         "facilitate"              => 3882,
                         "facilitated"             => 6775,
                         "facilitates"             => 8983,
                         "facilitating"            => 8645,
                         "facilitation"            => 16968,
                         "facilitator"             => 18857,
                         "facilitators"            => 28474,
                         "facilities"              => 874,
                         "facility"                => 1151,
                         "facing"                  => 2180,
                         "facings"                 => 27222,
                         "facsimile"               => 15400,
                         "factbook"                => 23024,
                         "faction"                 => 3800,
                         "factional"               => 17373,
                         "factionalism"            => 28805,
                         "factions"                => 5075,
                         "facto"                   => 4849,
                         "factor"                  => 1619,
                         "factorial"               => 21633,
                         "factories"               => 3861,
                         "factorization"           => 16964,
                         "factors"                 => 1777,
                         "factory"                 => 1381,
                         "factual"                 => 8752,
                         "facultative"             => 28399,
                         "faculties"               => 6128,
                         "faculty"                 => 1274,
                         "facundo"                 => 26678,
                         "faeces"                  => 28390,
                         "faience"                 => 25847,
                         "failed"                  => 806,
                         "failing"                 => 3038,
                         "fails"                   => 4493,
                         "failure"                 => 1523,
                         "failures"                => 5591,
                         "faintly"                 => 20301,
                         "faints"                  => 21446,
                         "faired"                  => 29950,
                         "fairfax"                 => 6444,
                         "fairground"              => 19918,
                         "fairgrounds"             => 12236,
                         "fairhaven"               => 24913,
                         "fairing"                 => 18240,
                         "fairlie"                 => 22817,
                         "fairmount"               => 16046,
                         "fairport"                => 19479,
                         "fairs"                   => 7079,
                         "fairtrade"               => 19109,
                         "faisalabad"              => 16900,
                         "faithfull"               => 24336,
                         "faiths"                  => 10125,
                         "faizabad"                => 28511,
                         "fakhr"                   => 27779,
                         "fakir"                   => 27501,
                         "falaise"                 => 23175,
                         "falange"                 => 29650,
                         "falcao"                  => 28921,
                         "falconiformesfamily"     => 27773,
                         "falconry"                => 29886,
                         "falkirk"                 => 10388,
                         "falkland"                => 8048,
                         "falklands"               => 11308,
                         "falla"                   => 24618,
                         "fallacy"                 => 14113,
                         "falls"                   => 1214,
                         "fallujah"                => 19234,
                         "falmouth"                => 10152,
                         "falsehood"               => 23999,
                         "falsely"                 => 8258,
                         "falsetto"                => 16722,
                         "falsification"           => 25218,
                         "falsifying"              => 28453,
                         "faltering"               => 25946,
                         "falun"                   => 13254,
                         "famagusta"               => 19779,
                         "famas"                   => 26993,
                         "fame"                    => 1209,
                         "famed"                   => 5217,
                         "famer"                   => 11626,
                         "famers"                  => 19084,
                         "famicom"                 => 14349,
                         "familial"                => 10864,
                         "familiarity"             => 11348,
                         "families"                => 421,
                         "family"                  => 94,
                         "famine"                  => 5745,
                         "famines"                 => 20867,
                         "famitsu"                 => 19965,
                         "famous"                  => 592,
                         "famously"                => 5981,
                         "fanbase"                 => 14547,
                         "fandom"                  => 15363,
                         "fanfare"                 => 11692,
                         "fangio"                  => 23183,
                         "fangoria"                => 29817,
                         "fanned"                  => 26191,
                         "fans"                    => 1203,
                         "fanshawe"                => 22506,
                         "fantail"                 => 23001,
                         "fantastical"             => 19693,
                         "fanzine"                 => 14434,
                         "fanzines"                => 23048,
                         "faraday"                 => 13104,
                         "farben"                  => 28709,
                         "farces"                  => 28826,
                         "farcical"                => 24870,
                         "fared"                   => 10418,
                         "fareham"                 => 24051,
                         "fares"                   => 8414,
                         "fargo"                   => 8156,
                         "farid"                   => 17198,
                         "farm"                    => 983,
                         "farmed"                  => 9418,
                         "farmers"                 => 2144,
                         "farmhouse"               => 7345,
                         "farmhouses"              => 19879,
                         "farming"                 => 2540,
                         "farmingdale"             => 29159,
                         "farmington"              => 11438,
                         "farmland"                => 5759,
                         "farmlands"               => 18324,
                         "farms"                   => 2960,
                         "farmstead"               => 11995,
                         "farmsteads"              => 26967,
                         "farmville"               => 28295,
                         "farnborough"             => 14140,
                         "farnese"                 => 15602,
                         "faroe"                   => 9951,
                         "faroese"                 => 11920,
                         "farringdon"              => 28205,
                         "fascia"                  => 10186,
                         "fascism"                 => 7850,
                         "fascist"                 => 5160,
                         "fascists"                => 12888,
                         "fashion"                 => 1537,
                         "fashionable"             => 7475,
                         "fassbinder"              => 29216,
                         "fastener"                => 28232,
                         "fasteners"               => 23093,
                         "fastest"                 => 3096,
                         "fasting"                 => 10752,
                         "fatah"                   => 12849,
                         "fatalities"              => 7027,
                         "fatality"                => 12432,
                         "fatally"                 => 9019,
                         "fated"                   => 9712,
                         "fateh"                   => 16448,
                         "fatehpur"                => 28737,
                         "fatherland"              => 13391,
                         "fatigue"                 => 7538,
                         "fatih"                   => 21712,
                         "fatimid"                 => 17097,
                         "fatimids"                => 27853,
                         "fatwa"                   => 17046,
                         "faubourg"                => 25287,
                         "faulted"                 => 20158,
                         "faulting"                => 19621,
                         "fauna"                   => 4541,
                         "faunal"                  => 18173,
                         "faure"                   => 13919,
                         "faversham"               => 23266,
                         "favorable"               => 4085,
                         "favorably"               => 9095,
                         "favored"                 => 4497,
                         "favoring"                => 11423,
                         "favour"                  => 2676,
                         "favourable"              => 6539,
                         "favourably"              => 13637,
                         "favoured"                => 5825,
                         "favouring"               => 15320,
                         "favourites"              => 8904,
                         "fayette"                 => 9433,
                         "fayetteville"            => 10285,
                         "fazal"                   => 24346,
                         "fealty"                  => 22268,
                         "feared"                  => 4555,
                         "fearful"                 => 9952,
                         "fearing"                 => 6164,
                         "fearsome"                => 16475,
                         "feasibility"             => 8004,
                         "feasible"                => 8059,
                         "feast"                   => 4001,
                         "feasts"                  => 12126,
                         "feat"                    => 4939,
                         "featherweight"           => 9333,
                         "feats"                   => 11405,
                         "feature"                 => 689,
                         "featured"                => 461,
                         "featureless"             => 27389,
                         "features"                => 420,
                         "featurette"              => 22893,
                         "featuring"               => 1049,
                         "february"                => 197,
                         "fecal"                   => 16710,
                         "fecundity"               => 29166,
                         "federacion"              => 18788,
                         "federal"                 => 462,
                         "federale"                => 28269,
                         "federalism"              => 15316,
                         "federalist"              => 9093,
                         "federalists"             => 15282,
                         "federalized"             => 25225,
                         "federally"               => 6931,
                         "federals"                => 20233,
                         "federated"               => 9560,
                         "federation"              => 1339,
                         "federations"             => 10232,
                         "federative"              => 23639,
                         "federer"                 => 9406,
                         "feedback"                => 4504,
                         "feeders"                 => 15058,
                         "feedstock"               => 21280,
                         "fees"                    => 3426,
                         "feigned"                 => 22710,
                         "feint"                   => 28685,
                         "felis"                   => 28589,
                         "felixstowe"              => 20410,
                         "felled"                  => 16992,
                         "fellow"                  => 858,
                         "fellowship"              => 3079,
                         "fellowships"             => 8463,
                         "feltham"                 => 28688,
                         "female"                  => 522,
                         "females"                 => 781,
                         "femina"                  => 21132,
                         "femininity"              => 17703,
                         "feminism"                => 7424,
                         "feminist"                => 4103,
                         "feminists"               => 10428,
                         "fenced"                  => 12808,
                         "fencers"                 => 18028,
                         "fencing"                 => 5485,
                         "fenders"                 => 16141,
                         "fengtian"                => 29967,
                         "fengxiang"               => 28823,
                         "fenian"                  => 20635,
                         "feodor"                  => 27108,
                         "feral"                   => 9324,
                         "ferdinando"              => 14986,
                         "ferenc"                  => 12220,
                         "ferencvaros"             => 24715,
                         "fergana"                 => 29805,
                         "fermanagh"               => 14083,
                         "fermentation"            => 9137,
                         "fermented"               => 12034,
                         "fermenting"              => 27403,
                         "fermi"                   => 12084,
                         "fermions"                => 21485,
                         "ferns"                   => 9720,
                         "ferocity"                => 20453,
                         "feroz"                   => 29674,
                         "ferran"                  => 29175,
                         "ferrand"                 => 19190,
                         "ferrers"                 => 17010,
                         "ferric"                  => 26725,
                         "ferried"                 => 17520,
                         "ferries"                 => 6598,
                         "ferrite"                 => 28976,
                         "ferrocarril"             => 26544,
                         "ferrol"                  => 23831,
                         "ferromagnetic"           => 25841,
                         "ferrous"                 => 16979,
                         "ferruccio"               => 25509,
                         "ferruginous"             => 23067,
                         "ferry"                   => 2384,
                         "ferrying"                => 18662,
                         "fertile"                 => 5324,
                         "fertilisation"           => 20707,
                         "fertiliser"              => 24384,
                         "fertilization"           => 11661,
                         "fertilized"              => 18067,
                         "fertilizers"             => 13167,
                         "fervent"                 => 14846,
                         "fervently"               => 28577,
                         "fervour"                 => 28592,
                         "festival"                => 431,
                         "festivals"               => 2285,
                         "festivity"               => 26653,
                         "festschrift"             => 26980,
                         "fetishism"               => 26873,
                         "feud"                    => 4705,
                         "feudal"                  => 5633,
                         "feudalism"               => 16422,
                         "feuded"                  => 15041,
                         "feuding"                 => 13361,
                         "feuds"                   => 12589,
                         "fewer"                   => 3072,
                         "fewest"                  => 12121,
                         "ffestiniog"              => 23478,
                         "ffffff"                  => 16799,
                         "fianna"                  => 9646,
                         "fiber"                   => 4413,
                         "fiberglass"              => 10779,
                         "fibers"                  => 5925,
                         "fibre"                   => 7319,
                         "fibreglass"              => 18998,
                         "fibres"                  => 11382,
                         "fibrillation"            => 21926,
                         "fibroblasts"             => 23153,
                         "fibrosis"                => 13203,
                         "fibrous"                 => 12460,
                         "fibula"                  => 20642,
                         "fiction"                 => 1192,
                         "fictional"               => 1992,
                         "fictionalised"           => 22458,
                         "fictionalized"           => 11789,
                         "fictions"                => 23942,
                         "fictitious"              => 8133,
                         "fiddlers"                => 26633,
                         "fidesz"                  => 26342,
                         "fiduciary"               => 17297,
                         "fiefs"                   => 17826,
                         "field"                   => 281,
                         "fielded"                 => 7181,
                         "fielders"                => 21885,
                         "fieldhouse"              => 17692,
                         "fieldwork"               => 13517,
                         "fiennes"                 => 17235,
                         "fierce"                  => 4869,
                         "fiercely"                => 10204,
                         "fiestas"                 => 27483,
                         "fifa"                    => 2282,
                         "fifteenth"               => 6084,
                         "fifth"                   => 827,
                         "fifths"                  => 12268,
                         "fighters"                => 2584,
                         "figueres"                => 28854,
                         "figurative"              => 9745,
                         "figures"                 => 1267,
                         "figurine"                => 18657,
                         "figurines"               => 11157,
                         "fiji"                    => 4189,
                         "fijian"                  => 10293,
                         "fijians"                 => 22540,
                         "filament"                => 12814,
                         "filamentous"             => 21027,
                         "filaments"               => 12336,
                         "filed"                   => 2214,
                         "filename"                => 24037,
                         "filesystem"              => 18209,
                         "filho"                   => 19785,
                         "filings"                 => 18504,
                         "filipina"                => 18980,
                         "filipino"                => 3761,
                         "filipinos"               => 9447,
                         "filipovic"               => 27118,
                         "fille"                   => 20770,
                         "fillies"                 => 13907,
                         "filly"                   => 8900,
                         "film"                    => 78,
                         "filmation"               => 27888,
                         "filmed"                  => 2052,
                         "filmfare"                => 9917,
                         "filming"                 => 2446,
                         "filmmaker"               => 4533,
                         "filmmakers"              => 5857,
                         "filmmaking"              => 8012,
                         "filmography"             => 7536,
                         "films"                   => 515,
                         "filmworks"               => 25913,
                         "filtered"                => 10556,
                         "filtering"               => 8682,
                         "filters"                 => 6460,
                         "filton"                  => 29152,
                         "filtration"              => 11151,
                         "final"                   => 188,
                         "finale"                  => 3512,
                         "finalised"               => 15052,
                         "finalist"                => 4557,
                         "finalists"               => 4947,
                         "finalized"               => 8254,
                         "finals"                  => 1183,
                         "finance"                 => 1732,
                         "financed"                => 4806,
                         "finances"                => 5766,
                         "financial"               => 668,
                         "financially"             => 5030,
                         "financier"               => 10372,
                         "financiers"              => 17507,
                         "financing"               => 4288,
                         "finches"                 => 17794,
                         "findings"                => 3364,
                         "fined"                   => 6145,
                         "finely"                  => 8911,
                         "fines"                   => 7666,
                         "fingal"                  => 20293,
                         "fingerboard"             => 23013,
                         "finial"                  => 26803,
                         "finials"                 => 27489,
                         "finished"                => 486,
                         "finisher"                => 12123,
                         "finishers"               => 9621,
                         "finishes"                => 4736,
                         "finishing"               => 1604,
                         "finistere"               => 24165,
                         "finisterre"              => 27624,
                         "finite"                  => 3823,
                         "finitely"                => 14526,
                         "finland"                 => 2074,
                         "finlandia"               => 29020,
                         "finned"                  => 12052,
                         "finnic"                  => 26874,
                         "finnish"                 => 2280,
                         "finnmark"                => 17290,
                         "finno"                   => 29294,
                         "finns"                   => 11740,
                         "finsbury"                => 17690,
                         "fionn"                   => 26970,
                         "fiorentina"              => 13477,
                         "firearm"                 => 8481,
                         "firearms"                => 4913,
                         "firebirds"               => 22752,
                         "firebox"                 => 17954,
                         "firebrand"               => 26843,
                         "firefighters"            => 8038,
                         "firefighting"            => 13226,
                         "fireside"                => 29148,
                         "firewalls"               => 26586,
                         "firings"                 => 23765,
                         "firm"                    => 1037,
                         "firmly"                  => 5644,
                         "firmness"                => 27428,
                         "firms"                   => 3359,
                         "firmware"                => 10831,
                         "first"                   => 26,
                         "first-past-the-post"     => 19780,
                         "firstly"                 => 6129,
                         "firsts"                  => 14270,
                         "firuzabad"               => 21919,
                         "fiscal"                  => 3807,
                         "fiscally"                => 27744,
                         "fisheries"               => 4990,
                         "fishermen"               => 5965,
                         "fishery"                 => 7706,
                         "fisichella"              => 22183,
                         "fissile"                 => 22227,
                         "fission"                 => 8757,
                         "fissure"                 => 17670,
                         "fissures"                => 21048,
                         "fistula"                 => 24077,
                         "fitchburg"               => 18974,
                         "fitted"                  => 2493,
                         "fittingly"               => 27855,
                         "fittings"                => 9826,
                         "fittipaldi"              => 20037,
                         "fitzalan"                => 21378,
                         "fitzherbert"             => 28585,
                         "fitzroy"                 => 7660,
                         "fitzwilliam"             => 13318,
                         "fiume"                   => 19536,
                         "five"                    => 181,
                         "fixture"                 => 5500,
                         "fixtures"                => 6165,
                         "fjord"                   => 8891,
                         "fjordane"                => 20861,
                         "fjords"                  => 21288,
                         "flacco"                  => 28417,
                         "flag"                    => 1569,
                         "flagella"                => 25432,
                         "flagrant"                => 26744,
                         "flags"                   => 4446,
                         "flagship"                => 3577,
                         "flagstaff"               => 14391,
                         "flamboyant"              => 12062,
                         "flamenco"                => 10946,
                         "flamethrower"            => 25880,
                         "flamingos"               => 18257,
                         "flanges"                 => 26820,
                         "flank"                   => 4565,
                         "flanked"                 => 6853,
                         "flanking"                => 9576,
                         "flanks"                  => 8593,
                         "flaps"                   => 10504,
                         "flashback"               => 8113,
                         "flashbacks"              => 9833,
                         "flashpoint"              => 20224,
                         "flat"                    => 1625,
                         "flatiron"                => 29224,
                         "flatly"                  => 22125,
                         "flats"                   => 5367,
                         "flattened"               => 7751,
                         "flattening"              => 22727,
                         "flatts"                  => 27184,
                         "flautist"                => 19066,
                         "flava"                   => 23437,
                         "flavius"                 => 17350,
                         "flavoring"               => 22175,
                         "flavour"                 => 9259,
                         "flavoured"               => 16702,
                         "flavours"                => 15366,
                         "fleche"                  => 23206,
                         "fled"                    => 2487,
                         "fledging"                => 25238,
                         "fledgling"               => 8771,
                         "flee"                    => 4250,
                         "fleeing"                 => 5961,
                         "flees"                   => 8412,
                         "fleet"                   => 981,
                         "fleets"                  => 8395,
                         "flemington"              => 21610,
                         "flemish"                 => 5427,
                         "flensburg"               => 18147,
                         "fleshed"                 => 24406,
                         "fleshy"                  => 11776,
                         "fleur"                   => 13139,
                         "fleurs"                  => 24174,
                         "flexed"                  => 29494,
                         "flexibility"             => 6002,
                         "flexion"                 => 21726,
                         "flexor"                  => 22107,
                         "flickr"                  => 26345,
                         "flight"                  => 868,
                         "flightless"              => 19831,
                         "flights"                 => 2553,
                         "flinders"                => 10148,
                         "flintlock"               => 28360,
                         "flintoff"                => 28424,
                         "flintshire"              => 18575,
                         "floated"                 => 10237,
                         "floatplane"              => 25075,
                         "flocked"                 => 17389,
                         "flocks"                  => 11071,
                         "flooded"                 => 5083,
                         "flooding"                => 3505,
                         "floodlights"             => 16824,
                         "floodlit"                => 18584,
                         "floodplain"              => 12697,
                         "floodplains"             => 20800,
                         "floods"                  => 5152,
                         "floodwaters"             => 22655,
                         "floorball"               => 19600,
                         "flooring"                => 11876,
                         "floors"                  => 3454,
                         "floral"                  => 7945,
                         "florentine"              => 10978,
                         "florets"                 => 12465,
                         "florins"                 => 24269,
                         "flotilla"                => 6108,
                         "flotillas"               => 28769,
                         "flour"                   => 5393,
                         "flourish"                => 9805,
                         "flourished"              => 6091,
                         "flourishes"              => 18970,
                         "flourishing"             => 9464,
                         "flow"                    => 1529,
                         "flowed"                  => 9530,
                         "flowered"                => 15830,
                         "flowering"               => 3969,
                         "flowing"                 => 3960,
                         "flown"                   => 4067,
                         "flows"                   => 1989,
                         "fluctuate"               => 21940,
                         "fluctuated"              => 17241,
                         "fluctuates"              => 27305,
                         "fluctuating"             => 16280,
                         "fluctuation"             => 20034,
                         "fluctuations"            => 9422,
                         "fluency"                 => 14799,
                         "fluent"                  => 6952,
                         "fluently"                => 15558,
                         "fluid"                   => 3250,
                         "fluidity"                => 23094,
                         "flume"                   => 20329,
                         "fluminense"              => 18757,
                         "fluorescence"            => 11662,
                         "fluorescent"             => 9386,
                         "fluoridation"            => 29814,
                         "fluoride"                => 10657,
                         "fluorine"                => 15502,
                         "flushing"                => 10064,
                         "flute"                   => 5084,
                         "fluted"                  => 16638,
                         "flutes"                  => 11828,
                         "flutist"                 => 24329,
                         "fluvial"                 => 19626,
                         "fluxes"                  => 24907,
                         "fluxus"                  => 22082,
                         "flyby"                   => 21709,
                         "flycatcher"              => 13547,
                         "flycatchers"             => 18639,
                         "flyover"                 => 14925,
                         "flyweight"               => 10394,
                         "foaled"                  => 12895,
                         "foals"                   => 15407,
                         "focal"                   => 5616,
                         "focke"                   => 19324,
                         "focus"                   => 1029,
                         "focused"                 => 1509,
                         "focuses"                 => 2581,
                         "focusing"                => 3172,
                         "focussed"                => 11751,
                         "foggia"                  => 21576,
                         "foils"                   => 22149,
                         "folate"                  => 24323,
                         "folded"                  => 4297,
                         "folds"                   => 8858,
                         "foliage"                 => 8144,
                         "folio"                   => 10409,
                         "folios"                  => 21377,
                         "folk"                    => 1597,
                         "folkestone"              => 15521,
                         "folklore"                => 4592,
                         "folkloric"               => 17999,
                         "folklorist"              => 16960,
                         "folktale"                => 27079,
                         "folktales"               => 20947,
                         "folkways"                => 25793,
                         "follicular"              => 25256,
                         "follies"                 => 13121,
                         "followed"                => 443,
                         "follower"                => 7911,
                         "followers"               => 3141,
                         "following"               => 111,
                         "follows"                 => 1014,
                         "fondation"               => 21944,
                         "fondazione"              => 29938,
                         "fondo"                   => 28672,
                         "fonds"                   => 20944,
                         "font"                    => 5779,
                         "fontainebleau"           => 15474,
                         "fonts"                   => 9291,
                         "foods"                   => 3291,
                         "foodservice"             => 24376,
                         "foodstuffs"              => 14888,
                         "footage"                 => 3127,
                         "footballer"              => 969,
                         "footballers"             => 8355,
                         "footballing"             => 13843,
                         "footbridge"              => 11230,
                         "footed"                  => 10320,
                         "foothills"               => 6660,
                         "footnotes"               => 12900,
                         "footpath"                => 10820,
                         "footpaths"               => 13929,
                         "footprint"               => 8552,
                         "footscray"               => 12811,
                         "footy"                   => 20236,
                         "for"                     => 7,
                         "forage"                  => 9924,
                         "forages"                 => 28402,
                         "foraging"                => 9180,
                         "foramen"                 => 17299,
                         "foray"                   => 11106,
                         "forays"                  => 17810,
                         "forbade"                 => 9253,
                         "forbidding"              => 12196,
                         "force"                   => 292,
                         "forced"                  => 741,
                         "forcefully"              => 12657,
                         "forces"                  => 376,
                         "forcible"                => 17337,
                         "forcibly"                => 7812,
                         "forcing"                 => 3182,
                         "fords"                   => 18935,
                         "forebears"               => 25694,
                         "forecast"                => 7042,
                         "forecasters"             => 27516,
                         "forecasting"             => 10546,
                         "forecastle"              => 19904,
                         "forecasts"               => 9573,
                         "foreclosure"             => 13258,
                         "forecourt"               => 18361,
                         "forefront"               => 8274,
                         "foregoing"               => 23330,
                         "foreground"              => 11861,
                         "foreign"                 => 595,
                         "foreigners"              => 5870,
                         "foreland"                => 23423,
                         "forelimbs"               => 19338,
                         "foremost"                => 5753,
                         "forerunner"              => 7720,
                         "forerunners"             => 18263,
                         "foreshadowed"            => 19515,
                         "foreshadowing"           => 20735,
                         "foreshore"               => 18400,
                         "forestall"               => 22732,
                         "forested"                => 5065,
                         "foresters"               => 15894,
                         "forestry"                => 4746,
                         "forests"                 => 1820,
                         "forewing"                => 10703,
                         "forewings"               => 4751,
                         "foreword"                => 9593,
                         "forfar"                  => 17874,
                         "forfeited"               => 11323,
                         "forfeiture"              => 16184,
                         "forgeries"               => 16812,
                         "forges"                  => 17594,
                         "forli"                   => 20794,
                         "form"                    => 235,
                         "forma"                   => 22979,
                         "formal"                  => 1671,
                         "formalised"              => 17621,
                         "formalism"               => 13806,
                         "formalize"               => 26419,
                         "formalized"              => 10783,
                         "formally"                => 1997,
                         "format"                  => 970,
                         "formation"               => 946,
                         "formations"              => 4679,
                         "formative"               => 9209,
                         "formats"                 => 3742,
                         "formatted"               => 10462,
                         "formatting"              => 17329,
                         "formed"                  => 366,
                         "former"                  => 163,
                         "formerly"                => 937,
                         "formers"                 => 28078,
                         "formidable"              => 7240,
                         "forming"                 => 1942,
                         "formosa"                 => 10961,
                         "forms"                   => 774,
                         "formula_1"               => 4070,
                         "formula_10"              => 8092,
                         "formula_11"              => 8272,
                         "formula_12"              => 8612,
                         "formula_13"              => 8958,
                         "formula_14"              => 9270,
                         "formula_15"              => 9513,
                         "formula_16"              => 9699,
                         "formula_17"              => 9858,
                         "formula_18"              => 10120,
                         "formula_19"              => 10557,
                         "formula_2"               => 4744,
                         "formula_20"              => 10850,
                         "formula_21"              => 11168,
                         "formula_22"              => 11391,
                         "formula_23"              => 11593,
                         "formula_24"              => 11925,
                         "formula_25"              => 12306,
                         "formula_26"              => 12760,
                         "formula_27"              => 12927,
                         "formula_28"              => 13223,
                         "formula_29"              => 13512,
                         "formula_3"               => 5389,
                         "formula_30"              => 14018,
                         "formula_31"              => 14311,
                         "formula_32"              => 14483,
                         "formula_33"              => 14787,
                         "formula_34"              => 15286,
                         "formula_35"              => 15495,
                         "formula_36"              => 15535,
                         "formula_37"              => 16242,
                         "formula_38"              => 16668,
                         "formula_39"              => 16617,
                         "formula_4"               => 5832,
                         "formula_40"              => 16611,
                         "formula_41"              => 17677,
                         "formula_42"              => 17842,
                         "formula_43"              => 18524,
                         "formula_44"              => 19097,
                         "formula_45"              => 18840,
                         "formula_46"              => 19387,
                         "formula_47"              => 20017,
                         "formula_48"              => 20492,
                         "formula_49"              => 20111,
                         "formula_5"               => 6316,
                         "formula_50"              => 20654,
                         "formula_51"              => 20975,
                         "formula_52"              => 21749,
                         "formula_53"              => 22239,
                         "formula_54"              => 22766,
                         "formula_55"              => 23341,
                         "formula_56"              => 23380,
                         "formula_57"              => 23054,
                         "formula_58"              => 24028,
                         "formula_59"              => 24603,
                         "formula_6"               => 6668,
                         "formula_60"              => 24577,
                         "formula_61"              => 25961,
                         "formula_62"              => 25055,
                         "formula_63"              => 26205,
                         "formula_64"              => 26061,
                         "formula_65"              => 27057,
                         "formula_66"              => 28364,
                         "formula_7"               => 7048,
                         "formula_8"               => 7500,
                         "formula_9"               => 7694,
                         "formulae"                => 12951,
                         "formulaic"               => 19096,
                         "formulas"                => 8285,
                         "formulate"               => 11888,
                         "formulated"              => 6736,
                         "formulating"             => 14791,
                         "formulation"             => 6579,
                         "formulations"            => 12111,
                         "forrestal"               => 23141,
                         "fort"                    => 718,
                         "fortaleza"               => 19758,
                         "fortescue"               => 16290,
                         "fortification"           => 7764,
                         "fortifications"          => 5047,
                         "fortified"               => 4802,
                         "fortify"                 => 19175,
                         "fortifying"              => 29607,
                         "fortnight"               => 11799,
                         "fortnightly"             => 16402,
                         "fortran"                 => 14725,
                         "fortress"                => 2948,
                         "fortresses"              => 9511,
                         "forts"                   => 5305,
                         "fortunes"                => 6284,
                         "forum"                   => 2345,
                         "forums"                  => 6890,
                         "forwards"                => 7557,
                         "forza"                   => 15168,
                         "fossa"                   => 16269,
                         "fossiliferous"           => 29364,
                         "fossils"                 => 4028,
                         "fostered"                => 10363,
                         "fostering"               => 10035,
                         "fotbollforbund"          => 28615,
                         "fouad"                   => 25531,
                         "fought"                  => 1335,
                         "fouling"                 => 17864,
                         "fouls"                   => 17643,
                         "found"                   => 139,
                         "foundation"              => 615,
                         "foundational"            => 12708,
                         "foundations"             => 3603,
                         "founded"                 => 295,
                         "founder"                 => 1007,
                         "foundered"               => 16941,
                         "founders"                => 2931,
                         "founding"                => 1316,
                         "foundling"               => 23021,
                         "foundress"               => 26844,
                         "foundries"               => 19371,
                         "foundry"                 => 6899,
                         "fountains"               => 8542,
                         "four"                    => 115,
                         "four-and-a-half"         => 24559,
                         "fourfold"                => 27466,
                         "fourier"                 => 8570,
                         "foursquare"              => 23947,
                         "fourteenth"              => 5527,
                         "fourth"                  => 495,
                         "fourths"                 => 15228,
                         "fowey"                   => 25089,
                         "foxes"                   => 8827,
                         "foxtel"                  => 18544,
                         "foyle"                   => 16873,
                         "fracking"                => 27148,
                         "fraction"                => 5381,
                         "fractional"              => 11165,
                         "fractionation"           => 29114,
                         "fractions"               => 11243,
                         "fractures"               => 10047,
                         "fracturing"              => 13999,
                         "fragility"               => 20541,
                         "fragment"                => 6304,
                         "fragmentary"             => 11528,
                         "fragmentation"           => 9207,
                         "fragmented"              => 9597,
                         "fragments"               => 4072,
                         "fragrant"                => 14114,
                         "frame"                   => 1812,
                         "frames"                  => 4286,
                         "framework"               => 2578,
                         "frameworks"              => 10718,
                         "framingham"              => 18894,
                         "francais"                => 9241,
                         "francaise"               => 7804,
                         "france"                  => 316,
                         "franche"                 => 13408,
                         "franchise"               => 1996,
                         "franchised"              => 19076,
                         "franchisee"              => 25917,
                         "franchisees"             => 24169,
                         "franchises"              => 7163,
                         "franchising"             => 20504,
                         "franchitti"              => 29079,
                         "franciscan"              => 6677,
                         "franciscans"             => 12542,
                         "franciszek"              => 19636,
                         "francoist"               => 23240,
                         "franconia"               => 13804,
                         "franconian"              => 16059,
                         "francophone"             => 9883,
                         "francophonie"            => 23066,
                         "francorchamps"           => 27541,
                         "franjo"                  => 22051,
                         "frankford"               => 18645,
                         "frankfort"               => 13566,
                         "frankfurt"               => 3793,
                         "frankfurter"             => 15696,
                         "frankish"                => 8339,
                         "frankivsk"               => 25190,
                         "frankland"               => 25461,
                         "frankston"               => 17072,
                         "frans"                   => 10518,
                         "frantisek"               => 13877,
                         "franziska"               => 23985,
                         "frass"                   => 23760,
                         "fraternal"               => 10582,
                         "fraternities"            => 11094,
                         "fraudulent"              => 9085,
                         "fraudulently"            => 22569,
                         "fraunhofer"              => 25051,
                         "frazione"                => 18404,
                         "frazioni"                => 20929,
                         "fredericksburg"          => 11514,
                         "fredericton"             => 14908,
                         "fredrik"                 => 10235,
                         "fredrikstad"             => 18390,
                         "free"                    => 338,
                         "freebsd"                 => 17227,
                         "freedmen"                => 12537,
                         "freedoms"                => 7964,
                         "freeform"                => 26847,
                         "freehold"                => 12213,
                         "freeholder"              => 28828,
                         "freeholders"             => 20476,
                         "freelance"               => 5670,
                         "freelancers"             => 27812,
                         "freely"                  => 4382,
                         "freemason"               => 14612,
                         "freemasonry"             => 11909,
                         "freemasons"              => 13889,
                         "freemen"                 => 18830,
                         "freestanding"            => 19155,
                         "freestyle"               => 3111,
                         "freetown"                => 12155,
                         "freeview"                => 18165,
                         "freeware"                => 16485,
                         "frege"                   => 24275,
                         "freiburg"                => 8520,
                         "freie"                   => 22981,
                         "freight"                 => 2907,
                         "freighter"               => 10001,
                         "freighters"              => 18520,
                         "freiherr"                => 14697,
                         "freikorps"               => 24788,
                         "freising"                => 25173,
                         "freleng"                 => 26049,
                         "frelimo"                 => 29035,
                         "fremantle"               => 7044,
                         "french"                  => 225,
                         "frenchman"               => 9682,
                         "frenetic"                => 23742,
                         "frente"                  => 22532,
                         "frentzen"                => 26584,
                         "frenzied"                => 25696,
                         "frequencies"             => 4579,
                         "frequency"               => 1908,
                         "frequent"                => 2262,
                         "frequented"              => 8775,
                         "frequenting"             => 28908,
                         "frequently"              => 1246,
                         "freres"                  => 18479,
                         "fresco"                  => 9448,
                         "frescoed"                => 24847,
                         "frescoes"                => 8200,
                         "frescos"                 => 16714,
                         "freshwater"              => 4148,
                         "fresnel"                 => 15782,
                         "frets"                   => 19905,
                         "friars"                  => 8176,
                         "friary"                  => 13821,
                         "fribourg"                => 14522,
                         "fricative"               => 16236,
                         "fricatives"              => 22968,
                         "friction"                => 5985,
                         "frictional"              => 26164,
                         "friedkin"                => 25011,
                         "friedrich"               => 3319,
                         "friedrichshafen"         => 25601,
                         "friendlies"              => 11811,
                         "friendliness"            => 23921,
                         "friesland"               => 13132,
                         "frieze"                  => 10688,
                         "friezes"                 => 24363,
                         "frigate"                 => 5349,
                         "frigates"                => 7677,
                         "fringe"                  => 5209,
                         "fringed"                 => 18053,
                         "fringes"                 => 10654,
                         "frisia"                  => 17835,
                         "frisian"                 => 11330,
                         "frisians"                => 24929,
                         "frits"                   => 29496,
                         "friuli"                  => 13520,
                         "frobenius"               => 20999,
                         "frolunda"                => 28023,
                         "from"                    => 14,
                         "frome"                   => 16109,
                         "fronds"                  => 18105,
                         "frontage"                => 11300,
                         "frontal"                 => 6847,
                         "fronted"                 => 8194,
                         "frontenac"               => 16686,
                         "frontieres"              => 28035,
                         "frontiers"               => 10124,
                         "frontispiece"            => 26543,
                         "frontline"               => 10620,
                         "frontman"                => 7147,
                         "frontrunner"             => 19902,
                         "fronts"                  => 7757,
                         "froome"                  => 28410,
                         "frosinone"               => 27854,
                         "frosts"                  => 24292,
                         "fructose"                => 15465,
                         "fruiting"                => 16084,
                         "fruition"                => 10540,
                         "fruits"                  => 3977,
                         "frusciante"              => 23173,
                         "frustrate"               => 27423,
                         "fuego"                   => 13538,
                         "fuel"                    => 1440,
                         "fueled"                  => 7299,
                         "fueling"                 => 14599,
                         "fuelled"                 => 13120,
                         "fuels"                   => 6951,
                         "fuerza"                  => 21422,
                         "fujian"                  => 9547,
                         "fujimori"                => 20791,
                         "fukuoka"                 => 9394,
                         "fukushima"               => 9812,
                         "fukuyama"                => 27009,
                         "fulani"                  => 19205,
                         "fulda"                   => 15169,
                         "fulfil"                  => 11655,
                         "fulfilment"              => 20202,
                         "full"                    => 312,
                         "fullness"                => 22437,
                         "fully"                   => 1249,
                         "fumble"                  => 7061,
                         "fumbled"                 => 14145,
                         "fumbles"                 => 12065,
                         "funafuti"                => 27021,
                         "funchal"                 => 27828,
                         "function"                => 881,
                         "functional"              => 2917,
                         "functionalism"           => 23889,
                         "functionalist"           => 28982,
                         "functionalities"         => 26773,
                         "functionality"           => 5246,
                         "functionally"            => 12110,
                         "functionaries"           => 21804,
                         "functionary"             => 25859,
                         "functioned"              => 7373,
                         "functioning"             => 4677,
                         "functions"               => 1388,
                         "functor"                 => 15099,
                         "functors"                => 24473,
                         "fund"                    => 1313,
                         "fundacion"               => 17583,
                         "fundamental"             => 2717,
                         "fundamentalism"          => 18045,
                         "fundamentalist"          => 12005,
                         "fundamentalists"         => 21479,
                         "fundamentally"           => 8468,
                         "funded"                  => 2169,
                         "funders"                 => 24423,
                         "funding"                 => 1294,
                         "fundraisers"             => 16439,
                         "fundraising"             => 5366,
                         "funds"                   => 1456,
                         "fundy"                   => 20634,
                         "funen"                   => 23757,
                         "funerary"                => 11947,
                         "fungal"                  => 9196,
                         "fungi"                   => 5226,
                         "fungicides"              => 29534,
                         "funicular"               => 15615,
                         "funimation"              => 16637,
                         "funkadelic"              => 24233,
                         "funnel"                  => 8919,
                         "funnels"                 => 17201,
                         "furlongs"                => 10012,
                         "furnaces"                => 10451,
                         "furnished"               => 7931,
                         "furnishing"              => 16959,
                         "furnishings"             => 9039,
                         "furrows"                 => 24741,
                         "furstenberg"             => 19684,
                         "furth"                   => 17069,
                         "further"                 => 326,
                         "furtherance"             => 26554,
                         "furthered"               => 13403,
                         "furthering"              => 13374,
                         "furthermore"             => 2388,
                         "fuscous"                 => 8178,
                         "fused"                   => 7534,
                         "fuselage"                => 4876,
                         "fushimi"                 => 27705,
                         "fusiliers"               => 11541,
                         "fusing"                  => 15618,
                         "futebol"                 => 11919,
                         "futsal"                  => 7782,
                         "futuna"                  => 25033,
                         "futurism"                => 20917,
                         "futurist"                => 16643,
                         "futuristic"              => 9764,
                         "futurity"                => 27226,
                         "fuzhou"                  => 15920,
                         "fylde"                   => 22095,
                         "fyodor"                  => 13376,
                         "g/cm3"                   => 28216,
                         "g/mol"                   => 27891,
                         "gabaa"                   => 27606,
                         "gabala"                  => 24479,
                         "gabba"                   => 25893,
                         "gabled"                  => 10652,
                         "gables"                  => 9572,
                         "gabon"                   => 8204,
                         "gabonese"                => 23692,
                         "gaborone"                => 24029,
                         "gabrovo"                 => 26035,
                         "gaddafi"                 => 8549,
                         "gaelic"                  => 3803,
                         "gaels"                   => 15946,
                         "gaeltacht"               => 22536,
                         "gaiden"                  => 24685,
                         "gaiety"                  => 17626,
                         "gaiman"                  => 16267,
                         "gain"                    => 1639,
                         "gained"                  => 1065,
                         "gainesville"             => 9499,
                         "gaining"                 => 3049,
                         "gains"                   => 4314,
                         "gainsborough"            => 12604,
                         "gainsbourg"              => 22952,
                         "gaius"                   => 9753,
                         "gakkai"                  => 28994,
                         "gakuen"                  => 23552,
                         "gakuin"                  => 27274,
                         "galactose"               => 23687,
                         "galapagos"               => 12342,
                         "galatians"               => 28714,
                         "galaxies"                => 7643,
                         "galba"                   => 28510,
                         "galeazzo"                => 24842,
                         "galeria"                 => 19101,
                         "galerie"                 => 10920,
                         "galesburg"               => 26795,
                         "galician"                => 8959,
                         "galilean"                => 24214,
                         "galilee"                 => 10306,
                         "galilei"                 => 23116,
                         "galium"                  => 29564,
                         "gallantry"               => 7935,
                         "gallaudet"               => 24678,
                         "gallen"                  => 12050,
                         "galleon"                 => 19463,
                         "galleons"                => 26445,
                         "galleria"                => 13186,
                         "galleries"               => 4227,
                         "gallery"                 => 1354,
                         "galleys"                 => 13424,
                         "gallia"                  => 20535,
                         "galliano"                => 29941,
                         "gallic"                  => 13712,
                         "gallifrey"               => 25905,
                         "gallipoli"               => 10062,
                         "gallium"                 => 16942,
                         "galois"                  => 15918,
                         "galton"                  => 19782,
                         "galvanic"                => 28256,
                         "galvatron"               => 20655,
                         "galveston"               => 8478,
                         "galway"                  => 5052,
                         "gamal"                   => 17869,
                         "gambia"                  => 9752,
                         "gambian"                 => 23011,
                         "gambier"                 => 16366,
                         "gambrinus"               => 27246,
                         "game"                    => 121,
                         "gamelan"                 => 18161,
                         "gameplay"                => 3305,
                         "gamepro"                 => 19385,
                         "gamerankings"            => 15284,
                         "games"                   => 195,
                         "gamespot"                => 11733,
                         "gamespy"                 => 22724,
                         "gamesradar"              => 19634,
                         "gametes"                 => 20860,
                         "gaming"                  => 3774,
                         "gamla"                   => 27758,
                         "ganassi"                 => 24945,
                         "ganda"                   => 28469,
                         "gandaki"                 => 29142,
                         "gandhara"                => 21769,
                         "gandharva"               => 29789,
                         "gandhi"                  => 4387,
                         "gandhian"                => 24909,
                         "gandhinagar"             => 29895,
                         "ganesan"                 => 17211,
                         "ganga"                   => 10180,
                         "ganges"                  => 10071,
                         "ganglia"                 => 15972,
                         "ganglion"                => 16417,
                         "gangnam"                 => 24209,
                         "ganguly"                 => 17516,
                         "gangwon"                 => 23408,
                         "gannet"                  => 28581,
                         "gannets"                 => 29277,
                         "gannett"                 => 15862,
                         "gansu"                   => 11849,
                         "gantry"                  => 22223,
                         "gaozong"                 => 17734,
                         "gaozu"                   => 19991,
                         "garages"                 => 13765,
                         "garda"                   => 11671,
                         "gardai"                  => 24495,
                         "garde"                   => 5488,
                         "gardens"                 => 1904,
                         "garhwal"                 => 19956,
                         "garibaldi"               => 10442,
                         "garifuna"                => 29987,
                         "garlands"                => 22718,
                         "garment"                 => 7989,
                         "garments"                => 8974,
                         "garmisch"                => 21229,
                         "garnered"                => 4548,
                         "garnering"               => 10845,
                         "garonne"                 => 12397,
                         "garrisoned"              => 12786,
                         "garrisons"               => 10711,
                         "garros"                  => 21577,
                         "garwolin"                => 27315,
                         "gascony"                 => 19388,
                         "gascoyne"                => 22091,
                         "gaseous"                 => 12827,
                         "gases"                   => 5545,
                         "gasification"            => 24249,
                         "gaspe"                   => 23874,
                         "gastric"                 => 12140,
                         "gastroenterology"        => 25814,
                         "gastrointestinal"        => 9985,
                         "gastronomy"              => 20679,
                         "gastropod"               => 3407,
                         "gastropoda"              => 28601,
                         "gastropods"              => 15906,
                         "gasworks"                => 27114,
                         "gated"                   => 11159,
                         "gatefold"                => 24397,
                         "gateshead"               => 10080,
                         "gathered"                => 2979,
                         "gatherer"                => 18698,
                         "gatherers"               => 15441,
                         "gathering"               => 3301,
                         "gatherings"              => 7509,
                         "gatineau"                => 15913,
                         "gating"                  => 28342,
                         "gatos"                   => 22907,
                         "gatwick"                 => 13838,
                         "gauche"                  => 25261,
                         "gauchos"                 => 29663,
                         "gaudens"                 => 25688,
                         "gaudi"                   => 21798,
                         "gauge"                   => 2664,
                         "gauges"                  => 12764,
                         "gauguin"                 => 17104,
                         "gauleiter"               => 28867,
                         "gauliga"                 => 24852,
                         "gaulish"                 => 19623,
                         "gaulle"                  => 9443,
                         "gauls"                   => 16259,
                         "gaultier"                => 25640,
                         "gaumont"                 => 23217,
                         "gauri"                   => 20237,
                         "gauss"                   => 12567,
                         "gaussian"                => 10761,
                         "gautama"                 => 16748,
                         "gauteng"                 => 13853,
                         "gautham"                 => 28129,
                         "gawain"                  => 18617,
                         "gawler"                  => 20438,
                         "gayatri"                 => 21207,
                         "gaza"                    => 4793,
                         "gazette"                 => 5123,
                         "gazetted"                => 11380,
                         "gazetteer"               => 15883,
                         "gazprom"                 => 17659,
                         "gbagbo"                  => 28910,
                         "gbit/s"                  => 19380,
                         "gcses"                   => 18538,
                         "gdansk"                  => 7354,
                         "gdanski"                 => 22987,
                         "gdynia"                  => 17963,
                         "ge'ez"                   => 29362,
                         "gearbox"                 => 7728,
                         "gearboxes"               => 23952,
                         "geared"                  => 8025,
                         "gears"                   => 8235,
                         "gediminas"               => 28622,
                         "geelong"                 => 6665,
                         "geert"                   => 25895,
                         "geeta"                   => 20039,
                         "geffen"                  => 12383,
                         "gehry"                   => 23360,
                         "gelatinous"              => 23253,
                         "gelder"                  => 27125,
                         "gelderland"              => 19075,
                         "gelding"                 => 19005,
                         "geldof"                  => 21891,
                         "gelechiidae"             => 9679,
                         "gelsenkirchen"           => 26617,
                         "gemara"                  => 19763,
                         "gemayel"                 => 28166,
                         "gemstones"               => 19740,
                         "gen."                    => 4545,
                         "gendarmerie"             => 11688,
                         "gendarmes"               => 21215,
                         "gender"                  => 2011,
                         "gendered"                => 20234,
                         "genders"                 => 12390,
                         "genealogical"            => 8303,
                         "genealogies"             => 16981,
                         "genealogist"             => 25924,
                         "genealogists"            => 29481,
                         "genealogy"               => 8709,
                         "geneon"                  => 28554,
                         "genera"                  => 3791,
                         "general"                 => 136,
                         "generale"                => 12979,
                         "generalised"             => 21764,
                         "generalissimo"           => 28774,
                         "generalist"              => 26818,
                         "generalitat"             => 24845,
                         "generality"              => 20557,
                         "generalization"          => 9816,
                         "generalizations"         => 14487,
                         "generalize"              => 20436,
                         "generalized"             => 6433,
                         "generalizes"             => 22929,
                         "generalleutnant"         => 24906,
                         "generally"               => 574,
                         "generalmajor"            => 25566,
                         "generals"                => 4127,
                         "generate"                => 3400,
                         "generated"               => 2295,
                         "generates"               => 6656,
                         "generating"              => 4040,
                         "generation"              => 1127,
                         "generational"            => 15700,
                         "generations"             => 3037,
                         "generative"              => 16392,
                         "generators"              => 6073,
                         "generically"             => 19599,
                         "generis"                 => 29702,
                         "genes"                   => 3493,
                         "genesee"                 => 11911,
                         "genetic"                 => 2646,
                         "geneticist"              => 17568,
                         "genetics"                => 5364,
                         "genital"                 => 10867,
                         "genitalia"               => 14090,
                         "genitive"                => 12792,
                         "genji"                   => 20605,
                         "gennady"                 => 21424,
                         "genocidal"               => 21862,
                         "genocide"                => 5068,
                         "genoese"                 => 11907,
                         "genome"                  => 4959,
                         "genomes"                 => 11336,
                         "genomic"                 => 11574,
                         "genomics"                => 13079,
                         "genotype"                => 16515,
                         "genotypes"               => 24942,
                         "genre"                   => 2163,
                         "genres"                  => 3819,
                         "genteel"                 => 28147,
                         "gentiles"                => 19689,
                         "gentrification"          => 16713,
                         "genus"                   => 764,
                         "geochemistry"            => 25212,
                         "geodesic"                => 16582,
                         "geodesics"               => 29096,
                         "geodesy"                 => 26565,
                         "geodetic"                => 16041,
                         "geoff"                   => 6139,
                         "geoffroy"                => 23589,
                         "geographer"              => 11092,
                         "geographers"             => 16823,
                         "geographic"              => 3152,
                         "geographical"            => 3375,
                         "geographically"          => 6781,
                         "geography"               => 1077,
                         "geologic"                => 6770,
                         "geological"              => 3709,
                         "geologically"            => 14901,
                         "geologist"               => 7827,
                         "geologists"              => 11639,
                         "geology"                 => 4005,
                         "geomagnetic"             => 23495,
                         "geometric"               => 5363,
                         "geometrical"             => 11910,
                         "geometrically"           => 20180,
                         "geometridae"             => 7576,
                         "geometries"              => 16414,
                         "geometry"                => 3850,
                         "geomorphology"           => 26644,
                         "geophysical"             => 11600,
                         "geophysics"              => 16174,
                         "geopolitical"            => 15675,
                         "geopolitics"             => 26527,
                         "georges"                 => 4386,
                         "georgetown"              => 4743,
                         "georgian"                => 3286,
                         "georgians"               => 13422,
                         "georgiev"                => 27711,
                         "georgios"                => 13314,
                         "geosciences"             => 29287,
                         "geospatial"              => 19470,
                         "geostationary"           => 19749,
                         "geotechnical"            => 25387,
                         "geothermal"              => 10274,
                         "geraint"                 => 22235,
                         "gerais"                  => 9664,
                         "geraldton"               => 18415,
                         "german"                  => 242,
                         "germaniawerft"           => 24083,
                         "germanic"                => 4969,
                         "germanicus"              => 26227,
                         "germanium"               => 19554,
                         "germans"                 => 2301,
                         "germantown"              => 12824,
                         "germanus"                => 28528,
                         "germany"                 => 395,
                         "germinal"                => 24026,
                         "germinate"               => 18398,
                         "germination"             => 15234,
                         "gerontology"             => 27094,
                         "geschichte"              => 17830,
                         "gesellschaft"            => 10676,
                         "gesta"                   => 18384,
                         "gestalt"                 => 17802,
                         "gestation"               => 11943,
                         "gestational"             => 24831,
                         "getafe"                  => 20829,
                         "gettysburg"              => 7675,
                         "gewog"                   => 20443,
                         "geysers"                 => 28310,
                         "ghalib"                  => 24022,
                         "ghana"                   => 3536,
                         "ghanaian"                => 9622,
                         "ghani"                   => 20257,
                         "gharana"                 => 18522,
                         "gharb"                   => 24827,
                         "gharbi"                  => 12285,
                         "ghats"                   => 11761,
                         "ghazal"                  => 16676,
                         "ghazali"                 => 24799,
                         "ghazals"                 => 29724,
                         "ghazi"                   => 13784,
                         "ghaziabad"               => 25410,
                         "ghazni"                  => 18638,
                         "ghent"                   => 8613,
                         "gheorghe"                => 12424,
                         "gheorghiu"               => 23592,
                         "gholam"                  => 28160,
                         "ghosh"                   => 11317,
                         "ghostface"               => 23058,
                         "ghraib"                  => 25322,
                         "ghulam"                  => 10231,
                         "giambattista"            => 27309,
                         "gianfranco"              => 21722,
                         "giannis"                 => 24834,
                         "gibraltar"               => 4290,
                         "gielgud"                 => 18383,
                         "giessen"                 => 16500,
                         "giffard"                 => 19532,
                         "gigabit"                 => 20248,
                         "gigantea"                => 27271,
                         "gigas"                   => 26139,
                         "giggs"                   => 22913,
                         "gijon"                   => 16628,
                         "gilad"                   => 26109,
                         "gilan"                   => 9851,
                         "gilani"                  => 26353,
                         "gilded"                  => 10154,
                         "gilding"                 => 27212,
                         "gilgit"                  => 16874,
                         "gimel"                   => 25752,
                         "gimnasia"                => 22601,
                         "ginebra"                 => 19083,
                         "ginzburg"                => 24162,
                         "giorgos"                 => 18321,
                         "gippsland"               => 13011,
                         "gipsy"                   => 19095,
                         "gipuzkoa"                => 22759,
                         "girardeau"               => 22323,
                         "girder"                  => 14556,
                         "girders"                 => 17193,
                         "girolamo"                => 14164,
                         "girona"                  => 14462,
                         "gironde"                 => 16621,
                         "gisborne"                => 16560,
                         "giscard"                 => 29972,
                         "github"                  => 29093,
                         "given"                   => 259,
                         "givenchy"                => 25278,
                         "glaad"                   => 22114,
                         "glabra"                  => 26890,
                         "glabrous"                => 19697,
                         "glace"                   => 27750,
                         "glacial"                 => 6236,
                         "glaciated"               => 25620,
                         "glaciation"              => 13265,
                         "glacier"                 => 3062,
                         "glaciers"                => 6999,
                         "gladiators"              => 10768,
                         "glamorgan"               => 7599,
                         "gland"                   => 8573,
                         "glandular"               => 15351,
                         "glans"                   => 29429,
                         "glarus"                  => 21490,
                         "glasgow"                 => 2300,
                         "glassworks"              => 29127,
                         "glastonbury"             => 10075,
                         "glauca"                  => 29497,
                         "glaxosmithkline"         => 24554,
                         "glazes"                  => 24973,
                         "glazing"                 => 16189,
                         "gleaned"                 => 20782,
                         "glebe"                   => 14458,
                         "gleizes"                 => 21342,
                         "glenbrook"               => 29646,
                         "glencairn"               => 26081,
                         "glenelg"                 => 16434,
                         "glenorchy"               => 29240,
                         "glens"                   => 17127,
                         "glentoran"               => 22324,
                         "glenview"                => 29717,
                         "glial"                   => 22026,
                         "glide"                   => 11310,
                         "gliders"                 => 10063,
                         "gliding"                 => 9520,
                         "gliese"                  => 22843,
                         "gliwice"                 => 28745,
                         "global"                  => 936,
                         "globalisation"           => 19873,
                         "globalization"           => 8391,
                         "globally"                => 5918,
                         "globe"                   => 2722,
                         "globemaster"             => 29774,
                         "globo"                   => 13489,
                         "globose"                 => 26531,
                         "globular"                => 14393,
                         "glockenspiel"            => 29036,
                         "glogow"                  => 24468,
                         "glories"                 => 24018,
                         "glorification"           => 24542,
                         "glorify"                 => 24750,
                         "glorifying"              => 27701,
                         "glossary"                => 13455,
                         "glosses"                 => 25199,
                         "glossop"                 => 19127,
                         "glossy"                  => 9738,
                         "glottal"                 => 19153,
                         "gloucester"              => 4823,
                         "gloucestershire"         => 5466,
                         "glucose"                 => 6457,
                         "glutamate"               => 12102,
                         "glutamine"               => 26428,
                         "glutathione"             => 20570,
                         "gluten"                  => 16229,
                         "glutinous"               => 28404,
                         "glycerol"                => 19238,
                         "glycine"                 => 16864,
                         "glycogen"                => 18475,
                         "glycol"                  => 16540,
                         "glycolysis"              => 24371,
                         "glycoprotein"            => 18117,
                         "glycoproteins"           => 26965,
                         "glycoside"               => 23403,
                         "glycosylation"           => 29335,
                         "glyndebourne"            => 21616,
                         "glyndwr"                 => 22553,
                         "glyph"                   => 17753,
                         "glyphipterix"            => 22435,
                         "glyphosate"              => 29949,
                         "glyphs"                  => 16778,
                         "gmail"                   => 22058,
                         "gmina"                   => 1745,
                         "gminas"                  => 9670,
                         "gnaeus"                  => 22193,
                         "gneisenau"               => 29905,
                         "gneiss"                  => 20365,
                         "gniezno"                 => 17007,
                         "gnostic"                 => 15504,
                         "gnosticism"              => 23098,
                         "gnu/linux"               => 28626,
                         "goal"                    => 605,
                         "goalkeeper"              => 3417,
                         "goalkeepers"             => 15144,
                         "goalkeeping"             => 15107,
                         "goalless"                => 13698,
                         "goals"                   => 728,
                         "goalscorer"              => 9611,
                         "goalscorers"             => 14397,
                         "goalscoring"             => 16885,
                         "goaltender"              => 7504,
                         "goaltenders"             => 13868,
                         "goaltending"             => 20948,
                         "gobind"                  => 17783,
                         "godalming"               => 27040,
                         "godavari"                => 12720,
                         "goddesses"               => 10928,
                         "godel"                   => 16200,
                         "godolphin"               => 18856,
                         "godot"                   => 28446,
                         "godunov"                 => 25114,
                         "gogol"                   => 17040,
                         "goguryeo"                => 12769,
                         "goiania"                 => 24658,
                         "goias"                   => 14033,
                         "golan"                   => 12718,
                         "golconda"                => 29358,
                         "gold"                    => 487,
                         "golders"                 => 25763,
                         "goldfield"               => 28388,
                         "goldfields"              => 13096,
                         "goldfrapp"               => 28815,
                         "golds"                   => 12544,
                         "goldsmiths"              => 15195,
                         "goldust"                 => 28495,
                         "goldwater"               => 12671,
                         "goldwyn"                 => 10751,
                         "golem"                   => 18594,
                         "golestan"                => 14922,
                         "golgi"                   => 19808,
                         "gollancz"                => 27071,
                         "gonbad"                  => 26673,
                         "goncalo"                 => 27598,
                         "gondwana"                => 16988,
                         "gongs"                   => 26640,
                         "gongsun"                 => 29437,
                         "gonville"                => 26351,
                         "gonzaga"                 => 9600,
                         "goodrem"                 => 26641,
                         "goods"                   => 1710,
                         "goole"                   => 22011,
                         "gopal"                   => 11979,
                         "gopala"                  => 28537,
                         "gopalakrishnan"          => 28083,
                         "gorakhpur"               => 23108,
                         "goran"                   => 10349,
                         "gorbachev"               => 11121,
                         "gorda"                   => 20105,
                         "gorge"                   => 5695,
                         "gorges"                  => 11439,
                         "gorica"                  => 18357,
                         "goring"                  => 10014,
                         "gorizia"                 => 17994,
                         "gorkha"                  => 18678,
                         "gorlitz"                 => 24549,
                         "gorna"                   => 24097,
                         "gorne"                   => 29412,
                         "gornik"                  => 27121,
                         "gornja"                  => 22192,
                         "gornji"                  => 16816,
                         "gorse"                   => 25267,
                         "goryeo"                  => 14189,
                         "gorzow"                  => 20745,
                         "gosford"                 => 19518,
                         "gosforth"                => 25597,
                         "goslar"                  => 27709,
                         "gospel"                  => 2777,
                         "gospels"                 => 7833,
                         "gosport"                 => 18660,
                         "gosta"                   => 25030,
                         "goswami"                 => 19838,
                         "gotaland"                => 16920,
                         "goteborg"                => 13500,
                         "gotha"                   => 11685,
                         "gothenburg"              => 8074,
                         "goths"                   => 12855,
                         "gotland"                 => 15311,
                         "gotra"                   => 20002,
                         "gotthard"                => 18939,
                         "gottingen"               => 8687,
                         "gottlob"                 => 23672,
                         "gottorp"                 => 27111,
                         "gouda"                   => 25611,
                         "goulburn"                => 14156,
                         "gounod"                  => 21517,
                         "gouverneur"              => 29574,
                         "govern"                  => 7352,
                         "governance"              => 3340,
                         "governed"                => 3365,
                         "governing"               => 2885,
                         "government"              => 122,
                         "governmental"            => 3570,
                         "governments"             => 2184,
                         "governor"                => 553,
                         "governorate"             => 5290,
                         "governorates"            => 17230,
                         "governors"               => 3541,
                         "governorship"            => 8866,
                         "governs"                 => 11697,
                         "govind"                  => 19735,
                         "gowda"                   => 23629,
                         "gowrie"                  => 27185,
                         "graaf"                   => 23805,
                         "graaff"                  => 27515,
                         "graced"                  => 15985,
                         "gracilis"                => 17284,
                         "gracillariidae"          => 15387,
                         "gradation"               => 28067,
                         "grade"                   => 979,
                         "graded"                  => 7532,
                         "grades"                  => 2404,
                         "gradient"                => 6295,
                         "gradients"               => 12534,
                         "gradual"                 => 5915,
                         "gradually"               => 2154,
                         "graduate"                => 1263,
                         "graduated"               => 919,
                         "graduates"               => 3551,
                         "graduating"              => 2250,
                         "graduation"              => 2596,
                         "graeme"                  => 8153,
                         "graffiti"                => 6824,
                         "grafting"                => 19497,
                         "grahame"                 => 18014,
                         "grahamstown"             => 21614,
                         "grain"                   => 3349,
                         "grained"                 => 12842,
                         "grains"                  => 6624,
                         "grama"                   => 23115,
                         "grameen"                 => 27360,
                         "gramercy"                => 27041,
                         "grammar"                 => 2611,
                         "grammarian"              => 21886,
                         "grammarians"             => 28470,
                         "grammars"                => 14297,
                         "grammatical"             => 7896,
                         "grammatically"           => 22325,
                         "grammophon"              => 28413,
                         "grammy"                  => 3058,
                         "grammys"                 => 21062,
                         "gramophone"              => 12787,
                         "grampian"                => 23247,
                         "granaries"               => 29416,
                         "granary"                 => 16880,
                         "granby"                  => 16839,
                         "grand"                   => 508,
                         "grande"                  => 3345,
                         "grandes"                 => 15042,
                         "grandfathered"           => 24305,
                         "grandis"                 => 20805,
                         "grandmaster"             => 9304,
                         "grandmasters"            => 28086,
                         "grandnephew"             => 26867,
                         "grands"                  => 13443,
                         "grandsons"               => 12486,
                         "grandstand"              => 10983,
                         "grandstands"             => 24904,
                         "grandview"               => 20757,
                         "grange"                  => 6373,
                         "granite"                 => 3893,
                         "granites"                => 27253,
                         "granitic"                => 23472,
                         "granted"                 => 1204,
                         "grantee"                 => 24714,
                         "granth"                  => 19354,
                         "granting"                => 5413,
                         "grants"                  => 2921,
                         "granular"                => 14664,
                         "granule"                 => 28939,
                         "granules"                => 15851,
                         "graph"                   => 3625,
                         "graphene"                => 17693,
                         "graphic"                 => 3105,
                         "graphical"               => 6878,
                         "graphically"             => 15613,
                         "graphics"                => 2966,
                         "graphite"                => 10765,
                         "graphs"                  => 6871,
                         "grappling"               => 14193,
                         "grass"                   => 2787,
                         "grasse"                  => 20346,
                         "grassed"                 => 29125,
                         "grasses"                 => 8116,
                         "grassland"               => 6864,
                         "grasslands"              => 8663,
                         "grassroots"              => 7704,
                         "graubunden"              => 18143,
                         "gravel"                  => 5396,
                         "gravelly"                => 20374,
                         "gravels"                 => 28451,
                         "gravesend"               => 14524,
                         "gravestone"              => 16507,
                         "gravestones"             => 19813,
                         "gravitated"              => 27787,
                         "gravitation"             => 17123,
                         "gravitational"           => 7035,
                         "gravity"                 => 3678,
                         "grayish"                 => 15525,
                         "grayling"                => 20080,
                         "graze"                   => 17152,
                         "grazer"                  => 29123,
                         "grazing"                 => 6263,
                         "greater"                 => 811,
                         "greatest"                => 1350,
                         "greatly"                 => 2114,
                         "grebes"                  => 23147,
                         "grecian"                 => 25733,
                         "greece"                  => 1681,
                         "greek"                   => 698,
                         "greeks"                  => 4685,
                         "greenback"               => 26567,
                         "greenbelt"               => 18226,
                         "greenbrier"              => 17347,
                         "greendale"               => 27083,
                         "greenhouse"              => 6275,
                         "greenhouses"             => 15929,
                         "greenish"                => 9375,
                         "greenland"               => 5799,
                         "greenlandic"             => 22619,
                         "greenock"                => 11966,
                         "greenpeace"              => 12000,
                         "greensand"               => 27560,
                         "greensboro"              => 9465,
                         "greensburg"              => 18573,
                         "greenstone"              => 21184,
                         "greenville"              => 7122,
                         "greenwich"               => 5212,
                         "greeted"                 => 7555,
                         "gregarious"              => 16627,
                         "gregorian"               => 8324,
                         "greifswald"              => 17879,
                         "grenada"                 => 9586,
                         "grenades"                => 8312,
                         "grenadier"               => 11017,
                         "grenadiers"              => 15741,
                         "grenadines"              => 16075,
                         "grenfell"                => 15541,
                         "grenoble"                => 10883,
                         "grenville"               => 12387,
                         "gresley"                 => 24598,
                         "grete"                   => 28513,
                         "gretna"                  => 17530,
                         "greville"                => 17857,
                         "grevillea"               => 19130,
                         "grew"                    => 990,
                         "grey"                    => 1711,
                         "greyfriars"              => 22898,
                         "greyhawk"                => 14375,
                         "greyhound"               => 8598,
                         "greyhounds"              => 18251,
                         "greyish"                 => 9146,
                         "greys"                   => 17003,
                         "grid"                    => 3158,
                         "gridiron"                => 13903,
                         "grids"                   => 13317,
                         "grieg"                   => 18040,
                         "grierson"                => 18731,
                         "grievances"              => 10844,
                         "grigor"                  => 26774,
                         "grigore"                 => 25032,
                         "grigori"                 => 25214,
                         "grigory"                 => 17695,
                         "grille"                  => 9015,
                         "grilles"                 => 26084,
                         "grimsby"                 => 8011,
                         "grindcore"               => 24738,
                         "gripped"                 => 23177,
                         "gristmill"               => 19233,
                         "grizzlies"               => 10950,
                         "grocers"                 => 20594,
                         "grodno"                  => 19292,
                         "grodzisk"                => 23621,
                         "groening"                => 19671,
                         "grohl"                   => 17805,
                         "grojec"                  => 23089,
                         "groningen"               => 9689,
                         "groot"                   => 17396,
                         "grooved"                 => 19504,
                         "grooves"                 => 9498,
                         "gropius"                 => 24525,
                         "grosjean"                => 23349,
                         "grossed"                 => 6835,
                         "grosser"                 => 14192,
                         "grosseto"                => 21954,
                         "grossing"                => 6519,
                         "grothendieck"            => 23546,
                         "groton"                  => 14881,
                         "ground"                  => 499,
                         "groundbreaking"          => 7837,
                         "groundnut"               => 28244,
                         "grounds"                 => 1666,
                         "groundwater"             => 7853,
                         "group"                   => 109,
                         "groupe"                  => 13347,
                         "grouped"                 => 5174,
                         "grouping"                => 6760,
                         "groupings"               => 10348,
                         "groups"                  => 459,
                         "grower"                  => 19958,
                         "growers"                 => 9191,
                         "growing"                 => 1048,
                         "grows"                   => 2786,
                         "growth"                  => 909,
                         "growths"                 => 24310,
                         "groza"                   => 26666,
                         "grozny"                  => 17931,
                         "grudgingly"              => 27243,
                         "gruffudd"                => 20543,
                         "gruffydd"                => 20692,
                         "gruiformesfamily"        => 27771,
                         "grumman"                 => 10870,
                         "grupo"                   => 9890,
                         "gruppe"                  => 17361,
                         "gruppo"                  => 23210,
                         "grzegorz"                => 23474,
                         "guadalajara"             => 7917,
                         "guadalcanal"             => 9237,
                         "guadeloupe"              => 10964,
                         "guam"                    => 5554,
                         "guanajuato"              => 15330,
                         "guangdong"               => 7419,
                         "guangxi"                 => 11608,
                         "guangzhou"               => 6711,
                         "guanine"                 => 22417,
                         "guano"                   => 17577,
                         "guantanamo"              => 7242,
                         "guarani"                 => 13805,
                         "guarantor"               => 28636,
                         "guaranty"                => 24706,
                         "guarda"                  => 27937,
                         "guardia"                 => 14359,
                         "guardians"               => 7066,
                         "guardsman"               => 27434,
                         "guardsmen"               => 15796,
                         "guatemala"               => 4331,
                         "guatemalan"              => 9702,
                         "guayaquil"               => 15106,
                         "gubernatorial"           => 5604,
                         "guelders"                => 26251,
                         "guelph"                  => 10433,
                         "guerilla"                => 13481,
                         "guernica"                => 29272,
                         "guerre"                  => 10408,
                         "guerrilla"               => 5375,
                         "guerrillas"              => 8611,
                         "guested"                 => 19056,
                         "guetta"                  => 17845,
                         "guggenheim"              => 7702,
                         "guiana"                  => 8737,
                         "guidance"                => 3168,
                         "guide"                   => 1805,
                         "guidebooks"              => 26118,
                         "guided"                  => 3510,
                         "guideline"               => 14832,
                         "guidelines"              => 4073,
                         "guides"                  => 4727,
                         "guiding"                 => 6293,
                         "guild"                   => 3440,
                         "guilders"                => 18556,
                         "guildford"               => 8379,
                         "guildhall"               => 12303,
                         "guilds"                  => 10717,
                         "guillaume"               => 8005,
                         "guimaraes"               => 16073,
                         "guinea"                  => 2457,
                         "guinean"                 => 14759,
                         "guineas"                 => 8105,
                         "guise"                   => 7975,
                         "guises"                  => 26988,
                         "guitarist"               => 1915,
                         "guitarists"              => 8701,
                         "guizhou"                 => 13777,
                         "gujarat"                 => 5232,
                         "gujarati"                => 10092,
                         "gujranwala"              => 24655,
                         "gujrat"                  => 21393,
                         "gulab"                   => 28276,
                         "gulbarga"                => 28336,
                         "gulch"                   => 13766,
                         "gulden"                  => 21533,
                         "gules"                   => 9345,
                         "gulf"                    => 1860,
                         "gulfport"                => 22686,
                         "gulfstream"              => 18620,
                         "gullies"                 => 19852,
                         "gulshan"                 => 26228,
                         "gulzar"                  => 25768,
                         "gunboat"                 => 10133,
                         "gunboats"                => 11145,
                         "gunfight"                => 14602,
                         "gunma"                   => 18542,
                         "gunmen"                  => 9973,
                         "gunnery"                 => 9082,
                         "gunpowder"               => 7939,
                         "guns"                    => 1470,
                         "gunships"                => 26027,
                         "guntur"                  => 15372,
                         "gunung"                  => 23343,
                         "gurdjieff"               => 23143,
                         "gurdwara"                => 16410,
                         "gurgaon"                 => 17176,
                         "gurion"                  => 13337,
                         "gurkha"                  => 15870,
                         "gurkhas"                 => 25147,
                         "gurps"                   => 20799,
                         "guru"                    => 4342,
                         "gurudwara"               => 23922,
                         "gurung"                  => 27506,
                         "gurus"                   => 15595,
                         "gustaf"                  => 11179,
                         "gustafsson"              => 21910,
                         "gustave"                 => 10221,
                         "gustavus"                => 13574,
                         "gusts"                   => 12755,
                         "gusty"                   => 27984,
                         "gutenberg"               => 16191,
                         "guttenberg"              => 25157,
                         "guwahati"                => 13234,
                         "guyana"                  => 6739,
                         "guyanese"                => 17706,
                         "guyed"                   => 27090,
                         "gwalior"                 => 13407,
                         "gwangju"                 => 17331,
                         "gwent"                   => 16655,
                         "gwinnett"                => 17808,
                         "gwynedd"                 => 10183,
                         "gwynne"                  => 19807,
                         "gyatso"                  => 21890,
                         "gyeonggi"                => 20600,
                         "gyeongju"                => 25140,
                         "gyeongsang"              => 27377,
                         "gygax"                   => 17771,
                         "gyllenhaal"              => 26611,
                         "gymkhana"                => 24698,
                         "gymnasium"               => 4074,
                         "gymnasiums"              => 20212,
                         "gymnastics"              => 4777,
                         "gymnasts"                => 14600,
                         "gymnopilus"              => 22484,
                         "gympie"                  => 21200,
                         "gynaecology"             => 24141,
                         "gynecology"              => 18635,
                         "gyorgy"                  => 13944,
                         "gypsum"                  => 12894,
                         "gyrus"                   => 18888,
                         "gyula"                   => 16721,
                         "h.m.s"                   => 24061,
                         "haakon"                  => 13975,
                         "haaretz"                 => 20147,
                         "haarlem"                 => 9960,
                         "haasan"                  => 17608,
                         "habeas"                  => 11339,
                         "habermas"                => 21112,
                         "habilitation"            => 15066,
                         "habitable"               => 13176,
                         "habitat"                 => 1648,
                         "habitation"              => 10246,
                         "habitats"                => 3497,
                         "habitually"              => 20182,
                         "habsburg"                => 5908,
                         "habsburgs"               => 13349,
                         "hachette"                => 26589,
                         "hacienda"                => 11309,
                         "haciendas"               => 27334,
                         "hackensack"              => 15767,
                         "had"                     => 25,
                         "hadamard"                => 26805,
                         "hadassah"                => 22862,
                         "haddington"              => 22611,
                         "hadid"                   => 29615,
                         "hadith"                  => 9239,
                         "hadiths"                 => 29200,
                         "hadron"                  => 25210,
                         "haeckel"                 => 28426,
                         "haemorrhage"             => 23683,
                         "hafez"                   => 19503,
                         "hafiz"                   => 15182,
                         "haganah"                 => 16370,
                         "hagerstown"              => 16379,
                         "hagia"                   => 22803,
                         "hagiography"             => 21942,
                         "haida"                   => 16845,
                         "haidar"                  => 28630,
                         "haifa"                   => 7443,
                         "hailed"                  => 6101,
                         "haileybury"              => 25494,
                         "hailing"                 => 12233,
                         "hails"                   => 11656,
                         "hainan"                  => 12113,
                         "hainaut"                 => 17790,
                         "hairdressing"            => 28588,
                         "hairpin"                 => 15633,
                         "haiti"                   => 4521,
                         "haitian"                 => 7407,
                         "haitians"                => 21441,
                         "haiyan"                  => 29904,
                         "hajji"                   => 12529,
                         "hajjiabad"               => 17967,
                         "hakka"                   => 14903,
                         "hakoah"                  => 29975,
                         "hakodate"                => 26828,
                         "hakon"                   => 19148,
                         "halakha"                 => 22266,
                         "halakhic"                => 25749,
                         "halal"                   => 19367,
                         "halberstadt"             => 21672,
                         "haldane"                 => 13844,
                         "halden"                  => 28524,
                         "haldimand"               => 27008,
                         "halen"                   => 12783,
                         "halesowen"               => 24491,
                         "halevi"                  => 29312,
                         "halevy"                  => 28225,
                         "half"                    => 345,
                         "halfback"                => 9151,
                         "halfdan"                 => 25570,
                         "halfpenny"               => 27717,
                         "halfpipe"                => 28292,
                         "halftime"                => 6917,
                         "halide"                  => 18819,
                         "halides"                 => 19499,
                         "halil"                   => 25318,
                         "halim"                   => 18940,
                         "halland"                 => 27417,
                         "hallmarks"               => 18182,
                         "halls"                   => 3908,
                         "hallstatt"               => 27257,
                         "hallucinogenic"          => 21758,
                         "halogaland"              => 29490,
                         "halt"                    => 4584,
                         "halted"                  => 5678,
                         "halting"                 => 13991,
                         "halts"                   => 18311,
                         "halved"                  => 17018,
                         "halves"                  => 8821,
                         "halych"                  => 26474,
                         "hamadan"                 => 13372,
                         "hamamatsu"               => 28167,
                         "hamas"                   => 7069,
                         "hamasaki"                => 17009,
                         "hambledon"               => 29586,
                         "hambro"                  => 29851,
                         "hamdi"                   => 28073,
                         "hameed"                  => 25324,
                         "hamid"                   => 8618,
                         "hamilcar"                => 29248,
                         "hamiltonian"             => 10973,
                         "hamlets"                 => 6874,
                         "hammam"                  => 24700,
                         "hammersmith"             => 9315,
                         "hammerstein"             => 12702,
                         "hammocks"                => 24527,
                         "hampden"                 => 10230,
                         "hampered"                => 7602,
                         "hampering"               => 28050,
                         "hampshire"               => 2201,
                         "hampstead"               => 9616,
                         "hamstring"               => 13133,
                         "hamza"                   => 15015,
                         "hanafi"                  => 21884,
                         "hanau"                   => 14542,
                         "hanbury"                 => 22513,
                         "handan"                  => 27978,
                         "handballer"              => 23766,
                         "handbook"                => 6659,
                         "handbooks"               => 23450,
                         "handcrafted"             => 26780,
                         "handcrafts"              => 29594,
                         "handedness"              => 26208,
                         "handel"                  => 7859,
                         "hander"                  => 16558,
                         "handheld"                => 9562,
                         "handicap"                => 5773,
                         "handicaps"               => 23291,
                         "handicraft"              => 18178,
                         "handicrafts"             => 14417,
                         "handlers"                => 14654,
                         "handover"                => 14779,
                         "handpicked"              => 27409,
                         "handset"                 => 17446,
                         "handsets"                => 21258,
                         "handsworth"              => 23823,
                         "handwritten"             => 12707,
                         "hangar"                  => 7839,
                         "hangars"                 => 11654,
                         "hanged"                  => 6638,
                         "hangings"                => 22476,
                         "hangul"                  => 12125,
                         "hangzhou"                => 11542,
                         "hanja"                   => 11295,
                         "hannity"                 => 22481,
                         "hanno"                   => 25164,
                         "hanns"                   => 21976,
                         "hanoi"                   => 8384,
                         "hanover"                 => 5159,
                         "hanoverian"              => 16337,
                         "hansa"                   => 14138,
                         "hanseatic"               => 14456,
                         "hanshin"                 => 21178,
                         "hanssen"                 => 25702,
                         "hansson"                 => 22162,
                         "hants"                   => 21727,
                         "hantuchova"              => 26065,
                         "hanyu"                   => 29405,
                         "hanzhong"                => 29488,
                         "haphazard"               => 23556,
                         "haplogroup"              => 10658,
                         "haplogroups"             => 23783,
                         "haploid"                 => 20824,
                         "haplotype"               => 22572,
                         "haplotypes"              => 28374,
                         "hapoel"                  => 8517,
                         "haram"                   => 15881,
                         "harappan"                => 27824,
                         "harare"                  => 13781,
                         "harbhajan"               => 24452,
                         "harbinger"               => 19325,
                         "harbor"                  => 2139,
                         "harbored"                => 22494,
                         "harborough"              => 25398,
                         "harbors"                 => 11554,
                         "harbour"                 => 2468,
                         "harbours"                => 12149,
                         "harburg"                 => 29046,
                         "harcourt"                => 9225,
                         "hardback"                => 17649,
                         "hardcover"               => 9685,
                         "hardening"               => 16310,
                         "hardiness"               => 19979,
                         "hardinge"                => 26763,
                         "hardness"                => 10859,
                         "hardships"               => 9940,
                         "hardtop"                 => 15980,
                         "hardware"                => 2694,
                         "hardwicke"               => 19294,
                         "hardwoods"               => 21105,
                         "haredi"                  => 16575,
                         "harel"                   => 27769,
                         "hares"                   => 16756,
                         "haridwar"                => 22409,
                         "haringey"                => 24230,
                         "hariri"                  => 18737,
                         "harith"                  => 28915,
                         "harlequin"               => 13326,
                         "harlequins"              => 17432,
                         "harlingen"               => 24892,
                         "harmful"                 => 6492,
                         "harmonia"                => 23508,
                         "harmonic"                => 6827,
                         "harmonica"               => 8630,
                         "harmonics"               => 14329,
                         "harmonies"               => 9440,
                         "harmonious"              => 12821,
                         "harmonium"               => 18846,
                         "harmonix"                => 25558,
                         "harmonization"           => 25332,
                         "harmonize"               => 23499,
                         "harmonized"              => 22049,
                         "harnesses"               => 21437,
                         "harnessing"              => 23335,
                         "harpalinae"              => 28257,
                         "harpalus"                => 19020,
                         "harpercollins"           => 15374,
                         "harpers"                 => 15839,
                         "harpist"                 => 21657,
                         "harpsichord"             => 11342,
                         "harpsichordist"          => 29023,
                         "harriers"                => 12174,
                         "harrisburg"              => 8065,
                         "harrisonburg"            => 26161,
                         "harrods"                 => 25143,
                         "harrogate"               => 12124,
                         "harrow"                  => 8284,
                         "harsher"                 => 16856,
                         "harshest"                => 26931,
                         "harshness"               => 24407,
                         "hartlepool"              => 10066,
                         "harun"                   => 18490,
                         "haruna"                  => 28701,
                         "harvard"                 => 1878,
                         "harvested"               => 7823,
                         "harvester"               => 15419,
                         "harvesters"              => 28393,
                         "harvesting"              => 7502,
                         "harvests"                => 15768,
                         "harwich"                 => 14247,
                         "haryana"                 => 8224,
                         "has"                     => 24,
                         "hasan"                   => 5996,
                         "hasanabad"               => 16537,
                         "hasbro"                  => 12726,
                         "hashanah"                => 29349,
                         "hashemi"                 => 27272,
                         "hashemite"               => 28494,
                         "hashim"                  => 15960,
                         "hashing"                 => 26220,
                         "hashtag"                 => 21421,
                         "hasidic"                 => 11252,
                         "hasidim"                 => 21702,
                         "hasidism"                => 27990,
                         "hasina"                  => 29128,
                         "haskovo"                 => 27558,
                         "hasselbeck"              => 29059,
                         "hasselt"                 => 28104,
                         "hastened"                => 16766,
                         "hastily"                 => 10083,
                         "hatchback"               => 12738,
                         "hatchery"                => 16216,
                         "hatchlings"              => 22140,
                         "hatshepsut"              => 28682,
                         "hatta"                   => 22404,
                         "hattiesburg"             => 24776,
                         "hatun"                   => 26311,
                         "haugesund"               => 22555,
                         "haulage"                 => 17990,
                         "hauptbahnhof"            => 13550,
                         "hauptmann"               => 16019,
                         "hausa"                   => 16163,
                         "hausdorff"               => 17761,
                         "haussmann"               => 28681,
                         "haute"                   => 5883,
                         "hautes"                  => 13068,
                         "hauts"                   => 24694,
                         "havant"                  => 23436,
                         "haveli"                  => 22499,
                         "havelock"                => 16732,
                         "haven"                   => 3475,
                         "haverford"               => 18790,
                         "haverfordwest"           => 29376,
                         "haverhill"               => 19008,
                         "havering"                => 25227,
                         "havilland"               => 8977,
                         "havre"                   => 9717,
                         "hawai'i"                 => 17838,
                         "hawai`i"                 => 27903,
                         "hawaiians"               => 17863,
                         "hawick"                  => 29550,
                         "hawke"                   => 8432,
                         "hawkesbury"              => 16633,
                         "hayat"                   => 17443,
                         "hayato"                  => 29353,
                         "haydn"                   => 8502,
                         "haydock"                 => 24586,
                         "haymarket"               => 12587,
                         "hazara"                  => 15964,
                         "hazardous"               => 6650,
                         "hazards"                 => 7482,
                         "hazleton"                => 24000,
                         "hazrat"                  => 12429,
                         "he"                      => 12,
                         "he/she"                  => 10435,
                         "header"                  => 7124,
                         "headingley"              => 14303,
                         "headings"                => 17027,
                         "headlamps"               => 17609,
                         "headland"                => 11184,
                         "headlands"               => 22307,
                         "headlined"               => 8340,
                         "headliner"               => 16199,
                         "headliners"              => 16921,
                         "headlining"              => 8963,
                         "headmaster"              => 6150,
                         "headmasters"             => 19609,
                         "headphone"               => 25483,
                         "headquarter"             => 19299,
                         "headquartered"           => 3098,
                         "headquarters"            => 1067,
                         "headship"                => 22474,
                         "headstock"               => 26322,
                         "headstones"              => 21462,
                         "headteacher"             => 16055,
                         "headwater"               => 23405,
                         "headwaters"              => 8487,
                         "health"                  => 404,
                         "healthcare"              => 3532,
                         "hearings"                => 6561,
                         "heartbreakers"           => 27526,
                         "hearths"                 => 24927,
                         "heartland"               => 9047,
                         "heated"                  => 4739,
                         "heaters"                 => 15150,
                         "heathfield"              => 28406,
                         "heathland"               => 17919,
                         "heating"                 => 4130,
                         "heats"                   => 5665,
                         "heatseekers"             => 14590,
                         "heavier"                 => 5005,
                         "heaviest"                => 8839,
                         "heavily"                 => 1491,
                         "heavy"                   => 815,
                         "heavyweight"             => 3265,
                         "heavyweights"            => 23691,
                         "hebdo"                   => 28593,
                         "hebei"                   => 9713,
                         "hebrew"                  => 2557,
                         "hebrides"                => 11459,
                         "hectare"                 => 8345,
                         "hectares"                => 4553,
                         "hedgehogs"               => 21988,
                         "hedmark"                 => 25909,
                         "hedong"                  => 23235,
                         "hedonistic"              => 28444,
                         "heeded"                  => 28219,
                         "heerenveen"              => 18792,
                         "hefei"                   => 28616,
                         "hegel"                   => 11998,
                         "hegemonic"               => 24873,
                         "hegemony"                => 10724,
                         "heian"                   => 15090,
                         "heidegger"               => 13269,
                         "heidelberg"              => 6506,
                         "heidfeld"                => 23365,
                         "height"                  => 1503,
                         "heights"                 => 2593,
                         "heikki"                  => 23385,
                         "heilbronn"               => 19160,
                         "heilongjiang"            => 16751,
                         "heinkel"                 => 14818,
                         "heir"                    => 3120,
                         "heiress"                 => 7483,
                         "heirs"                   => 5816,
                         "heisenberg"              => 15331,
                         "heisman"                 => 10674,
                         "hejaz"                   => 21151,
                         "held"                    => 167,
                         "helder"                  => 21143,
                         "helens"                  => 7681,
                         "helgi"                   => 27585,
                         "helical"                 => 13497,
                         "helices"                 => 17263,
                         "helicopters"             => 4585,
                         "helier"                  => 24830,
                         "heligoland"              => 23493,
                         "helio"                   => 20885,
                         "heliocentric"            => 27408,
                         "heliopolis"              => 22867,
                         "heliport"                => 14884,
                         "helix"                   => 8728,
                         "hellenic"                => 7930,
                         "hellenistic"             => 8982,
                         "hellinsia"               => 27875,
                         "hells"                   => 16173,
                         "helmand"                 => 16868,
                         "helmed"                  => 19186,
                         "helmholtz"               => 17956,
                         "helmsman"                => 24725,
                         "helpline"                => 23980,
                         "helsing"                 => 24131,
                         "helsingborg"             => 21069,
                         "helsinki"                => 4591,
                         "helvetic"                => 26542,
                         "hematite"                => 25897,
                         "hematology"              => 28538,
                         "hematopoietic"           => 24773,
                         "hemel"                   => 19267,
                         "hemings"                 => 23294,
                         "hemisphere"              => 5014,
                         "hemispheres"             => 16776,
                         "hemispheric"             => 29071,
                         "hemispherical"           => 22048,
                         "hemorrhagic"             => 23863,
                         "henan"                   => 9003,
                         "hence"                   => 2049,
                         "henceforth"              => 10935,
                         "henchmen"                => 11520,
                         "hendrik"                 => 10491,
                         "henin"                   => 20509,
                         "henna"                   => 25390,
                         "hennepin"                => 16969,
                         "henri"                   => 3702,
                         "henrico"                 => 24502,
                         "henricus"                => 27073,
                         "henryk"                  => 13982,
                         "hepatic"                 => 15742,
                         "heptathlon"              => 18061,
                         "her"                     => 35,
                         "heracles"                => 13250,
                         "heraclius"               => 15184,
                         "heraklion"               => 24832,
                         "herald"                  => 3523,
                         "heralded"                => 11533,
                         "heraldic"                => 8956,
                         "heraldry"                => 10243,
                         "heralds"                 => 18646,
                         "herat"                   => 15257,
                         "herault"                 => 21680,
                         "herbaceous"              => 11350,
                         "herbarium"               => 13101,
                         "herbicide"               => 21125,
                         "herbicides"              => 18695,
                         "herbivore"               => 23596,
                         "herbivores"              => 16435,
                         "herbivorous"             => 16104,
                         "herders"                 => 20964,
                         "herding"                 => 13388,
                         "herds"                   => 9726,
                         "hereditary"              => 5266,
                         "heredity"                => 20762,
                         "herefordshire"           => 10640,
                         "herero"                  => 26615,
                         "heresies"                => 24439,
                         "heresy"                  => 9549,
                         "heretical"               => 14778,
                         "heretics"                => 14758,
                         "herge"                   => 14942,
                         "heriot"                  => 21648,
                         "heritable"               => 23637,
                         "heritage"                => 1182,
                         "herkimer"                => 21673,
                         "hermanos"                => 24049,
                         "hermeneutics"            => 21754,
                         "hermetic"                => 20173,
                         "hermitage"               => 8689,
                         "hermitian"               => 21106,
                         "hermits"                 => 18614,
                         "hernando"                => 14544,
                         "herne"                   => 15714,
                         "herodotus"               => 10699,
                         "heroes"                  => 2811,
                         "heroically"              => 29345,
                         "heroine"                 => 7241,
                         "heroines"                => 15035,
                         "heroism"                 => 9612,
                         "herpetologist"           => 27938,
                         "hertford"                => 12177,
                         "hertfordshire"           => 6559,
                         "hertogenbosch"           => 24120,
                         "herts"                   => 29211,
                         "herzegovina"             => 3955,
                         "herzl"                   => 21239,
                         "herzliya"                => 25456,
                         "hesar"                   => 23744,
                         "heseltine"               => 27935,
                         "hesiod"                  => 21376,
                         "hesketh"                 => 20368,
                         "hesperiidae"             => 16682,
                         "hessen"                  => 18186,
                         "heterodox"               => 26221,
                         "heterogeneity"           => 21211,
                         "heterogeneous"           => 11237,
                         "heterozygous"            => 23511,
                         "hetman"                  => 15242,
                         "heung"                   => 26057,
                         "heuristic"               => 15048,
                         "heuristics"              => 23049,
                         "hexadecimal"             => 22462,
                         "hexagonal"               => 10037,
                         "hexham"                  => 18065,
                         "heydar"                  => 24419,
                         "heyday"                  => 9235,
                         "heydrich"                => 19732,
                         "hezbollah"               => 8480,
                         "hezekiah"                => 20731,
                         "hialeah"                 => 23560,
                         "hiatus"                  => 4840,
                         "hibernate"               => 25192,
                         "hibernation"             => 16319,
                         "hibernian"               => 11417,
                         "hideo"                   => 20373,
                         "hideout"                 => 11081,
                         "hideyoshi"               => 14404,
                         "hierarchical"            => 8382,
                         "hierarchies"             => 15732,
                         "hierarchy"               => 4711,
                         "hieroglyph"              => 22833,
                         "hieroglyphic"            => 21363,
                         "hieronymus"              => 18919,
                         "high"                    => 91,
                         "higher"                  => 561,
                         "highest"                 => 639,
                         "highgate"                => 14242,
                         "highlanders"             => 8556,
                         "highlands"               => 4176,
                         "highlight"               => 4574,
                         "highlighted"             => 4470,
                         "highlighting"            => 7792,
                         "highlights"              => 4023,
                         "highly"                  => 891,
                         "highs"                   => 8895,
                         "highschool"              => 21686,
                         "highway"                 => 622,
                         "highwayman"              => 26515,
                         "highways"                => 3243,
                         "hijab"                   => 21133,
                         "hijackers"               => 15590,
                         "hijacking"               => 14028,
                         "hijra"                   => 28625,
                         "hikers"                  => 10906,
                         "hilal"                   => 16375,
                         "hildesheim"              => 16479,
                         "hillcrest"               => 15723,
                         "hillel"                  => 16700,
                         "hillfort"                => 24123,
                         "hillingdon"              => 21994,
                         "hills"                   => 1311,
                         "hillsboro"               => 12558,
                         "hillsborough"            => 9167,
                         "hillsdale"               => 18505,
                         "hillsides"               => 16001,
                         "hillsong"                => 23012,
                         "hilly"                   => 7738,
                         "hilversum"               => 26067,
                         "him/her"                 => 22922,
                         "himachal"                => 11032,
                         "himalaya"                => 15077,
                         "himalayan"               => 9280,
                         "himalayas"               => 8972,
                         "himmler"                 => 10805,
                         "himself"                 => 375,
                         "hindemith"               => 22559,
                         "hindenburg"              => 12501,
                         "hinder"                  => 11224,
                         "hindered"                => 9871,
                         "hindering"               => 20114,
                         "hindi"                   => 3496,
                         "hindley"                 => 21095,
                         "hindmarsh"               => 22185,
                         "hindrance"               => 17586,
                         "hindu"                   => 2481,
                         "hinduism"                => 6456,
                         "hindus"                  => 6369,
                         "hindustan"               => 12325,
                         "hindustani"              => 12672,
                         "hindwing"                => 13941,
                         "hindwings"               => 6060,
                         "hinged"                  => 12112,
                         "hingham"                 => 21655,
                         "hinsdale"                => 25709,
                         "hinted"                  => 9175,
                         "hinterland"              => 12267,
                         "hipparchus"              => 29236,
                         "hipped"                  => 11792,
                         "hipper"                  => 20815,
                         "hippocampal"             => 22457,
                         "hippocampus"             => 13623,
                         "hippocrates"             => 20399,
                         "hippodrome"              => 16352,
                         "hippolyta"               => 26856,
                         "hippolyte"               => 16826,
                         "hippolytus"              => 23818,
                         "hiragana"                => 22651,
                         "hiroshima"               => 7726,
                         "his"                     => 15,
                         "his/her"                 => 8137,
                         "hisar"                   => 21608,
                         "hisham"                  => 19934,
                         "hispania"                => 14100,
                         "hispanic"                => 1967,
                         "hispanicized"            => 15353,
                         "hispanics"               => 12135,
                         "hispaniola"              => 14782,
                         "hispano"                 => 14854,
                         "histidine"               => 23162,
                         "histoire"                => 15105,
                         "histological"            => 25923,
                         "histology"               => 20890,
                         "histone"                 => 14558,
                         "historia"                => 8333,
                         "historian"               => 1684,
                         "historians"              => 2542,
                         "historic"                => 509,
                         "historical"              => 666,
                         "historically"            => 2254,
                         "historicity"             => 19757,
                         "histories"               => 5768,
                         "historiography"          => 10201,
                         "historique"              => 18882,
                         "history"                 => 96,
                         "hitchin"                 => 20189,
                         "hitfix"                  => 28231,
                         "hitherto"                => 10070,
                         "hitless"                 => 29635,
                         "hits"                    => 1446,
                         "hitter"                  => 6277,
                         "hitters"                 => 11821,
                         "hittite"                 => 13039,
                         "hittites"                => 23489,
                         "hiv/aids"                => 7478,
                         "hjalmar"                 => 20536,
                         "hmong"                   => 10570,
                         "hoards"                  => 28763,
                         "hoare"                   => 15695,
                         "hobbyist"                => 25969,
                         "hobbyists"               => 17571,
                         "hochschule"              => 11967,
                         "hockeyallsvenskan"       => 28370,
                         "hodgkin"                 => 15455,
                         "hoffenheim"              => 28972,
                         "hofstadter"              => 28836,
                         "hofstra"                 => 17321,
                         "hogarth"                 => 14338,
                         "hohenlohe"               => 19595,
                         "hohenstaufen"            => 20739,
                         "hohenzollern"            => 12807,
                         "hoisted"                 => 13649,
                         "hokkaido"                => 7290,
                         "hokkien"                 => 15993,
                         "holbein"                 => 23851,
                         "holborn"                 => 16171,
                         "holby"                   => 14871,
                         "hold'em"                 => 21601,
                         "holders"                 => 4852,
                         "holdings"                => 3399,
                         "holds"                   => 1283,
                         "holistic"                => 10185,
                         "holkar"                  => 21915,
                         "hollande"                => 23670,
                         "hollandia"               => 21952,
                         "hollies"                 => 20833,
                         "hollows"                 => 18288,
                         "hollyoaks"               => 11874,
                         "hollywood"               => 1731,
                         "holme"                   => 15811,
                         "holmenkollen"            => 24378,
                         "holocaust"               => 4198,
                         "holocene"                => 15113,
                         "holographic"             => 15603,
                         "holomorphic"             => 17105,
                         "holon"                   => 26209,
                         "holotype"                => 10380,
                         "holyhead"                => 20477,
                         "holyoke"                 => 13417,
                         "holyrood"                => 17991,
                         "holywell"                => 23357,
                         "homage"                  => 5481,
                         "home"                    => 145,
                         "homebuilt"               => 25148,
                         "homegrown"               => 18136,
                         "homeland"                => 4014,
                         "homelands"               => 16673,
                         "homelessness"            => 12264,
                         "homeopathy"              => 20665,
                         "homeostasis"             => 18408,
                         "homeowner"               => 13205,
                         "homeowners"              => 10650,
                         "homeport"                => 20644,
                         "homeported"              => 28860,
                         "homeric"                 => 18773,
                         "homes"                   => 1519,
                         "homeschooled"            => 23812,
                         "homestead"               => 5438,
                         "homesteaders"            => 27479,
                         "homesteads"              => 18208,
                         "hometown"                => 3446,
                         "homeward"                => 21565,
                         "homilies"                => 23618,
                         "hominid"                 => 26059,
                         "hommes"                  => 28272,
                         "homoerotic"              => 28095,
                         "homogeneity"             => 21286,
                         "homogeneous"             => 8138,
                         "homogenous"              => 23138,
                         "homolog"                 => 21201,
                         "homologation"            => 27117,
                         "homologous"              => 12754,
                         "homology"                => 10976,
                         "homomorphism"            => 16058,
                         "homomorphisms"           => 28866,
                         "homonymous"              => 25522,
                         "homophobia"              => 14273,
                         "homophobic"              => 15799,
                         "homosexuality"           => 5574,
                         "homotopy"                => 14374,
                         "homozygous"              => 19604,
                         "honduran"                => 10494,
                         "honduras"                => 5233,
                         "honeycomb"               => 11638,
                         "honeycombs"              => 28433,
                         "honeyeater"              => 21431,
                         "honiara"                 => 26788,
                         "honorary"                => 2037,
                         "honoree"                 => 18418,
                         "honorees"                => 19867,
                         "honorific"               => 11844,
                         "honoris"                 => 14935,
                         "honorius"                => 17033,
                         "honors"                  => 2136,
                         "honour"                  => 2129,
                         "honourable"              => 7427,
                         "honoured"                => 5731,
                         "honouring"               => 16040,
                         "honours"                 => 2221,
                         "honshu"                  => 12868,
                         "honved"                  => 26761,
                         "hooghly"                 => 20417,
                         "hooliganism"             => 27198,
                         "hoorn"                   => 27439,
                         "hopefuls"                => 23259,
                         "hopital"                 => 26258,
                         "hoppus"                  => 25162,
                         "hordaland"               => 17168,
                         "horde"                   => 9868,
                         "horizontal"              => 3605,
                         "horizontally"            => 8519,
                         "horizonte"               => 15856,
                         "hormozgan"               => 12728,
                         "hormuz"                  => 29138,
                         "hornbill"                => 20207,
                         "hornblower"              => 20734,
                         "hornby"                  => 14511,
                         "hornchurch"              => 23199,
                         "horned"                  => 9458,
                         "horni"                   => 28297,
                         "hornsey"                 => 24202,
                         "horror"                  => 2533,
                         "horsemanship"            => 26459,
                         "horsepower"              => 8426,
                         "horseshoe"               => 7996,
                         "horseshoes"              => 28101,
                         "horsham"                 => 13086,
                         "horthy"                  => 20135,
                         "horticultural"           => 8715,
                         "horticulture"            => 9988,
                         "horticulturist"          => 29476,
                         "hortons"                 => 24905,
                         "hoseyn"                  => 19624,
                         "hoseynabad"              => 12481,
                         "hoshi"                   => 28430,
                         "hoshino"                 => 28452,
                         "hosiery"                 => 24530,
                         "hosni"                   => 21755,
                         "hosokawa"                => 25883,
                         "hospice"                 => 9950,
                         "hospitalised"            => 17264,
                         "hospitalization"         => 15665,
                         "hospitalized"            => 8529,
                         "hospitaller"             => 20878,
                         "hospitallers"            => 25365,
                         "hospitals"               => 2886,
                         "hossein"                 => 14501,
                         "host"                    => 917,
                         "hosted"                  => 1144,
                         "hostel"                  => 7938,
                         "hostels"                 => 12210,
                         "hostilities"             => 5945,
                         "hosting"                 => 3462,
                         "hosts"                   => 1934,
                         "hotelier"                => 24925,
                         "hotels"                  => 3228,
                         "hotham"                  => 20704,
                         "hotly"                   => 14306,
                         "houbraken"               => 23690,
                         "houma"                   => 24794,
                         "hounslow"                => 17163,
                         "hourly"                  => 7403,
                         "housatonic"              => 23157,
                         "house"                   => 123,
                         "housed"                  => 2541,
                         "houseguests"             => 13782,
                         "household"               => 1050,
                         "householder"             => 2128,
                         "householders"            => 28654,
                         "households"              => 765,
                         "housemate"               => 13217,
                         "housemates"              => 9658,
                         "houses"                  => 791,
                         "housewives"              => 11016,
                         "housing"                 => 840,
                         "houten"                  => 23633,
                         "houthi"                  => 28294,
                         "houthis"                 => 29839,
                         "hovered"                 => 27629,
                         "howards"                 => 24274,
                         "however"                 => 92,
                         "howitzer"                => 12031,
                         "howitzers"               => 13109,
                         "howmeh"                  => 16946,
                         "howrah"                  => 12021,
                         "howth"                   => 25853,
                         "hoxha"                   => 20316,
                         "hoxton"                  => 26325,
                         "hoyas"                   => 18663,
                         "hoysala"                 => 22647,
                         "hradec"                  => 18090,
                         "hristo"                  => 26187,
                         "hsien"                   => 21582,
                         "hsinchu"                 => 25830,
                         "html5"                   => 19104,
                         "http"                    => 2212,
                         "https"                   => 21,
                         "huawei"                  => 24712,
                         "hubei"                   => 11040,
                         "hubli"                   => 26010,
                         "hucknall"                => 27359,
                         "huddersfield"            => 6453,
                         "huelva"                  => 18992,
                         "huesca"                  => 19638,
                         "huffington"              => 9173,
                         "hugely"                  => 9470,
                         "hughie"                  => 24276,
                         "huguenot"                => 12562,
                         "huguenots"               => 14929,
                         "hulled"                  => 14482,
                         "hulls"                   => 11788,
                         "human"                   => 392,
                         "humane"                  => 8449,
                         "humanism"                => 11926,
                         "humanist"                => 8132,
                         "humanistic"              => 12613,
                         "humanists"               => 20174,
                         "humanitarian"            => 4115,
                         "humanities"              => 4435,
                         "humankind"               => 13756,
                         "humanoid"                => 10026,
                         "humanoids"               => 21443,
                         "humans"                  => 1591,
                         "humayun"                 => 16248,
                         "humber"                  => 9636,
                         "humberside"              => 22763,
                         "humboldt"                => 6965,
                         "humerus"                 => 18762,
                         "humid"                   => 5287,
                         "humidity"                => 7049,
                         "hummingbird"             => 13817,
                         "hummingbirds"            => 18997,
                         "humorist"                => 17086,
                         "humorous"                => 5322,
                         "humorously"              => 16741,
                         "hunan"                   => 9459,
                         "hundreds"                => 2030,
                         "hundredths"              => 28844,
                         "hungama"                 => 28770,
                         "hungarian"               => 1830,
                         "hungarians"              => 7922,
                         "hungary"                 => 1901,
                         "hunslet"                 => 18303,
                         "hunsruck"                => 20043,
                         "hunterdon"               => 20490,
                         "hunters"                 => 4894,
                         "huntingdon"              => 10645,
                         "huntingdonshire"         => 18331,
                         "huntly"                  => 17708,
                         "huntsville"              => 9128,
                         "hunza"                   => 29812,
                         "huracan"                 => 20933,
                         "hurdler"                 => 19712,
                         "hurdles"                 => 6361,
                         "hurler"                  => 11867,
                         "hurlers"                 => 27199,
                         "hurling"                 => 4222,
                         "huron"                   => 7591,
                         "hurricane"               => 2138,
                         "hurricanes"              => 5840,
                         "hurriedly"               => 18421,
                         "hurries"                 => 25364,
                         "husayn"                  => 12965,
                         "husbandry"               => 11797,
                         "huseyin"                 => 25725,
                         "hussars"                 => 10753,
                         "hussein"                 => 5892,
                         "husserl"                 => 21238,
                         "hussite"                 => 22948,
                         "huxley"                  => 10701,
                         "huygens"                 => 18219,
                         "hyacinthe"               => 20939,
                         "hyaline"                 => 19311,
                         "hyannis"                 => 29222,
                         "hybrid"                  => 3227,
                         "hybridization"           => 13706,
                         "hybrids"                 => 7699,
                         "hyderabad"               => 4829,
                         "hydra"                   => 10605,
                         "hydration"               => 19953,
                         "hydraulic"               => 5253,
                         "hydraulically"           => 21965,
                         "hydrazine"               => 26252,
                         "hydride"                 => 15124,
                         "hydrocarbon"             => 11742,
                         "hydrocarbons"            => 11302,
                         "hydrodynamic"            => 21004,
                         "hydroelectric"           => 6075,
                         "hydroelectricity"        => 19814,
                         "hydrogen"                => 3344,
                         "hydrogenation"           => 20928,
                         "hydrographic"            => 13813,
                         "hydrography"             => 26861,
                         "hydrolases"              => 23761,
                         "hydrological"            => 19916,
                         "hydrology"               => 13656,
                         "hydrolysis"              => 12148,
                         "hydrolyzed"              => 28556,
                         "hydrophilic"             => 21765,
                         "hydrophobic"             => 12163,
                         "hydropower"              => 12774,
                         "hydrostatic"             => 18977,
                         "hydrothermal"            => 16580,
                         "hydroxide"               => 11231,
                         "hydroxy"                 => 23221,
                         "hydroxyl"                => 13899,
                         "hydroxylase"             => 21534,
                         "hyeon"                   => 29870,
                         "hyksos"                  => 29246,
                         "hylidae"                 => 24611,
                         "hymenoptera"             => 25538,
                         "hymn"                    => 5723,
                         "hymnal"                  => 16601,
                         "hymns"                   => 6510,
                         "hyogo"                   => 14747,
                         "hyperactivity"           => 22498,
                         "hyperbaric"              => 28758,
                         "hyperbola"               => 29690,
                         "hyperbolic"              => 9930,
                         "hypergeometric"          => 28661,
                         "hyperinflation"          => 23084,
                         "hypermarket"             => 28122,
                         "hyperplane"              => 29158,
                         "hyperplasia"             => 24265,
                         "hypersensitivity"        => 22848,
                         "hypersonic"              => 26263,
                         "hypertension"            => 10606,
                         "hypertext"               => 21240,
                         "hypertrophy"             => 23620,
                         "hyphae"                  => 15249,
                         "hyphenated"              => 29516,
                         "hyposmocoma"             => 22229,
                         "hypotension"             => 25123,
                         "hypothalamus"            => 18994,
                         "hypotheses"              => 9203,
                         "hypothesis"              => 3643,
                         "hypothesized"            => 9922,
                         "hypoxia"                 => 17094,
                         "hypoxic"                 => 29503,
                         "hysteresis"              => 26036,
                         "hythe"                   => 19276,
                         "hyung"                   => 24298,
                         "hywel"                   => 22994,
                         "i.e."                    => 3275,
                         "ibadan"                  => 15354,
                         "ibaraki"                 => 18759,
                         "iberia"                  => 9763,
                         "iberian"                 => 7222,
                         "ibero"                   => 21271,
                         "ibises"                  => 22490,
                         "ibiza"                   => 12809,
                         "ibrox"                   => 21948,
                         "ibsen"                   => 13142,
                         "icann"                   => 19107,
                         "icbms"                   => 26767,
                         "icebreaker"              => 15329,
                         "icebreakers"             => 23734,
                         "iceland"                 => 3766,
                         "icelanders"              => 27239,
                         "icelandic"               => 5187,
                         "icon"                    => 4785,
                         "iconic"                  => 5199,
                         "iconoclasm"              => 25119,
                         "iconoclastic"            => 26121,
                         "iconographic"            => 25440,
                         "iconography"             => 10162,
                         "iconostasis"             => 26978,
                         "icons"                   => 6511,
                         "icosahedral"             => 25253,
                         "icosahedron"             => 28326,
                         "idaho"                   => 3486,
                         "ideal"                   => 2785,
                         "idealised"               => 28221,
                         "idealism"                => 12415,
                         "idealized"               => 13095,
                         "ideally"                 => 9435,
                         "ideals"                  => 5411,
                         "ident"                   => 24930,
                         "identical"               => 2579,
                         "identically"             => 15100,
                         "identifiable"            => 9327,
                         "identification"          => 3121,
                         "identifications"         => 21993,
                         "identified"              => 1212,
                         "identifier"              => 9212,
                         "identifiers"             => 16172,
                         "identifies"              => 5261,
                         "identify"                => 2403,
                         "identifying"             => 4513,
                         "identities"              => 6072,
                         "identity"                => 1453,
                         "idents"                  => 21575,
                         "ideological"             => 6172,
                         "ideologically"           => 17383,
                         "ideologies"              => 10683,
                         "ideology"                => 4485,
                         "idiomatic"               => 23814,
                         "idioms"                  => 17496,
                         "idiopathic"              => 19812,
                         "idiosyncratic"           => 14219,
                         "idlib"                   => 22398,
                         "idmanyurdu"              => 26814,
                         "idol"                    => 3633,
                         "idolator"                => 21879,
                         "idolatry"                => 19058,
                         "idols"                   => 8221,
                         "idris"                   => 13092,
                         "ieyasu"                  => 15344,
                         "iftikhar"                => 29387,
                         "igcse"                   => 26904,
                         "ignace"                  => 20940,
                         "ignacy"                  => 21980,
                         "ignaz"                   => 19736,
                         "ignazio"                 => 28242,
                         "igneous"                 => 12519,
                         "ignited"                 => 10191,
                         "ignites"                 => 28664,
                         "igniting"                => 19716,
                         "igreja"                  => 27285,
                         "iheartmedia"             => 20269,
                         "ilaiyaraaja"             => 21430,
                         "iliac"                   => 27919,
                         "iliad"                   => 13571,
                         "ilija"                   => 26960,
                         "ilium"                   => 29120,
                         "ilkeston"                => 26246,
                         "ilkley"                  => 28796,
                         "illawarra"               => 11687,
                         "illegality"              => 29232,
                         "illegitimate"            => 6461,
                         "illicit"                 => 9390,
                         "illinois"                => 1023,
                         "illiteracy"              => 17157,
                         "illness"                 => 2599,
                         "illnesses"               => 8535,
                         "illuminated"             => 7571,
                         "illuminates"             => 23759,
                         "illumination"            => 9009,
                         "illuminations"           => 23619,
                         "illusionist"             => 27462,
                         "illusory"                => 19407,
                         "illustrate"              => 6578,
                         "illustrated"             => 2641,
                         "illustrates"             => 8079,
                         "illustrating"            => 9104,
                         "illustration"            => 5615,
                         "illustrations"           => 4289,
                         "illustrative"            => 17175,
                         "illustrator"             => 5543,
                         "illustrators"            => 13304,
                         "illyria"                 => 21279,
                         "illyrian"                => 13287,
                         "illyrians"               => 23617,
                         "ilocos"                  => 17651,
                         "iloilo"                  => 12169,
                         "ilves"                   => 27759,
                         "ilyich"                  => 25248,
                         "ilyushin"                => 20196,
                         "image"                   => 1130,
                         "imaged"                  => 20971,
                         "imagery"                 => 4820,
                         "images"                  => 1714,
                         "imaging"                 => 4409,
                         "imago"                   => 29351,
                         "imamate"                 => 28265,
                         "imams"                   => 14763,
                         "imbalances"              => 21783,
                         "imbued"                  => 16926,
                         "imereti"                 => 23509,
                         "imitated"                => 11982,
                         "imitates"                => 24216,
                         "imitations"              => 16821,
                         "imitative"               => 27830,
                         "imitators"               => 23286,
                         "immaculate"              => 7787,
                         "immanuel"                => 12906,
                         "immediacy"               => 20041,
                         "immediate"               => 2246,
                         "immediately"             => 926,
                         "immemorial"              => 24401,
                         "immense"                 => 6120,
                         "immensely"               => 9716,
                         "immersed"                => 10145,
                         "immersion"               => 9055,
                         "immersive"               => 17312,
                         "immigrant"               => 4124,
                         "immigrants"              => 2431,
                         "immigrate"               => 20786,
                         "immigrated"              => 5963,
                         "immigrating"             => 20520,
                         "immigration"             => 2603,
                         "imminent"                => 7068,
                         "immobilized"             => 22740,
                         "immolation"              => 26394,
                         "immorality"              => 18472,
                         "immortalised"            => 27737,
                         "immortalized"            => 17462,
                         "immortals"               => 15291,
                         "immovable"               => 25044,
                         "immunities"              => 24168,
                         "immunization"            => 17385,
                         "immunodeficiency"        => 22792,
                         "immunoglobulin"          => 20115,
                         "immunological"           => 22403,
                         "immunology"              => 13453,
                         "imola"                   => 21467,
                         "impact"                  => 1124,
                         "impacted"                => 7359,
                         "impacting"               => 14889,
                         "impacts"                 => 5281,
                         "impair"                  => 19753,
                         "impaired"                => 6782,
                         "impairment"              => 8945,
                         "impairments"             => 15574,
                         "impaling"                => 28478,
                         "imparted"                => 17779,
                         "impartiality"            => 19249,
                         "imparting"               => 19809,
                         "imparts"                 => 21689,
                         "impassable"              => 16140,
                         "impeachment"             => 9671,
                         "impedance"               => 9135,
                         "impede"                  => 15414,
                         "impeded"                 => 16350,
                         "impending"               => 7815,
                         "imperfect"               => 10808,
                         "imperial"                => 1239,
                         "imperialism"             => 9307,
                         "imperialist"             => 12898,
                         "imperialists"            => 28830,
                         "imperials"               => 25589,
                         "imperio"                 => 29455,
                         "impermeable"             => 25631,
                         "impetus"                 => 8948,
                         "imphal"                  => 20312,
                         "implacable"              => 28708,
                         "implantation"            => 16374,
                         "implement"               => 3753,
                         "implementation"          => 2430,
                         "implementations"         => 7476,
                         "implemented"             => 2491,
                         "implementing"            => 5380,
                         "implements"              => 7910,
                         "implicated"              => 7034,
                         "implications"            => 5188,
                         "implicit"                => 8227,
                         "implicitly"              => 11232,
                         "implied"                 => 5293,
                         "implies"                 => 4452,
                         "implored"                => 29445,
                         "import"                  => 4703,
                         "importance"              => 1515,
                         "importation"             => 11324,
                         "imported"                => 3863,
                         "importers"               => 17908,
                         "importing"               => 9963,
                         "imports"                 => 6031,
                         "imposed"                 => 3461,
                         "imposes"                 => 14574,
                         "imposing"                => 6851,
                         "impoundment"             => 25347,
                         "impoverished"            => 8461,
                         "imprecise"               => 22861,
                         "impresario"              => 14817,
                         "impressionism"           => 14206,
                         "impressionist"           => 11110,
                         "impressionistic"         => 23251,
                         "imprint"                 => 5853,
                         "imprinting"              => 29483,
                         "imprints"                => 17063,
                         "imprisoned"              => 3088,
                         "imprisoning"             => 25408,
                         "imprisonment"            => 3582,
                         "improper"                => 8600,
                         "improperly"              => 12185,
                         "improve"                 => 1628,
                         "improved"                => 1602,
                         "improvement"             => 2613,
                         "improvements"            => 2762,
                         "improves"                => 8442,
                         "improving"               => 3269,
                         "improvisation"           => 8402,
                         "improvisational"         => 12733,
                         "improvisations"          => 18290,
                         "improvised"              => 7056,
                         "impurities"              => 13320,
                         "impurity"                => 19795,
                         "imran"                   => 13466,
                         "imtiaz"                  => 23340,
                         "in"                      => 4,
                         "inability"               => 5337,
                         "inaccessible"            => 9643,
                         "inaccuracy"              => 24503,
                         "inaccurate"              => 8503,
                         "inaccurately"            => 24461,
                         "inacio"                  => 27173,
                         "inaction"                => 19239,
                         "inactivated"             => 6535,
                         "inactivation"            => 11422,
                         "inactive"                => 6149,
                         "inactivity"              => 14726,
                         "inadequate"              => 5590,
                         "inadequately"            => 25535,
                         "inadvertent"             => 24150,
                         "inari"                   => 26088,
                         "inaugural"               => 2638,
                         "inaugurate"              => 28254,
                         "inaugurated"             => 3910,
                         "inauguration"            => 6133,
                         "inboard"                 => 21396,
                         "inc."                    => 1554,
                         "inc.."                   => 13733,
                         "incandescent"            => 14927,
                         "incapacity"              => 23623,
                         "incarnation"             => 5410,
                         "incarnations"            => 10113,
                         "incentives"              => 7281,
                         "inception"               => 3934,
                         "incertae"                => 18318,
                         "incheon"                 => 12637,
                         "inches"                  => 3017,
                         "inchon"                  => 23854,
                         "incidence"               => 6409,
                         "incidences"              => 24416,
                         "incident"                => 1547,
                         "incidental"              => 10205,
                         "incidents"               => 3472,
                         "incineration"            => 26444,
                         "incipient"               => 23016,
                         "incised"                 => 16004,
                         "incisions"               => 27461,
                         "incisive"                => 22178,
                         "incite"                  => 16260,
                         "incited"                 => 17261,
                         "incitement"              => 18552,
                         "inciting"                => 13927,
                         "inclination"             => 9644,
                         "inclinations"            => 20426,
                         "incline"                 => 11377,
                         "inclines"                => 25938,
                         "include"                 => 190,
                         "included"                => 223,
                         "includes"                => 452,
                         "including"               => 87,
                         "inclusion"               => 3693,
                         "inclusions"              => 16139,
                         "inclusive"               => 6928,
                         "income"                  => 564,
                         "incomes"                 => 9295,
                         "incompatibility"         => 19181,
                         "incompatible"            => 8595,
                         "incomplete"              => 4516,
                         "incompleteness"          => 29390,
                         "incompressible"          => 28115,
                         "inconsistencies"         => 12876,
                         "inconsistency"           => 14769,
                         "inconsistent"            => 7089,
                         "incontinence"            => 22070,
                         "incorporate"             => 4530,
                         "incorporated"            => 1394,
                         "incorporates"            => 4680,
                         "incorporating"           => 4742,
                         "incorporation"           => 5656,
                         "incorrect"               => 5993,
                         "incorrectly"             => 6820,
                         "increase"                => 816,
                         "increased"               => 720,
                         "increases"               => 2476,
                         "increasing"              => 1395,
                         "increasingly"            => 1982,
                         "increment"               => 17351,
                         "incremental"             => 12116,
                         "incrementally"           => 25152,
                         "increments"              => 15580,
                         "incubate"                => 27193,
                         "incubated"               => 20089,
                         "incubation"              => 12131,
                         "incumbencies"            => 28674,
                         "incumbency"              => 29080,
                         "incumbent"               => 2851,
                         "incumbents"              => 12181,
                         "incurred"                => 7647,
                         "incurring"               => 19167,
                         "incursion"               => 13626,
                         "incursions"              => 11470,
                         "indebtedness"            => 21028,
                         "indecency"               => 23501,
                         "indefatigable"           => 21339,
                         "indefinite"              => 8762,
                         "indelible"               => 21934,
                         "indemnity"               => 15428,
                         "indented"                => 20980,
                         "indentured"              => 13348,
                         "independence"            => 1074,
                         "independencia"           => 22654,
                         "independent"             => 472,
                         "independently"           => 3093,
                         "independents"            => 7914,
                         "independiente"           => 13939,
                         "index"                   => 2063,
                         "indexed"                 => 8141,
                         "indexes"                 => 12493,
                         "indexing"                => 9281,
                         "india"                   => 322,
                         "indian"                  => 423,
                         "indianapolis"            => 3380,
                         "indianola"               => 25473,
                         "indias"                  => 25665,
                         "indic"                   => 23713,
                         "indicate"                => 2329,
                         "indicated"               => 2113,
                         "indicates"               => 2618,
                         "indicating"              => 3325,
                         "indications"             => 8247,
                         "indicative"              => 8476,
                         "indicator"               => 6300,
                         "indicators"              => 7030,
                         "indices"                 => 9035,
                         "indicted"                => 7325,
                         "indie"                   => 3745,
                         "indies"                  => 3164,
                         "indigenous"              => 2080,
                         "indigent"                => 19419,
                         "indios"                  => 24705,
                         "indirect"                => 5420,
                         "indirectly"              => 6250,
                         "indiscriminate"          => 17320,
                         "indiscriminately"        => 19947,
                         "indistinct"              => 14013,
                         "indistinguishable"       => 12237,
                         "indium"                  => 19994,
                         "individual"              => 632,
                         "individualism"           => 14761,
                         "individualist"           => 15996,
                         "individualistic"         => 20702,
                         "individualized"          => 14035,
                         "individually"            => 5220,
                         "individuals"             => 751,
                         "indivisible"             => 25136,
                         "indo"                    => 3909,
                         "indochina"               => 8986,
                         "indoctrination"          => 22209,
                         "indole"                  => 23730,
                         "indomitable"             => 22780,
                         "indonesia"               => 2061,
                         "indonesian"              => 3371,
                         "indonesians"             => 16796,
                         "indoor"                  => 2356,
                         "indore"                  => 12430,
                         "indra"                   => 10819,
                         "indre"                   => 16142,
                         "induce"                  => 7111,
                         "induced"                 => 3966,
                         "induces"                 => 10686,
                         "inducing"                => 10467,
                         "inductance"              => 20548,
                         "inducted"                => 2900,
                         "inductee"                => 12625,
                         "inductees"               => 13143,
                         "induction"               => 5503,
                         "inductive"               => 13527,
                         "inductor"                => 25273,
                         "indulgences"             => 24067,
                         "indus"                   => 8696,
                         "industrial"              => 939,
                         "industrialisation"       => 15873,
                         "industrialised"          => 20839,
                         "industrialist"           => 7644,
                         "industrialists"          => 13590,
                         "industrialization"       => 9739,
                         "industrialized"          => 11519,
                         "industrially"            => 19015,
                         "industries"              => 1858,
                         "industry"                => 492,
                         "ineffective"             => 7238,
                         "ineffectiveness"         => 28211,
                         "inefficiencies"          => 27261,
                         "inefficiency"            => 18492,
                         "inefficient"             => 10505,
                         "inelastic"               => 28608,
                         "ineligible"              => 8024,
                         "inequalities"            => 12161,
                         "inequality"              => 5978,
                         "inert"                   => 11766,
                         "inertia"                 => 11563,
                         "inertial"                => 11012,
                         "inescapable"             => 29320,
                         "inexpensive"             => 7711,
                         "inexplicably"            => 17881,
                         "inextricably"            => 24255,
                         "infallibility"           => 25229,
                         "infamous"                => 5292,
                         "infamously"              => 27192,
                         "infancy"                 => 8149,
                         "infant"                  => 4212,
                         "infanta"                 => 16367,
                         "infanterie"              => 23599,
                         "infanticide"             => 19598,
                         "infantry"                => 1046,
                         "infantryman"             => 21732,
                         "infantrymen"             => 18551,
                         "infants"                 => 6213,
                         "infections"              => 5521,
                         "infectious"              => 6574,
                         "infective"               => 28223,
                         "infer"                   => 14598,
                         "inference"               => 9477,
                         "inferences"              => 18780,
                         "inferior"                => 5198,
                         "inferred"                => 10373,
                         "infertility"             => 15806,
                         "infestations"            => 23414,
                         "infidels"                => 24981,
                         "infield"                 => 13501,
                         "infielder"               => 12468,
                         "infighting"              => 16175,
                         "infill"                  => 18891,
                         "infiltrated"             => 12302,
                         "infiltrates"             => 22936,
                         "infiltrating"            => 19495,
                         "infiltration"            => 10415,
                         "infinite"                => 4166,
                         "infinitely"              => 10984,
                         "infinitesimal"           => 17065,
                         "infinitive"              => 16725,
                         "infirm"                  => 23491,
                         "inflammation"            => 7705,
                         "inflammatory"            => 7153,
                         "inflation"               => 4817,
                         "inflationary"            => 23872,
                         "inflected"               => 16357,
                         "inflection"              => 17059,
                         "inflectional"            => 27929,
                         "inflections"             => 29569,
                         "inflicted"               => 6955,
                         "inflicting"              => 12843,
                         "inflorescence"           => 8829,
                         "inflorescences"          => 13659,
                         "inflow"                  => 14689,
                         "inflows"                 => 26317,
                         "influence"               => 826,
                         "influenced"              => 1418,
                         "influences"              => 2381,
                         "influencing"             => 8773,
                         "influential"             => 1973,
                         "influenza"               => 8070,
                         "influx"                  => 6310,
                         "infocom"                 => 29873,
                         "infomercials"            => 23490,
                         "informal"                => 4196,
                         "informally"              => 7198,
                         "informatics"             => 10560,
                         "information"             => 378,
                         "informational"           => 13013,
                         "informers"               => 25026,
                         "informing"               => 8147,
                         "informs"                 => 5674,
                         "infosys"                 => 29832,
                         "infotainment"            => 28913,
                         "infractions"             => 19741,
                         "infrared"                => 5929,
                         "infrastructural"         => 20277,
                         "infrastructure"          => 1950,
                         "infrastructures"         => 14802,
                         "infrequent"              => 13279,
                         "infrequently"            => 12996,
                         "infringed"               => 17083,
                         "infringement"            => 6969,
                         "infringements"           => 27248,
                         "infringing"              => 16261,
                         "infuriated"              => 12763,
                         "infused"                 => 11728,
                         "infusion"                => 12921,
                         "ingestion"               => 12677,
                         "inglewood"               => 15262,
                         "ingmar"                  => 24501,
                         "ingolstadt"              => 16530,
                         "ingots"                  => 24949,
                         "ingrained"               => 25945,
                         "ingredients"             => 4788,
                         "inguinal"                => 28998,
                         "ingush"                  => 23808,
                         "ingushetia"              => 29627,
                         "inhabit"                 => 7308,
                         "inhabitant"              => 14272,
                         "inhabitants"             => 1479,
                         "inhabited"               => 3333,
                         "inhabiting"              => 11613,
                         "inhabits"                => 9899,
                         "inherent"                => 5911,
                         "inherently"              => 8908,
                         "inherited"               => 2823,
                         "inheriting"              => 14377,
                         "inhibit"                 => 8855,
                         "inhibited"               => 12023,
                         "inhibiting"              => 12178,
                         "inhibition"              => 8094,
                         "inhibitor"               => 8280,
                         "inhibitors"              => 8539,
                         "inhibitory"              => 12739,
                         "inhibits"                => 10644,
                         "inhospitable"            => 21436,
                         "inhumans"                => 25947,
                         "initial"                 => 973,
                         "initialization"          => 24302,
                         "initialized"             => 28610,
                         "initially"               => 640,
                         "initiate"                => 6886,
                         "initiated"               => 2466,
                         "initiates"               => 12310,
                         "initiating"              => 8938,
                         "initiation"              => 6680,
                         "initiative"              => 2038,
                         "initiatives"             => 3717,
                         "initiator"               => 15009,
                         "initiators"              => 24160,
                         "initio"                  => 29830,
                         "injective"               => 21529,
                         "injectors"               => 26406,
                         "injects"                 => 22899,
                         "injunctions"             => 19582,
                         "injured"                 => 1839,
                         "injures"                 => 20667,
                         "injuries"                => 2287,
                         "injuring"                => 8211,
                         "injurious"               => 27366,
                         "injury"                  => 1355,
                         "injustices"              => 17071,
                         "inked"                   => 16437,
                         "inker"                   => 25851,
                         "inking"                  => 23819,
                         "inland"                  => 3376,
                         "inlays"                  => 25361,
                         "inlet"                   => 5468,
                         "inlets"                  => 17940,
                         "inline"                  => 8029,
                         "inmates"                 => 4908,
                         "innate"                  => 9827,
                         "inner"                   => 1828,
                         "innervated"              => 29621,
                         "innervation"             => 25134,
                         "inning"                  => 4700,
                         "innings"                 => 2125,
                         "innovate"                => 22533,
                         "innovated"               => 27312,
                         "innovation"              => 2989,
                         "innovations"             => 5183,
                         "innovative"              => 3251,
                         "innovator"               => 12490,
                         "innovators"              => 15212,
                         "innsbruck"               => 9767,
                         "innumerable"             => 14183,
                         "inoculation"             => 21957,
                         "inoperable"              => 21307,
                         "inorganic"               => 9238,
                         "inositol"                => 23741,
                         "inowroclaw"              => 27751,
                         "inpatient"               => 15266,
                         "input"                   => 2815,
                         "input/output"            => 22804,
                         "inputs"                  => 6963,
                         "inquest"                 => 11099,
                         "inquired"                => 19548,
                         "inquirer"                => 12666,
                         "inquires"                => 29790,
                         "inquiry"                 => 3632,
                         "inscribed"               => 5384,
                         "inscription"             => 3509,
                         "inscriptions"            => 4715,
                         "insecticide"             => 19042,
                         "insecticides"            => 20566,
                         "insectivores"            => 21547,
                         "insectivorous"           => 16872,
                         "insects"                 => 3513,
                         "insee"                   => 29311,
                         "inserted"                => 5100,
                         "inserting"               => 11628,
                         "inserts"                 => 11791,
                         "inset"                   => 23184,
                         "inshore"                 => 14308,
                         "insiders"                => 16070,
                         "insignia"                => 5709,
                         "insistence"              => 7893,
                         "insofar"                 => 14384,
                         "insoluble"               => 15061,
                         "insolvency"              => 12745,
                         "insolvent"               => 15808,
                         "inspected"               => 9579,
                         "inspecting"              => 15301,
                         "inspection"              => 4253,
                         "inspections"             => 9634,
                         "inspectorate"            => 16562,
                         "inspectors"              => 9480,
                         "inspiration"             => 2667,
                         "inspirations"            => 12610,
                         "inspired"                => 1220,
                         "instability"             => 6617,
                         "instagram"               => 15517,
                         "installation"            => 2965,
                         "installations"           => 4919,
                         "installed"               => 1659,
                         "installer"               => 20266,
                         "installing"              => 8114,
                         "installment"             => 7080,
                         "installments"            => 11366,
                         "installs"                => 22666,
                         "instalment"              => 20942,
                         "instalments"             => 24874,
                         "instance"                => 1921,
                         "instances"               => 4264,
                         "instantaneous"           => 13754,
                         "instar"                  => 20143,
                         "instars"                 => 26594,
                         "instated"                => 19523,
                         "instead"                 => 476,
                         "instigated"              => 10233,
                         "instigating"             => 23968,
                         "instigation"             => 14232,
                         "instilling"              => 26949,
                         "institut"                => 7032,
                         "institute"               => 441,
                         "instituted"              => 5025,
                         "institutes"              => 4262,
                         "instituting"             => 18964,
                         "institution"             => 1465,
                         "institutional"           => 4354,
                         "institutionalized"       => 9023,
                         "institutions"            => 1308,
                         "instituto"               => 8457,
                         "instructed"              => 4822,
                         "instruction"             => 2738,
                         "instructional"           => 7710,
                         "instructor"              => 3583,
                         "instructors"             => 6943,
                         "instructs"               => 12273,
                         "instrument"              => 2183,
                         "instrumental"            => 2171,
                         "instrumentalist"         => 9510,
                         "instrumentalists"        => 17813,
                         "instrumentals"           => 14225,
                         "instrumentation"         => 5881,
                         "instruments"             => 1816,
                         "insufficiency"           => 19858,
                         "insufficient"            => 5070,
                         "insufficiently"          => 18062,
                         "insular"                 => 11419,
                         "insulated"               => 12647,
                         "insulating"              => 16198,
                         "insulation"              => 8916,
                         "insulator"               => 19929,
                         "insulators"              => 23342,
                         "insurer"                 => 15854,
                         "insurers"                => 14241,
                         "insurgency"              => 7712,
                         "insurgent"               => 10228,
                         "insurgents"              => 6932,
                         "insurrection"            => 9033,
                         "intact"                  => 4261,
                         "intake"                  => 5378,
                         "intakes"                 => 18483,
                         "intangible"              => 13323,
                         "integer"                 => 5923,
                         "integers"                => 7867,
                         "integrable"              => 19456,
                         "integral"                => 3370,
                         "integrals"               => 15013,
                         "integrate"               => 6116,
                         "integrated"              => 2018,
                         "integrates"              => 10811,
                         "integrating"             => 7664,
                         "integration"             => 2880,
                         "integrative"             => 15857,
                         "integrator"              => 24142,
                         "intellectual"            => 2681,
                         "intellectuals"           => 6050,
                         "intelligence"            => 1349,
                         "intelligencer"           => 20408,
                         "intelligentsia"          => 15216,
                         "intelligibility"         => 24730,
                         "intelligible"            => 14165,
                         "intelsat"                => 23030,
                         "intendant"               => 21025,
                         "intended"                => 993,
                         "intending"               => 7224,
                         "intends"                 => 6881,
                         "intensification"         => 13957,
                         "intensified"             => 6538,
                         "intensifies"             => 29991,
                         "intensify"               => 13608,
                         "intensifying"            => 17694,
                         "intensities"             => 19318,
                         "intensity"               => 3517,
                         "intensive"               => 4155,
                         "intensively"             => 14633,
                         "intent"                  => 3539,
                         "inter"                   => 2230,
                         "interact"                => 4391,
                         "interacted"              => 14532,
                         "interacting"             => 7778,
                         "interaction"             => 2908,
                         "interactions"            => 3412,
                         "interactive"             => 3208,
                         "interactivity"           => 21337,
                         "interacts"               => 10678,
                         "interagency"             => 20132,
                         "interbank"               => 28479,
                         "intercalated"            => 26982,
                         "intercepted"             => 6117,
                         "interception"            => 5910,
                         "interceptions"           => 6336,
                         "interceptor"             => 9088,
                         "interceptors"            => 19093,
                         "intercepts"              => 20133,
                         "intercession"            => 14989,
                         "interchange"             => 3027,
                         "interchangeable"         => 10287,
                         "interchangeably"         => 11892,
                         "interchanged"            => 29508,
                         "interchanges"            => 9843,
                         "intercity"               => 7887,
                         "intercollegiate"         => 6862,
                         "interconnect"            => 16834,
                         "interconnected"          => 9906,
                         "interconnecting"         => 26538,
                         "interconnection"         => 17030,
                         "intercontinental"        => 6678,
                         "intercultural"           => 14812,
                         "intercut"                => 23934,
                         "interdenominational"     => 28902,
                         "interdependence"         => 19472,
                         "interdependent"          => 20863,
                         "interdict"               => 21278,
                         "interdiction"            => 15636,
                         "interdisciplinary"       => 6689,
                         "interes"                 => 29593,
                         "interest"                => 575,
                         "interestingly"           => 9162,
                         "interests"               => 1636,
                         "interface"               => 2795,
                         "interfaces"              => 6780,
                         "interfaith"              => 11944,
                         "interferometer"          => 19027,
                         "interferometry"          => 24341,
                         "intergovernmental"       => 11322,
                         "intergroup"              => 28482,
                         "interim"                 => 3508,
                         "interior"                => 1390,
                         "interiors"               => 7267,
                         "interlaced"              => 20496,
                         "interlaken"              => 24518,
                         "interleague"             => 24032,
                         "interleukin"             => 18435,
                         "interlingua"             => 26705,
                         "interlinked"             => 27189,
                         "interlock"               => 29872,
                         "interlocking"            => 12401,
                         "interludes"              => 17457,
                         "intermarriage"           => 16363,
                         "intermarried"            => 20201,
                         "intermedia"              => 19172,
                         "intermediaries"          => 17024,
                         "intermediary"            => 11112,
                         "intermediate"            => 2720,
                         "intermediates"           => 15671,
                         "interment"               => 13343,
                         "interments"              => 26570,
                         "intermingled"            => 29448,
                         "intermittent"            => 8009,
                         "intermittently"          => 10475,
                         "intermixed"              => 25249,
                         "intermodal"              => 14820,
                         "intermolecular"          => 27743,
                         "internacional"           => 10060,
                         "internal"                => 1377,
                         "internalized"            => 26741,
                         "internally"              => 6253,
                         "international"           => 132,
                         "internationale"          => 8019,
                         "internationalism"        => 26453,
                         "internationalist"        => 18995,
                         "internationalization"    => 22246,
                         "internationally"         => 2422,
                         "internationals"          => 7909,
                         "internazionale"          => 12470,
                         "internazionali"          => 25530,
                         "interned"                => 8496,
                         "internees"               => 18953,
                         "internment"              => 9133,
                         "internships"             => 13972,
                         "interoperability"        => 11080,
                         "interoperable"           => 25671,
                         "interpersonal"           => 10516,
                         "interplanetary"          => 15629,
                         "interplay"               => 11706,
                         "interpolated"            => 22600,
                         "interpolation"           => 12889,
                         "interpretation"          => 2502,
                         "interpretations"         => 5263,
                         "interpretative"          => 28299,
                         "interpreted"             => 3528,
                         "interpreter"             => 7084,
                         "interpreters"            => 12187,
                         "interpreting"            => 8909,
                         "interpretive"            => 11223,
                         "interprets"              => 12286,
                         "interprovincial"         => 25466,
                         "interracial"             => 14209,
                         "interred"                => 4595,
                         "interregnum"             => 17344,
                         "interrelated"            => 17865,
                         "interrogative"           => 24646,
                         "interrogator"            => 27206,
                         "interrogators"           => 23441,
                         "interrupts"              => 12724,
                         "interscholastic"         => 10954,
                         "interscope"              => 13029,
                         "intersect"               => 9103,
                         "intersected"             => 16349,
                         "intersecting"            => 8638,
                         "intersection"            => 2266,
                         "intersections"           => 8578,
                         "intersects"              => 5751,
                         "intersex"                => 16376,
                         "interspersed"            => 8927,
                         "interstate"              => 2439,
                         "interstates"             => 20585,
                         "interstellar"            => 10097,
                         "interstitial"            => 16212,
                         "intertidal"              => 16080,
                         "intertoto"               => 18021,
                         "interuniversity"         => 27965,
                         "interurban"              => 13949,
                         "interval"                => 4784,
                         "intervals"               => 5218,
                         "intervene"               => 7362,
                         "intervened"              => 7937,
                         "intervenes"              => 14789,
                         "intervening"             => 9229,
                         "intervention"            => 3167,
                         "interventional"          => 23880,
                         "interventionist"         => 26853,
                         "interventions"           => 6947,
                         "interview"               => 1287,
                         "interviewed"             => 3714,
                         "interviewees"            => 24509,
                         "interviewer"             => 11287,
                         "interviewers"            => 27928,
                         "interviews"              => 2647,
                         "interwar"                => 10068,
                         "interwoven"              => 16453,
                         "intestinal"              => 10095,
                         "intifada"                => 16218,
                         "intimidation"            => 10240,
                         "into"                    => 43,
                         "intolerance"             => 11884,
                         "intonation"              => 15038,
                         "intoxicated"             => 12857,
                         "intra"                   => 9170,
                         "intracellular"           => 10746,
                         "intracoastal"            => 26958,
                         "intracranial"            => 20742,
                         "intractable"             => 23960,
                         "intramolecular"          => 25500,
                         "intramural"              => 14668,
                         "intramuros"              => 28849,
                         "intransitive"            => 21642,
                         "intrastate"              => 26540,
                         "intravenous"             => 12661,
                         "intrepidity"             => 27831,
                         "intricate"               => 7997,
                         "intricately"             => 18885,
                         "intrigues"               => 15039,
                         "intrinsic"               => 8087,
                         "intrinsically"           => 16336,
                         "introduced"              => 548,
                         "introduces"              => 5189,
                         "introducing"             => 3845,
                         "introduction"            => 1498,
                         "introductory"            => 8455,
                         "intron"                  => 27545,
                         "introns"                 => 26210,
                         "introspection"           => 20136,
                         "introspective"           => 15978,
                         "introverted"             => 23036,
                         "intrusions"              => 17828,
                         "intuitively"             => 16919,
                         "inuktitut"               => 27790,
                         "inundated"               => 13136,
                         "inundation"              => 23622,
                         "invaded"                 => 4016,
                         "invaders"                => 6473,
                         "invades"                 => 22379,
                         "invalidated"             => 17932,
                         "invalided"               => 26466,
                         "invariably"              => 9416,
                         "invariance"              => 18355,
                         "invariant"               => 7906,
                         "invariants"              => 17032,
                         "invasion"                => 1513,
                         "invasions"               => 7603,
                         "invasive"                => 6221,
                         "invention"               => 3914,
                         "inventions"              => 7301,
                         "inventive"               => 11679,
                         "inventiveness"           => 27070,
                         "inventor"                => 4633,
                         "inventories"             => 16504,
                         "inventors"               => 11531,
                         "invents"                 => 24633,
                         "invercargill"            => 18420,
                         "inverness"               => 7848,
                         "inverse"                 => 6583,
                         "inversely"               => 17492,
                         "inversion"               => 9210,
                         "inversions"              => 22041,
                         "invert"                  => 29352,
                         "invertebrate"            => 15087,
                         "invertebrates"           => 8088,
                         "inverted"                => 7464,
                         "inverter"                => 20884,
                         "invertible"              => 18245,
                         "inverting"               => 24960,
                         "invested"                => 4224,
                         "investigate"             => 3366,
                         "investigated"            => 3967,
                         "investigates"            => 9531,
                         "investigations"          => 3484,
                         "investigative"           => 5864,
                         "investigators"           => 5724,
                         "investing"               => 7196,
                         "investiture"             => 15265,
                         "investment"              => 1564,
                         "investments"             => 3763,
                         "investor"                => 5259,
                         "investors"               => 3279,
                         "invests"                 => 15656,
                         "invicta"                 => 19055,
                         "invitational"            => 7633,
                         "invites"                 => 6657,
                         "invocation"              => 14531,
                         "invoked"                 => 8704,
                         "invokes"                 => 19002,
                         "involuntarily"           => 22376,
                         "involution"              => 27256,
                         "involved"                => 488,
                         "involvement"             => 2081,
                         "involves"                => 2428,
                         "involving"               => 1887,
                         "inward"                  => 10342,
                         "inwardly"                => 24632,
                         "inwards"                 => 16747,
                         "inwood"                  => 27991,
                         "ioannina"                => 19378,
                         "ioannis"                 => 16486,
                         "iodide"                  => 15211,
                         "iodine"                  => 10301,
                         "iommi"                   => 26927,
                         "ionia"                   => 21615,
                         "ionian"                  => 11877,
                         "ionic"                   => 8288,
                         "ionization"              => 12314,
                         "ionized"                 => 17903,
                         "ionizing"                => 17681,
                         "ionosphere"              => 20978,
                         "ionospheric"             => 29480,
                         "ions"                    => 5522,
                         "iorga"                   => 20656,
                         "iosif"                   => 25613,
                         "iowa"                    => 1736,
                         "iphigenia"               => 27649,
                         "iqbal"                   => 10280,
                         "iquique"                 => 27638,
                         "iraklis"                 => 20040,
                         "iran"                    => 954,
                         "irani"                   => 18920,
                         "iranian"                 => 2567,
                         "iranians"                => 11695,
                         "iraq"                    => 1726,
                         "iraqi"                   => 3107,
                         "iraqis"                  => 12649,
                         "ireland"                 => 555,
                         "irenaeus"                => 20516,
                         "irfan"                   => 22608,
                         "irgun"                   => 17228,
                         "iridescent"              => 18081,
                         "irises"                  => 22015,
                         "irish"                   => 734,
                         "irishmen"                => 18832,
                         "irkutsk"                 => 15991,
                         "iron"                    => 995,
                         "ironclads"               => 22951,
                         "ironi"                   => 26245,
                         "ironically"              => 5791,
                         "ironstone"               => 20534,
                         "ironwood"                => 25286,
                         "ironwork"                => 25375,
                         "ironworks"               => 11340,
                         "iroquoian"               => 29897,
                         "iroquois"                => 7876,
                         "irradiated"              => 22116,
                         "irradiation"             => 16179,
                         "irrawaddy"               => 19717,
                         "irreconcilable"          => 21472,
                         "irreducible"             => 12700,
                         "irregular"               => 4589,
                         "irregularities"          => 9441,
                         "irregularly"             => 11228,
                         "irregulars"              => 20300,
                         "irrespective"            => 11126,
                         "irreverent"              => 17979,
                         "irrigated"               => 11777,
                         "irrigation"              => 4356,
                         "irritant"                => 25839,
                         "irritation"              => 12781,
                         "irrorated"               => 21564,
                         "irtysh"                  => 28909,
                         "irvington"               => 22811,
                         "irwell"                  => 24504,
                         "is"                      => 6,
                         "isaak"                   => 20500,
                         "isambard"                => 29423,
                         "isbn"                    => 4108,
                         "ischemia"                => 20724,
                         "ischemic"                => 19443,
                         "isenburg"                => 24996,
                         "isere"                   => 18016,
                         "isfahan"                 => 8456,
                         "ishaq"                   => 17713,
                         "isidore"                 => 13582,
                         "ising"                   => 28695,
                         "iskandar"                => 20066,
                         "iskcon"                  => 22032,
                         "islam"                   => 2297,
                         "islamabad"               => 9142,
                         "islami"                  => 14945,
                         "islamia"                 => 23384,
                         "islamic"                 => 1699,
                         "islamism"                => 28169,
                         "islamist"                => 8873,
                         "islamists"               => 16105,
                         "island"                  => 248,
                         "islanders"               => 5953,
                         "islands"                 => 708,
                         "islay"                   => 19679,
                         "isle"                    => 3225,
                         "isles"                   => 5009,
                         "islet"                   => 11029,
                         "islets"                  => 11912,
                         "isleworth"               => 29150,
                         "islington"               => 10159,
                         "islip"                   => 20007,
                         "isma'il"                 => 26783,
                         "ismaili"                 => 18679,
                         "ismailis"                => 27158,
                         "iso/iec"                 => 12523,
                         "isoform"                 => 21035,
                         "isoforms"                => 14390,
                         "isolated"                => 2622,
                         "isolates"                => 16950,
                         "isolating"               => 14174,
                         "isolation"               => 4767,
                         "isolationist"            => 27200,
                         "isomer"                  => 16211,
                         "isomerase"               => 26449,
                         "isomers"                 => 16132,
                         "isometric"               => 17852,
                         "isometry"                => 28465,
                         "isomorphic"              => 11507,
                         "isomorphism"             => 12504,
                         "isotope"                 => 9311,
                         "isotopes"                => 8971,
                         "isotopic"                => 17630,
                         "isotropic"               => 17824,
                         "israeli"                 => 1677,
                         "israelis"                => 8939,
                         "israelite"               => 14151,
                         "israelites"              => 9754,
                         "issuance"                => 10972,
                         "issue"                   => 695,
                         "issued"                  => 921,
                         "issuer"                  => 19091,
                         "issuers"                 => 22356,
                         "issues"                  => 657,
                         "issuing"                 => 5603,
                         "istana"                  => 28266,
                         "isthmian"                => 13082,
                         "isthmus"                 => 10077,
                         "istituto"                => 20125,
                         "istria"                  => 15238,
                         "istvan"                  => 11890,
                         "isuzu"                   => 15849,
                         "italian"                 => 559,
                         "italiana"                => 11775,
                         "italianate"              => 9205,
                         "italians"                => 5968,
                         "italic"                  => 13535,
                         "italics"                 => 9341,
                         "italo"                   => 12064,
                         "italy"                   => 686,
                         "itasca"                  => 25441,
                         "items"                   => 1709,
                         "iterated"                => 22928,
                         "iteration"               => 9613,
                         "iterations"              => 14248,
                         "iterative"               => 14938,
                         "ithaca"                  => 9559,
                         "itinerant"               => 12578,
                         "its"                     => 29,
                         "itself"                  => 580,
                         "ittihad"                 => 19010,
                         "itunes"                  => 4099,
                         "iturbide"                => 23912,
                         "iulia"                   => 25418,
                         "iupac"                   => 20529,
                         "ivano"                   => 20973,
                         "ivanovic"                => 16568,
                         "ivanovich"               => 13463,
                         "ivanovo"                 => 25014,
                         "iveco"                   => 28468,
                         "ivica"                   => 25609,
                         "ivorian"                 => 16390,
                         "iwate"                   => 18488,
                         "iyengar"                 => 20641,
                         "izmir"                   => 10660,
                         "izumo"                   => 28697,
                         "ja'far"                  => 21219,
                         "jabal"                   => 15841,
                         "jabalpur"                => 18131,
                         "jacksonian"              => 21371,
                         "jacksonville"            => 4571,
                         "jacobean"                => 15774,
                         "jacobian"                => 27528,
                         "jacobin"                 => 23119,
                         "jacobins"                => 28213,
                         "jacobite"                => 9028,
                         "jacobites"               => 19558,
                         "jacopo"                  => 16122,
                         "jadid"                   => 22824,
                         "jaffna"                  => 11136,
                         "jagan"                   => 28471,
                         "jagannath"               => 15190,
                         "jagdgeschwader"          => 22584,
                         "jagiellon"               => 29140,
                         "jagiellonian"            => 20167,
                         "jahan"                   => 12568,
                         "jahangir"                => 14910,
                         "jailed"                  => 7330,
                         "jaina"                   => 28463,
                         "jainism"                 => 13075,
                         "jains"                   => 17205,
                         "jaipur"                  => 9450,
                         "jakob"                   => 7995,
                         "jakub"                   => 16224,
                         "jalal"                   => 14167,
                         "jalalabad"               => 21544,
                         "jalan"                   => 9875,
                         "jalandhar"               => 18401,
                         "jalgaon"                 => 29511,
                         "jalil"                   => 19750,
                         "jalisco"                 => 10395,
                         "jalpaiguri"              => 27067,
                         "jamaat"                  => 17089,
                         "jamaican"                => 6396,
                         "jamaicans"               => 29656,
                         "jamboree"                => 12838,
                         "jamestown"               => 8758,
                         "jamia"                   => 19490,
                         "jamil"                   => 18633,
                         "jammu"                   => 7768,
                         "jamshedpur"              => 27721,
                         "jamtland"                => 23531,
                         "jamuna"                  => 26102,
                         "janacek"                 => 20294,
                         "janaki"                  => 22573,
                         "janakpur"                => 26356,
                         "janata"                  => 9008,
                         "janeiro"                 => 4635,
                         "janesville"              => 24687,
                         "janez"                   => 22570,
                         "janissaries"             => 24594,
                         "janko"                   => 22042,
                         "jankovic"                => 15593,
                         "janos"                   => 12158,
                         "janow"                   => 26451,
                         "january"                 => 158,
                         "japan"                   => 458,
                         "japanese"                => 445,
                         "japonica"                => 17255,
                         "jardim"                  => 27510,
                         "jaroslav"                => 14979,
                         "jaroslaw"                => 20332,
                         "jarrah"                  => 19714,
                         "jarre"                   => 23597,
                         "jarrow"                  => 22825,
                         "jasta"                   => 19703,
                         "jatin"                   => 26906,
                         "jatra"                   => 29167,
                         "jaume"                   => 25442,
                         "javan"                   => 22625,
                         "javanese"                => 8879,
                         "javascript"              => 10565,
                         "javed"                   => 15882,
                         "jawahar"                 => 23009,
                         "jawaharlal"              => 12173,
                         "jayanti"                 => 26438,
                         "jayaram"                 => 28210,
                         "jazeera"                 => 10176,
                         "jazira"                  => 29339,
                         "jazz"                    => 1108,
                         "jcpenney"                => 20893,
                         "jebel"                   => 18860,
                         "jeddah"                  => 14286,
                         "jedrzejow"               => 28258,
                         "jeeva"                   => 28442,
                         "jeevan"                  => 25447,
                         "jeezy"                   => 24031,
                         "jeffersonian"            => 29371,
                         "jeffersonville"          => 26452,
                         "jehan"                   => 21160,
                         "jekyll"                  => 13878,
                         "jellicoe"                => 24557,
                         "jenin"                   => 22146,
                         "jeolla"                  => 29299,
                         "jeong"                   => 12794,
                         "jermyn"                  => 27906,
                         "jersey"                  => 918,
                         "jerseys"                 => 9188,
                         "jerusalem"               => 2294,
                         "jerzy"                   => 10866,
                         "jessore"                 => 28741,
                         "jesuit"                  => 4807,
                         "jesuits"                 => 6921,
                         "jetties"                 => 28304,
                         "jettisoned"              => 23709,
                         "jetty"                   => 12212,
                         "jeunesse"                => 23455,
                         "jeweller"                => 20858,
                         "jewellers"               => 26907,
                         "jewellery"               => 7524,
                         "jewish"                  => 805,
                         "jewry"                   => 14150,
                         "jews"                    => 1493,
                         "jhansi"                  => 19664,
                         "jharkhand"               => 11023,
                         "jhelum"                  => 17950,
                         "jiangsu"                 => 9248,
                         "jiangxi"                 => 12195,
                         "jiedushi"                => 27659,
                         "jigme"                   => 24086,
                         "jihad"                   => 8371,
                         "jihadist"                => 23367,
                         "jihlava"                 => 20746,
                         "jilin"                   => 15555,
                         "jinan"                   => 19077,
                         "jindal"                  => 17844,
                         "jinja"                   => 22072,
                         "jinnah"                  => 13161,
                         "jinping"                 => 29714,
                         "jintao"                  => 26711,
                         "jirga"                   => 27156,
                         "jiroft"                  => 23832,
                         "jitsu"                   => 12081,
                         "joachim"                 => 6784,
                         "joannes"                 => 27502,
                         "joaquim"                 => 15230,
                         "jobim"                   => 29342,
                         "jodhpur"                 => 14713,
                         "joffre"                  => 21193,
                         "joffrey"                 => 25714,
                         "jogaila"                 => 26006,
                         "johan"                   => 5145,
                         "johannesburg"            => 6076,
                         "johar"                   => 24953,
                         "johnsons"                => 26112,
                         "johnstown"               => 11879,
                         "johor"                   => 9016,
                         "joined"                  => 314,
                         "joinery"                 => 23973,
                         "joining"                 => 1644,
                         "joins"                   => 3571,
                         "joint"                   => 1092,
                         "jointly"                 => 3884,
                         "joinville"               => 23700,
                         "joked"                   => 12749,
                         "jokingly"                => 12088,
                         "jolgeh"                  => 22864,
                         "jomon"                   => 28817,
                         "jonesboro"               => 17660,
                         "jonkoping"               => 24244,
                         "jonsson"                 => 14322,
                         "jonubi"                  => 12573,
                         "jools"                   => 22423,
                         "joost"                   => 22442,
                         "jordanian"               => 8857,
                         "jordi"                   => 16144,
                         "jorgen"                  => 12351,
                         "jorhat"                  => 28085,
                         "joris"                   => 22912,
                         "jorma"                   => 28810,
                         "joseon"                  => 9901,
                         "josephus"                => 12040,
                         "josias"                  => 28555,
                         "josip"                   => 12682,
                         "joule"                   => 22971,
                         "journal"                 => 886,
                         "journalism"              => 2704,
                         "journalist"              => 1574,
                         "journalistic"            => 9587,
                         "journalists"             => 3144,
                         "journals"                => 3223,
                         "journey"                 => 1888,
                         "journeyed"               => 14688,
                         "journeying"              => 27952,
                         "journeyman"              => 14603,
                         "journeys"                => 7012,
                         "jousting"                => 28918,
                         "jovanovic"               => 16915,
                         "jovial"                  => 28361,
                         "jovian"                  => 27242,
                         "jozef"                   => 8241,
                         "jozsef"                  => 15063,
                         "jpmorgan"                => 21111,
                         "jrotc"                   => 23682,
                         "jubal"                   => 29509,
                         "jubilant"                => 29580,
                         "judah"                   => 7793,
                         "judaic"                  => 22641,
                         "judaism"                 => 4419,
                         "judea"                   => 15381,
                         "judean"                  => 22031,
                         "judeo"                   => 17280,
                         "judged"                  => 5164,
                         "judgements"              => 17846,
                         "judges"                  => 2200,
                         "judgeship"               => 23859,
                         "judicature"              => 25592,
                         "judicial"                => 2688,
                         "judiciary"               => 5265,
                         "judicious"               => 26368,
                         "judoka"                  => 12261,
                         "jujutsu"                 => 26056,
                         "jujuy"                   => 24771,
                         "jukka"                   => 27356,
                         "julich"                  => 19981,
                         "july"                    => 156,
                         "jumpers"                 => 14562,
                         "junagadh"                => 25050,
                         "junction"                => 1582,
                         "junctions"               => 8680,
                         "june"                    => 149,
                         "jungian"                 => 26893,
                         "juniata"                 => 19203,
                         "junin"                   => 25094,
                         "junior/senior"           => 29943,
                         "juniors"                 => 6093,
                         "juniperus"               => 24446,
                         "junius"                  => 16091,
                         "junkers"                 => 11839,
                         "junta"                   => 7338,
                         "juraj"                   => 23993,
                         "jurchen"                 => 18942,
                         "jurchens"                => 28500,
                         "jurgen"                  => 9331,
                         "juridical"               => 18363,
                         "juried"                  => 26892,
                         "juris"                   => 9797,
                         "jurisdiction"            => 2500,
                         "jurisdictional"          => 14780,
                         "jurisdictions"           => 5742,
                         "jurisprudence"           => 8337,
                         "jurist"                  => 8055,
                         "jurists"                 => 14401,
                         "jurong"                  => 18676,
                         "juryo"                   => 24476,
                         "jussi"                   => 24118,
                         "justices"                => 6568,
                         "justicia"                => 28704,
                         "justiciar"               => 29118,
                         "justification"           => 7178,
                         "justifications"          => 22035,
                         "justinian"               => 10853,
                         "justly"                  => 20836,
                         "justo"                   => 18481,
                         "jutland"                 => 10307,
                         "jutting"                 => 27381,
                         "juvenal"                 => 24188,
                         "juveniles"               => 8436,
                         "juventud"                => 18162,
                         "juxtaposed"              => 17980,
                         "juxtaposition"           => 17635,
                         "jyoti"                   => 18794,
                         "jyvaskyla"               => 24777,
                         "k'iche"                  => 26933,
                         "kabaddi"                 => 21641,
                         "kabbalah"                => 13739,
                         "kabbalistic"             => 22671,
                         "kabhi"                   => 26402,
                         "kabila"                  => 24012,
                         "kabir"                   => 12090,
                         "kabud"                   => 27442,
                         "kabul"                   => 6939,
                         "kachin"                  => 17590,
                         "kadir"                   => 29227,
                         "kadokawa"                => 20853,
                         "kaduna"                  => 19778,
                         "kagame"                  => 28679,
                         "kagoshima"               => 13803,
                         "kagyu"                   => 21775,
                         "kahane"                  => 27542,
                         "kahlo"                   => 26921,
                         "kahne"                   => 18884,
                         "kaifeng"                 => 18353,
                         "kailash"                 => 19342,
                         "kaine"                   => 19774,
                         "kaiserliche"             => 28267,
                         "kaiserslautern"          => 13745,
                         "kakheti"                 => 20272,
                         "kakinada"                => 29453,
                         "kalahari"                => 21895,
                         "kalakaua"                => 26638,
                         "kalam"                   => 15292,
                         "kalamazoo"               => 10675,
                         "kalan"                   => 16359,
                         "kalat"                   => 20931,
                         "kalateh"                 => 13968,
                         "kalevala"                => 27924,
                         "kalgoorlie"              => 19036,
                         "kalimantan"              => 14905,
                         "kalinga"                 => 15130,
                         "kaliningrad"             => 12619,
                         "kalisz"                  => 16318,
                         "kalki"                   => 28576,
                         "kalmar"                  => 14827,
                         "kalyan"                  => 13977,
                         "kamakura"                => 12960,
                         "kamboja"                 => 29772,
                         "kambojas"                => 26815,
                         "kamchatka"               => 16049,
                         "kamen"                   => 8740,
                         "kamien"                  => 23909,
                         "kamloops"                => 16063,
                         "kampala"                 => 11801,
                         "kampong"                 => 17430,
                         "kampuchea"               => 22222,
                         "kampung"                 => 16583,
                         "kamui"                   => 29409,
                         "kanaan"                  => 22433,
                         "kanagawa"                => 12153,
                         "kanal"                   => 18694,
                         "kanata"                  => 25813,
                         "kanawha"                 => 15112,
                         "kanazawa"                => 21425,
                         "kanchipuram"             => 23180,
                         "kanda"                   => 17562,
                         "kandahar"                => 11617,
                         "kandinsky"               => 23634,
                         "kandyan"                 => 29015,
                         "kangaroos"               => 11493,
                         "kangra"                  => 25271,
                         "kangxi"                  => 16784,
                         "kanji"                   => 10486,
                         "kankakee"                => 20065,
                         "kannada"                 => 5069,
                         "kannur"                  => 15707,
                         "kanon"                   => 26800,
                         "kanpur"                  => 11734,
                         "kansai"                  => 15138,
                         "kantakouzenos"           => 26025,
                         "kantian"                 => 26612,
                         "kanto"                   => 14325,
                         "kanya"                   => 29699,
                         "kanyakumari"             => 17911,
                         "kanye"                   => 10980,
                         "kaohsiung"               => 12839,
                         "kaori"                   => 23710,
                         "kaoru"                   => 18854,
                         "kapellmeister"           => 24279,
                         "kapil"                   => 24090,
                         "kapitanleutnant"         => 25678,
                         "kapoor"                  => 7239,
                         "karabakh"                => 9728,
                         "karadzic"                => 22602,
                         "karaite"                 => 29541,
                         "karakoram"               => 24737,
                         "karbala"                 => 18914,
                         "kardashian"              => 25869,
                         "kardzhali"               => 24486,
                         "karel"                   => 9842,
                         "karelia"                 => 15136,
                         "karelian"                => 17876,
                         "kargil"                  => 20372,
                         "karimabad"               => 29526,
                         "karimnagar"              => 27651,
                         "karlheinz"               => 22696,
                         "karlovac"                => 26508,
                         "karlovy"                 => 21451,
                         "karlsruhe"               => 9675,
                         "karmapa"                 => 25515,
                         "karna"                   => 19362,
                         "karnak"                  => 25058,
                         "karnataka"               => 4122,
                         "karoly"                  => 20544,
                         "karoo"                   => 18073,
                         "kartik"                  => 24435,
                         "kartli"                  => 17296,
                         "karts"                   => 23333,
                         "kartuzy"                 => 22390,
                         "karunanidhi"             => 28751,
                         "karur"                   => 28853,
                         "karzai"                  => 13767,
                         "kasai"                   => 20304,
                         "kasaragod"               => 27187,
                         "kasem"                   => 28041,
                         "kashgar"                 => 18643,
                         "kashi"                   => 18496,
                         "kashima"                 => 22754,
                         "kashmiri"                => 12750,
                         "kashubian"               => 26383,
                         "kashyap"                 => 22609,
                         "kasim"                   => 27413,
                         "kaskaskia"               => 26903,
                         "kassel"                  => 9787,
                         "kastamonu"               => 27945,
                         "katakana"                => 21241,
                         "katanga"                 => 16749,
                         "katarzyna"               => 25345,
                         "katha"                   => 15925,
                         "kathak"                  => 27398,
                         "kathakali"               => 24607,
                         "kathmandu"               => 9417,
                         "katipunan"               => 22743,
                         "katowice"                => 11701,
                         "katsina"                 => 29011,
                         "katyn"                   => 27550,
                         "kauai"                   => 13515,
                         "kaunas"                  => 10581,
                         "kauri"                   => 28973,
                         "kavala"                  => 26669,
                         "kaveri"                  => 19698,
                         "kavya"                   => 29317,
                         "kayfabe"                 => 27792,
                         "kayseri"                 => 26367,
                         "kazakh"                  => 9895,
                         "kazakhs"                 => 24613,
                         "kazakhstan"              => 4535,
                         "kazakhstani"             => 21235,
                         "kazan"                   => 7742,
                         "kazhagam"                => 15843,
                         "kazim"                   => 28503,
                         "kazimierz"               => 12139,
                         "kazuki"                  => 25951,
                         "kbit/s"                  => 15895,
                         "kearny"                  => 14427,
                         "kebir"                   => 24778,
                         "keble"                   => 22624,
                         "kedah"                   => 13918,
                         "keelung"                 => 24657,
                         "keeneland"               => 28948,
                         "keenly"                  => 19475,
                         "keighley"                => 16478,
                         "keiji"                   => 24612,
                         "keisei"                  => 28941,
                         "keisuke"                 => 28238,
                         "keita"                   => 16436,
                         "kelantan"                => 14844,
                         "kelis"                   => 28111,
                         "kelowna"                 => 16687,
                         "kemal"                   => 12186,
                         "kempe"                   => 19836,
                         "kenai"                   => 24073,
                         "kendriya"                => 28033,
                         "kenilworth"              => 15492,
                         "kennebec"                => 20306,
                         "kennels"                 => 28583,
                         "kennesaw"                => 20804,
                         "kenora"                  => 21599,
                         "kenrick"                 => 23394,
                         "kensal"                  => 23652,
                         "kenseth"                 => 16339,
                         "kensington"              => 6488,
                         "kenta"                   => 25788,
                         "kentish"                 => 15908,
                         "kentucky"                => 1585,
                         "kenyan"                  => 6996,
                         "kenyans"                 => 29307,
                         "kenzo"                   => 26530,
                         "keokuk"                  => 24946,
                         "kerala"                  => 3055,
                         "keratin"                 => 22603,
                         "kerch"                   => 25679,
                         "kerman"                  => 6727,
                         "kermanshah"              => 9423,
                         "kernels"                 => 15537,
                         "kerrang"                 => 14630,
                         "keselowski"              => 17416,
                         "kesteven"                => 23220,
                         "keswick"                 => 17700,
                         "ketchikan"               => 28885,
                         "ketone"                  => 17048,
                         "ketones"                 => 20706,
                         "ketrzyn"                 => 27330,
                         "kettering"               => 11013,
                         "keyboardist"             => 7083,
                         "keyboards"               => 4726,
                         "keying"                  => 25878,
                         "keynes"                  => 7760,
                         "keynesian"               => 16736,
                         "keynote"                 => 8838,
                         "keyong"                  => 17696,
                         "keystones"               => 28040,
                         "keyword"                 => 14418,
                         "keywords"                => 16002,
                         "khabarovsk"              => 19654,
                         "khadr"                   => 25439,
                         "khagan"                  => 25716,
                         "khaganate"               => 26398,
                         "khaimah"                 => 29293,
                         "khaki"                   => 15703,
                         "khaldun"                 => 29993,
                         "khali"                   => 24356,
                         "khalidi"                 => 29719,
                         "khalifa"                 => 9507,
                         "khamenei"                => 22963,
                         "khana"                   => 29288,
                         "khanate"                 => 10882,
                         "khaneh"                  => 23787,
                         "khanh"                   => 14264,
                         "khani"                   => 20738,
                         "khans"                   => 20892,
                         "khanty"                  => 26639,
                         "khanum"                  => 26234,
                         "kharagpur"               => 21816,
                         "kharkiv"                 => 10662,
                         "kharkov"                 => 16811,
                         "khartoum"                => 12588,
                         "khash"                   => 29773,
                         "khasi"                   => 26513,
                         "khatami"                 => 22238,
                         "khatib"                  => 26966,
                         "khattab"                 => 28279,
                         "khattak"                 => 27291,
                         "khatun"                  => 24810,
                         "khawaja"                 => 23438,
                         "khayyam"                 => 25567,
                         "khazar"                  => 17075,
                         "khazars"                 => 23572,
                         "khedive"                 => 26819,
                         "kheil"                   => 18180,
                         "kherson"                 => 26764,
                         "kheyrabad"               => 28378,
                         "khilji"                  => 26972,
                         "khitan"                  => 15367,
                         "khlong"                  => 27950,
                         "khmelnytsky"             => 23868,
                         "khmer"                   => 6930,
                         "khoja"                   => 27448,
                         "khomeini"                => 13229,
                         "khorasan"                => 6191,
                         "khorramabad"             => 20018,
                         "khosrau"                 => 23631,
                         "khosrow"                 => 25348,
                         "khrushchev"              => 10407,
                         "khufu"                   => 27740,
                         "khulna"                  => 20567,
                         "khurasan"                => 25388,
                         "khurd"                   => 24572,
                         "khuzestan"               => 8326,
                         "khvajeh"                 => 27801,
                         "khwaja"                  => 18675,
                         "khyber"                  => 9150,
                         "kibaki"                  => 25434,
                         "kibbutz"                 => 9935,
                         "kibbutzim"               => 29647,
                         "kickapoo"                => 22615,
                         "kickboxer"               => 19622,
                         "kickboxing"              => 11668,
                         "kickers"                 => 13948,
                         "kickoff"                 => 7864,
                         "kickoffs"                => 22840,
                         "kickstarter"             => 11262,
                         "kidderminster"           => 14178,
                         "kiedis"                  => 25036,
                         "kielce"                  => 10594,
                         "kierkegaard"             => 13714,
                         "kieron"                  => 28401,
                         "kiev"                    => 4619,
                         "kievan"                  => 15678,
                         "kigali"                  => 21488,
                         "kikuchi"                 => 20450,
                         "kikuyu"                  => 23779,
                         "kilda"                   => 7954,
                         "kildare"                 => 8203,
                         "kilimanjaro"             => 18144,
                         "kilkenny"                => 5770,
                         "killarney"               => 17128,
                         "killings"                => 6079,
                         "kilmarnock"              => 10289,
                         "kilmore"                 => 21978,
                         "kilns"                   => 14245,
                         "kilogram"                => 13871,
                         "kilograms"               => 9415,
                         "kilometer"               => 7766,
                         "kilometers"              => 3056,
                         "kilometre"               => 7361,
                         "kilometres"              => 3222,
                         "kilowatt"                => 16092,
                         "kilowatts"               => 20498,
                         "kilwinning"              => 27410,
                         "kinabalu"                => 19612,
                         "kinase"                  => 7430,
                         "kinases"                 => 15698,
                         "kincardine"              => 24016,
                         "kindergarten"            => 4334,
                         "kindergartens"           => 18682,
                         "kinect"                  => 22814,
                         "kinematic"               => 24319,
                         "kinematics"              => 27885,
                         "kinesiology"             => 28380,
                         "kinetic"                 => 7151,
                         "kinetics"                => 14855,
                         "kingdom"                 => 477,
                         "kingdoms"                => 4380,
                         "kingfishers"             => 18804,
                         "kings"                   => 1750,
                         "kingship"                => 11509,
                         "kingsmill"               => 29355,
                         "kingsport"               => 23807,
                         "kingstown"               => 22009,
                         "kingsville"              => 27948,
                         "kingsway"                => 18221,
                         "kingswood"               => 18211,
                         "kinnock"                 => 29060,
                         "kinsale"                 => 25260,
                         "kinshasa"                => 14696,
                         "kinship"                 => 9855,
                         "kinsmen"                 => 19973,
                         "kinston"                 => 25004,
                         "kintetsu"                => 19505,
                         "kintyre"                 => 27490,
                         "kiosks"                  => 15436,
                         "kiowa"                   => 14290,
                         "kirchberg"               => 29758,
                         "kirche"                  => 24125,
                         "kiribati"                => 13684,
                         "kirilenko"               => 27644,
                         "kirin"                   => 23521,
                         "kirkby"                  => 15274,
                         "kirkcaldy"               => 21586,
                         "kirke"                   => 21080,
                         "kirkuk"                  => 20021,
                         "kirkus"                  => 15840,
                         "kirov"                   => 14842,
                         "kirtland"                => 16215,
                         "kiryat"                  => 15268,
                         "kisan"                   => 24286,
                         "kishan"                  => 24375,
                         "kissimmee"               => 24568,
                         "kisumu"                  => 27106,
                         "kitab"                   => 18234,
                         "kitano"                  => 28838,
                         "kitchener"               => 9211,
                         "kites"                   => 12545,
                         "kitsap"                  => 24108,
                         "kitsch"                  => 22277,
                         "kitzbuhel"               => 27258,
                         "kiwis"                   => 15859,
                         "kiyoshi"                 => 22880,
                         "kjell"                   => 18454,
                         "klagenfurt"              => 20694,
                         "klaipeda"                => 18548,
                         "klamath"                 => 12475,
                         "klang"                   => 13648,
                         "klasse"                  => 21970,
                         "klerk"                   => 29396,
                         "klezmer"                 => 21743,
                         "klitschko"               => 23299,
                         "klodzko"                 => 28799,
                         "km/h"                    => 3922,
                         "km/hr"                   => 24982,
                         "knesset"                 => 8506,
                         "knighted"                => 6531,
                         "knighthood"              => 11084,
                         "knightley"               => 22886,
                         "knightsbridge"           => 23949,
                         "knockout"                => 4182,
                         "knockouts"               => 17005,
                         "knowle"                  => 26821,
                         "knowledge"               => 1055,
                         "knowledgeable"           => 12020,
                         "known"                   => 66,
                         "knowsley"                => 20823,
                         "knoxville"               => 6672,
                         "kobani"                  => 28969,
                         "koblenz"                 => 14153,
                         "kochi"                   => 9199,
                         "kodagu"                  => 26603,
                         "kodansha"                => 16746,
                         "kohat"                   => 29587,
                         "kohgiluyeh"              => 12853,
                         "kohima"                  => 29963,
                         "kohlberg"                => 26009,
                         "kohneh"                  => 28187,
                         "koine"                   => 23962,
                         "koirala"                 => 24343,
                         "kokoda"                  => 27407,
                         "kolhapur"                => 18196,
                         "kolkata"                 => 5186,
                         "kollam"                  => 12307,
                         "kolmogorov"              => 23679,
                         "kolonia"                 => 10098,
                         "komnenos"                => 16443,
                         "komsomol"                => 24173,
                         "konami"                  => 12372,
                         "kong"                    => 1178,
                         "kongo"                   => 14120,
                         "kongsberg"               => 21539,
                         "kongsvinger"             => 28058,
                         "konig"                   => 15453,
                         "konigsberg"              => 10106,
                         "konin"                   => 18317,
                         "koninklijke"             => 26674,
                         "konkan"                  => 19221,
                         "konkani"                 => 12913,
                         "konnan"                  => 24569,
                         "konskie"                 => 29946,
                         "konstantinos"            => 17923,
                         "konstanz"                => 25556,
                         "kontinental"             => 15256,
                         "konya"                   => 19888,
                         "kooning"                 => 26364,
                         "kootenay"                => 14582,
                         "koper"                   => 19502,
                         "koppen"                  => 6836,
                         "korce"                   => 21345,
                         "korda"                   => 19359,
                         "korea"                   => 1270,
                         "korean"                  => 1371,
                         "koreans"                 => 7886,
                         "korfball"                => 28396,
                         "korps"                   => 20574,
                         "korra"                   => 26951,
                         "korsakov"                => 16225,
                         "kortrijk"                => 24171,
                         "koscierzyna"             => 27281,
                         "kosciuszko"              => 16076,
                         "koshi"                   => 25864,
                         "kosice"                  => 12980,
                         "kosovar"                 => 25785,
                         "kosovo"                  => 4054,
                         "kossuth"                 => 20493,
                         "kosta"                   => 26992,
                         "kostroma"                => 21063,
                         "koszalin"                => 22915,
                         "kotaro"                  => 28157,
                         "kothen"                  => 27627,
                         "kotor"                   => 19930,
                         "kottayam"                => 13300,
                         "kovalainen"              => 25016,
                         "kovil"                   => 23729,
                         "kowloon"                 => 10680,
                         "kozhikode"               => 15050,
                         "kraftwerk"               => 20297,
                         "kragujevac"              => 20953,
                         "krajina"                 => 18135,
                         "krajowa"                 => 27027,
                         "krakow"                  => 5210,
                         "kralove"                 => 20935,
                         "kramnik"                 => 26510,
                         "krasinski"               => 25516,
                         "krasnoyarsk"             => 17184,
                         "krautrock"               => 28533,
                         "krefeld"                 => 24837,
                         "kreis"                   => 12844,
                         "kreuzberg"               => 27620,
                         "kreuznach"               => 21598,
                         "kriegsmarine"            => 11568,
                         "kripke"                  => 23040,
                         "krishnamurthy"           => 29151,
                         "krishnamurti"            => 28571,
                         "kristallnacht"           => 26463,
                         "kristiania"              => 16636,
                         "kristiansand"            => 15755,
                         "kristiansund"            => 29107,
                         "kristofferson"           => 22678,
                         "krona"                   => 26557,
                         "kronecker"               => 28713,
                         "kronstadt"               => 20879,
                         "kropotkin"               => 27993,
                         "krosno"                  => 22491,
                         "kryptonian"              => 25753,
                         "krzysztof"               => 13426,
                         "kshatriya"               => 19889,
                         "kuala"                   => 5917,
                         "kuban"                   => 15770,
                         "kubica"                  => 24154,
                         "kublai"                  => 16902,
                         "kuching"                 => 18085,
                         "kucinich"                => 26728,
                         "kulkarni"                => 21991,
                         "kultur"                  => 28189,
                         "kumamoto"                => 15523,
                         "kumanovo"                => 24481,
                         "kumaon"                  => 23421,
                         "kumara"                  => 21152,
                         "kumasi"                  => 18761,
                         "kumbakonam"              => 21992,
                         "kunal"                   => 24076,
                         "kunming"                 => 15567,
                         "kunste"                  => 23893,
                         "kunsthalle"              => 22205,
                         "kuomintang"              => 10593,
                         "kuopio"                  => 29792,
                         "kurdish"                 => 5824,
                         "kurdistan"               => 7572,
                         "kurds"                   => 10110,
                         "kuril"                   => 23186,
                         "kurnool"                 => 26361,
                         "kuroda"                  => 22088,
                         "kursk"                   => 14750,
                         "kurukshetra"             => 21138,
                         "kurzweil"                => 23827,
                         "kushan"                  => 24859,
                         "kutaisi"                 => 29878,
                         "kutno"                   => 20660,
                         "kutuzov"                 => 29188,
                         "kuwait"                  => 4856,
                         "kuwaiti"                 => 12042,
                         "kuyavian"                => 9127,
                         "kuznetsov"               => 17730,
                         "kuznetsova"              => 21518,
                         "kvitova"                 => 27959,
                         "kwajalein"               => 17346,
                         "kwame"                   => 17165,
                         "kwazulu"                 => 11983,
                         "kweli"                   => 28715,
                         "kyoto"                   => 5765,
                         "kyrgyz"                  => 12993,
                         "kyrgyzstan"              => 8032,
                         "kyrie"                   => 26506,
                         "kyushu"                  => 9523,
                         "l'air"                   => 27519,
                         "l'aquila"                => 21793,
                         "l'arc"                   => 18314,
                         "l'art"                   => 21820,
                         "l'ecole"                 => 20961,
                         "l'enfant"                => 20452,
                         "l'histoire"              => 26319,
                         "l'homme"                 => 19919,
                         "l'isle"                  => 24772,
                         "l'oeil"                  => 26032,
                         "l'ordre"                 => 25950,
                         "l'oreal"                 => 22507,
                         "laane"                   => 19642,
                         "laban"                   => 17986,
                         "label"                   => 854,
                         "labeled"                 => 4776,
                         "labeling"                => 9329,
                         "labelled"                => 6423,
                         "labelling"               => 14937,
                         "labels"                  => 3659,
                         "labem"                   => 20618,
                         "labial"                  => 18899,
                         "labor"                   => 1226,
                         "laboratories"            => 4193,
                         "laboratory"              => 1987,
                         "laborer"                 => 15024,
                         "laborers"                => 8066,
                         "laborious"               => 21675,
                         "labors"                  => 20335,
                         "labour"                  => 1200,
                         "labourer"                => 13875,
                         "labourers"               => 8231,
                         "labours"                 => 18764,
                         "labs"                    => 5161,
                         "labuan"                  => 22056,
                         "labyrinth"               => 10550,
                         "lacan"                   => 20209,
                         "lachaise"                => 26911,
                         "lachine"                 => 28328,
                         "lachlan"                 => 14880,
                         "lack"                    => 1009,
                         "lackawanna"              => 12287,
                         "lacked"                  => 4270,
                         "lacking"                 => 4376,
                         "lackluster"              => 16188,
                         "lacks"                   => 5155,
                         "laconia"                 => 20213,
                         "lactarius"               => 25934,
                         "lactation"               => 23383,
                         "lactobacillus"           => 28563,
                         "lacunae"                 => 26083,
                         "ladakh"                  => 15334,
                         "ladders"                 => 13146,
                         "laden"                   => 6135,
                         "ladin"                   => 28868,
                         "ladino"                  => 29629,
                         "ladislaus"               => 15255,
                         "ladislav"                => 22272,
                         "ladysmith"               => 21216,
                         "lafitte"                 => 27713,
                         "lagging"                 => 16005,
                         "lagoa"                   => 25820,
                         "lagoon"                  => 5744,
                         "lagoons"                 => 12402,
                         "lagos"                   => 6471,
                         "lagrangian"              => 14361,
                         "lahiri"                  => 23858,
                         "lahore"                  => 5295,
                         "laid"                    => 1573,
                         "laissez"                 => 18199,
                         "laity"                   => 13681,
                         "lajos"                   => 17795,
                         "lake"                    => 372,
                         "lakes"                   => 2010,
                         "lakeshore"               => 12841,
                         "lakeville"               => 25458,
                         "lakhs"                   => 17606,
                         "lakshman"                => 24333,
                         "lakshmana"               => 26156,
                         "lambton"                 => 16538,
                         "lamellar"                => 29544,
                         "lamentation"             => 29313,
                         "lamentations"            => 29270,
                         "lamented"                => 13370,
                         "lamenting"               => 19760,
                         "laments"                 => 15037,
                         "lamia"                   => 21588,
                         "lamiinae"                => 19892,
                         "lamina"                  => 17855,
                         "laminar"                 => 20187,
                         "laminate"                => 25939,
                         "lammermoor"              => 27561,
                         "lampeter"                => 25708,
                         "lampooned"               => 26304,
                         "lamprey"                 => 24581,
                         "lamps"                   => 6270,
                         "lanao"                   => 21837,
                         "lanark"                  => 15028,
                         "lanarkshire"             => 11604,
                         "lancashire"              => 3229,
                         "lancastrian"             => 21632,
                         "lanceolate"              => 15243,
                         "lancet"                  => 12033,
                         "lanchester"              => 23847,
                         "lancing"                 => 29145,
                         "land"                    => 246,
                         "landed"                  => 2576,
                         "landesliga"              => 15812,
                         "landfall"                => 6832,
                         "landfill"                => 9249,
                         "landfills"               => 19633,
                         "landform"                => 25293,
                         "landforms"               => 19877,
                         "landgrave"               => 16685,
                         "landholders"             => 23916,
                         "landholdings"            => 22211,
                         "landing"                 => 1737,
                         "landings"                => 5648,
                         "landkreis"               => 26307,
                         "landless"                => 18015,
                         "landline"                => 20004,
                         "landlocked"              => 16491,
                         "landlords"               => 9781,
                         "landmark"                => 2856,
                         "landmarks"               => 4587,
                         "landmass"                => 20533,
                         "landmine"                => 24780,
                         "landowner"               => 7106,
                         "landowners"              => 6729,
                         "landowning"              => 26876,
                         "landrieu"                => 28305,
                         "lands"                   => 1508,
                         "landscape"               => 2137,
                         "landscaped"              => 11290,
                         "landscapes"              => 4762,
                         "landscaping"             => 9869,
                         "landshut"                => 20467,
                         "landskrona"              => 29146,
                         "landslide"               => 7046,
                         "landslides"              => 11991,
                         "landtag"                 => 17122,
                         "landward"                => 26293,
                         "lanes"                   => 4032,
                         "langa"                   => 25109,
                         "langlands"               => 28260,
                         "langmuir"                => 29546,
                         "language"                => 319,
                         "languages"               => 962,
                         "langue"                  => 22473,
                         "languedoc"               => 14650,
                         "languished"              => 21920,
                         "lanka"                   => 2392,
                         "lankan"                  => 5571,
                         "lankans"                 => 29213,
                         "lansdowne"               => 12678,
                         "lansky"                  => 23277,
                         "lanus"                   => 27124,
                         "lanzhou"                 => 22901,
                         "laoghaire"               => 21293,
                         "laois"                   => 13720,
                         "laos"                    => 5673,
                         "laotian"                 => 15352,
                         "laparoscopic"            => 27454,
                         "lapis"                   => 24895,
                         "laplace"                 => 13148,
                         "laplacian"               => 26446,
                         "lapland"                 => 17325,
                         "lapped"                  => 27982,
                         "laps"                    => 4534,
                         "laptops"                 => 12280,
                         "large"                   => 189,
                         "largely"                 => 1062,
                         "largemouth"              => 19725,
                         "larger"                  => 750,
                         "largest"                 => 422,
                         "largs"                   => 28651,
                         "larks"                   => 21906,
                         "larnaca"                 => 19180,
                         "larne"                   => 20601,
                         "larouche"                => 17303,
                         "larva"                   => 9725,
                         "larvae"                  => 3146,
                         "larval"                  => 10549,
                         "larvik"                  => 23563,
                         "laryngeal"               => 22568,
                         "lascelles"               => 24813,
                         "laserdisc"               => 16547,
                         "lashkar"                 => 21706,
                         "laski"                   => 27762,
                         "lasted"                  => 2130,
                         "lasting"                 => 3527,
                         "lastly"                  => 8397,
                         "latakia"                 => 24629,
                         "late"                    => 234,
                         "latency"                 => 11698,
                         "latent"                  => 10308,
                         "later"                   => 58,
                         "lateral"                 => 4220,
                         "laterally"               => 11407,
                         "lateran"                 => 15194,
                         "laterite"                => 22855,
                         "lathes"                  => 28859,
                         "latif"                   => 16320,
                         "latifah"                 => 23575,
                         "latin"                   => 916,
                         "latinized"               => 19559,
                         "latins"                  => 22022,
                         "latitude"                => 4943,
                         "latitudes"               => 10912,
                         "latium"                  => 23842,
                         "latrobe"                 => 14002,
                         "latter"                  => 839,
                         "latterly"                => 12976,
                         "lattice"                 => 6203,
                         "lattices"                => 17859,
                         "latur"                   => 28193,
                         "latvia"                  => 4556,
                         "latvian"                 => 5437,
                         "latvians"                => 25954,
                         "lauda"                   => 17197,
                         "laude"                   => 7322,
                         "lauded"                  => 8912,
                         "lauenburg"               => 19088,
                         "launceston"              => 10677,
                         "launch"                  => 1421,
                         "launched"                => 691,
                         "launcher"                => 8856,
                         "launchers"               => 10249,
                         "launches"                => 6848,
                         "launching"               => 4477,
                         "lauper"                  => 17760,
                         "laureate"                => 7162,
                         "laureates"               => 13891,
                         "laurens"                 => 15299,
                         "laurentian"              => 19510,
                         "laurier"                 => 13245,
                         "lausanne"                => 8242,
                         "lautrec"                 => 29542,
                         "lava"                    => 5526,
                         "laval"                   => 8987,
                         "lavas"                   => 21924,
                         "lavish"                  => 8632,
                         "lavishly"                => 17905,
                         "lavoisier"               => 28574,
                         "lavra"                   => 26244,
                         "law"                     => 206,
                         "lawlessness"             => 22189,
                         "lawmaker"                => 25352,
                         "lawmakers"               => 11881,
                         "lawrenceville"           => 19539,
                         "laws"                    => 1186,
                         "laxmi"                   => 19297,
                         "layer"                   => 2434,
                         "layered"                 => 8421,
                         "layering"                => 17401,
                         "layers"                  => 3546,
                         "laymen"                  => 16394,
                         "layoff"                  => 27961,
                         "layoffs"                 => 17998,
                         "layout"                  => 3092,
                         "layouts"                 => 11865,
                         "lazier"                  => 26034,
                         "lazio"                   => 9409,
                         "leaching"                => 20584,
                         "lead"                    => 389,
                         "leaded"                  => 21849,
                         "leader"                  => 584,
                         "leaderboard"             => 23393,
                         "leaders"                 => 984,
                         "leadership"              => 972,
                         "leading"                 => 457,
                         "leadoff"                 => 23707,
                         "leads"                   => 1747,
                         "leadville"               => 25200,
                         "leaf"                    => 2605,
                         "leaflet"                 => 16117,
                         "leaflets"                => 8880,
                         "league"                  => 120,
                         "leaguer"                 => 19179,
                         "leaguers"                => 21785,
                         "leagues"                 => 2626,
                         "leakage"                 => 11172,
                         "leakey"                  => 23963,
                         "leamington"              => 14484,
                         "leanings"                => 14957,
                         "leaped"                  => 26181,
                         "learners"                => 8639,
                         "learning"                => 1114,
                         "learns"                  => 3631,
                         "learnt"                  => 7646,
                         "leased"                  => 4237,
                         "leasehold"               => 27658,
                         "leases"                  => 9493,
                         "leasing"                 => 8823,
                         "leatherhead"             => 23636,
                         "leathery"                => 18250,
                         "leaved"                  => 13389,
                         "leavenworth"             => 12477,
                         "leavers"                 => 29783,
                         "leaves"                  => 1016,
                         "lebanese"                => 4368,
                         "lebanon"                 => 2833,
                         "leben"                   => 17776,
                         "lebesgue"                => 20048,
                         "lecce"                   => 16252,
                         "lecco"                   => 27204,
                         "leche"                   => 26613,
                         "lectern"                 => 26126,
                         "lectionary"              => 13998,
                         "lectured"                => 6894,
                         "lecturer"                => 3381,
                         "lecturers"               => 12248,
                         "lectures"                => 3204,
                         "lectureship"             => 18776,
                         "leczyca"                 => 23702,
                         "led"                     => 240,
                         "ledges"                  => 18494,
                         "leeds"                   => 2609,
                         "leela"                   => 12581,
                         "leesburg"                => 19530,
                         "leeuwarden"              => 23681,
                         "leeward"                 => 12950,
                         "left"                    => 187,
                         "leftist"                 => 7865,
                         "leftists"                => 19236,
                         "legacies"                => 16472,
                         "legal"                   => 692,
                         "legalised"               => 27794,
                         "legality"                => 9837,
                         "legalization"            => 14060,
                         "legalized"               => 13019,
                         "legate"                  => 13183,
                         "legation"                => 14236,
                         "legazpi"                 => 26260,
                         "legco"                   => 28354,
                         "legendary"               => 3020,
                         "legends"                 => 3672,
                         "legia"                   => 25069,
                         "legible"                 => 26880,
                         "legio"                   => 20260,
                         "legionaries"             => 25598,
                         "legionary"               => 21856,
                         "legionnaire"             => 29472,
                         "legionnaires"            => 17645,
                         "legions"                 => 8660,
                         "legislated"              => 17917,
                         "legislation"             => 1829,
                         "legislative"             => 1310,
                         "legislator"              => 8601,
                         "legislators"             => 7713,
                         "legislature"             => 1913,
                         "legislatures"            => 8504,
                         "legitimacy"              => 7686,
                         "legitimately"            => 16593,
                         "legitimized"             => 28107,
                         "legnica"                 => 20652,
                         "legume"                  => 13577,
                         "legumes"                 => 19134,
                         "lehigh"                  => 7952,
                         "leiber"                  => 20263,
                         "leibniz"                 => 12097,
                         "leicester"               => 3976,
                         "leicestershire"          => 6587,
                         "leichhardt"              => 20748,
                         "leiden"                  => 7942,
                         "leiningen"               => 28384,
                         "leinster"                => 5729,
                         "leipzig"                 => 4741,
                         "leiria"                  => 24354,
                         "leisure"                 => 4443,
                         "leitrim"                 => 16758,
                         "lelouch"                 => 25757,
                         "lemberg"                 => 24349,
                         "lemma"                   => 11375,
                         "lemmy"                   => 25066,
                         "lemnos"                  => 26869,
                         "lemur"                   => 12943,
                         "lemurs"                  => 13855,
                         "lenape"                  => 13362,
                         "lender"                  => 12291,
                         "lenders"                 => 11601,
                         "lending"                 => 6710,
                         "lendl"                   => 27678,
                         "lends"                   => 11240,
                         "length"                  => 651,
                         "lengthen"                => 23751,
                         "lengthened"              => 11098,
                         "lengthening"             => 16007,
                         "lengths"                 => 4096,
                         "lengthwise"              => 28199,
                         "lengthy"                 => 4620,
                         "lengua"                  => 29775,
                         "lenin"                   => 6756,
                         "leningrad"               => 5838,
                         "leninism"                => 19451,
                         "leninist"                => 11677,
                         "lens"                    => 3729,
                         "lenses"                  => 5948,
                         "lenten"                  => 27786,
                         "lenticular"              => 23976,
                         "leominster"              => 22959,
                         "leonards"                => 19232,
                         "leonean"                 => 22677,
                         "leonese"                 => 23586,
                         "leonhard"                => 18122,
                         "leopards"                => 11381,
                         "lepanto"                 => 27534,
                         "lepidoptera"             => 13531,
                         "lepidus"                 => 25978,
                         "lermontov"               => 28054,
                         "lesions"                 => 7875,
                         "lesnar"                  => 16647,
                         "lesotho"                 => 10687,
                         "less"                    => 425,
                         "lessen"                  => 14211,
                         "lessened"                => 16032,
                         "lessening"               => 23796,
                         "lesser"                  => 2873,
                         "lessing"                 => 19390,
                         "leste"                   => 18189,
                         "leszek"                  => 21186,
                         "leszno"                  => 27499,
                         "lethality"               => 28001,
                         "lethargy"                => 29230,
                         "lethbridge"              => 12360,
                         "lettered"                => 12725,
                         "lettering"               => 9938,
                         "letterkenny"             => 24524,
                         "letters"                 => 1215,
                         "lettres"                 => 13178,
                         "leucine"                 => 22169,
                         "leukaemia"               => 23228,
                         "leukocytes"              => 29579,
                         "leumit"                  => 22594,
                         "leutnant"                => 18078,
                         "leuven"                  => 11078,
                         "levant"                  => 9040,
                         "levante"                 => 18648,
                         "levantine"               => 22822,
                         "levee"                   => 12772,
                         "levees"                  => 17445,
                         "level"                   => 289,
                         "leveling"                => 15377,
                         "levelled"                => 14352,
                         "levelling"               => 22288,
                         "levels"                  => 908,
                         "leveraged"               => 14111,
                         "leveraging"              => 19727,
                         "leverkusen"              => 15056,
                         "levers"                  => 16233,
                         "leveson"                 => 18218,
                         "levied"                  => 10490,
                         "levies"                  => 16599,
                         "leviticus"               => 19541,
                         "levski"                  => 13922,
                         "levying"                 => 29042,
                         "lewes"                   => 10571,
                         "lewinsky"                => 29243,
                         "lewisburg"               => 21523,
                         "lewisham"                => 14709,
                         "lewiston"                => 13124,
                         "lewisville"              => 29620,
                         "lexical"                 => 9894,
                         "lexicographer"           => 24752,
                         "lexington"               => 5307,
                         "leyla"                   => 23160,
                         "leyland"                 => 9545,
                         "leyte"                   => 8409,
                         "leyton"                  => 11414,
                         "lgbt"                    => 4424,
                         "lgbtq"                   => 22311,
                         "liabilities"             => 11213,
                         "liability"               => 5201,
                         "liangshan"               => 21249,
                         "liaodong"                => 28194,
                         "liaoning"                => 11693,
                         "libel"                   => 8249,
                         "liber"                   => 11645,
                         "libera"                  => 25981,
                         "liberal"                 => 1093,
                         "liberalisation"          => 21350,
                         "liberalism"              => 8521,
                         "liberalization"          => 14615,
                         "liberally"               => 21458,
                         "liberals"                => 4529,
                         "liberated"               => 7121,
                         "liberation"              => 2723,
                         "liberator"               => 12160,
                         "liberators"              => 18873,
                         "liberec"                 => 19467,
                         "liberia"                 => 6321,
                         "liberian"                => 11815,
                         "libertadores"            => 9813,
                         "libertarian"             => 6675,
                         "libertarianism"          => 23728,
                         "libertarians"            => 19640,
                         "liberties"               => 6452,
                         "libertine"               => 28077,
                         "libor"                   => 25980,
                         "librarians"              => 11443,
                         "librarianship"           => 22884,
                         "libraries"               => 2974,
                         "library"                 => 628,
                         "libre"                   => 7781,
                         "libretti"                => 29056,
                         "librettist"              => 16362,
                         "libretto"                => 7197,
                         "libreville"              => 28516,
                         "libri"                   => 23082,
                         "libro"                   => 22297,
                         "libya"                   => 4582,
                         "libyan"                  => 6436,
                         "libyans"                 => 24434,
                         "licence"                 => 4174,
                         "licenced"                => 19355,
                         "licences"                => 10814,
                         "licensed"                => 2283,
                         "licensee"                => 12199,
                         "licensees"               => 18319,
                         "licenses"                => 5584,
                         "licensing"               => 4564,
                         "licensure"               => 18864,
                         "licentiate"              => 15545,
                         "liceo"                   => 19913,
                         "lichen"                  => 12379,
                         "lichens"                 => 14007,
                         "lichfield"               => 10941,
                         "licinius"                => 20414,
                         "lidar"                   => 24340,
                         "liechtenstein"           => 8862,
                         "lieder"                  => 16657,
                         "liege"                   => 7284,
                         "liepaja"                 => 22099,
                         "lies"                    => 823,
                         "lietuvos"                => 27953,
                         "lieut"                   => 20723,
                         "lieutenant"              => 1088,
                         "lieutenants"             => 11233,
                         "life"                    => 108,
                         "lifeboat"                => 7775,
                         "lifeboats"               => 13069,
                         "lifecycle"               => 14330,
                         "lifelong"                => 4774,
                         "lifes"                   => 16384,
                         "lifespan"                => 8828,
                         "lifestyle"               => 3521,
                         "liffey"                  => 23107,
                         "liga"                    => 3075,
                         "ligament"                => 8188,
                         "ligaments"               => 14004,
                         "ligand"                  => 8834,
                         "ligands"                 => 9881,
                         "ligase"                  => 18667,
                         "ligation"                => 24394,
                         "ligatures"               => 28240,
                         "liger"                   => 25732,
                         "light"                   => 416,
                         "lighted"                 => 12008,
                         "lightest"                => 17662,
                         "lighthouse"              => 3597,
                         "lighthouses"             => 12080,
                         "lighting"                => 3114,
                         "lightship"               => 22673,
                         "lightweight"             => 4803,
                         "ligier"                  => 25724,
                         "ligne"                   => 24742,
                         "lignin"                  => 26695,
                         "lignite"                 => 19449,
                         "ligue"                   => 6702,
                         "liguria"                 => 16361,
                         "ligurian"                => 21034,
                         "liiga"                   => 13344,
                         "likeable"                => 21861,
                         "likelihood"              => 6363,
                         "likely"                  => 986,
                         "likened"                 => 9344,
                         "likening"                => 26634,
                         "likewise"                => 3916,
                         "likud"                   => 15729,
                         "lille"                   => 8210,
                         "lillehammer"             => 15434,
                         "lillestrom"              => 21579,
                         "lillooet"                => 20651,
                         "liman"                   => 25767,
                         "limassol"                => 15159,
                         "limbic"                  => 26703,
                         "limbs"                   => 6830,
                         "limburg"                 => 10523,
                         "limerick"                => 5558,
                         "limestone"               => 3435,
                         "limestones"              => 19998,
                         "limit"                   => 1922,
                         "limitation"              => 7730,
                         "limitations"             => 4329,
                         "limited"                 => 588,
                         "limiting"                => 5282,
                         "limits"                  => 2292,
                         "limousin"                => 18426,
                         "limpet"                  => 22024,
                         "limpets"                 => 18225,
                         "lincolnshire"            => 5688,
                         "lindau"                  => 23300,
                         "lindbergh"               => 12358,
                         "lindenwood"              => 27580,
                         "lindisfarne"             => 18509,
                         "lindwall"                => 18149,
                         "line"                    => 148,
                         "lineages"                => 9640,
                         "lineal"                  => 20830,
                         "linear"                  => 2394,
                         "linearity"               => 21629,
                         "linearly"                => 13166,
                         "linebacker"              => 5769,
                         "linebackers"             => 15315,
                         "linemen"                 => 17809,
                         "liner"                   => 4606,
                         "liners"                  => 10619,
                         "lines"                   => 679,
                         "linesman"                => 26224,
                         "lineup"                  => 3455,
                         "lineups"                 => 17214,
                         "linfield"                => 17679,
                         "linga"                   => 18968,
                         "lingam"                  => 20239,
                         "lingayen"                => 19290,
                         "lingered"                => 21274,
                         "lingua"                  => 12636,
                         "lingual"                 => 15572,
                         "linguist"                => 8142,
                         "linguistic"              => 4169,
                         "linguistically"          => 16028,
                         "linguistics"             => 5672,
                         "linguists"               => 9878,
                         "linings"                 => 24855,
                         "linkage"                 => 10223,
                         "linkages"                => 14395,
                         "linked"                  => 1889,
                         "linkedin"                => 22812,
                         "linking"                 => 4046,
                         "linkoping"               => 19507,
                         "links"                   => 1458,
                         "linlithgow"              => 21221,
                         "linnaeus"                => 11119,
                         "linnean"                 => 19908,
                         "linotype"                => 28991,
                         "linseed"                 => 29365,
                         "lintel"                  => 19850,
                         "lintels"                 => 21131,
                         "linux"                   => 4120,
                         "lions"                   => 2555,
                         "lionsgate"               => 18206,
                         "lipid"                   => 9727,
                         "lipids"                  => 14061,
                         "lipno"                   => 29191,
                         "lipoprotein"             => 27050,
                         "lippe"                   => 14109,
                         "lippi"                   => 23673,
                         "lippmann"                => 29726,
                         "liquefaction"            => 27767,
                         "liquefied"               => 18756,
                         "liquidated"              => 12768,
                         "liquidation"             => 9309,
                         "liquidator"              => 26138,
                         "liquidity"               => 12129,
                         "liquids"                 => 9276,
                         "liquors"                 => 28418,
                         "lisbon"                  => 4417,
                         "lisburn"                 => 20149,
                         "lisieux"                 => 29136,
                         "liskeard"                => 27254,
                         "lismore"                 => 17529,
                         "list"                    => 231,
                         "listed"                  => 596,
                         "listeners"               => 4797,
                         "listing"                 => 2053,
                         "listings"                => 4659,
                         "lists"                   => 2145,
                         "liszt"                   => 8644,
                         "liter"                   => 8500,
                         "literacy"                => 2847,
                         "literal"                 => 6834,
                         "literary"                => 1268,
                         "literate"                => 9524,
                         "literati"                => 24115,
                         "literature"              => 922,
                         "literatures"             => 19483,
                         "litex"                   => 29829,
                         "lithgow"                 => 18782,
                         "lithic"                  => 22620,
                         "lithograph"              => 27132,
                         "lithographer"            => 27368,
                         "lithographic"            => 25343,
                         "lithographs"             => 18605,
                         "lithography"             => 14305,
                         "lithosphere"             => 21918,
                         "lithuania"               => 3485,
                         "lithuanian"              => 3735,
                         "lithuanians"             => 13639,
                         "litigants"               => 24920,
                         "litigation"              => 5338,
                         "litovsk"                 => 25676,
                         "litre"                   => 6106,
                         "litres"                  => 10803,
                         "litters"                 => 20176,
                         "littoral"                => 11496,
                         "liturgical"              => 6554,
                         "liturgics"               => 25280,
                         "liturgies"               => 22213,
                         "liturgy"                 => 6940,
                         "litvinenko"              => 28912,
                         "lived"                   => 610,
                         "livelihoods"             => 16243,
                         "liveries"                => 21535,
                         "livery"                  => 6411,
                         "livestock"               => 4089,
                         "living"                  => 344,
                         "livonia"                 => 13606,
                         "livonian"                => 15709,
                         "livorno"                 => 13567,
                         "livre"                   => 17427,
                         "livres"                  => 18863,
                         "lizards"                 => 8423,
                         "ljubljana"               => 7487,
                         "llandaff"                => 19895,
                         "llandudno"               => 23906,
                         "llanelli"                => 14489,
                         "llangollen"              => 26929,
                         "llano"                   => 16798,
                         "lleida"                  => 16608,
                         "llewelyn"                => 23346,
                         "llobregat"               => 29444,
                         "lluis"                   => 24985,
                         "llywelyn"                => 14756,
                         "loaders"                 => 21871,
                         "loading"                 => 4494,
                         "loan"                    => 1695,
                         "loaned"                  => 4864,
                         "loans"                   => 3853,
                         "loanwords"               => 13863,
                         "loaves"                  => 14240,
                         "lobbied"                 => 8559,
                         "lobbies"                 => 18577,
                         "lobbying"                => 6518,
                         "lobbyist"                => 13098,
                         "lobbyists"               => 16768,
                         "lobed"                   => 13111,
                         "lobes"                   => 8513,
                         "lobos"                   => 12620,
                         "local"                   => 170,
                         "locale"                  => 12684,
                         "locales"                 => 12902,
                         "localised"               => 15962,
                         "localities"              => 5050,
                         "locality"                => 3490,
                         "localization"            => 9817,
                         "localize"                => 26504,
                         "localized"               => 7700,
                         "locally"                 => 2322,
                         "locals"                  => 3953,
                         "locarno"                 => 16656,
                         "located"                 => 134,
                         "locates"                 => 15185,
                         "location"                => 611,
                         "locations"               => 1423,
                         "locative"                => 23297,
                         "loch"                    => 5490,
                         "lochaber"                => 27216,
                         "lockerbie"               => 24626,
                         "lockheed"                => 6589,
                         "lockport"                => 19162,
                         "lockyer"                 => 18243,
                         "locomotion"              => 13612,
                         "locomotive"              => 2727,
                         "locomotives"             => 2415,
                         "locos"                   => 15620,
                         "locus"                   => 8485,
                         "lodge"                   => 2739,
                         "lodger"                  => 24213,
                         "lodges"                  => 8631,
                         "lodging"                 => 9509,
                         "lodgings"                => 15062,
                         "lodz"                    => 5054,
                         "loess"                   => 22142,
                         "loewe"                   => 25488,
                         "lofoten"                 => 29947,
                         "lofty"                   => 12508,
                         "logano"                  => 21121,
                         "logarithm"               => 15215,
                         "logarithmic"             => 16146,
                         "logarithms"              => 26718,
                         "loggers"                 => 20659,
                         "loggia"                  => 18743,
                         "logging"                 => 5696,
                         "logic"                   => 3097,
                         "logics"                  => 21771,
                         "logie"                   => 14845,
                         "login"                   => 18589,
                         "logistical"              => 9387,
                         "logistics"               => 4853,
                         "logo"                    => 2705,
                         "logos"                   => 8102,
                         "lohan"                   => 16895,
                         "lohengrin"               => 26213,
                         "loire"                   => 7018,
                         "loiret"                  => 27682,
                         "lollapalooza"            => 22121,
                         "lombards"                => 15912,
                         "lombardy"                => 8443,
                         "lombok"                  => 22364,
                         "lomza"                   => 22187,
                         "londonderry"             => 10585,
                         "londoners"               => 22729,
                         "longchamp"               => 17077,
                         "longest"                 => 2159,
                         "longevity"               => 8947,
                         "longford"                => 11430,
                         "longinus"                => 28164,
                         "longitude"               => 6247,
                         "longitudes"              => 27836,
                         "longitudinal"            => 7254,
                         "longitudinally"          => 19225,
                         "longlisted"              => 29639,
                         "longstanding"            => 10181,
                         "longtime"                => 3854,
                         "longueuil"               => 21770,
                         "longus"                  => 27543,
                         "lookalike"               => 29478,
                         "loomed"                  => 25778,
                         "looms"                   => 14579,
                         "loong"                   => 28891,
                         "loop"                    => 2538,
                         "looping"                 => 15498,
                         "loops"                   => 6487,
                         "loosely"                 => 4720,
                         "looted"                  => 9306,
                         "looters"                 => 24163,
                         "looting"                 => 9762,
                         "lorain"                  => 20603,
                         "lord"                    => 660,
                         "lorde"                   => 22508,
                         "lords"                   => 2889,
                         "lordship"                => 7984,
                         "lordships"               => 21573,
                         "lorestan"                => 10667,
                         "lorient"                 => 15200,
                         "lorries"                 => 17203,
                         "los"                     => 568,
                         "loss"                    => 737,
                         "losses"                  => 1859,
                         "lossless"                => 20653,
                         "lossy"                   => 28278,
                         "lothair"                 => 18618,
                         "lothian"                 => 10224,
                         "lotteries"               => 18993,
                         "loudness"                => 21859,
                         "loudoun"                 => 13002,
                         "loudspeaker"             => 14974,
                         "loudspeakers"            => 16241,
                         "loughborough"            => 11390,
                         "loughton"                => 25624,
                         "louisbourg"              => 19400,
                         "louisiana"               => 1690,
                         "louisville"              => 4049,
                         "lounges"                 => 15140,
                         "louth"                   => 12510,
                         "louvain"                 => 16596,
                         "louvre"                  => 9399,
                         "lovat"                   => 22976,
                         "lovech"                  => 23275,
                         "lovecraft"               => 10382,
                         "low"                     => 450,
                         "lower"                   => 502,
                         "lowercase"               => 17411,
                         "lowered"                 => 5524,
                         "lowering"                => 7600,
                         "lowest"                  => 2532,
                         "lowestoft"               => 16164,
                         "lowicz"                  => 28373,
                         "lowland"                 => 4980,
                         "lowlands"                => 8489,
                         "loxton"                  => 25794,
                         "loyalist"                => 7479,
                         "loyalists"               => 8569,
                         "lozenge"                 => 26346,
                         "ltd."                    => 3596,
                         "luanda"                  => 15568,
                         "luang"                   => 14554,
                         "lubavitch"               => 27486,
                         "lubbock"                 => 10520,
                         "lubeck"                  => 10913,
                         "lubelski"                => 20446,
                         "lublin"                  => 5599,
                         "lubomirski"              => 29880,
                         "lubricating"             => 27960,
                         "lubrication"             => 15986,
                         "lubusz"                  => 12593,
                         "lucan"                   => 17960,
                         "lucasarts"               => 23431,
                         "lucasfilm"               => 22805,
                         "lucchese"                => 20673,
                         "lucerne"                 => 11161,
                         "lucha"                   => 9214,
                         "lucknow"                 => 8179,
                         "lucrative"               => 7405,
                         "lucrezia"                => 21175,
                         "lucullus"                => 28856,
                         "ludendorff"              => 24238,
                         "ludhiana"                => 18417,
                         "ludovico"                => 16240,
                         "ludvig"                  => 18134,
                         "ludwigsburg"             => 24806,
                         "ludwigshafen"            => 25325,
                         "ludwik"                  => 25700,
                         "lufthansa"               => 15649,
                         "luftwaffe"               => 5960,
                         "luger"                   => 12565,
                         "luhansk"                 => 17987,
                         "lukashenko"              => 25282,
                         "lukow"                   => 27308,
                         "lulea"                   => 21508,
                         "lully"                   => 25979,
                         "lumberjacks"             => 21180,
                         "lumbini"                 => 25379,
                         "lumen"                   => 15318,
                         "lumia"                   => 21335,
                         "lumiere"                 => 17717,
                         "luminance"               => 21469,
                         "luminaries"              => 14204,
                         "luminescence"            => 29025,
                         "luminosity"              => 11959,
                         "luminous"                => 11075,
                         "lumpur"                  => 6604,
                         "lumumba"                 => 23112,
                         "lunar"                   => 4065,
                         "luneburg"                => 12082,
                         "lunenburg"               => 17792,
                         "lunga"                   => 26270,
                         "luoyang"                 => 11373,
                         "lupin"                   => 15734,
                         "lures"                   => 16249,
                         "lurgan"                  => 26688,
                         "lusaka"                  => 17762,
                         "lusatia"                 => 21040,
                         "lusatian"                => 28229,
                         "lushan"                  => 28175,
                         "lusignan"                => 22463,
                         "lusitania"               => 19534,
                         "lustre"                  => 22449,
                         "lutheran"                => 3569,
                         "lutheranism"             => 17307,
                         "lutherans"               => 13078,
                         "luthier"                 => 23475,
                         "luthor"                  => 12265,
                         "luton"                   => 6905,
                         "lutsk"                   => 27916,
                         "lutyens"                 => 21569,
                         "lutzow"                  => 24545,
                         "luxembourg"              => 3932,
                         "luxembourgian"           => 27416,
                         "luxembourgish"           => 18413,
                         "luxemburg"               => 17748,
                         "luxurious"               => 8946,
                         "luxury"                  => 3843,
                         "luzerne"                 => 17947,
                         "luzon"                   => 7480,
                         "lyase"                   => 16951,
                         "lycaenidae"              => 12656,
                         "lycee"                   => 10253,
                         "lyceum"                  => 10234,
                         "lycia"                   => 26172,
                         "lycoming"                => 13076,
                         "lydian"                  => 26804,
                         "lyell"                   => 16600,
                         "lymington"               => 25587,
                         "lymphatic"               => 18279,
                         "lymphocyte"              => 25985,
                         "lymphocytes"             => 15287,
                         "lymphoid"                => 27915,
                         "lympne"                  => 29916,
                         "lynchburg"               => 13951,
                         "lynching"                => 14454,
                         "lyndhurst"               => 22332,
                         "lyonnais"                => 20923,
                         "lyric"                   => 5330,
                         "lyrical"                 => 5627,
                         "lyrically"               => 9836,
                         "lyricism"                => 18086,
                         "lyricist"                => 7788,
                         "lyricists"               => 22834,
                         "lyrics"                  => 1400,
                         "lysine"                  => 15887,
                         "lysis"                   => 26836,
                         "lytham"                  => 28620,
                         "lyttelton"               => 13310,
                         "m*a*s*h"                 => 20927,
                         "m.b.a."                  => 21623,
                         "m.f.a"                   => 23542,
                         "m.i.a"                   => 21604,
                         "m.phil"                  => 26272,
                         "ma'mun"                  => 26040,
                         "maasai"                  => 20967,
                         "maastricht"              => 11539,
                         "maastrichtian"           => 27776,
                         "maatschappij"            => 26786,
                         "macao"                   => 18827,
                         "macapagal"               => 16733,
                         "macaque"                 => 20549,
                         "macaques"                => 23168,
                         "macau"                   => 6204,
                         "macaw"                   => 22691,
                         "maccabees"               => 23793,
                         "maccabi"                 => 8437,
                         "maccabiah"               => 21806,
                         "macclesfield"            => 11062,
                         "maccoll"                 => 25684,
                         "macdill"                 => 26917,
                         "macedon"                 => 13157,
                         "macedonia"               => 4011,
                         "macedonian"              => 4935,
                         "macedonians"             => 14076,
                         "machi"                   => 24380,
                         "machined"                => 19695,
                         "machinegun"              => 23948,
                         "machinery"               => 3890,
                         "machines"                => 2351,
                         "machinima"               => 23498,
                         "machining"               => 15110,
                         "machinist"               => 17710,
                         "maciej"                  => 20126,
                         "mackaye"                 => 29861,
                         "mackinac"                => 14608,
                         "mackintosh"              => 12243,
                         "macleay"                 => 26997,
                         "macomb"                  => 16967,
                         "macquarie"               => 8444,
                         "macro"                   => 9078,
                         "macroeconomic"           => 16193,
                         "macroeconomics"          => 21128,
                         "macromedia"              => 29824,
                         "macromolecules"          => 26073,
                         "macrophages"             => 15045,
                         "macroscopic"             => 16151,
                         "macular"                 => 24795,
                         "maculata"                => 23632,
                         "madagascar"              => 4398,
                         "madama"                  => 23071,
                         "madan"                   => 14424,
                         "made"                    => 65,
                         "madea"                   => 28125,
                         "madhav"                  => 24639,
                         "madhava"                 => 24395,
                         "madhavan"                => 19033,
                         "madhya"                  => 7140,
                         "madinah"                 => 29756,
                         "madoff"                  => 15596,
                         "madras"                  => 4782,
                         "madrasa"                 => 18803,
                         "madrasah"                => 23913,
                         "madrigals"               => 18637,
                         "madura"                  => 25306,
                         "madurai"                 => 9861,
                         "maegashira"              => 28917,
                         "maeve"                   => 28246,
                         "mafic"                   => 27390,
                         "mafiosi"                 => 28869,
                         "magadha"                 => 26425,
                         "magalhaes"               => 24801,
                         "magazine"                => 456,
                         "magazines"               => 2418,
                         "magdeburg"               => 9886,
                         "magellanic"              => 24879,
                         "maggiore"                => 14792,
                         "maghreb"                 => 15936,
                         "maginot"                 => 22154,
                         "magistrate"              => 5496,
                         "magistrates"             => 7648,
                         "maglev"                  => 25736,
                         "magma"                   => 10135,
                         "magmatic"                => 29028,
                         "magna"                   => 6972,
                         "magnate"                 => 9072,
                         "magnates"                => 14412,
                         "magne"                   => 27689,
                         "magnesia"                => 27594,
                         "magnesium"               => 8281,
                         "magnetic"                => 2800,
                         "magnetite"               => 21716,
                         "magnetization"           => 18332,
                         "magnetosphere"           => 23467,
                         "magnificat"              => 22788,
                         "magnification"           => 16820,
                         "magnitude"               => 3822,
                         "magnitudes"              => 17528,
                         "magny"                   => 29514,
                         "magog"                   => 26072,
                         "magsaysay"               => 20972,
                         "maguindanao"             => 25275,
                         "magus"                   => 22092,
                         "magyars"                 => 21294,
                         "mahabharata"             => 10150,
                         "mahadev"                 => 19352,
                         "mahadeva"                => 24838,
                         "mahadevan"               => 23664,
                         "mahalleh"                => 13437,
                         "maharaj"                 => 10626,
                         "maharaja"                => 7747,
                         "maharana"                => 27813,
                         "maharani"                => 22742,
                         "maharashtra"             => 4543,
                         "maharishi"               => 14919,
                         "maharshi"                => 28606,
                         "mahathir"                => 21038,
                         "mahatma"                 => 10255,
                         "mahavidyalaya"           => 27165,
                         "mahavira"                => 29366,
                         "mahayana"                => 12207,
                         "mahdi"                   => 11523,
                         "mahendra"                => 14413,
                         "mahila"                  => 29609,
                         "mahinda"                 => 22906,
                         "mahindra"                => 15530,
                         "mahjong"                 => 23879,
                         "mahmud"                  => 8407,
                         "mahmudabad"              => 21426,
                         "mahoning"                => 23606,
                         "maidan"                  => 16932,
                         "maidenhead"              => 17222,
                         "maidens"                 => 15019,
                         "maidstone"               => 10868,
                         "maimonides"              => 13498,
                         "main"                    => 198,
                         "maine"                   => 2267,
                         "mainframes"              => 26423,
                         "mainichi"                => 25510,
                         "mainland"                => 2729,
                         "mainline"                => 6883,
                         "mainly"                  => 792,
                         "mainstage"               => 28703,
                         "mainstay"                => 9887,
                         "mainstays"               => 23736,
                         "mainstream"              => 2447,
                         "maintain"                => 1735,
                         "maintained"              => 1521,
                         "maintaining"             => 3008,
                         "maintains"               => 3005,
                         "maintenance"             => 2015,
                         "mainz"                   => 7159,
                         "maior"                   => 26516,
                         "maisonneuve"             => 29141,
                         "maisons"                 => 26194,
                         "maithili"                => 26932,
                         "maitreya"                => 23544,
                         "maize"                   => 7355,
                         "majapahit"               => 19706,
                         "majid"                   => 14118,
                         "majlis"                  => 14806,
                         "major"                   => 177,
                         "majorca"                 => 14119,
                         "majored"                 => 9641,
                         "majoring"                => 11404,
                         "majoris"                 => 27425,
                         "majorities"              => 14955,
                         "majority"                => 699,
                         "majumdar"                => 24110,
                         "majuro"                  => 23103,
                         "makai"                   => 25378,
                         "makassar"                => 20672,
                         "makati"                  => 14857,
                         "maker"                   => 3591,
                         "makerere"                => 21949,
                         "makers"                  => 3938,
                         "makeshift"               => 10121,
                         "makeup"                  => 1907,
                         "makhachkala"             => 26590,
                         "makkah"                  => 27379,
                         "makow"                   => 29934,
                         "maktoum"                 => 20160,
                         "makuuchi"                => 28795,
                         "malabar"                 => 8675,
                         "malacca"                 => 9070,
                         "malagasy"                => 12134,
                         "malai"                   => 27874,
                         "malang"                  => 28408,
                         "malankara"               => 15547,
                         "malappuram"              => 21622,
                         "malaria"                 => 6681,
                         "malarial"                => 29657,
                         "malate"                  => 29061,
                         "malawi"                  => 6445,
                         "malawian"                => 22387,
                         "malay"                   => 4801,
                         "malaya"                  => 7265,
                         "malayalam"               => 4673,
                         "malayan"                 => 11272,
                         "malays"                  => 12872,
                         "malaysia"                => 2024,
                         "malaysian"               => 4304,
                         "malaysians"              => 25181,
                         "malden"                  => 14985,
                         "maldives"                => 8430,
                         "maldivian"               => 18904,
                         "maldon"                  => 20563,
                         "male"                    => 776,
                         "maleficent"              => 27249,
                         "males"                   => 778,
                         "malformation"            => 25998,
                         "malformations"           => 22340,
                         "mali"                    => 5687,
                         "malian"                  => 14644,
                         "malignancies"            => 29322,
                         "malignancy"              => 27447,
                         "maliki"                  => 18056,
                         "malini"                  => 24640,
                         "malla"                   => 18003,
                         "malleable"               => 22802,
                         "mallee"                  => 18740,
                         "malls"                   => 8152,
                         "malmesbury"              => 19436,
                         "malmo"                   => 7669,
                         "malnutrition"            => 11970,
                         "malolos"                 => 25586,
                         "malory"                  => 27331,
                         "malta"                   => 3668,
                         "maltese"                 => 6700,
                         "malthus"                 => 28069,
                         "malton"                  => 19625,
                         "maltreatment"            => 29043,
                         "maluku"                  => 19022,
                         "malus"                   => 23238,
                         "malvern"                 => 9382,
                         "malwa"                   => 18588,
                         "malware"                 => 13568,
                         "mamba"                   => 23899,
                         "mamet"                   => 23227,
                         "mamluk"                  => 13794,
                         "mamluks"                 => 17053,
                         "mammal"                  => 8148,
                         "mammalian"               => 8652,
                         "mammals"                 => 3936,
                         "mammary"                 => 23039,
                         "mammootty"               => 20627,
                         "mammoths"                => 25657,
                         "mamoru"                  => 22604,
                         "managed"                 => 878,
                         "management"              => 490,
                         "manager"                 => 653,
                         "managerial"              => 6808,
                         "managers"                => 3504,
                         "manages"                 => 3165,
                         "managing"                => 2334,
                         "manama"                  => 23917,
                         "manas"                   => 21117,
                         "manassas"                => 16244,
                         "manasseh"                => 27231,
                         "manaus"                  => 24288,
                         "manawatu"                => 16760,
                         "manche"                  => 17925,
                         "manchu"                  => 8706,
                         "manchukuo"               => 16372,
                         "manchuria"               => 9873,
                         "manchurian"              => 19611,
                         "manchus"                 => 20725,
                         "mandal"                  => 7902,
                         "mandala"                 => 16089,
                         "mandalay"                => 12985,
                         "mandals"                 => 29706,
                         "mandan"                  => 25774,
                         "mandate"                 => 3858,
                         "mandated"                => 6104,
                         "mandates"                => 8860,
                         "mandating"               => 20299,
                         "mandatory"               => 3896,
                         "mande"                   => 25336,
                         "mandela"                 => 9349,
                         "mandible"                => 10969,
                         "mandibles"               => 12221,
                         "mandibular"              => 19366,
                         "mandir"                  => 8609,
                         "mandurah"                => 29838,
                         "manet"                   => 19403,
                         "maneuverability"         => 17985,
                         "maneuverable"            => 25789,
                         "maneuvers"               => 8383,
                         "manga"                   => 2834,
                         "mangal"                  => 24382,
                         "mangalore"               => 11538,
                         "manganese"               => 10304,
                         "mangeshkar"              => 22112,
                         "mangrove"                => 9609,
                         "mangroves"               => 13764,
                         "manhattan"               => 2459,
                         "manheim"                 => 29583,
                         "manhunter"               => 22567,
                         "manifestation"           => 8541,
                         "manifestations"          => 9709,
                         "manifested"              => 9268,
                         "manifesto"               => 6068,
                         "manifestos"              => 29915,
                         "manifests"               => 13023,
                         "manifold"                => 6546,
                         "manifolds"               => 10861,
                         "manila"                  => 3303,
                         "manipal"                 => 29930,
                         "manipur"                 => 11186,
                         "manipuri"                => 25627,
                         "manistee"                => 29913,
                         "manitoba"                => 3367,
                         "manitowoc"               => 21843,
                         "manju"                   => 26021,
                         "mankato"                 => 20107,
                         "mankiewicz"              => 24643,
                         "manlius"                 => 27294,
                         "manmade"                 => 24919,
                         "manmohan"                => 18035,
                         "mannar"                  => 24264,
                         "manned"                  => 5504,
                         "manner"                  => 2012,
                         "mannerheim"              => 25818,
                         "mannerism"               => 25984,
                         "mannerisms"              => 16646,
                         "mannerist"               => 20157,
                         "manningham"              => 27120,
                         "mannose"                 => 29202,
                         "manoa"                   => 21624,
                         "manoel"                  => 23903,
                         "manoeuvre"               => 13970,
                         "manoeuvres"              => 15261,
                         "manohar"                 => 19822,
                         "manoj"                   => 16719,
                         "manor"                   => 2330,
                         "manorama"                => 27064,
                         "manorial"                => 18933,
                         "manors"                  => 11065,
                         "mans"                    => 5617,
                         "mansa"                   => 23149,
                         "mansard"                 => 18393,
                         "mansfeld"                => 26879,
                         "mansions"                => 9279,
                         "mantegna"                => 26794,
                         "mantras"                 => 20030,
                         "mantua"                  => 11177,
                         "manually"                => 7412,
                         "manufactory"             => 22523,
                         "manufacture"             => 3343,
                         "manufactured"            => 2473,
                         "manufacturer"            => 2513,
                         "manufacturers"           => 2799,
                         "manufactures"            => 7212,
                         "manufacturing"           => 1742,
                         "manukau"                 => 21198,
                         "manuscript"              => 2822,
                         "manuscripts"             => 3644,
                         "many"                    => 68,
                         "manzanillo"              => 25959,
                         "manzoni"                 => 29822,
                         "maoist"                  => 13288,
                         "maoists"                 => 28646,
                         "maori"                   => 4346,
                         "maozhen"                 => 27319,
                         "mapped"                  => 6190,
                         "mapping"                 => 4472,
                         "mappings"                => 21262,
                         "maps"                    => 2550,
                         "mapuche"                 => 17656,
                         "maputo"                  => 19776,
                         "maquis"                  => 21465,
                         "maracaibo"               => 19668,
                         "marae"                   => 28852,
                         "marais"                  => 16382,
                         "maramures"               => 28416,
                         "maranhao"                => 18892,
                         "maratha"                 => 9427,
                         "marathas"                => 13761,
                         "marathi"                 => 6621,
                         "marathons"               => 16131,
                         "marauders"               => 16009,
                         "marauding"               => 25246,
                         "marbled"                 => 19616,
                         "marblehead"              => 21651,
                         "marburg"                 => 12461,
                         "marca"                   => 28660,
                         "marcellinus"             => 28315,
                         "march"                   => 141,
                         "marche"                  => 11333,
                         "marched"                 => 4483,
                         "marcher"                 => 25430,
                         "marchers"                => 19680,
                         "marches"                 => 7521,
                         "marching"                => 4341,
                         "marchioness"             => 21015,
                         "mardan"                  => 27601,
                         "mardin"                  => 22414,
                         "mare"                    => 4657,
                         "marechal"                => 19245,
                         "marella"                 => 28964,
                         "marfa"                   => 28144,
                         "marga"                   => 24206,
                         "margaretha"              => 27941,
                         "margarine"               => 24134,
                         "margin"                  => 2564,
                         "marginal"                => 5449,
                         "marginalised"            => 22634,
                         "marginalization"         => 23750,
                         "marginalized"            => 11781,
                         "marginata"               => 28691,
                         "margins"                 => 6251,
                         "margrave"                => 10399,
                         "margraves"               => 29983,
                         "margraviate"             => 23461,
                         "margrethe"               => 24256,
                         "marianas"                => 13446,
                         "maribor"                 => 12208,
                         "maricopa"                => 17102,
                         "mariinsky"               => 22823,
                         "marikina"                => 22296,
                         "marinette"               => 28445,
                         "marionette"              => 22835,
                         "marischal"               => 28505,
                         "marist"                  => 12602,
                         "maritima"                => 23536,
                         "maritime"                => 2632,
                         "maritimes"               => 15337,
                         "maritimo"                => 25634,
                         "markazi"                 => 13621,
                         "marked"                  => 1292,
                         "markedly"                => 9340,
                         "markers"                 => 5849,
                         "market"                  => 494,
                         "marketed"                => 3962,
                         "marketer"                => 21667,
                         "marketers"               => 16808,
                         "marketing"               => 1768,
                         "marketplace"             => 6442,
                         "marketplaces"            => 27862,
                         "markets"                 => 1857,
                         "marking"                 => 3906,
                         "markings"                => 5336,
                         "markov"                  => 12231,
                         "marksman"                => 18379,
                         "marksmen"                => 24759,
                         "markt"                   => 25689,
                         "markup"                  => 13406,
                         "marlborough"             => 7657,
                         "marmara"                 => 17460,
                         "marne"                   => 8246,
                         "maronite"                => 14426,
                         "maronites"               => 28619,
                         "maroons"                 => 11518,
                         "marque"                  => 12299,
                         "marquee"                 => 12087,
                         "marquesas"               => 24418,
                         "marquess"                => 6552,
                         "marrakech"               => 18905,
                         "marrakesh"               => 20993,
                         "marred"                  => 10073,
                         "married"                 => 297,
                         "mars"                    => 2955,
                         "marsalis"                => 18150,
                         "marshal"                 => 3516,
                         "marshalling"             => 16231,
                         "marshalls"               => 19032,
                         "marshes"                 => 6370,
                         "marshfield"              => 20631,
                         "marshland"               => 16594,
                         "marshlands"              => 27197,
                         "marshy"                  => 12983,
                         "marsupial"               => 22598,
                         "marsupials"              => 22177,
                         "martial"                 => 2580,
                         "martinique"              => 10046,
                         "martinsburg"             => 22232,
                         "martinsville"            => 15646,
                         "martinus"                => 26850,
                         "martius"                 => 27394,
                         "martyrdom"               => 9892,
                         "martyred"                => 13816,
                         "martyrology"             => 24766,
                         "martyrs"                 => 7072,
                         "maruti"                  => 22854,
                         "marvell"                 => 28420,
                         "marvels"                 => 19163,
                         "marxian"                 => 26986,
                         "marxism"                 => 8864,
                         "marxist"                 => 5323,
                         "marxists"                => 17510,
                         "maryborough"             => 18606,
                         "maryhill"                => 27931,
                         "maryland"                => 1492,
                         "marylebone"              => 9556,
                         "marymount"               => 16419,
                         "marysville"              => 17036,
                         "maryville"               => 24254,
                         "masaaki"                 => 29431,
                         "masada"                  => 25723,
                         "masala"                  => 19269,
                         "masao"                   => 29171,
                         "masaryk"                 => 23861,
                         "masashi"                 => 28956,
                         "masato"                  => 21090,
                         "masayuki"                => 29289,
                         "mascarene"               => 25554,
                         "mascot"                  => 4323,
                         "mascots"                 => 13905,
                         "masculine"               => 5735,
                         "masculinity"             => 13898,
                         "mashhad"                 => 15030,
                         "mashonaland"             => 25485,
                         "mashup"                  => 23406,
                         "masjid"                  => 9186,
                         "masonic"                 => 7257,
                         "masonry"                 => 6809,
                         "masood"                  => 17866,
                         "masoretic"               => 26068,
                         "masovia"                 => 24231,
                         "masovian"                => 5954,
                         "masque"                  => 14490,
                         "mass"                    => 945,
                         "massachusetts"           => 1105,
                         "massacre"                => 3143,
                         "massacred"               => 10898,
                         "massacres"               => 9109,
                         "massed"                  => 14835,
                         "massena"                 => 17245,
                         "massenet"                => 21413,
                         "masses"                  => 4404,
                         "massif"                  => 8351,
                         "massillon"               => 20758,
                         "massing"                 => 19744,
                         "massively"               => 11396,
                         "massoud"                 => 19747,
                         "masted"                  => 18913,
                         "masterchef"              => 19761,
                         "masterclasses"           => 24721,
                         "mastered"                => 7358,
                         "mastering"               => 10156,
                         "masterly"                => 28201,
                         "masterpieces"            => 11424,
                         "masterplan"              => 22588,
                         "masterton"               => 22402,
                         "masterworks"             => 21858,
                         "mastery"                 => 9158,
                         "masthead"                => 20331,
                         "mastodon"                => 21435,
                         "masts"                   => 9788,
                         "masud"                   => 26709,
                         "masurian"                => 8338,
                         "matabeleland"            => 27313,
                         "matanzas"                => 23839,
                         "mataram"                 => 20838,
                         "match"                   => 381,
                         "matchday"                => 14198,
                         "matched"                 => 4973,
                         "matches"                 => 777,
                         "matchless"               => 28392,
                         "matchplay"               => 27625,
                         "matchup"                 => 12506,
                         "matchups"                => 20636,
                         "mated"                   => 14134,
                         "matej"                   => 29776,
                         "mater"                   => 5781,
                         "material"                => 745,
                         "materialise"             => 23032,
                         "materialised"            => 20070,
                         "materialism"             => 12600,
                         "materialist"             => 22389,
                         "materialized"            => 12752,
                         "materially"              => 17992,
                         "materials"               => 1228,
                         "materiel"                => 12036,
                         "maternal"                => 4079,
                         "mathematica"             => 24353,
                         "mathematical"            => 2813,
                         "mathematically"          => 10671,
                         "mathematician"           => 5087,
                         "mathematicians"          => 9374,
                         "mathematics"             => 1771,
                         "maths"                   => 11371,
                         "mathura"                 => 16630,
                         "matic"                   => 16698,
                         "matins"                  => 26008,
                         "matlab"                  => 25464,
                         "matra"                   => 20138,
                         "matriarchal"             => 29469,
                         "matrices"                => 7477,
                         "matriculated"            => 10596,
                         "matriculating"           => 26759,
                         "matriculation"           => 12054,
                         "matrilineal"             => 19273,
                         "matroid"                 => 21701,
                         "matsu"                   => 27340,
                         "matsudaira"              => 21130,
                         "matsuri"                 => 27548,
                         "matsuyama"               => 25020,
                         "mattel"                  => 13686,
                         "matterhorn"              => 21664,
                         "matti"                   => 16383,
                         "maturation"              => 12525,
                         "matures"                 => 18002,
                         "maturin"                 => 21044,
                         "maturing"                => 16795,
                         "maturity"                => 5681,
                         "mauboy"                  => 24854,
                         "maugham"                 => 20915,
                         "maulana"                 => 13327,
                         "maumee"                  => 24222,
                         "mauna"                   => 19476,
                         "maung"                   => 18719,
                         "mauretania"              => 23000,
                         "maurier"                 => 22018,
                         "mauritania"              => 9506,
                         "mauritanian"             => 22524,
                         "mauritian"               => 17654,
                         "mauritius"               => 6449,
                         "maurya"                  => 21265,
                         "mauryan"                 => 26550,
                         "mausoleums"              => 29672,
                         "mauthausen"              => 26103,
                         "maven"                   => 29984,
                         "maxilla"                 => 20607,
                         "maxillary"               => 12416,
                         "maximilien"              => 29847,
                         "maximise"                => 17560,
                         "maximization"            => 26884,
                         "maximize"                => 8543,
                         "maximized"               => 24912,
                         "maximizes"               => 27485,
                         "maximizing"              => 15460,
                         "maxims"                  => 25008,
                         "maximum"                 => 1346,
                         "may"                     => 46,
                         "mayaguez"                => 15370,
                         "maybach"                 => 21792,
                         "mayenne"                 => 25090,
                         "maynooth"                => 18707,
                         "mayor"                   => 893,
                         "mayoral"                 => 7501,
                         "mayoralty"               => 16065,
                         "mayors"                  => 6320,
                         "mayotte"                 => 21298,
                         "mayport"                 => 25896,
                         "mazandaran"              => 9792,
                         "mazar"                   => 18201,
                         "mazarin"                 => 22186,
                         "mazes"                   => 25060,
                         "mazhar"                  => 29581,
                         "mazowiecka"              => 23025,
                         "mazowiecki"              => 13504,
                         "mazowieckie"             => 26273,
                         "mazra'eh"                => 22996,
                         "mazraeh"                 => 11690,
                         "mbeki"                   => 18145,
                         "mbit/s"                  => 12025,
                         "mcclatchy"               => 25681,
                         "mcduck"                  => 28082,
                         "mcenroe"                 => 19182,
                         "mcguinty"                => 26684,
                         "mckellen"                => 26399,
                         "mcluhan"                 => 23284,
                         "mcminnville"             => 27235,
                         "mcmurdo"                 => 17613,
                         "meadowlands"             => 18541,
                         "meagre"                  => 21391,
                         "meander"                 => 19114,
                         "meandering"              => 15921,
                         "meanders"                => 18129,
                         "meaning"                 => 835,
                         "meanings"                => 5827,
                         "meanwhile"               => 1764,
                         "measurable"              => 10387,
                         "measure"                 => 1799,
                         "measured"                => 2706,
                         "measurement"             => 3739,
                         "measurements"            => 4172,
                         "measures"                => 1846,
                         "measuring"               => 3526,
                         "meath"                   => 8960,
                         "mecca"                   => 7442,
                         "mechanical"              => 2162,
                         "mechanically"            => 9772,
                         "mechanics"               => 3550,
                         "mechanised"              => 15204,
                         "mechanism"               => 2406,
                         "mechanisms"              => 3725,
                         "mechanistic"             => 22492,
                         "mechanization"           => 20988,
                         "mechanized"              => 9277,
                         "mechelen"                => 15909,
                         "mecklenburg"             => 7123,
                         "mecyclothorax"           => 28224,
                         "medaille"                => 25154,
                         "medak"                   => 27451,
                         "medal"                   => 618,
                         "medalist"                => 5593,
                         "medalists"               => 10960,
                         "medallion"               => 10414,
                         "medallions"              => 16536,
                         "medallist"               => 10406,
                         "medallists"              => 20662,
                         "medals"                  => 2076,
                         "medan"                   => 17634,
                         "medea"                   => 15795,
                         "medes"                   => 26462,
                         "media"                   => 415,
                         "mediacorp"               => 15739,
                         "mediaeval"               => 10799,
                         "medial"                  => 7987,
                         "medially"                => 28457,
                         "median"                  => 783,
                         "mediate"                 => 11200,
                         "mediated"                => 7105,
                         "mediates"                => 19524,
                         "mediating"               => 18623,
                         "mediation"               => 8628,
                         "mediator"                => 11188,
                         "mediators"               => 19433,
                         "mediaworks"              => 27623,
                         "medica"                  => 19885,
                         "medicaid"                => 11721,
                         "medical"                 => 527,
                         "medicare"                => 8995,
                         "medici"                  => 7923,
                         "medicinal"               => 6994,
                         "medicine"                => 1194,
                         "medicines"               => 7673,
                         "medico"                  => 21319,
                         "medieval"                => 1752,
                         "medio"                   => 25316,
                         "meditation"              => 5385,
                         "meditations"             => 16288,
                         "meditative"              => 17057,
                         "mediterranean"           => 2286,
                         "medium"                  => 1605,
                         "mediums"                 => 12389,
                         "medway"                  => 11817,
                         "meena"                   => 15376,
                         "meenakshi"               => 20047,
                         "meera"                   => 15888,
                         "meerut"                  => 17587,
                         "meetinghouse"            => 16889,
                         "meetings"                => 2126,
                         "meets"                   => 1972,
                         "mega"                    => 4598,
                         "megachile"               => 5863,
                         "megachilidae"            => 16906,
                         "megalithic"              => 16202,
                         "megapixel"               => 18816,
                         "megas"                   => 14065,
                         "megawatt"                => 16787,
                         "megawatts"               => 13973,
                         "meghalaya"               => 17118,
                         "mehdi"                   => 13194,
                         "meher"                   => 20128,
                         "mehmed"                  => 10721,
                         "mehmood"                 => 26111,
                         "mehra"                   => 24403,
                         "meiji"                   => 7809,
                         "meine"                   => 29653,
                         "meiningen"               => 20270,
                         "meiosis"                 => 17420,
                         "meissen"                 => 15990,
                         "meistriliiga"            => 27905,
                         "meitetsu"                => 29085,
                         "mekong"                  => 11259,
                         "melaka"                  => 22925,
                         "melaleuca"               => 12538,
                         "melamine"                => 26680,
                         "melancholic"             => 18296,
                         "melanchthon"             => 26777,
                         "melanesia"               => 23400,
                         "melanesian"              => 24155,
                         "melanin"                 => 21898,
                         "melanogaster"            => 24194,
                         "melanoma"                => 14864,
                         "melatonin"               => 25170,
                         "melayu"                  => 22487,
                         "melbourne"               => 1445,
                         "melee"                   => 10927,
                         "melies"                  => 18880,
                         "melilla"                 => 24850,
                         "melkite"                 => 20341,
                         "mellencamp"              => 22576,
                         "mellitus"                => 18103,
                         "mellotron"               => 27832,
                         "melodic"                 => 6113,
                         "melodies"                => 6008,
                         "melodifestivalen"        => 15867,
                         "melodious"               => 22159,
                         "melodramas"              => 27399,
                         "meltwater"               => 22071,
                         "melvyn"                  => 25018,
                         "melzer"                  => 23574,
                         "member"                  => 151,
                         "membered"                => 22225,
                         "members"                 => 180,
                         "membership"              => 1632,
                         "memberships"             => 10477,
                         "membrane"                => 3816,
                         "membranes"               => 8401,
                         "membranous"              => 24015,
                         "memel"                   => 28535,
                         "memes"                   => 26781,
                         "memoir"                  => 4960,
                         "memoires"                => 22935,
                         "memoirs"                 => 4992,
                         "memorabilia"             => 9298,
                         "memorable"               => 4597,
                         "memorably"               => 23080,
                         "memoranda"               => 26359,
                         "memorandum"              => 7200,
                         "memoria"                 => 28747,
                         "memorial"                => 1021,
                         "memorialized"            => 19363,
                         "memorials"               => 7125,
                         "memoriam"                => 21515,
                         "memorization"            => 28106,
                         "men"                     => 212,
                         "menachem"                => 15396,
                         "menahem"                 => 29325,
                         "menai"                   => 28403,
                         "menander"                => 28091,
                         "mencken"                 => 27613,
                         "mendelssohn"             => 11111,
                         "mendicant"               => 28570,
                         "mendip"                  => 21803,
                         "mendocino"               => 15658,
                         "mendota"                 => 26846,
                         "menelik"                 => 24402,
                         "menem"                   => 23771,
                         "menezes"                 => 18826,
                         "meniscus"                => 21228,
                         "menlo"                   => 17285,
                         "mennonite"               => 9979,
                         "mennonites"              => 15080,
                         "menominee"               => 19459,
                         "menon"                   => 9913,
                         "menstruation"            => 20569,
                         "menswear"                => 21142,
                         "mentalist"               => 28415,
                         "mentioned"               => 1089,
                         "mentions"                => 3424,
                         "mentored"                => 10715,
                         "mentoring"               => 9743,
                         "mentors"                 => 10423,
                         "mentorship"              => 16592,
                         "menuhin"                 => 21549,
                         "menxia"                  => 26948,
                         "merah"                   => 26124,
                         "mercantile"              => 8429,
                         "mercenaries"             => 7484,
                         "merchandising"           => 11870,
                         "merchantman"             => 23743,
                         "merchantmen"             => 20792,
                         "merchants"               => 3806,
                         "mercia"                  => 12353,
                         "mercian"                 => 20421,
                         "mercosur"                => 29163,
                         "mercurial"               => 27500,
                         "merdeka"                 => 22096,
                         "merge"                   => 5122,
                         "merged"                  => 1633,
                         "merger"                  => 2453,
                         "mergers"                 => 8710,
                         "merges"                  => 10554,
                         "merging"                 => 6094,
                         "meriden"                 => 20057,
                         "merion"                  => 23301,
                         "merit"                   => 3324,
                         "merite"                  => 22689,
                         "merited"                 => 21640,
                         "meritorious"             => 8470,
                         "merovingian"             => 19293,
                         "merrimack"               => 14928,
                         "merseburg"               => 23850,
                         "mersenne"                => 29795,
                         "mersey"                  => 11118,
                         "merseyrail"              => 29660,
                         "merseyside"              => 10256,
                         "mersin"                  => 10714,
                         "merthyr"                 => 13050,
                         "merton"                  => 9250,
                         "mervyn"                  => 13900,
                         "mesenchymal"             => 28731,
                         "meshes"                  => 27233,
                         "mesic"                   => 21941,
                         "mesoamerica"             => 15571,
                         "mesoamerican"            => 13530,
                         "mesoderm"                => 25710,
                         "mesolithic"              => 15983,
                         "mesopotamia"             => 8526,
                         "mesopotamian"            => 15165,
                         "mesozoic"                => 13840,
                         "messaging"               => 8315,
                         "messe"                   => 21998,
                         "messengers"              => 10576,
                         "messerschmitt"           => 13103,
                         "messiaen"                => 20856,
                         "messianic"               => 14512,
                         "messines"                => 27816,
                         "messrs"                  => 21713,
                         "messrs."                 => 20354,
                         "mestizo"                 => 17547,
                         "mestizos"                => 23361,
                         "mesto"                   => 20391,
                         "metabolic"               => 7415,
                         "metabolism"              => 6387,
                         "metabolite"              => 15941,
                         "metabolites"             => 13413,
                         "metabolized"             => 19790,
                         "metacomet"               => 27746,
                         "metacritic"              => 6132,
                         "metadata"                => 9236,
                         "metairie"                => 26431,
                         "metal"                   => 923,
                         "metalcore"               => 15283,
                         "metallurg"               => 24387,
                         "metallurgical"           => 14369,
                         "metallurgy"              => 11843,
                         "metals"                  => 4330,
                         "metalurh"                => 27683,
                         "metalwork"               => 17959,
                         "metalworking"            => 20319,
                         "metamorphic"             => 14081,
                         "metamorphism"            => 24161,
                         "metamorphosed"           => 22055,
                         "metamorphoses"           => 21123,
                         "metanotum"               => 18079,
                         "metaphorical"            => 15546,
                         "metaphysical"            => 10116,
                         "metaphysics"             => 10536,
                         "metastasis"              => 18952,
                         "metastatic"              => 19031,
                         "metatarsal"              => 25721,
                         "metathorax"              => 17721,
                         "meteoric"                => 26116,
                         "meteorite"               => 10855,
                         "meteorites"              => 15232,
                         "meteorological"          => 6658,
                         "meteorologist"           => 12804,
                         "meteorologists"          => 23878,
                         "meteorology"             => 10873,
                         "meter"                   => 3024,
                         "metered"                 => 26838,
                         "metering"                => 14652,
                         "meters"                  => 1909,
                         "methamphetamine"         => 15815,
                         "methane"                 => 8348,
                         "methanol"                => 13461,
                         "methionine"              => 19962,
                         "method"                  => 991,
                         "methodically"            => 29959,
                         "methodism"               => 17270,
                         "methodist"               => 3002,
                         "methodists"              => 12877,
                         "methodius"               => 19906,
                         "methodological"          => 12922,
                         "methodologies"           => 11410,
                         "methodology"             => 5418,
                         "methods"                 => 1279,
                         "methuen"                 => 19493,
                         "methyl"                  => 9430,
                         "methylated"              => 25514,
                         "methylation"             => 13382,
                         "methylene"               => 24825,
                         "methyltransferase"       => 16293,
                         "meticulously"            => 16398,
                         "metis"                   => 10731,
                         "metra"                   => 15433,
                         "metre"                   => 2698,
                         "metres"                  => 1319,
                         "metric"                  => 4686,
                         "metrical"                => 17291,
                         "metrics"                 => 10769,
                         "metro"                   => 1754,
                         "metrobus"                => 22881,
                         "metrodome"               => 27691,
                         "metrolink"               => 13812,
                         "metrology"               => 23725,
                         "metronome"               => 25891,
                         "metroplex"               => 21167,
                         "metropole"               => 19872,
                         "metropolis"              => 6950,
                         "metropolitan"            => 1405,
                         "metropolitana"           => 22878,
                         "metropolitans"           => 19901,
                         "metrorail"               => 21663,
                         "metternich"              => 20227,
                         "meurthe"                 => 19393,
                         "meuse"                   => 10642,
                         "mewar"                   => 24060,
                         "mexican"                 => 1401,
                         "mexicana"                => 12309,
                         "meydan"                  => 29161,
                         "meyerbeer"               => 23862,
                         "meyrick"                 => 11434,
                         "mezzanine"               => 12847,
                         "mezzo"                   => 13479,
                         "mg/kg"                   => 15785,
                         "mi'kmaq"                 => 13056,
                         "miasto"                  => 24584,
                         "mice"                    => 4831,
                         "michaelmas"              => 25543,
                         "michelangelo"            => 9853,
                         "michiel"                 => 22719,
                         "michinoku"               => 29555,
                         "michoacan"               => 13921,
                         "mickiewicz"              => 22810,
                         "microarchitecture"       => 29241,
                         "microarray"              => 27572,
                         "microbes"                => 14217,
                         "microbial"               => 10360,
                         "microbiologist"          => 26724,
                         "microbiology"            => 11067,
                         "microcomputer"           => 22179,
                         "microcontroller"         => 23558,
                         "microcontrollers"        => 28202,
                         "microcosm"               => 24865,
                         "microelectronics"        => 24151,
                         "microfinance"            => 17356,
                         "microgravity"            => 22746,
                         "micrometer"              => 28947,
                         "micrometers"             => 23198,
                         "micrometres"             => 25182,
                         "micromollusk"            => 21698,
                         "micronesia"              => 13150,
                         "micronesian"             => 28003,
                         "microorganisms"          => 11487,
                         "microphones"             => 11500,
                         "micropolitan"            => 11517,
                         "microprocessor"          => 11565,
                         "microprocessors"         => 16972,
                         "microregion"             => 25600,
                         "microrna"                => 20442,
                         "microscopes"             => 20896,
                         "microscopic"             => 8975,
                         "microscopy"              => 9563,
                         "microstructure"          => 28518,
                         "microsystems"            => 15008,
                         "microtubule"             => 23007,
                         "microtubules"            => 21652,
                         "mid"                     => 531,
                         "midday"                  => 10324,
                         "middelburg"              => 23158,
                         "middens"                 => 25790,
                         "middle"                  => 455,
                         "middlebury"              => 15057,
                         "middlemen"               => 29310,
                         "middlesbrough"           => 7047,
                         "middlesex"               => 4825,
                         "middletown"              => 9749,
                         "middleware"              => 18146,
                         "middleweight"            => 6829,
                         "midfield"                => 7411,
                         "midfielder"              => 3108,
                         "midfielders"             => 18666,
                         "midhurst"                => 29707,
                         "midland"                 => 4248,
                         "midlands"                => 4787,
                         "midline"                 => 17497,
                         "midlothian"              => 12652,
                         "midpoint"                => 10601,
                         "midrash"                 => 12603,
                         "midrib"                  => 26547,
                         "midseason"               => 17189,
                         "midsection"              => 27343,
                         "midshipman"              => 11236,
                         "midshipmen"              => 13001,
                         "midsomer"                => 26499,
                         "midsummer"               => 10401,
                         "midtown"                 => 9233,
                         "midweek"                 => 20904,
                         "midwest"                 => 4881,
                         "midwestern"              => 9557,
                         "midwifery"               => 16886,
                         "midwinter"               => 26004,
                         "midwives"                => 15880,
                         "mieczyslaw"              => 22916,
                         "mieszko"                 => 17913,
                         "migrant"                 => 7584,
                         "migrants"                => 6147,
                         "migrate"                 => 7697,
                         "migrated"                => 4569,
                         "migrates"                => 23647,
                         "migrating"               => 9176,
                         "migration"               => 3170,
                         "migrations"              => 10762,
                         "migratory"               => 7316,
                         "mihai"                   => 15198,
                         "mihailovic"              => 19769,
                         "mihiel"                  => 29854,
                         "mihrab"                  => 29006,
                         "mikan"                   => 28262,
                         "mikawa"                  => 24647,
                         "mikhail"                 => 5185,
                         "mikhailovich"            => 18242,
                         "mikko"                   => 21483,
                         "miklos"                  => 14672,
                         "mikolaj"                 => 21126,
                         "mikoyan"                 => 22330,
                         "milanese"                => 15955,
                         "mild"                    => 4219,
                         "milder"                  => 14624,
                         "mildura"                 => 22656,
                         "mile"                    => 967,
                         "milecastle"              => 21696,
                         "milepost"                => 23230,
                         "milestone"               => 6920,
                         "milestones"              => 10367,
                         "miletus"                 => 23369,
                         "milhaud"                 => 24785,
                         "miliband"                => 18716,
                         "milieu"                  => 13243,
                         "militaire"               => 18710,
                         "militancy"               => 20229,
                         "militant"                => 6034,
                         "militants"               => 6637,
                         "militaries"              => 20435,
                         "militarily"              => 12331,
                         "militarism"              => 18487,
                         "militaristic"            => 21737,
                         "military"                => 257,
                         "militia"                 => 2943,
                         "militiamen"              => 14655,
                         "militias"                => 9107,
                         "militum"                 => 28382,
                         "mill"                    => 1409,
                         "millais"                 => 25845,
                         "millbrook"               => 21889,
                         "milled"                  => 19421,
                         "millennia"               => 11150,
                         "millennial"              => 20766,
                         "millennium"              => 3658,
                         "millimeters"             => 11038,
                         "millimetre"              => 28252,
                         "millimetres"             => 12914,
                         "milling"                 => 9313,
                         "million"                 => 251,
                         "millipedes"              => 28123,
                         "milliseconds"            => 18746,
                         "millstone"               => 20208,
                         "millstones"              => 24668,
                         "millville"               => 22428,
                         "milosevic"               => 11945,
                         "milwaukee"               => 3155,
                         "mimic"                   => 8589,
                         "mimicked"                => 21612,
                         "mimicking"               => 15175,
                         "mimicry"                 => 14800,
                         "mimics"                  => 14160,
                         "minaj"                   => 12292,
                         "minamoto"                => 16844,
                         "minangkabau"             => 24635,
                         "minaret"                 => 16113,
                         "minas"                   => 7719,
                         "minato"                  => 22501,
                         "minbari"                 => 28227,
                         "mindanao"                => 8301,
                         "mindedness"              => 24988,
                         "minden"                  => 10904,
                         "mindfulness"             => 19373,
                         "mindoro"                 => 17113,
                         "mined"                   => 7402,
                         "minefields"              => 17058,
                         "minehead"                => 26715,
                         "mineiro"                 => 19049,
                         "minelayer"               => 22767,
                         "mineola"                 => 28506,
                         "mineral"                 => 3413,
                         "mineralization"          => 28584,
                         "mineralogical"           => 25086,
                         "mineralogist"            => 25902,
                         "mineralogy"              => 15011,
                         "minerals"                => 4660,
                         "miners"                  => 4041,
                         "mines"                   => 2380,
                         "minesweeper"             => 11963,
                         "minesweepers"            => 15758,
                         "minesweeping"            => 16327,
                         "mingled"                 => 21921,
                         "minho"                   => 26841,
                         "mini"                    => 2683,
                         "miniature"               => 5407,
                         "miniatures"              => 9548,
                         "minibus"                 => 19724,
                         "minibuses"               => 25581,
                         "minigame"                => 27170,
                         "minigames"               => 21853,
                         "minima"                  => 18282,
                         "minimal"                 => 3712,
                         "minimalism"              => 17508,
                         "minimalist"              => 11431,
                         "minimalistic"            => 29766,
                         "minimally"               => 13695,
                         "minimise"                => 14291,
                         "minimization"            => 21369,
                         "minimize"                => 6754,
                         "minimized"               => 13942,
                         "minimizes"               => 17620,
                         "minimizing"              => 11955,
                         "minimum"                 => 2106,
                         "mining"                  => 1641,
                         "minis"                   => 28922,
                         "miniseries"              => 5469,
                         "minister"                => 394,
                         "ministered"              => 21694,
                         "ministerial"             => 6372,
                         "ministering"             => 26578,
                         "ministers"               => 2497,
                         "ministries"              => 5579,
                         "ministry"                => 942,
                         "minkowski"               => 16658,
                         "minneapolis"             => 4200,
                         "minnelli"                => 20633,
                         "minnesota"               => 1369,
                         "minnows"                 => 27035,
                         "minoan"                  => 16588,
                         "minogue"                 => 8934,
                         "minorca"                 => 21494,
                         "minorities"              => 5138,
                         "minority"                => 2341,
                         "minors"                  => 6877,
                         "minoru"                  => 17829,
                         "minos"                   => 21830,
                         "minot"                   => 15463,
                         "minsk"                   => 7618,
                         "minsky"                  => 24236,
                         "minster"                 => 11746,
                         "minstrels"               => 18549,
                         "minted"                  => 9903,
                         "minting"                 => 19610,
                         "minuet"                  => 25138,
                         "minuscule"               => 8310,
                         "minutely"                => 29430,
                         "minuteman"               => 18075,
                         "miocene"                 => 9795,
                         "miquelon"                => 28666,
                         "mirabeau"                => 26812,
                         "mirabilis"               => 21825,
                         "miraflores"              => 29887,
                         "miramichi"               => 22126,
                         "mired"                   => 22377,
                         "mirpur"                  => 23727,
                         "mirren"                  => 12592,
                         "mirrored"                => 10780,
                         "mirroring"               => 14923,
                         "mirza"                   => 6663,
                         "misadventures"           => 19349,
                         "misaki"                  => 23155,
                         "misamis"                 => 27902,
                         "misappropriation"        => 23387,
                         "miscegenation"           => 23328,
                         "miscellaneous"           => 8269,
                         "miscellany"              => 21366,
                         "misconduct"              => 8311,
                         "miserables"              => 15305,
                         "mises"                   => 21661,
                         "mishaps"                 => 20305,
                         "mishnah"                 => 14592,
                         "mishra"                  => 12719,
                         "misidentified"           => 20711,
                         "misiones"                => 24580,
                         "miskolc"                 => 24410,
                         "misleading"              => 7855,
                         "mismanagement"           => 12984,
                         "mismatch"                => 17022,
                         "misogyny"                => 26080,
                         "misrata"                 => 28318,
                         "misrepresentation"       => 17896,
                         "missa"                   => 17856,
                         "missal"                  => 17978,
                         "missile"                 => 2608,
                         "missiles"                => 4036,
                         "mission"                 => 670,
                         "missionaries"            => 4021,
                         "missionary"              => 3033,
                         "missions"                => 2005,
                         "mississauga"             => 11215,
                         "mississippi"             => 1772,
                         "mississippian"           => 14610,
                         "missoula"                => 13702,
                         "missouri"                => 1497,
                         "misspelling"             => 26517,
                         "mistakenly"              => 7206,
                         "mistico"                 => 26125,
                         "mistreatment"            => 14631,
                         "mists"                   => 23458,
                         "misuse"                  => 10315,
                         "misused"                 => 20517,
                         "mitchells"               => 28938,
                         "miters"                  => 29018,
                         "mites"                   => 13087,
                         "mitford"                 => 20144,
                         "mithila"                 => 27400,
                         "mithridates"             => 16391,
                         "mithun"                  => 20223,
                         "mitigate"                => 10473,
                         "mitigated"               => 17955,
                         "mitigation"              => 10463,
                         "mitochondria"            => 13026,
                         "mitochondrial"           => 8099,
                         "mitotic"                 => 21407,
                         "mitra"                   => 11573,
                         "mitral"                  => 22028,
                         "mitre"                   => 13665,
                         "mitrovica"               => 21113,
                         "mitsubishi"              => 7078,
                         "mitsui"                  => 20952,
                         "mittal"                  => 24731,
                         "mitte"                   => 19884,
                         "mitterrand"              => 16407,
                         "miwok"                   => 27168,
                         "mixed"                   => 1080,
                         "mixes"                   => 7349,
                         "mixing"                  => 4353,
                         "mixtape"                 => 6976,
                         "mixtapes"                => 16614,
                         "mixtec"                  => 24654,
                         "mixture"                 => 3085,
                         "mixtures"                => 11095,
                         "miyagi"                  => 15515,
                         "miyako"                  => 24619,
                         "miyan"                   => 25355,
                         "miyazaki"                => 12591,
                         "mizoram"                 => 14578,
                         "mizuki"                  => 21471,
                         "mlada"                   => 24477,
                         "mladen"                  => 22851,
                         "mladost"                 => 25731,
                         "mlawa"                   => 27495,
                         "mmorpg"                  => 19412,
                         "mnemonic"                => 17218,
                         "moana"                   => 24478,
                         "moated"                  => 25779,
                         "mobile"                  => 1364,
                         "mobiles"                 => 24023,
                         "mobilisation"            => 17502,
                         "mobilise"                => 27286,
                         "mobilised"               => 15787,
                         "mobility"                => 4707,
                         "mobilization"            => 8694,
                         "mobilized"               => 9038,
                         "mobutu"                  => 19106,
                         "moche"                   => 29970,
                         "mockumentary"            => 20326,
                         "modal"                   => 9810,
                         "modalities"              => 16386,
                         "modality"                => 17366,
                         "mode"                    => 1882,
                         "model"                   => 465,
                         "modele"                  => 26533,
                         "modeled"                 => 5129,
                         "modell"                  => 23884,
                         "modelled"                => 7682,
                         "modelling"               => 6751,
                         "models"                  => 1054,
                         "moderate"                => 2987,
                         "moderated"               => 12736,
                         "moderately"              => 6418,
                         "moderates"               => 16446,
                         "moderating"              => 24871,
                         "moderator"               => 10167,
                         "moderators"              => 23463,
                         "modern"                  => 354,
                         "moderna"                 => 21735,
                         "moderne"                 => 12730,
                         "modernisation"           => 11246,
                         "modernise"               => 21311,
                         "modernised"              => 13171,
                         "modernising"             => 27921,
                         "modernism"               => 8869,
                         "modernist"               => 6892,
                         "modernists"              => 22919,
                         "modernity"               => 10987,
                         "modernization"           => 6730,
                         "modernize"               => 12462,
                         "modernized"              => 9025,
                         "modernizing"             => 17400,
                         "modes"                   => 3989,
                         "modest"                  => 4177,
                         "modestly"                => 15961,
                         "modification"            => 4963,
                         "modifications"           => 4349,
                         "modified"                => 2020,
                         "modifier"                => 19492,
                         "modifiers"               => 20718,
                         "modifies"                => 18534,
                         "modify"                  => 7009,
                         "modifying"               => 9484,
                         "modigliani"              => 25825,
                         "modoc"                   => 19131,
                         "modular"                 => 6582,
                         "modularity"              => 26255,
                         "modulate"                => 19169,
                         "modulated"               => 14009,
                         "modulates"               => 27789,
                         "modulating"              => 22305,
                         "modulation"              => 8229,
                         "modulator"               => 20156,
                         "module"                  => 4038,
                         "modules"                 => 4888,
                         "moduli"                  => 24802,
                         "modulo"                  => 14339,
                         "modulus"                 => 13964,
                         "moesia"                  => 24447,
                         "mogadishu"               => 11629,
                         "mogilev"                 => 29562,
                         "mohamad"                 => 19406,
                         "mohammadabad"            => 16590,
                         "mohammedan"              => 28329,
                         "mohandas"                => 23358,
                         "mohanlal"                => 17306,
                         "mohave"                  => 19794,
                         "mohawks"                 => 25618,
                         "mohegan"                 => 22295,
                         "mohini"                  => 25015,
                         "mohsen"                  => 20565,
                         "mohun"                   => 16640,
                         "moiety"                  => 18715,
                         "moines"                  => 8140,
                         "moist"                   => 4228,
                         "moisture"                => 6412,
                         "moksha"                  => 20225,
                         "molar"                   => 11724,
                         "moldavia"                => 11124,
                         "moldavian"               => 13241,
                         "molde"                   => 15824,
                         "molded"                  => 11370,
                         "molding"                 => 12780,
                         "moldova"                 => 6030,
                         "moldovan"                => 10351,
                         "molds"                   => 13476,
                         "molecular"               => 2878,
                         "molecule"                => 4886,
                         "molecules"               => 3833,
                         "molesworth"              => 23398,
                         "moliere"                 => 15807,
                         "molise"                  => 25240,
                         "molla"                   => 16939,
                         "mollusc"                 => 13294,
                         "molluscs"                => 10625,
                         "mollusk"                 => 4050,
                         "mollusks"                => 8809,
                         "molten"                  => 10566,
                         "moltke"                  => 17495,
                         "moluccas"                => 24880,
                         "molybdenum"              => 14398,
                         "mombasa"                 => 15317,
                         "momentum"                => 4384,
                         "mommsen"                 => 26765,
                         "monadnock"               => 27110,
                         "monarchical"             => 22838,
                         "monarchies"              => 16965,
                         "monarchist"              => 15233,
                         "monarchists"             => 24617,
                         "monarchs"                => 6490,
                         "monarchy"                => 4030,
                         "monash"                  => 11875,
                         "monasteries"             => 5320,
                         "monastery"               => 1995,
                         "monastic"                => 5812,
                         "monasticism"             => 20385,
                         "monchengladbach"         => 15486,
                         "monck"                   => 21191,
                         "monckton"                => 21782,
                         "moncton"                 => 12343,
                         "mondale"                 => 19628,
                         "mondays"                 => 9751,
                         "monde"                   => 10346,
                         "mondrian"                => 27481,
                         "monegasque"              => 27329,
                         "monetary"                => 4351,
                         "monferrato"              => 28888,
                         "mongol"                  => 5944,
                         "mongolia"                => 4970,
                         "mongolian"               => 6570,
                         "mongols"                 => 7493,
                         "moniker"                 => 7393,
                         "monitored"               => 6778,
                         "monitoring"              => 3311,
                         "monkees"                 => 15638,
                         "monks"                   => 3553,
                         "monkton"                 => 27817,
                         "monmouth"                => 6803,
                         "monmouthshire"           => 11544,
                         "monnaie"                 => 29722,
                         "monoamine"               => 23708,
                         "monochromatic"           => 19482,
                         "monochrome"              => 13042,
                         "monoclonal"              => 17705,
                         "monocoque"               => 17417,
                         "monogatari"              => 20874,
                         "monogram"                => 15937,
                         "monograph"               => 8968,
                         "monographs"              => 10767,
                         "monoid"                  => 22653,
                         "monolingual"             => 26808,
                         "monolithic"              => 14762,
                         "monologues"              => 14497,
                         "monomer"                 => 17308,
                         "monomers"                => 18991,
                         "monongahela"             => 16705,
                         "monooxygenase"           => 26604,
                         "monophyletic"            => 15533,
                         "monoplane"               => 9624,
                         "monopolies"              => 14341,
                         "monopolistic"            => 28771,
                         "monorail"                => 11736,
                         "monotheism"              => 22496,
                         "monotheistic"            => 22452,
                         "monotone"                => 21108,
                         "monotype"                => 27176,
                         "monotypic"               => 9730,
                         "monoxide"                => 11367,
                         "monro"                   => 18844,
                         "monrovia"                => 16228,
                         "monsanto"                => 15272,
                         "monsignor"               => 12547,
                         "monsoons"                => 24499,
                         "montage"                 => 11132,
                         "montagu"                 => 9650,
                         "montaigne"               => 24851,
                         "montalban"               => 27429,
                         "montane"                 => 6857,
                         "montauban"               => 23123,
                         "montbeliard"             => 28362,
                         "montcalm"                => 23887,
                         "montclair"               => 13204,
                         "montebello"              => 20920,
                         "montefiore"              => 22850,
                         "montenegrin"             => 8653,
                         "montenegrins"            => 26146,
                         "monterrey"               => 8854,
                         "montesquieu"             => 30000,
                         "montessori"              => 12968,
                         "monteverdi"              => 18031,
                         "montevideo"              => 7846,
                         "montezuma"               => 17731,
                         "montferrat"              => 22964,
                         "montfort"                => 11505,
                         "montgomerie"             => 18276,
                         "montgomeryshire"         => 21677,
                         "month"                   => 712,
                         "monthan"                 => 27396,
                         "monthly"                 => 2347,
                         "months"                  => 451,
                         "monticello"              => 12079,
                         "montmartre"              => 18193,
                         "montmorency"             => 17134,
                         "montparnasse"            => 21179,
                         "montpelier"              => 16094,
                         "montpellier"             => 10054,
                         "montreux"                => 14263,
                         "montserrat"              => 12357,
                         "montt"                   => 23389,
                         "monument"                => 2029,
                         "monumental"              => 5896,
                         "monuments"               => 3500,
                         "monza"                   => 11056,
                         "moonstone"               => 23196,
                         "moorcock"                => 24451,
                         "moored"                  => 11400,
                         "moorings"                => 19676,
                         "moorish"                 => 11031,
                         "moorland"                => 16060,
                         "mooted"                  => 20087,
                         "moradabad"               => 24963,
                         "moraes"                  => 22168,
                         "morag"                   => 26726,
                         "moraine"                 => 12627,
                         "moraines"                => 23772,
                         "morale"                  => 7022,
                         "morane"                  => 29937,
                         "morava"                  => 19773,
                         "moravia"                 => 9554,
                         "moravian"                => 8847,
                         "moray"                   => 9350,
                         "morazan"                 => 25546,
                         "morbidity"               => 18340,
                         "morbihan"                => 27768,
                         "morcha"                  => 28906,
                         "mordaunt"                => 22320,
                         "mordechai"               => 15826,
                         "mordella"                => 15007,
                         "mordellidae"             => 15399,
                         "mordellistena"           => 11043,
                         "more"                    => 45,
                         "morecambe"               => 12378,
                         "moreover"                => 3302,
                         "moresby"                 => 13572,
                         "moreton"                 => 10788,
                         "morganatic"              => 28285,
                         "morgantown"              => 18156,
                         "morgenthau"              => 22075,
                         "moribund"                => 21911,
                         "mormon"                  => 5417,
                         "mormonism"               => 17539,
                         "mormons"                 => 11279,
                         "morne"                   => 29242,
                         "morningside"             => 15969,
                         "mornington"              => 17546,
                         "moroccan"                => 6299,
                         "moroccans"               => 26859,
                         "morocco"                 => 3560,
                         "moroder"                 => 24976,
                         "morotai"                 => 25990,
                         "morpeth"                 => 22493,
                         "morpheme"                => 21135,
                         "morphemes"               => 20012,
                         "morphism"                => 17382,
                         "morphisms"               => 19110,
                         "morphological"           => 8049,
                         "morphologically"         => 16739,
                         "morphology"              => 6182,
                         "morphs"                  => 20314,
                         "morphy"                  => 29552,
                         "morricone"               => 21659,
                         "morrisons"               => 25202,
                         "morristown"              => 13872,
                         "morsi"                   => 17418,
                         "mortality"               => 5076,
                         "mortally"                => 9049,
                         "mortar"                  => 5716,
                         "mortars"                 => 9454,
                         "morte"                   => 18159,
                         "mortgages"               => 11314,
                         "mortlake"                => 28247,
                         "mosaic"                  => 6197,
                         "mosaics"                 => 10840,
                         "moselle"                 => 9569,
                         "moshav"                  => 18214,
                         "moshi"                   => 28734,
                         "moslem"                  => 25276,
                         "mosque"                  => 3057,
                         "mosques"                 => 7312,
                         "mosses"                  => 15207,
                         "mossy"                   => 23875,
                         "most"                    => 51,
                         "mostar"                  => 15223,
                         "mostly"                  => 716,
                         "mosul"                   => 11631,
                         "motagua"                 => 28582,
                         "motet"                   => 22316,
                         "motets"                  => 18903,
                         "moth"                    => 1708,
                         "mothballed"              => 25645,
                         "motherboard"             => 15651,
                         "motherboards"            => 24024,
                         "motherhouse"             => 29451,
                         "motherland"              => 15413,
                         "motherwell"              => 10339,
                         "moths"                   => 4542,
                         "motif"                   => 5972,
                         "motifs"                  => 6246,
                         "motile"                  => 19089,
                         "motion"                  => 1471,
                         "motionless"              => 18590,
                         "motivating"              => 16222,
                         "motivational"            => 10923,
                         "motivations"             => 10179,
                         "motogp"                  => 16672,
                         "motor"                   => 1506,
                         "motorbikes"              => 27920,
                         "motorboat"               => 22451,
                         "motorcycles"             => 6633,
                         "motorcycling"            => 25751,
                         "motorcyclist"            => 24210,
                         "motorcyclists"           => 26142,
                         "motoring"                => 14553,
                         "motorised"               => 15139,
                         "motorist"                => 20230,
                         "motorists"               => 10991,
                         "motorized"               => 9508,
                         "motors"                  => 3358,
                         "motorsport"              => 7013,
                         "motorsports"             => 7029,
                         "motorway"                => 4439,
                         "motorways"               => 12566,
                         "motte"                   => 11402,
                         "mottled"                 => 13974,
                         "motto"                   => 4287,
                         "mould"                   => 11076,
                         "moulded"                 => 13309,
                         "moulding"                => 17655,
                         "mouldings"               => 22444,
                         "moult"                   => 23882,
                         "mound"                   => 4877,
                         "mounds"                  => 7340,
                         "mount"                   => 989,
                         "mountaineering"          => 10879,
                         "mountaineers"            => 10790,
                         "mountainous"             => 5211,
                         "mountains"               => 1075,
                         "mountbatten"             => 15171,
                         "mounted"                 => 1868,
                         "mounting"                => 6315,
                         "mountings"               => 20513,
                         "mourinho"                => 20685,
                         "mourners"                => 15516,
                         "mousavi"                 => 28989,
                         "mouthparts"              => 14355,
                         "mouvement"               => 22989,
                         "movable"                 => 10471,
                         "moveable"                => 18847,
                         "moved"                   => 243,
                         "movement"                => 496,
                         "movements"               => 2062,
                         "movimiento"              => 26211,
                         "mowat"                   => 23281,
                         "mowtowr"                 => 12142,
                         "moyne"                   => 21516,
                         "mozambican"              => 20816,
                         "mozambique"              => 5843,
                         "mpumalanga"              => 18822,
                         "mrnas"                   => 28062,
                         "mrs."                    => 2354,
                         "msnbc"                   => 11220,
                         "mstislav"                => 22308,
                         "mtdna"                   => 15069,
                         "muammar"                 => 18440,
                         "muang"                   => 22251,
                         "muawiyah"                => 28036,
                         "muban"                   => 21670,
                         "mubarak"                 => 10321,
                         "muchmusic"               => 15890,
                         "mucosa"                  => 17617,
                         "mucosal"                 => 24786,
                         "mudaliar"                => 25617,
                         "mudflats"                => 22657,
                         "mudslides"               => 24846,
                         "mudstone"                => 22694,
                         "mueang"                  => 13116,
                         "mufti"                   => 13820,
                         "mugabe"                  => 13660,
                         "mughal"                  => 5994,
                         "mughals"                 => 13594,
                         "muhammad"                => 2368,
                         "muhammed"                => 13295,
                         "muharram"                => 27753,
                         "muhlenberg"              => 16616,
                         "mujahideen"              => 13938,
                         "mujer"                   => 17614,
                         "mujib"                   => 28607,
                         "mujibur"                 => 29678,
                         "mukherjee"               => 10784,
                         "mukhtar"                 => 21932,
                         "mukti"                   => 22509,
                         "mulatto"                 => 20164,
                         "mules"                   => 12002,
                         "mulhouse"                => 20358,
                         "mulla"                   => 22317,
                         "mullah"                  => 19651,
                         "mullingar"               => 25302,
                         "mullioned"               => 29981,
                         "multan"                  => 12642,
                         "multi"                   => 1333,
                         "multicast"               => 18172,
                         "multicellular"           => 21570,
                         "multichannel"            => 25313,
                         "multicolored"            => 26700,
                         "multicultural"           => 9123,
                         "multiculturalism"        => 15196,
                         "multidimensional"        => 17439,
                         "multidisciplinary"       => 10299,
                         "multifaceted"            => 20082,
                         "multifunctional"         => 26935,
                         "multilateral"            => 12120,
                         "multilevel"              => 29040,
                         "multilingual"            => 13650,
                         "multimedia"              => 5369,
                         "multimodal"              => 26677,
                         "multinational"           => 7053,
                         "multiparty"              => 25734,
                         "multiplayer"             => 6856,
                         "multiple"                => 904,
                         "multiples"               => 14187,
                         "multiplex"               => 11341,
                         "multiplexed"             => 16879,
                         "multiplexes"             => 23239,
                         "multiplexing"            => 20903,
                         "multiplication"          => 8139,
                         "multiplicative"          => 17051,
                         "multiplicity"            => 15415,
                         "multiplied"              => 9733,
                         "multiplier"              => 13604,
                         "multipliers"             => 28093,
                         "multiplying"             => 13467,
                         "multipurpose"            => 12348,
                         "multiracial"             => 19550,
                         "multitude"               => 8185,
                         "multivariate"            => 17618,
                         "multiverse"              => 15149,
                         "multnomah"               => 19147,
                         "mumbai"                  => 3189,
                         "mumtaz"                  => 20841,
                         "munchen"                 => 12419,
                         "munda"                   => 21208,
                         "mundi"                   => 14899,
                         "mundial"                 => 16227,
                         "munich"                  => 2673,
                         "municipal"               => 1154,
                         "municipalities"          => 2304,
                         "municipality"            => 524,
                         "municipally"             => 22683,
                         "municipio"               => 29687,
                         "munir"                   => 20889,
                         "munition"                => 22815,
                         "munitions"               => 7472,
                         "munna"                   => 28447,
                         "munnetra"                => 17491,
                         "munshi"                  => 25940,
                         "munster"                 => 4242,
                         "murad"                   => 11686,
                         "murali"                  => 18795,
                         "muralist"                => 26093,
                         "murals"                  => 6761,
                         "murcia"                  => 12048,
                         "mures"                   => 15940,
                         "murex"                   => 15101,
                         "murfreesboro"            => 17592,
                         "muricidae"               => 17042,
                         "muridae"                 => 29303,
                         "murnau"                  => 29682,
                         "muromachi"               => 25259,
                         "murong"                  => 12298,
                         "murrayfield"             => 28127,
                         "murrumbidgee"            => 25095,
                         "murshidabad"             => 24729,
                         "muruga"                  => 29826,
                         "murugan"                 => 19115,
                         "muscat"                  => 12109,
                         "muscatine"               => 29977,
                         "muscogee"                => 23146,
                         "muscovite"               => 21538,
                         "muscovy"                 => 21162,
                         "muscular"                => 7665,
                         "musculature"             => 27602,
                         "musculoskeletal"         => 23496,
                         "musee"                   => 8154,
                         "museo"                   => 8336,
                         "museu"                   => 21401,
                         "museum"                  => 402,
                         "museums"                 => 3313,
                         "museveni"                => 23695,
                         "musharraf"               => 13994,
                         "music"                   => 110,
                         "musical"                 => 626,
                         "musicale"                => 20451,
                         "musicality"              => 25801,
                         "musically"               => 7271,
                         "musicals"                => 6614,
                         "musician"                => 1687,
                         "musicians"               => 1629,
                         "musicianship"            => 16781,
                         "musicologist"            => 11298,
                         "musicologists"           => 29457,
                         "musicology"              => 15430,
                         "musicomh"                => 27665,
                         "musik"                   => 11058,
                         "musings"                 => 26716,
                         "musique"                 => 10314,
                         "muskegon"                => 16206,
                         "muskets"                 => 13901,
                         "muskingum"               => 24413,
                         "muskogee"                => 19102,
                         "muskoka"                 => 23502,
                         "muslim"                  => 1483,
                         "muslims"                 => 2479,
                         "mussel"                  => 15285,
                         "musselburgh"             => 27289,
                         "mussels"                 => 14353,
                         "mussolini"               => 7512,
                         "mussorgsky"              => 23399,
                         "mustapha"                => 20842,
                         "mustered"                => 8027,
                         "mustering"               => 29225,
                         "musume"                  => 19569,
                         "mutagenesis"             => 24573,
                         "mutation"                => 6021,
                         "mutations"               => 5408,
                         "mutineers"               => 16571,
                         "mutinied"                => 21107,
                         "mutiny"                  => 6908,
                         "mutsu"                   => 26597,
                         "mutualism"               => 29308,
                         "mutually"                => 7253,
                         "muzaffar"                => 22876,
                         "muzaffarpur"             => 29403,
                         "muzik"                   => 21282,
                         "muzzle"                  => 7920,
                         "mv/pi"                   => 27324,
                         "myanmar"                 => 5250,
                         "mycelium"                => 25604,
                         "mycenaean"               => 17566,
                         "mycobacterium"           => 19742,
                         "mycologist"              => 15805,
                         "mycorrhizal"             => 25252,
                         "myelin"                  => 23608,
                         "myeloid"                 => 24779,
                         "myeloma"                 => 23023,
                         "myeon"                   => 24682,
                         "mykola"                  => 19207,
                         "mykolaiv"                => 26608,
                         "mymensingh"              => 26133,
                         "mynetworktv"             => 14463,
                         "mynydd"                  => 25564,
                         "myocardial"              => 15023,
                         "myosin"                  => 22548,
                         "myotis"                  => 27983,
                         "myriad"                  => 10038,
                         "myrrh"                   => 27182,
                         "myrtaceae"               => 20683,
                         "mysims"                  => 25953,
                         "mysore"                  => 7180,
                         "mysql"                   => 17440,
                         "mysticism"               => 10378,
                         "mystics"                 => 15408,
                         "myth"                    => 4302,
                         "mythbusters"             => 27809,
                         "mythical"                => 7261,
                         "mythological"            => 7422,
                         "mythologies"             => 21397,
                         "mythology"               => 3601,
                         "myths"                   => 6551,
                         "n't"                     => 300,
                         "n.w.a"                   => 28356,
                         "naacp"                   => 8902,
                         "nabil"                   => 21791,
                         "nablus"                  => 15031,
                         "nacelle"                 => 25832,
                         "nacelles"                => 27934,
                         "nacht"                   => 23678,
                         "nacion"                  => 23877,
                         "nacional"                => 4159,
                         "nacionalista"            => 28456,
                         "nacogdoches"             => 25350,
                         "nadal"                   => 10053,
                         "nadar"                   => 24107,
                         "nadeem"                  => 24968,
                         "nadir"                   => 13399,
                         "nadp+"                   => 18554,
                         "nadph"                   => 17831,
                         "nadu"                    => 3641,
                         "nagaland"                => 15907,
                         "nagano"                  => 10791,
                         "nagapattinam"            => 29460,
                         "nagar"                   => 6003,
                         "nagara"                  => 27020,
                         "nagarjuna"               => 19284,
                         "nagas"                   => 23292,
                         "nagasaki"                => 9043,
                         "nagercoil"               => 26842,
                         "nagorno"                 => 12165,
                         "nagoya"                  => 8992,
                         "nagpur"                  => 9796,
                         "nahal"                   => 26748,
                         "nahuatl"                 => 12828,
                         "nahum"                   => 26152,
                         "nahyan"                  => 26839,
                         "naidu"                   => 13864,
                         "nainital"                => 29500,
                         "nairn"                   => 18741,
                         "nairobi"                 => 7718,
                         "naismith"                => 15763,
                         "naive"                   => 7891,
                         "najaf"                   => 18567,
                         "najib"                   => 17704,
                         "nakajima"                => 12901,
                         "nakhchivan"              => 20015,
                         "nakhon"                  => 12676,
                         "naklo"                   => 29491,
                         "nalanda"                 => 19448,
                         "nalgonda"                => 23612,
                         "nambiar"                 => 25017,
                         "nambu"                   => 28215,
                         "namco"                   => 11846,
                         "name"                    => 106,
                         "named"                   => 166,
                         "namely"                  => 2863,
                         "nameplate"               => 16566,
                         "names"                   => 717,
                         "namesake"                => 6056,
                         "namesakes"               => 24828,
                         "namespace"               => 26626,
                         "namgyal"                 => 23984,
                         "namibia"                 => 5559,
                         "namibian"                => 13065,
                         "naming"                  => 3377,
                         "namor"                   => 21961,
                         "namur"                   => 13239,
                         "nanaimo"                 => 17112,
                         "nanak"                   => 16420,
                         "nanchang"                => 21981,
                         "nanda"                   => 13880,
                         "nanded"                  => 26377,
                         "nandi"                   => 13791,
                         "nandini"                 => 22596,
                         "nanjing"                 => 7441,
                         "nankai"                  => 25610,
                         "nanking"                 => 15343,
                         "nanna"                   => 27969,
                         "nanometer"               => 29921,
                         "nanometers"              => 25211,
                         "nanoparticles"           => 14560,
                         "nanoscale"               => 21936,
                         "nanotechnology"          => 11395,
                         "nanotubes"               => 17642,
                         "nansen"                  => 17758,
                         "nantes"                  => 9113,
                         "nanticoke"               => 29506,
                         "nantwich"                => 17977,
                         "nanyang"                 => 17536,
                         "naoki"                   => 22574,
                         "naoko"                   => 28960,
                         "naperville"              => 25300,
                         "naples"                  => 3726,
                         "napoca"                  => 19094,
                         "napoleonic"              => 6141,
                         "narada"                  => 20137,
                         "narain"                  => 21450,
                         "narasimha"               => 14724,
                         "narayan"                 => 8778,
                         "narayana"                => 11328,
                         "narayani"                => 27278,
                         "narbonne"                => 17847,
                         "narcissus"               => 16881,
                         "narendra"                => 13700,
                         "nares"                   => 29065,
                         "nargis"                  => 28899,
                         "narita"                  => 19404,
                         "narmada"                 => 20643,
                         "narragansett"            => 14865,
                         "narrate"                 => 22153,
                         "narrated"                => 6397,
                         "narrates"                => 11577,
                         "narrating"               => 18578,
                         "narration"               => 7753,
                         "narrations"              => 28441,
                         "narrative"               => 2922,
                         "narratives"              => 8006,
                         "narrator"                => 4558,
                         "narrators"               => 22338,
                         "narrow"                  => 1933,
                         "narrower"                => 8263,
                         "narrowest"               => 17564,
                         "narrowing"               => 13589,
                         "narrowly"                => 4306,
                         "narthex"                 => 22997,
                         "narva"                   => 16892,
                         "narvik"                  => 17002,
                         "nasa"                    => 3398,
                         "nasals"                  => 28686,
                         "nascent"                 => 10250,
                         "nashik"                  => 21030,
                         "nashville"               => 3041,
                         "nasional"                => 17180,
                         "nasir"                   => 10279,
                         "nassau"                  => 5332,
                         "natak"                   => 21909,
                         "natan"                   => 28919,
                         "natchitoches"            => 18163,
                         "natick"                  => 24019,
                         "nation"                  => 903,
                         "national"                => 63,
                         "nationale"               => 6618,
                         "nationalisation"         => 12092,
                         "nationalised"            => 13191,
                         "nationalism"             => 5120,
                         "nationalist"             => 3001,
                         "nationalistic"           => 12272,
                         "nationalists"            => 6040,
                         "nationalities"           => 8120,
                         "nationality"             => 5441,
                         "nationalization"         => 14550,
                         "nationalized"            => 12099,
                         "nationalliga"            => 24972,
                         "nationally"              => 3159,
                         "nationals"               => 3877,
                         "nations"                 => 828,
                         "nationwide"              => 3074,
                         "native"                  => 521,
                         "natively"                => 15885,
                         "natives"                 => 4484,
                         "nativity"                => 10641,
                         "nato"                    => 3555,
                         "natsume"                 => 29168,
                         "naturae"                 => 29951,
                         "natural"                 => 551,
                         "naturalisation"          => 29553,
                         "naturalised"             => 16492,
                         "naturalism"              => 14274,
                         "naturalist"              => 7071,
                         "naturalistic"            => 12528,
                         "naturalists"             => 14382,
                         "naturalization"          => 14440,
                         "naturalized"             => 9172,
                         "nature"                  => 735,
                         "naturelle"               => 22721,
                         "natures"                 => 19940,
                         "naumburg"                => 28776,
                         "nauru"                   => 12413,
                         "nautical"                => 6282,
                         "nauvoo"                  => 15609,
                         "naval"                   => 957,
                         "navarre"                 => 7772,
                         "navarrese"               => 22348,
                         "navies"                  => 11794,
                         "navigable"               => 8811,
                         "navigated"               => 21056,
                         "navigation"              => 3209,
                         "navigational"            => 10684,
                         "navigators"              => 15829,
                         "navratilova"             => 19707,
                         "navy"                    => 594,
                         "nawab"                   => 8679,
                         "nawaz"                   => 14037,
                         "naxos"                   => 14730,
                         "nayak"                   => 16324,
                         "nayaka"                  => 26400,
                         "nayanar"                 => 21996,
                         "nayarit"                 => 25695,
                         "nazar"                   => 21561,
                         "nazarbayev"              => 28551,
                         "nazarene"                => 12041,
                         "nazca"                   => 27325,
                         "nazi"                    => 2026,
                         "nazim"                   => 20610,
                         "nazionale"               => 12715,
                         "nazir"                   => 15312,
                         "nazis"                   => 4681,
                         "nazism"                  => 10917,
                         "nazrul"                  => 27437,
                         "nbcuniversal"            => 22961,
                         "ncaa"                    => 1678,
                         "ndebele"                 => 26348,
                         "neamt"                   => 26868,
                         "neapolitan"              => 11360,
                         "near"                    => 233,
                         "nearby"                  => 847,
                         "neared"                  => 15183,
                         "nearest"                 => 3160,
                         "nearly"                  => 796,
                         "nears"                   => 26145,
                         "neath"                   => 13748,
                         "nebria"                  => 24514,
                         "nebuchadnezzar"          => 23975,
                         "nebulae"                 => 21321,
                         "necaxa"                  => 29666,
                         "necessitate"             => 23295,
                         "necessitated"            => 9466,
                         "necessitates"            => 25129,
                         "necessitating"           => 14685,
                         "necessities"             => 13613,
                         "necessity"               => 5412,
                         "neckar"                  => 14642,
                         "necked"                  => 11020,
                         "necropolis"              => 12346,
                         "necrotic"                => 27384,
                         "nectar"                  => 7137,
                         "nederlandse"             => 19759,
                         "needlework"              => 25299,
                         "negara"                  => 19125,
                         "negated"                 => 18510,
                         "negating"                => 26369,
                         "negation"                => 13394,
                         "negative"                => 1536,
                         "negatively"              => 7256,
                         "negeri"                  => 15189,
                         "negev"                   => 13525,
                         "neglect"                 => 7189,
                         "neglects"                => 27436,
                         "negligible"              => 10313,
                         "negotiated"              => 4863,
                         "negotiates"              => 27482,
                         "negotiations"            => 2587,
                         "negotiators"             => 18445,
                         "negro"                   => 4818,
                         "negros"                  => 12368,
                         "nehemiah"                => 18024,
                         "nehru"                   => 7957,
                         "neighborhood"            => 1611,
                         "neighborhoods"           => 3880,
                         "neighboring"             => 2918,
                         "neighbourhood"           => 3860,
                         "neighbourhoods"          => 8323,
                         "neighbouring"            => 2984,
                         "neighbours"              => 5252,
                         "neisse"                  => 23749,
                         "nellore"                 => 22549,
                         "nelvana"                 => 29178,
                         "nemanja"                 => 21023,
                         "nematode"                => 16306,
                         "nematodes"               => 17154,
                         "nemours"                 => 26381,
                         "nemzeti"                 => 21560,
                         "nenad"                   => 17796,
                         "neoclassical"            => 7800,
                         "neoclassicism"           => 22975,
                         "neocollyris"             => 25216,
                         "neogene"                 => 23069,
                         "neoliberal"              => 22137,
                         "neoliberalism"           => 29900,
                         "neolithic"               => 6496,
                         "neologism"               => 24268,
                         "neoregelia"              => 23905,
                         "neosho"                  => 28174,
                         "neotropical"             => 17135,
                         "nepal"                   => 2730,
                         "nepalese"                => 9756,
                         "nepali"                  => 9369,
                         "nepean"                  => 16262,
                         "nepenthes"               => 13735,
                         "nephews"                 => 10806,
                         "nephi"                   => 24080,
                         "nephrology"              => 29282,
                         "nepomuk"                 => 24666,
                         "nepticulidae"            => 25377,
                         "neptunes"                => 23961,
                         "neretva"                 => 23770,
                         "nest"                    => 2953,
                         "nested"                  => 12632,
                         "nesting"                 => 7208,
                         "nestlings"               => 25783,
                         "nestorian"               => 19968,
                         "nests"                   => 5316,
                         "netaji"                  => 26771,
                         "netanya"                 => 20122,
                         "netanyahu"               => 13529,
                         "netball"                 => 8342,
                         "netflix"                 => 11814,
                         "netherlandish"           => 23964,
                         "netherlands"             => 1269,
                         "netted"                  => 9925,
                         "netting"                 => 10022,
                         "network"                 => 424,
                         "networked"               => 11089,
                         "networking"              => 4732,
                         "networks"                => 1880,
                         "neuburg"                 => 25957,
                         "neuchatel"               => 14790,
                         "neues"                   => 27822,
                         "neuilly"                 => 20422,
                         "neuquen"                 => 25652,
                         "neural"                  => 5814,
                         "neurobiology"            => 22470,
                         "neurodegenerative"       => 20775,
                         "neuroimaging"            => 21644,
                         "neurologic"              => 27756,
                         "neurology"               => 11476,
                         "neuromuscular"           => 18948,
                         "neuronal"                => 10881,
                         "neurons"                 => 5575,
                         "neuropsychological"      => 28761,
                         "neuroscience"            => 8398,
                         "neuroscientist"          => 23790,
                         "neurotransmitter"        => 14983,
                         "neurotransmitters"       => 18260,
                         "neustadt"                => 12498,
                         "neuter"                  => 12454,
                         "neutral"                 => 3351,
                         "neutrality"              => 7270,
                         "neutralization"          => 26571,
                         "neutralizing"            => 24130,
                         "neutrinos"               => 16830,
                         "neutrons"                => 10136,
                         "neutrophils"             => 24258,
                         "neuve"                   => 27525,
                         "neuville"                => 25870,
                         "nevertheless"            => 2213,
                         "nevis"                   => 11115,
                         "nevsky"                  => 19424,
                         "new"                     => 31,
                         "newar"                   => 29082,
                         "newbery"                 => 17056,
                         "newbridge"               => 21003,
                         "newburyport"             => 24166,
                         "newcastle"               => 2742,
                         "newcomers"               => 8941,
                         "newer"                   => 3838,
                         "newfoundland"            => 3885,
                         "newgate"                 => 20288,
                         "newham"                  => 18929,
                         "newington"               => 12513,
                         "newlands"                => 19261,
                         "newly"                   => 1177,
                         "newlyn"                  => 28720,
                         "newmarket"               => 7813,
                         "newnham"                 => 19829,
                         "newquay"                 => 24636,
                         "newry"                   => 15597,
                         "news/talk"               => 17686,
                         "newscast"                => 6713,
                         "newscasts"               => 7511,
                         "newsday"                 => 16457,
                         "newsgroup"               => 26813,
                         "newsletter"              => 6413,
                         "newsletters"             => 15834,
                         "newsmagazine"            => 22276,
                         "newsnight"               => 22122,
                         "newspaper"               => 889,
                         "newspapers"              => 1999,
                         "newsreader"              => 19376,
                         "newsreel"                => 17971,
                         "newsreels"               => 26405,
                         "newstead"                => 27876,
                         "newsweek"                => 8602,
                         "newtonian"               => 15308,
                         "newtown"                 => 8547,
                         "newts"                   => 26043,
                         "nexstar"                 => 27365,
                         "ngati"                   => 12561,
                         "nguesso"                 => 29208,
                         "nhtsa"                   => 25948,
                         "niagara"                 => 5529,
                         "niall"                   => 11808,
                         "niamey"                  => 28670,
                         "niazi"                   => 29538,
                         "nicaea"                  => 15027,
                         "nicaragua"               => 5530,
                         "nicaraguan"              => 11315,
                         "niccolo"                 => 12909,
                         "nicene"                  => 19265,
                         "niche"                   => 6472,
                         "niches"                  => 10815,
                         "nichiren"                => 20019,
                         "nickelback"              => 26329,
                         "nickelodeon"             => 6988,
                         "nickname"                => 2809,
                         "nicknamed"               => 3363,
                         "nicobar"                 => 16333,
                         "nicolae"                 => 11304,
                         "nicolau"                 => 29582,
                         "nicolaus"                => 17258,
                         "nicolet"                 => 27146,
                         "nicotinic"               => 28545,
                         "nidaros"                 => 23840,
                         "niels"                   => 11088,
                         "nietzsche"               => 9411,
                         "nieuport"                => 18674,
                         "nieuw"                   => 24272,
                         "nieuwe"                  => 23260,
                         "nievre"                  => 29869,
                         "nigam"                   => 26013,
                         "niger"                   => 5831,
                         "nigeria"                 => 2633,
                         "nigerian"                => 4491,
                         "nigerians"               => 22271,
                         "nigerien"                => 23497,
                         "nightclubs"              => 10578,
                         "nighthawks"              => 21352,
                         "nightjar"                => 28353,
                         "nightjars"               => 27264,
                         "nightlife"               => 12830,
                         "nightly"                 => 8540,
                         "nigra"                   => 17004,
                         "nihilism"                => 23459,
                         "nihon"                   => 13672,
                         "niigata"                 => 13339,
                         "nijinsky"                => 27338,
                         "nijmegen"                => 13746,
                         "nikaya"                  => 24787,
                         "nikephoros"              => 17799,
                         "nikkatsu"                => 24599,
                         "nikolaevich"             => 26024,
                         "nikolaos"                => 18779,
                         "nikolayevich"            => 19374,
                         "nikos"                   => 13697,
                         "niksic"                  => 25887,
                         "nile"                    => 5710,
                         "nilgiri"                 => 23739,
                         "nilgiris"                => 29498,
                         "nimes"                   => 17827,
                         "nimoy"                   => 22502,
                         "nine"                    => 672,
                         "nineteenth"              => 3194,
                         "nineveh"                 => 20315,
                         "ningbo"                  => 17543,
                         "ningxia"                 => 23865,
                         "ninian"                  => 17698,
                         "ninth"                   => 2172,
                         "niobe"                   => 28857,
                         "niobium"                 => 21767,
                         "nipissing"               => 20389,
                         "nisan"                   => 26509,
                         "nisei"                   => 28366,
                         "nishapur"                => 20590,
                         "nishi"                   => 14684,
                         "nisibis"                 => 28788,
                         "nitin"                   => 23483,
                         "nitra"                   => 16884,
                         "nitrate"                 => 9343,
                         "nitrates"                => 25860,
                         "nitric"                  => 13006,
                         "nitride"                 => 21662,
                         "nitrite"                 => 21789,
                         "nitrogen"                => 5049,
                         "nizam"                   => 10910,
                         "nizamabad"               => 27174,
                         "nizami"                  => 25469,
                         "nizamuddin"              => 26600,
                         "nizhny"                  => 13177,
                         "njcaa"                   => 21045,
                         "njegos"                  => 29447,
                         "njsiaa"                  => 20916,
                         "nkrumah"                 => 18262,
                         "noailles"                => 25577,
                         "nobel"                   => 3889,
                         "nobilis"                 => 29633,
                         "nobility"                => 4088,
                         "nobleman"                => 6907,
                         "noblemen"                => 12043,
                         "noblewoman"              => 15536,
                         "nobunaga"                => 15552,
                         "nobuo"                   => 27622,
                         "noche"                   => 18181,
                         "noctuidae"               => 7615,
                         "nocturnal"               => 8289,
                         "node"                    => 4880,
                         "nodes"                   => 5141,
                         "noether"                 => 28154,
                         "noetherian"              => 28575,
                         "noguchi"                 => 22385,
                         "noida"                   => 18269,
                         "noinclude"               => 26885,
                         "noire"                   => 16797,
                         "noize"                   => 28903,
                         "nomadic"                 => 7272,
                         "nomen"                   => 17355,
                         "nomenclature"            => 6911,
                         "nominal"                 => 5267,
                         "nominally"               => 8015,
                         "nominate"                => 8295,
                         "nominated"               => 1175,
                         "nominating"              => 12683,
                         "nomination"              => 2253,
                         "nominations"             => 2961,
                         "nominative"              => 14479,
                         "nominee"                 => 4234,
                         "nominees"                => 5872,
                         "non"                     => 264,
                         "nonconformist"           => 16644,
                         "nonesuch"                => 29054,
                         "nonetheless"             => 3818,
                         "nonfiction"              => 9552,
                         "nongovernmental"         => 26502,
                         "nonhuman"                => 27685,
                         "nonlinear"               => 9283,
                         "nonpartisan"             => 12858,
                         "nonprofit"               => 5154,
                         "nonprofits"              => 20550,
                         "nonpublic"               => 23540,
                         "nontrivial"              => 23914,
                         "nonverbal"               => 20361,
                         "nonviolence"             => 19584,
                         "nonviolent"              => 13268,
                         "nonzero"                 => 15657,
                         "noord"                   => 24652,
                         "nootka"                  => 20092,
                         "nord-pas-de-calais"      => 20262,
                         "nordic"                  => 4811,
                         "nordiques"               => 17240,
                         "nordisk"                 => 25672,
                         "nordland"                => 14400,
                         "norepinephrine"          => 17377,
                         "norfolk"                 => 2556,
                         "norge"                   => 20168,
                         "norges"                  => 24167,
                         "norm"                    => 5109,
                         "normale"                 => 15253,
                         "normalised"              => 28879,
                         "normality"               => 22418,
                         "normalization"           => 15141,
                         "normalize"               => 29521,
                         "normalized"              => 10623,
                         "normally"                => 2014,
                         "normandie"               => 11784,
                         "normans"                 => 11147,
                         "normanton"               => 25191,
                         "normative"               => 11683,
                         "norms"                   => 6431,
                         "norodom"                 => 25639,
                         "noronha"                 => 28145,
                         "norra"                   => 21463,
                         "norristown"              => 25811,
                         "norrkoping"              => 21739,
                         "norrland"                => 28273,
                         "norse"                   => 5234,
                         "norsk"                   => 13267,
                         "norske"                  => 16017,
                         "norte"                   => 7156,
                         "north"                   => 90,
                         "north/south"             => 21974,
                         "northallerton"           => 28158,
                         "northampton"             => 5583,
                         "northamptonshire"        => 6984,
                         "northbound"              => 6953,
                         "northbrook"              => 29809,
                         "northcote"               => 16771,
                         "northeast"               => 1379,
                         "northeasterly"           => 18217,
                         "northeastern"            => 2899,
                         "northeastward"           => 14823,
                         "northerly"               => 10195,
                         "northern"                => 309,
                         "northerners"             => 20591,
                         "northernmost"            => 7324,
                         "northfield"              => 13753,
                         "northgate"               => 21077,
                         "northland"               => 12680,
                         "northport"               => 25967,
                         "northridge"              => 16190,
                         "northside"               => 15599,
                         "northumberland"          => 5798,
                         "northumbria"             => 11757,
                         "northumbrian"            => 16341,
                         "northward"               => 5810,
                         "northwards"              => 8837,
                         "northwest"               => 1238,
                         "northwesterly"           => 21493,
                         "northwestern"            => 2549,
                         "northwestward"           => 14128,
                         "northwich"               => 15710,
                         "northwood"               => 15263,
                         "norwalk"                 => 11415,
                         "norway"                  => 1449,
                         "norwegian"               => 1414,
                         "norwegians"              => 13563,
                         "nossa"                   => 17341,
                         "notability"              => 18924,
                         "notable"                 => 627,
                         "notables"                => 11575,
                         "notably"                 => 1545,
                         "notaries"                => 22937,
                         "notary"                  => 12308,
                         "notated"                 => 21572,
                         "notation"                => 4933,
                         "notations"               => 16963,
                         "notaulices"              => 18301,
                         "notched"                 => 13084,
                         "notching"                => 24620,
                         "noted"                   => 665,
                         "notes"                   => 1098,
                         "noteworthy"              => 6269,
                         "noticeable"              => 7086,
                         "noticeably"              => 9893,
                         "notices"                 => 5941,
                         "noticias"                => 23694,
                         "notification"            => 9388,
                         "notifications"           => 18685,
                         "noting"                  => 3584,
                         "notion"                  => 3757,
                         "notional"                => 20273,
                         "notions"                 => 7983,
                         "notodontidae"            => 25819,
                         "notoriety"               => 7432,
                         "notorious"               => 4622,
                         "notoriously"             => 11362,
                         "notre"                   => 3844,
                         "nottingham"              => 4042,
                         "nottinghamshire"         => 6719,
                         "notts"                   => 10573,
                         "noumea"                  => 18500,
                         "noun"                    => 5478,
                         "nouns"                   => 6646,
                         "nouveau"                 => 9360,
                         "nouvel"                  => 28900,
                         "nouvelle"                => 13493,
                         "nouvelles"               => 26105,
                         "novae"                   => 25285,
                         "novara"                  => 16353,
                         "novaya"                  => 24033,
                         "novel"                   => 572,
                         "novelette"               => 22846,
                         "novelisation"            => 27385,
                         "novelist"                => 3740,
                         "novelists"               => 12845,
                         "novelization"            => 17897,
                         "novellas"                => 16924,
                         "novels"                  => 1794,
                         "novelties"               => 25478,
                         "novelty"                 => 7631,
                         "november"                => 171,
                         "novgorod"                => 7619,
                         "novice"                  => 8417,
                         "novices"                 => 14504,
                         "novitiate"               => 16548,
                         "novosibirsk"             => 14692,
                         "novus"                   => 28920,
                         "nowadays"                => 4723,
                         "nozze"                   => 29612,
                         "nozzle"                  => 12197,
                         "nozzles"                 => 19112,
                         "nsaids"                  => 25894,
                         "nscaa"                   => 25550,
                         "nsdap"                   => 15452,
                         "nswrfl"                  => 24038,
                         "nswrl"                   => 21301,
                         "nuanced"                 => 17084,
                         "nucky"                   => 29340,
                         "nuclear"                 => 1208,
                         "nucleation"              => 24422,
                         "nuclei"                  => 7731,
                         "nucleic"                 => 13778,
                         "nucleolar"               => 20936,
                         "nucleophile"             => 26226,
                         "nucleophilic"            => 18376,
                         "nucleoside"              => 26457,
                         "nucleotide"              => 10643,
                         "nucleotides"             => 14226,
                         "nucleus"                 => 4683,
                         "nuclides"                => 27224,
                         "nudibranch"              => 15639,
                         "nuestra"                 => 10878,
                         "nuestro"                 => 19085,
                         "nueva"                   => 8903,
                         "nuevo"                   => 7908,
                         "nuffield"                => 19675,
                         "nullified"               => 17353,
                         "nullify"                 => 24767,
                         "numan"                   => 18220,
                         "number"                  => 112,
                         "numbered"                => 2910,
                         "numbering"               => 4837,
                         "numeral"                 => 12319,
                         "numerals"                => 9486,
                         "numerator"               => 25746,
                         "numeric"                 => 12038,
                         "numerical"               => 5512,
                         "numerically"             => 12427,
                         "numerous"                => 629,
                         "numidia"                 => 28877,
                         "numismatic"              => 17223,
                         "numismatics"             => 28395,
                         "nunatak"                 => 11954,
                         "nunataks"                => 18429,
                         "nunavut"                 => 9666,
                         "nuncio"                  => 13452,
                         "nuneaton"                => 16223,
                         "nuova"                   => 18697,
                         "nuovo"                   => 21156,
                         "nurburgring"             => 14704,
                         "nuremberg"               => 6596,
                         "nureyev"                 => 29998,
                         "nurnberg"                => 14266,
                         "nurseries"               => 14894,
                         "nursing"                 => 3393,
                         "nusra"                   => 21029,
                         "nutrient"                => 8790,
                         "nutrients"               => 7183,
                         "nutrition"               => 5221,
                         "nutritional"             => 8920,
                         "nyack"                   => 26159,
                         "nyasaland"               => 16822,
                         "nyerere"                 => 29928,
                         "nyingma"                 => 25928,
                         "nymphalidae"             => 13557,
                         "nyssa"                   => 24659,
                         "o'brian"                 => 19216,
                         "o'brien"                 => 3737,
                         "o'byrne"                 => 26607,
                         "o'callaghan"             => 18455,
                         "o'connor"                => 4846,
                         "o'day"                   => 20405,
                         "o'dea"                   => 24645,
                         "o'dell"                  => 26697,
                         "o'doherty"               => 25886,
                         "o'donnell"               => 7101,
                         "o'donoghue"              => 18270,
                         "o'donovan"               => 18503,
                         "o'dowd"                  => 27458,
                         "o'driscoll"              => 25295,
                         "o'farrell"               => 19562,
                         "o'flaherty"              => 28843,
                         "o'gorman"                => 27024,
                         "o'grady"                 => 13894,
                         "o'hagan"                 => 28833,
                         "o'halloran"              => 24432,
                         "o'hanlon"                => 24791,
                         "o'keefe"                 => 11802,
                         "o'keeffe"                => 18325,
                         "o'kelly"                 => 23584,
                         "o'loughlin"              => 27034,
                         "o'mahony"                => 27788,
                         "o'meara"                 => 22741,
                         "o'neal"                  => 9804,
                         "o'odham"                 => 29892,
                         "o'rourke"                => 12977,
                         "o'shaughnessy"           => 22135,
                         "o'shea"                  => 13849,
                         "o'sullivan"              => 8634,
                         "oakenfold"               => 29173,
                         "oakham"                  => 29034,
                         "oakleigh"                => 24390,
                         "oakville"                => 15998,
                         "oases"                   => 24128,
                         "oaths"                   => 13610,
                         "oaxaca"                  => 9071,
                         "obadiah"                 => 25583,
                         "obama"                   => 2741,
                         "obasanjo"                => 22164,
                         "obedience"               => 9147,
                         "oberland"                => 26591,
                         "oberleutnant"            => 18382,
                         "oberliga"                => 10199,
                         "oberoi"                  => 25930,
                         "oberst"                  => 17785,
                         "obesity"                 => 8236,
                         "obispo"                  => 13431,
                         "obituary"                => 7750,
                         "object"                  => 1657,
                         "objected"                => 6364,
                         "objective"               => 2691,
                         "objectives"              => 3689,
                         "objector"                => 21047,
                         "objectors"               => 21956,
                         "objects"                 => 1626,
                         "oblast"                  => 2909,
                         "oblasts"                 => 23216,
                         "oblate"                  => 26772,
                         "oblates"                 => 29560,
                         "obligate"                => 20514,
                         "obligations"             => 5457,
                         "obligatory"              => 8725,
                         "oblique"                 => 7755,
                         "obliquely"               => 15482,
                         "oblong"                  => 11416,
                         "oboes"                   => 15992,
                         "obrenovic"               => 26973,
                         "obscenity"               => 14135,
                         "obscura"                 => 19335,
                         "obscure"                 => 5649,
                         "obscured"                => 11093,
                         "obscuring"               => 19142,
                         "obscurity"               => 10755,
                         "observable"              => 11274,
                         "observance"              => 9596,
                         "observances"             => 19341,
                         "observation"             => 3215,
                         "observational"           => 12425,
                         "observations"            => 3470,
                         "observatories"           => 16254,
                         "observatory"             => 3639,
                         "observed"                => 1716,
                         "observer"                => 3630,
                         "observers"               => 4808,
                         "observes"                => 8534,
                         "observing"               => 5935,
                         "obsolescence"            => 22781,
                         "obsolescent"             => 29095,
                         "obsolete"                => 5595,
                         "obstetric"               => 25503,
                         "obstetrics"              => 13602,
                         "obstructions"            => 18723,
                         "obstructive"             => 20284,
                         "obtain"                  => 2273,
                         "obtainable"              => 22762,
                         "obtained"                => 1288,
                         "obtaining"               => 3993,
                         "obtains"                 => 10857,
                         "obverse"                 => 10894,
                         "ocala"                   => 19540,
                         "occasional"              => 3262,
                         "occasionally"            => 1896,
                         "occasioned"              => 18979,
                         "occasions"               => 2191,
                         "occidental"              => 10461,
                         "occidentalis"            => 18215,
                         "occipital"               => 16898,
                         "occitan"                 => 13924,
                         "occlusion"               => 19770,
                         "occultation"             => 28552,
                         "occultism"               => 28659,
                         "occultist"               => 26968,
                         "occupancy"               => 10114,
                         "occupant"                => 13021,
                         "occupants"               => 7574,
                         "occupation"              => 1894,
                         "occupational"            => 6124,
                         "occupations"             => 7736,
                         "occupied"                => 1278,
                         "occupier"                => 28203,
                         "occupiers"               => 13396,
                         "occupies"                => 4883,
                         "occupy"                  => 4112,
                         "occupying"               => 5112,
                         "occur"                   => 1451,
                         "occurred"                => 1152,
                         "occurrence"              => 5046,
                         "occurrences"             => 8739,
                         "occurring"               => 3529,
                         "occurs"                  => 1505,
                         "ocean"                   => 1242,
                         "oceana"                  => 24017,
                         "oceania"                 => 7505,
                         "oceanic"                 => 6701,
                         "oceanographic"           => 13933,
                         "oceanography"            => 14231,
                         "oceanside"               => 20645,
                         "ochre"                   => 14873,
                         "ochreous"                => 9449,
                         "oconee"                  => 26737,
                         "octagonal"               => 7692,
                         "octahedral"              => 18681,
                         "octahedron"              => 27648,
                         "octave"                  => 8072,
                         "octaves"                 => 14357,
                         "octet"                   => 20366,
                         "october"                 => 159,
                         "oculus"                  => 26326,
                         "odawara"                 => 27979,
                         "oddities"                => 25131,
                         "oddity"                  => 22897,
                         "odenwald"                => 27607,
                         "odeon"                   => 13943,
                         "odile"                   => 28461,
                         "odisha"                  => 7629,
                         "odors"                   => 21183,
                         "odostomia"               => 19420,
                         "oecophoridae"            => 20403,
                         "oerlikon"                => 19439,
                         "oeste"                   => 21873,
                         "oeuvre"                  => 14284,
                         "of"                      => 2,
                         "ofcom"                   => 14601,
                         "offaly"                  => 10588,
                         "offenbach"               => 12997,
                         "offences"                => 6644,
                         "offenders"               => 6914,
                         "offenses"                => 8525,
                         "offensive"               => 1826,
                         "offensively"             => 19314,
                         "offensives"              => 14385,
                         "offered"                 => 789,
                         "offerings"               => 5216,
                         "offers"                  => 974,
                         "office"                  => 283,
                         "officer"                 => 604,
                         "officers"                => 913,
                         "officership"             => 19531,
                         "offices"                 => 1375,
                         "official"                => 439,
                         "officially"              => 977,
                         "officials"               => 1235,
                         "officiated"              => 11238,
                         "officiating"             => 13723,
                         "officinalis"             => 28692,
                         "officio"                 => 12150,
                         "offline"                 => 10535,
                         "offload"                 => 29449,
                         "offs"                    => 4887,
                         "offseason"               => 8868,
                         "offset"                  => 5998,
                         "offsets"                 => 18959,
                         "offsetting"              => 27056,
                         "offshoot"                => 10018,
                         "offshoots"               => 24035,
                         "offshore"                => 4362,
                         "offside"                 => 17286,
                         "offspring"               => 5168,
                         "offstage"                => 24540,
                         "ofsted"                  => 12037,
                         "often"                   => 215,
                         "ogaden"                  => 28190,
                         "ogdensburg"              => 28345,
                         "oghuz"                   => 26219,
                         "ogilvy"                  => 16516,
                         "oglethorpe"              => 18330,
                         "ohio"                    => 899,
                         "ohrid"                   => 16728,
                         "oilfield"                => 20118,
                         "oilfields"               => 29030,
                         "oirat"                   => 28662,
                         "oireachtas"              => 17511,
                         "ojibwa"                  => 22534,
                         "ojibwe"                  => 13260,
                         "okanagan"                => 13371,
                         "okanogan"                => 27818,
                         "okayama"                 => 15779,
                         "okeechobee"              => 23163,
                         "okhotsk"                 => 21699,
                         "okinawa"                 => 5245,
                         "okinawan"                => 16869,
                         "oklahoma"                => 1758,
                         "okrug"                   => 10019,
                         "olafur"                  => 27963,
                         "olave"                   => 27085,
                         "olbermann"               => 26572,
                         "old"                     => 186,
                         "older"                   => 617,
                         "oldest"                  => 1254,
                         "oldies"                  => 8667,
                         "oleksandr"               => 16166,
                         "olesnica"                => 29220,
                         "olfactory"               => 11754,
                         "oligarchy"               => 20526,
                         "oligocene"               => 15823,
                         "olimpico"                => 17498,
                         "olimpija"                => 20444,
                         "olivet"                  => 19986,
                         "olivine"                 => 20392,
                         "olmec"                   => 18259,
                         "olmert"                  => 25056,
                         "olomouc"                 => 13284,
                         "olsztyn"                 => 10362,
                         "olusegun"                => 25982,
                         "olympiacos"              => 11634,
                         "olympiad"                => 9075,
                         "olympiads"               => 18171,
                         "olympiakos"              => 20881,
                         "olympian"                => 9724,
                         "olympians"               => 14310,
                         "olympic"                 => 1148,
                         "olympics"                => 759,
                         "olympique"               => 11942,
                         "omagh"                   => 22586,
                         "omaha"                   => 4638,
                         "omani"                   => 18572,
                         "ombudsman"               => 11003,
                         "omissions"               => 19312,
                         "omits"                   => 16214,
                         "omitted"                 => 6159,
                         "omitting"                => 14673,
                         "omiya"                   => 29999,
                         "omnibus"                 => 9615,
                         "omnipresent"             => 25337,
                         "omniscient"              => 25885,
                         "omnium"                  => 27911,
                         "omnivorous"              => 19871,
                         "omonia"                  => 27553,
                         "on"                      => 9,
                         "on/off"                  => 29413,
                         "onassis"                 => 21750,
                         "oncology"                => 10603,
                         "ondrej"                  => 24634,
                         "one"                     => 27,
                         "one-and-a-half"          => 27565,
                         "one-of-a-kind"           => 26091,
                         "onegin"                  => 25106,
                         "oneness"                 => 17818,
                         "oneonta"                 => 25454,
                         "onerous"                 => 24713,
                         "ongoing"                 => 2565,
                         "onlookers"               => 18207,
                         "only"                    => 49,
                         "onlyinclude"             => 6357,
                         "onondaga"                => 13636,
                         "onscreen"                => 12345,
                         "onsen"                   => 21351,
                         "onset"                   => 5196,
                         "onshore"                 => 14378,
                         "onside"                  => 23635,
                         "onsite"                  => 17843,
                         "onslaught"               => 12789,
                         "onslow"                  => 14496,
                         "ontario"                 => 1165,
                         "ontological"             => 16332,
                         "ontologies"              => 28443,
                         "ontology"                => 12206,
                         "onward"                  => 6553,
                         "onwards"                 => 3459,
                         "oocyte"                  => 27628,
                         "opacity"                 => 27784,
                         "opaque"                  => 11418,
                         "opatow"                  => 27698,
                         "opava"                   => 28317,
                         "open"                    => 302,
                         "openbsd"                 => 27494,
                         "opened"                  => 364,
                         "opengl"                  => 16648,
                         "opening"                 => 677,
                         "openings"                => 6601,
                         "openly"                  => 4026,
                         "openness"                => 11394,
                         "opera"                   => 941,
                         "operable"                => 27006,
                         "operand"                 => 28802,
                         "operands"                => 29661,
                         "operas"                  => 4731,
                         "operate"                 => 1609,
                         "operated"                => 709,
                         "operates"                => 1672,
                         "operatic"                => 7458,
                         "operating"               => 975,
                         "operation"               => 583,
                         "operational"             => 1966,
                         "operationally"           => 13369,
                         "operations"              => 535,
                         "operative"               => 4604,
                         "operators"               => 3035,
                         "operculum"               => 13834,
                         "operetta"                => 11737,
                         "operettas"               => 18442,
                         "operon"                  => 29343,
                         "ophir"                   => 26609,
                         "ophthalmic"              => 19581,
                         "ophthalmology"           => 13552,
                         "opined"                  => 9046,
                         "opines"                  => 28863,
                         "opining"                 => 26340,
                         "opinions"                => 3970,
                         "opioid"                  => 12806,
                         "opioids"                 => 22292,
                         "opoczno"                 => 29045,
                         "opole"                   => 8970,
                         "oporto"                  => 28323,
                         "opossum"                 => 20353,
                         "oppland"                 => 22139,
                         "opponent"                => 2510,
                         "opponents"               => 2547,
                         "opportunistic"           => 13904,
                         "opportunities"           => 2182,
                         "oppose"                  => 5555,
                         "opposed"                 => 1407,
                         "opposes"                 => 9439,
                         "opposing"                => 3586,
                         "opposite"                => 1669,
                         "opposition"              => 1162,
                         "oppositional"            => 25771,
                         "oppositions"             => 29604,
                         "oppression"              => 7636,
                         "oppressive"              => 11468,
                         "opted"                   => 4813,
                         "optic"                   => 7821,
                         "optical"                 => 3242,
                         "optically"               => 18986,
                         "optics"                  => 7280,
                         "optimal"                 => 5645,
                         "optimally"               => 24042,
                         "optimised"               => 25798,
                         "optimization"            => 7136,
                         "optimizations"           => 25762,
                         "optimize"                => 11864,
                         "optimized"               => 9653,
                         "optimizing"              => 18815,
                         "optimum"                 => 10084,
                         "opting"                  => 11311,
                         "optional"                => 4456,
                         "optionally"              => 13119,
                         "optioned"                => 12086,
                         "optometry"               => 20264,
                         "optus"                   => 26175,
                         "opulent"                 => 19526,
                         "or"                      => 23,
                         "oradea"                  => 22565,
                         "oral"                    => 3140,
                         "orally"                  => 12549,
                         "orangeburg"              => 28117,
                         "orangeville"             => 26017,
                         "orangutans"              => 24888,
                         "oranje"                  => 28951,
                         "oration"                 => 16757,
                         "orator"                  => 11127,
                         "oratorio"                => 11857,
                         "oratorios"               => 23041,
                         "orators"                 => 27217,
                         "oratory"                 => 10003,
                         "orbis"                   => 22522,
                         "orbit"                   => 3293,
                         "orbital"                 => 4930,
                         "orbitals"                => 13605,
                         "orbited"                 => 29958,
                         "orbiter"                 => 11480,
                         "orbiting"                => 8940,
                         "orbits"                  => 7650,
                         "orcas"                   => 28045,
                         "orchards"                => 7552,
                         "orchestra"               => 1232,
                         "orchestral"              => 5085,
                         "orchestras"              => 6339,
                         "orchestrated"            => 8717,
                         "orchestration"           => 11387,
                         "orchestrations"          => 20532,
                         "orchestrator"            => 27896,
                         "orchestre"               => 17267,
                         "orchidaceae"             => 22265,
                         "ordain"                  => 23845,
                         "ordained"                => 3260,
                         "orden"                   => 23894,
                         "order"                   => 203,
                         "ordered"                 => 1015,
                         "ordinal"                 => 13035,
                         "ordinals"                => 23693,
                         "ordinance"               => 6026,
                         "ordinances"              => 9986,
                         "ordinated"               => 17138,
                         "ordinating"              => 21520,
                         "ordination"              => 6218,
                         "ordinator"               => 19124,
                         "ordnance"                => 5562,
                         "ordos"                   => 29539,
                         "ordovician"              => 12484,
                         "ordre"                   => 20151,
                         "orebro"                  => 16957,
                         "oregon"                  => 1527,
                         "oregonian"               => 20279,
                         "orestes"                 => 17928,
                         "oresund"                 => 26064,
                         "orfeo"                   => 26051,
                         "orford"                  => 19816,
                         "organ"                   => 2236,
                         "organelles"              => 22117,
                         "organic"                 => 2607,
                         "organically"             => 20979,
                         "organics"                => 29784,
                         "organisation"            => 1612,
                         "organisational"          => 11436,
                         "organisations"           => 2831,
                         "organise"                => 7871,
                         "organised"               => 2441,
                         "organiser"               => 11027,
                         "organisers"              => 10177,
                         "organises"               => 10454,
                         "organising"              => 7398,
                         "organism"                => 5855,
                         "organisms"               => 4025,
                         "organist"                => 6087,
                         "organists"               => 18658,
                         "organization"            => 478,
                         "organizational"          => 4536,
                         "organizations"           => 1058,
                         "organize"                => 3920,
                         "organized"               => 1036,
                         "organizer"               => 6909,
                         "organizers"              => 6491,
                         "organizes"               => 7331,
                         "organizing"              => 3886,
                         "organometallic"          => 24515,
                         "orhan"                   => 25222,
                         "oricon"                  => 7743,
                         "oriel"                   => 14994,
                         "oriental"                => 4303,
                         "orientale"               => 26267,
                         "orientales"              => 22267,
                         "orientalis"              => 19161,
                         "orientalism"             => 26881,
                         "orientalist"             => 16000,
                         "orientated"              => 15076,
                         "orientation"             => 3679,
                         "orientations"            => 14671,
                         "oriente"                 => 18380,
                         "oriented"                => 2590,
                         "orienteering"            => 11744,
                         "origen"                  => 16346,
                         "origin"                  => 1147,
                         "original"                => 236,
                         "originality"             => 9999,
                         "originally"              => 371,
                         "originate"               => 7335,
                         "originated"              => 2572,
                         "originates"              => 5686,
                         "originating"             => 5042,
                         "origination"             => 20347,
                         "originator"              => 13219,
                         "originators"             => 24490,
                         "origins"                 => 1951,
                         "orinoco"                 => 17683,
                         "orissa"                  => 10531,
                         "oriya"                   => 16182,
                         "orkney"                  => 8978,
                         "orleans"                 => 2056,
                         "orlov"                   => 19567,
                         "ornamental"              => 6429,
                         "ornamentation"           => 10738,
                         "ornamented"              => 13005,
                         "ornate"                  => 8291,
                         "ornette"                 => 29898,
                         "ornithological"          => 18791,
                         "ornithologist"           => 13936,
                         "ornithologists"          => 19263,
                         "ornithology"             => 16774,
                         "orogeny"                 => 15833,
                         "oromia"                  => 22528,
                         "oromo"                   => 15193,
                         "orphanages"              => 16030,
                         "orphaned"                => 9544,
                         "orpheum"                 => 21887,
                         "orquesta"                => 19201,
                         "orthodox"                => 1910,
                         "orthodoxy"               => 8404,
                         "orthogonal"              => 9129,
                         "orthogonius"             => 29819,
                         "orthographic"            => 19275,
                         "orthography"             => 9054,
                         "orthologs"               => 29406,
                         "orthonormal"             => 25019,
                         "orthopaedic"             => 16750,
                         "orthopedics"             => 27104,
                         "ortsgemeinde"            => 21218,
                         "oruro"                   => 29572,
                         "orvieto"                 => 28886,
                         "oryol"                   => 24600,
                         "oryzomys"                => 29344,
                         "osage"                   => 12923,
                         "osaka"                   => 5162,
                         "osamu"                   => 19307,
                         "osceola"                 => 15472,
                         "oscillate"               => 26952,
                         "oscillating"             => 17287,
                         "oscillation"             => 11896,
                         "oscillations"            => 13324,
                         "oscillator"              => 11160,
                         "oscillators"             => 16871,
                         "oscilloscope"            => 27917,
                         "osgoode"                 => 25373,
                         "oshawa"                  => 14605,
                         "osijek"                  => 15174,
                         "oskar"                   => 10209,
                         "oslo"                    => 3535,
                         "osmania"                 => 27062,
                         "osmena"                  => 29619,
                         "osmosis"                 => 22165,
                         "osmotic"                 => 21220,
                         "osnabruck"               => 15670,
                         "ospreys"                 => 20650,
                         "ossetia"                 => 12574,
                         "ossetian"                => 18428,
                         "ossian"                  => 25204,
                         "ossory"                  => 23246,
                         "ossuary"                 => 28126,
                         "osten"                   => 28118,
                         "ostend"                  => 16665,
                         "ostensible"              => 27697,
                         "ostensibly"              => 8067,
                         "osteoarthritis"          => 25502,
                         "osteopathic"             => 14304,
                         "osteoporosis"            => 19126,
                         "ostergotland"            => 26627,
                         "ostersund"               => 26888,
                         "ostfold"                 => 23855,
                         "ostia"                   => 21460,
                         "ostra"                   => 29072,
                         "ostrava"                 => 17021,
                         "ostroda"                 => 24225,
                         "ostrogoths"              => 28248,
                         "ostroleka"               => 23413,
                         "ostrovsky"               => 24482,
                         "oswestry"                => 20252,
                         "oswiecim"                => 26302,
                         "otago"                   => 7707,
                         "otaku"                   => 26524,
                         "other"                   => 38,
                         "others"                  => 361,
                         "otherworld"              => 27562,
                         "otley"                   => 26283,
                         "otomi"                   => 24385,
                         "otomo"                   => 28245,
                         "otranto"                 => 24716,
                         "otsego"                  => 23513,
                         "ottavio"                 => 27909,
                         "ottawa"                  => 2697,
                         "ottokar"                 => 22658,
                         "ottoman"                 => 1899,
                         "ottomans"                => 6267,
                         "otway"                   => 21139,
                         "ouachita"                => 17111,
                         "ouagadougou"             => 25553,
                         "ouest"                   => 18302,
                         "oulton"                  => 25205,
                         "ourense"                 => 27736,
                         "ousted"                  => 8865,
                         "ouster"                  => 19196,
                         "ousting"                 => 18299,
                         "outages"                 => 15468,
                         "outboard"                => 14775,
                         "outbound"                => 15248,
                         "outbreak"                => 2718,
                         "outbreaks"               => 10439,
                         "outbuildings"            => 12007,
                         "outclassed"              => 23371,
                         "outcome"                 => 3665,
                         "outcomes"                => 4859,
                         "outcrop"                 => 13705,
                         "outcropping"             => 29623,
                         "outcrops"                => 11908,
                         "outcry"                  => 11070,
                         "outdated"                => 9183,
                         "outdoor"                 => 2534,
                         "outer"                   => 2179,
                         "outermost"               => 16195,
                         "outfield"                => 9954,
                         "outfielder"              => 7314,
                         "outfielders"             => 25807,
                         "outfitted"               => 12421,
                         "outfitters"              => 25120,
                         "outfitting"              => 25608,
                         "outflank"                => 27930,
                         "outflow"                 => 10168,
                         "outgoing"                => 7847,
                         "outgrowth"               => 16573,
                         "outlawed"                => 9543,
                         "outlawing"               => 24052,
                         "outlet"                  => 4904,
                         "outlets"                 => 4107,
                         "outlier"                 => 27596,
                         "outliers"                => 24139,
                         "outline"                 => 5352,
                         "outlined"                => 5900,
                         "outlines"                => 8411,
                         "outlining"               => 12017,
                         "outlived"                => 15570,
                         "outlook"                 => 6422,
                         "outlying"                => 8218,
                         "outmoded"                => 29853,
                         "outpaced"                => 29073,
                         "outpatient"              => 11163,
                         "outperform"              => 26698,
                         "outperformed"            => 21308,
                         "outpost"                 => 7756,
                         "outposts"                => 11579,
                         "output"                  => 2039,
                         "outputs"                 => 9052,
                         "outreach"                => 5274,
                         "outrigger"               => 28449,
                         "outright"                => 5756,
                         "outro"                   => 20810,
                         "outscored"               => 14370,
                         "outset"                  => 8848,
                         "outskirts"               => 5027,
                         "outsold"                 => 28109,
                         "outsourced"              => 16753,
                         "outsourcing"             => 11432,
                         "outspoken"               => 7533,
                         "outstanding"             => 1739,
                         "outstretched"            => 19568,
                         "outtake"                 => 27692,
                         "outtakes"                => 15721,
                         "outward"                 => 7435,
                         "outwardly"               => 15485,
                         "outwards"                => 13221,
                         "outweighed"              => 22110,
                         "ouvrage"                 => 20382,
                         "oval"                    => 3579,
                         "ovals"                   => 23543,
                         "ovarian"                 => 11854,
                         "ovate"                   => 13328,
                         "over"                    => 48,
                         "overall"                 => 807,
                         "overarching"             => 13786,
                         "overcame"                => 10059,
                         "overcoming"              => 9757,
                         "overcrowding"            => 11652,
                         "overdubbed"              => 21320,
                         "overdubs"                => 18598,
                         "overexpression"          => 26424,
                         "overfishing"             => 20283,
                         "overflow"                => 10922,
                         "overflowed"              => 22716,
                         "overflows"               => 26160,
                         "overgrazing"             => 27529,
                         "overground"              => 18817,
                         "overgrown"               => 13335,
                         "overhang"                => 21148,
                         "overhanging"             => 17625,
                         "overhangs"               => 28013,
                         "overhaul"                => 6130,
                         "overhauled"              => 13093,
                         "overhead"                => 4945,
                         "overhears"               => 13303,
                         "overijssel"              => 26851,
                         "overlaid"                => 15278,
                         "overlain"                => 21541,
                         "overland"                => 7282,
                         "overlap"                 => 6209,
                         "overlapped"              => 14907,
                         "overlapping"             => 7454,
                         "overlaps"                => 11482,
                         "overlay"                 => 13137,
                         "overlays"                => 24498,
                         "overloading"             => 27504,
                         "overlooking"             => 5067,
                         "overlooks"               => 9912,
                         "overlords"               => 21690,
                         "overlordship"            => 20249,
                         "overlying"               => 15819,
                         "overpass"                => 13126,
                         "overpasses"              => 29017,
                         "overpopulation"          => 21019,
                         "overpowers"              => 29027,
                         "overprinted"             => 21087,
                         "overran"                 => 14521,
                         "overridden"              => 27175,
                         "overriding"              => 17140,
                         "overruns"                => 20811,
                         "overs"                   => 5539,
                         "oversaw"                 => 5071,
                         "overseas"                => 2281,
                         "oversee"                 => 6407,
                         "overseeing"              => 7050,
                         "overseen"                => 7596,
                         "overseer"                => 13611,
                         "overseers"               => 18592,
                         "oversees"                => 7426,
                         "overshadowed"            => 9618,
                         "overshot"                => 28602,
                         "oversight"               => 5962,
                         "overstated"              => 25023,
                         "overt"                   => 10830,
                         "overtaken"               => 11105,
                         "overtaking"              => 15055,
                         "overthrew"               => 12214,
                         "overthrow"               => 5951,
                         "overthrowing"            => 18464,
                         "overthrown"              => 9850,
                         "overtly"                 => 12441,
                         "overtone"                => 28835,
                         "overtones"               => 13427,
                         "overtook"                => 12377,
                         "overture"                => 10614,
                         "overturned"              => 6613,
                         "overturning"             => 18377,
                         "overuse"                 => 20768,
                         "overview"                => 2337,
                         "overwhelmingly"          => 8431,
                         "overwinter"              => 25929,
                         "overwintering"           => 28512,
                         "overwinters"             => 25932,
                         "oviparous"               => 29762,
                         "ovoid"                   => 18157,
                         "owain"                   => 13539,
                         "owensboro"               => 26155,
                         "owing"                   => 4045,
                         "own"                     => 202,
                         "owned"                   => 544,
                         "owner"                   => 1091,
                         "owners"                  => 1724,
                         "ownership"               => 1827,
                         "oxalate"                 => 26243,
                         "oxbow"                   => 20687,
                         "oxfam"                   => 17060,
                         "oxfordshire"             => 6893,
                         "oxidant"                 => 23590,
                         "oxidase"                 => 13302,
                         "oxidation"               => 6645,
                         "oxidative"               => 12409,
                         "oxide"                   => 5347,
                         "oxides"                  => 11676,
                         "oxidize"                 => 26350,
                         "oxidized"                => 13164,
                         "oxidizer"                => 23104,
                         "oxidizing"               => 17243,
                         "oxidoreductase"          => 15746,
                         "oxidoreductases"         => 22545,
                         "oxygenated"              => 25843,
                         "oxygenation"             => 28690,
                         "oxyrhynchus"             => 17408,
                         "oxytocin"                => 28012,
                         "ozark"                   => 13352,
                         "ozawa"                   => 19164,
                         "ozeki"                   => 25311,
                         "p.m."                    => 3543,
                         "pa'in"                   => 14607,
                         "paavo"                   => 28218,
                         "paced"                   => 8764,
                         "pacemakers"              => 29893,
                         "pacha"                   => 28002,
                         "pachuca"                 => 20464,
                         "pacific"                 => 724,
                         "pacification"            => 17087,
                         "pacifism"                => 18373,
                         "pacifist"                => 11173,
                         "packaged"                => 7575,
                         "packaging"               => 5294,
                         "packet"                  => 6230,
                         "pacquiao"                => 17449,
                         "pacts"                   => 28287,
                         "padang"                  => 17374,
                         "paderborn"               => 16860,
                         "padma"                   => 9156,
                         "padmini"                 => 27640,
                         "padova"                  => 19350,
                         "padraig"                 => 22303,
                         "padua"                   => 8648,
                         "paducah"                 => 19060,
                         "paediatric"              => 21591,
                         "paganism"                => 13100,
                         "pagans"                  => 14866,
                         "pagasa"                  => 19574,
                         "pageant"                 => 3996,
                         "pageantry"               => 23754,
                         "pageants"                => 12262,
                         "pages"                   => 2379,
                         "paget"                   => 12128,
                         "pagoda"                  => 9198,
                         "pagodas"                 => 20415,
                         "pahang"                  => 14906,
                         "pahlavi"                 => 13749,
                         "painstaking"             => 23317,
                         "painstakingly"           => 25748,
                         "painted"                 => 1761,
                         "painterly"               => 26733,
                         "painters"                => 4396,
                         "painting"                => 1244,
                         "paintings"               => 1706,
                         "pair"                    => 1500,
                         "paired"                  => 4964,
                         "pairing"                 => 8030,
                         "pairings"                => 17384,
                         "pairs"                   => 2875,
                         "pairwise"                => 20528,
                         "paiute"                  => 19925,
                         "pakeha"                  => 26023,
                         "pakenham"                => 21838,
                         "pakhtunkhwa"             => 11072,
                         "pakistani"               => 3718,
                         "pakistanis"              => 14589,
                         "palace"                  => 1213,
                         "palaces"                 => 7641,
                         "palaeographically"       => 21731,
                         "palaeolithic"            => 20820,
                         "palaeontology"           => 29757,
                         "palaiologos"             => 16542,
                         "palais"                  => 8458,
                         "palakkad"                => 17811,
                         "palatal"                 => 16550,
                         "palatalization"          => 29768,
                         "palatial"                => 20327,
                         "palatinate"              => 6121,
                         "palatine"                => 7379,
                         "palau"                   => 9683,
                         "palawan"                 => 15550,
                         "palazzo"                 => 7108,
                         "palearctic"              => 18467,
                         "palembang"               => 23010,
                         "paleo"                   => 16629,
                         "paleocene"               => 19220,
                         "paleogene"               => 17849,
                         "paleolithic"             => 11803,
                         "paleontological"         => 21114,
                         "paleontologists"         => 20005,
                         "paleozoic"               => 16255,
                         "paler"                   => 10219,
                         "palestine"               => 3113,
                         "palestinian"             => 3023,
                         "palestinians"            => 6904,
                         "palestrina"              => 23841,
                         "palette"                 => 9373,
                         "palettes"                => 29049,
                         "palgrave"                => 23885,
                         "palin"                   => 9715,
                         "palisade"                => 17550,
                         "palisades"               => 12483,
                         "palladian"               => 15761,
                         "palladio"                => 20540,
                         "palladium"               => 10184,
                         "pallava"                 => 21519,
                         "pallets"                 => 23468,
                         "palliative"              => 17188,
                         "pallida"                 => 28363,
                         "palliser"                => 23151,
                         "pallium"                 => 27322,
                         "palm"                    => 2895,
                         "palmach"                 => 26770,
                         "palmar"                  => 25328,
                         "palmares"                => 22243,
                         "palmas"                  => 13212,
                         "palme"                   => 15079,
                         "palmerston"              => 10297,
                         "palmyra"                 => 13513,
                         "palpatine"               => 29688,
                         "palps"                   => 16157,
                         "palsy"                   => 12205,
                         "paltz"                   => 28047,
                         "palustris"               => 25082,
                         "pambansa"                => 29016,
                         "pamir"                   => 25013,
                         "pampa"                   => 16047,
                         "pampanga"                => 15828,
                         "pampas"                  => 23345,
                         "pamphlet"                => 7245,
                         "pamphlets"               => 8381,
                         "pamplona"                => 14447,
                         "panagiotis"              => 24768,
                         "panamanian"              => 11914,
                         "panathinaikos"           => 12192,
                         "panay"                   => 19123,
                         "panchayat"               => 6897,
                         "panchayath"              => 24096,
                         "panchayats"              => 11750,
                         "pancras"                 => 13441,
                         "pancrase"                => 21778,
                         "pancreatic"              => 10999,
                         "pancreatitis"            => 26889,
                         "pandava"                 => 29902,
                         "pandavas"                => 17064,
                         "pandemic"                => 11644,
                         "pandey"                  => 16543,
                         "pandit"                  => 9879,
                         "pandyan"                 => 23377,
                         "panel"                   => 2140,
                         "paneled"                 => 21165,
                         "panelist"                => 14157,
                         "panelists"               => 18063,
                         "panelled"                => 20639,
                         "panelling"               => 19308,
                         "panellist"               => 24918,
                         "panels"                  => 3533,
                         "pangasinan"              => 17023,
                         "panhandle"               => 11100,
                         "panhard"                 => 23809,
                         "panhellenic"             => 21759,
                         "panicles"                => 23866,
                         "panini"                  => 21896,
                         "panionios"               => 23035,
                         "panipat"                 => 25629,
                         "panjang"                 => 27544,
                         "pankhurst"               => 24881,
                         "panna"                   => 28346,
                         "panned"                  => 11113,
                         "pannonia"                => 17269,
                         "pannonian"               => 25184,
                         "panoramic"               => 9958,
                         "pantheon"                => 8953,
                         "pantograph"              => 21907,
                         "pantomime"               => 11280,
                         "pantomimes"              => 23824,
                         "panzergrenadier"         => 22083,
                         "papacy"                  => 9649,
                         "papal"                   => 4077,
                         "papandreou"              => 23194,
                         "paperback"               => 6785,
                         "paperbacks"              => 18246,
                         "paphos"                  => 22016,
                         "papilio"                 => 19170,
                         "papillae"                => 23279,
                         "pappus"                  => 25569,
                         "papua"                   => 4778,
                         "papuan"                  => 16917,
                         "papyri"                  => 18829,
                         "papyrus"                 => 8792,
                         "para"                    => 5213,
                         "parabellum"              => 29318,
                         "parable"                 => 13505,
                         "parables"                => 22029,
                         "parabolic"               => 13325,
                         "paracetamol"             => 28255,
                         "parachute"               => 5032,
                         "parachuted"              => 21284,
                         "parachutist"             => 27215,
                         "paraded"                 => 16313,
                         "parades"                 => 8590,
                         "paradigms"               => 14916,
                         "paradoxes"               => 20051,
                         "paradoxical"             => 17556,
                         "paradoxically"           => 19129,
                         "paraffin"                => 21475,
                         "paragliding"             => 28019,
                         "paraguay"                => 5132,
                         "paraguayan"              => 9184,
                         "paraiba"                 => 18895,
                         "parallel"                => 1884,
                         "paralleled"              => 13645,
                         "paralleling"             => 13251,
                         "parallelism"             => 19551,
                         "parallelogram"           => 29624,
                         "parallels"               => 6303,
                         "paralympian"             => 26231,
                         "paralympic"              => 6641,
                         "paralympics"             => 4616,
                         "paralysed"               => 19157,
                         "paralytic"               => 29797,
                         "param"                   => 28089,
                         "paramagnetic"            => 29771,
                         "parameter"               => 5835,
                         "parameters"              => 4162,
                         "parametric"              => 14335,
                         "paramilitaries"          => 20075,
                         "paramilitary"            => 7446,
                         "paramount"               => 4258,
                         "parana"                  => 9138,
                         "paranaense"              => 27129,
                         "paranaque"               => 28928,
                         "parapet"                 => 10530,
                         "parapets"                => 24309,
                         "paraphrase"              => 20969,
                         "paraphrased"             => 26601,
                         "paraphyletic"            => 19375,
                         "parapsychology"          => 27444,
                         "parashah"                => 19243,
                         "parasitic"               => 8727,
                         "parasitism"              => 25988,
                         "parasol"                 => 19119,
                         "parasympathetic"         => 29007,
                         "parathyroid"             => 27532,
                         "paratransit"             => 29195,
                         "paratroopers"            => 11301,
                         "paratroops"              => 29911,
                         "paraul"                  => 16031,
                         "parcel"                  => 7746,
                         "parcels"                 => 9690,
                         "parchment"               => 9737,
                         "pardubice"               => 18962,
                         "pared"                   => 29575,
                         "parentage"               => 13211,
                         "parentheses"             => 8849,
                         "parenthesis"             => 25338,
                         "pareto"                  => 20551,
                         "parganas"                => 22394,
                         "paribas"                 => 17049,
                         "parietal"                => 13238,
                         "paris"                   => 630,
                         "parish"                  => 758,
                         "parishad"                => 15088,
                         "parishes"                => 3747,
                         "parishioners"            => 10147,
                         "parisian"                => 8445,
                         "parisians"               => 24388,
                         "parity"                  => 9351,
                         "park"                    => 205,
                         "parkdale"                => 24853,
                         "parkersburg"             => 22252,
                         "parkland"                => 9529,
                         "parklands"               => 19327,
                         "parkway"                 => 4315,
                         "parkways"                => 27414,
                         "parlance"                => 17909,
                         "parle"                   => 25995,
                         "parlement"               => 20052,
                         "parley"                  => 25047,
                         "parliament"              => 601,
                         "parliamentarian"         => 10144,
                         "parliamentarians"        => 11494,
                         "parliamentary"           => 1693,
                         "parliaments"             => 9932,
                         "parlophone"              => 20572,
                         "parma"                   => 6499,
                         "parnassus"               => 26751,
                         "parnu"                   => 19511,
                         "parochial"               => 9029,
                         "parodied"                => 10534,
                         "parodies"                => 8973,
                         "parody"                  => 4662,
                         "parodying"               => 19865,
                         "parque"                  => 11557,
                         "parramatta"              => 8716,
                         "parrots"                 => 12371,
                         "parse"                   => 22299,
                         "parser"                  => 17944,
                         "parsi"                   => 19258,
                         "parsing"                 => 19150,
                         "parsonage"               => 15791,
                         "part"                    => 72,
                         "partaking"               => 27555,
                         "parte"                   => 17413,
                         "parted"                  => 7570,
                         "partenkirchen"           => 22870,
                         "parthenon"               => 21174,
                         "parthia"                 => 20222,
                         "parthian"                => 12887,
                         "parthians"               => 21477,
                         "parti"                   => 10561,
                         "partial"                 => 2692,
                         "partially"               => 2445,
                         "participant"             => 4870,
                         "participants"            => 2150,
                         "participate"             => 1720,
                         "participated"            => 1061,
                         "participates"            => 5743,
                         "participating"           => 2600,
                         "participation"           => 2060,
                         "participations"          => 28694,
                         "participatory"           => 11636,
                         "participle"              => 15365,
                         "partick"                 => 15073,
                         "particle"                => 3796,
                         "particles"               => 3329,
                         "particular"              => 736,
                         "particularly"            => 710,
                         "particulate"             => 16069,
                         "partido"                 => 10411,
                         "parties"                 => 1107,
                         "partisan"                => 5072,
                         "partisans"               => 7132,
                         "partition"               => 4857,
                         "partitioned"             => 11826,
                         "partitioning"            => 14924,
                         "partitions"              => 10247,
                         "partly"                  => 2320,
                         "partnered"               => 4670,
                         "partnering"              => 9140,
                         "partners"                => 1877,
                         "partnership"             => 1616,
                         "partnerships"            => 4399,
                         "partridges"              => 26470,
                         "parts"                   => 552,
                         "partway"                 => 26522,
                         "party"                   => 165,
                         "parva"                   => 16993,
                         "parvathi"                => 27538,
                         "parvati"                 => 13110,
                         "pasay"                   => 24692,
                         "pascagoula"              => 24522,
                         "paseo"                   => 18683,
                         "pasha"                   => 5104,
                         "pashto"                  => 14364,
                         "pashtun"                 => 12944,
                         "pashtuns"                => 20184,
                         "pasig"                   => 17487,
                         "pasir"                   => 20991,
                         "pasok"                   => 26055,
                         "pasolini"                => 27677,
                         "passage"                 => 2176,
                         "passages"                => 5276,
                         "passaic"                 => 12693,
                         "passant"                 => 29190,
                         "passau"                  => 19938,
                         "passchendaele"           => 23355,
                         "passed"                  => 770,
                         "passenger"               => 1475,
                         "passengers"              => 1810,
                         "passeriformesfamily"     => 8212,
                         "passerine"               => 9514,
                         "passers"                 => 19748,
                         "passersby"               => 29723,
                         "passes"                  => 1593,
                         "passing"                 => 1525,
                         "passive"                 => 5022,
                         "passively"               => 18845,
                         "passo"                   => 25653,
                         "passos"                  => 28137,
                         "passover"                => 12709,
                         "pasteur"                 => 14146,
                         "pastiche"                => 17402,
                         "pastimes"                => 25236,
                         "paston"                  => 27791,
                         "pastor"                  => 3511,
                         "pastoral"                => 4993,
                         "pastoralist"             => 21487,
                         "pastoralists"            => 20518,
                         "pastorate"               => 21812,
                         "pastors"                 => 9937,
                         "pasture"                 => 8168,
                         "pastureland"             => 24835,
                         "pastures"                => 8410,
                         "patagonia"               => 13689,
                         "patagonian"              => 24176,
                         "pataki"                  => 21788,
                         "patan"                   => 23643,
                         "patanjali"               => 26433,
                         "patapsco"                => 26704,
                         "patchwork"               => 18473,
                         "patent"                  => 2544,
                         "patented"                => 5801,
                         "patents"                 => 4770,
                         "paternal"                => 5652,
                         "path"                    => 1741,
                         "pathan"                  => 20127,
                         "pathanamthitta"          => 25115,
                         "pathe"                   => 15725,
                         "pathet"                  => 23241,
                         "pathogen"                => 8980,
                         "pathogenesis"            => 16667,
                         "pathogenic"              => 12658,
                         "pathogens"               => 9791,
                         "pathologies"             => 26746,
                         "pathologists"            => 23264,
                         "pathology"               => 6859,
                         "pathophysiology"         => 16503,
                         "paths"                   => 4373,
                         "pathway"                 => 5113,
                         "pathways"                => 6469,
                         "patiala"                 => 16978,
                         "patients"                => 1511,
                         "patil"                   => 13676,
                         "patna"                   => 9844,
                         "patnaik"                 => 28422,
                         "patras"                  => 14141,
                         "patrese"                 => 21617,
                         "patriarch"               => 4503,
                         "patriarchal"             => 10069,
                         "patriarchate"            => 10241,
                         "patriarchs"              => 13717,
                         "patriarchy"              => 20951,
                         "patrician"               => 12609,
                         "patricians"              => 22709,
                         "patrilineal"             => 20275,
                         "patrimony"               => 18562,
                         "patriotic"               => 5399,
                         "patriotism"              => 9741,
                         "patristic"               => 27752,
                         "patrol"                  => 2227,
                         "patrolled"               => 10087,
                         "patrols"                 => 5355,
                         "patron"                  => 3278,
                         "patronage"               => 5327,
                         "patroness"               => 21124,
                         "patronised"              => 24027,
                         "patrons"                 => 5423,
                         "patronymic"              => 16036,
                         "pattern"                 => 1873,
                         "patterned"               => 9541,
                         "patterning"              => 17610,
                         "patterns"                => 2477,
                         "pattinson"               => 23979,
                         "patuxent"                => 19357,
                         "paucity"                 => 26672,
                         "paulet"                  => 25747,
                         "paulinus"                => 25910,
                         "paulista"                => 13028,
                         "paulo"                   => 3449,
                         "pausanias"               => 16819,
                         "pausini"                 => 26268,
                         "paved"                   => 4505,
                         "pavelic"                 => 25718,
                         "pavements"               => 22244,
                         "pavia"                   => 11254,
                         "pavilions"               => 10519,
                         "paving"                  => 9632,
                         "pavle"                   => 26487,
                         "pavlo"                   => 25327,
                         "pavlovic"                => 25180,
                         "pawan"                   => 24063,
                         "pawar"                   => 25231,
                         "pawel"                   => 16851,
                         "pawnee"                  => 14191,
                         "pawtucket"               => 15473,
                         "payers"                  => 22256,
                         "payload"                 => 6804,
                         "payloads"                => 15421,
                         "paymaster"               => 19381,
                         "payment"                 => 2954,
                         "payments"                => 3834,
                         "payout"                  => 15855,
                         "payouts"                 => 28772,
                         "pazar"                   => 22839,
                         "peacebuilding"           => 27088,
                         "peacekeepers"            => 16067,
                         "peacekeeping"            => 8892,
                         "peacetime"               => 10206,
                         "peachtree"               => 16348,
                         "peacocks"                => 23821,
                         "peak"                    => 1233,
                         "peaked"                  => 2120,
                         "peaking"                 => 4325,
                         "peaks"                   => 4154,
                         "peano"                   => 27714,
                         "peasant"                 => 5611,
                         "peasantry"               => 13708,
                         "peasants"                => 4830,
                         "peckinpah"               => 24431,
                         "pectoral"                => 11584,
                         "peculiarities"           => 18823,
                         "peculiarity"             => 23087,
                         "peculiarly"              => 27234,
                         "pecuniary"               => 28171,
                         "pedagogical"             => 10634,
                         "pedagogue"               => 19737,
                         "pedagogy"                => 10858,
                         "pedals"                  => 11597,
                         "peder"                   => 18140,
                         "pedestals"               => 29367,
                         "pedestrian"              => 5564,
                         "pedestrians"             => 9736,
                         "pedigrees"               => 27908,
                         "pediment"                => 12044,
                         "pedimented"              => 19957,
                         "pediments"               => 24764,
                         "pedophilia"              => 29047,
                         "pedra"                   => 26413,
                         "peduncle"                => 20215,
                         "peekskill"               => 28043,
                         "peer"                    => 3077,
                         "peerage"                 => 6160,
                         "peerages"                => 21855,
                         "peers"                   => 4892,
                         "peeters"                 => 25838,
                         "pejorative"              => 14213,
                         "pekin"                   => 25257,
                         "peking"                  => 9505,
                         "pekka"                   => 18362,
                         "pelagic"                 => 15244,
                         "pelecaniformesfamily"    => 22938,
                         "peleliu"                 => 27943,
                         "pelicans"                => 13398,
                         "pellew"                  => 26287,
                         "peloponnese"             => 14072,
                         "peloponnesian"           => 19435,
                         "peloton"                 => 12639,
                         "pembina"                 => 22783,
                         "pembroke"                => 7535,
                         "pembrokeshire"           => 12295,
                         "penal"                   => 6577,
                         "penalised"               => 27244,
                         "penalized"               => 14996,
                         "penalties"               => 4455,
                         "penalty"                 => 2204,
                         "penang"                  => 8427,
                         "penarol"                 => 21596,
                         "penarth"                 => 22954,
                         "penciled"                => 26454,
                         "penda"                   => 26281,
                         "pendants"                => 26664,
                         "pendle"                  => 24511,
                         "pendulum"                => 9959,
                         "penetrated"              => 10100,
                         "penicillium"             => 14965,
                         "peninsula"               => 1814,
                         "peninsular"              => 7653,
                         "peninsulas"              => 25822,
                         "penitent"                => 26236,
                         "penitential"             => 29641,
                         "pennant"                 => 7542,
                         "pennants"                => 22313,
                         "penned"                  => 6199,
                         "pennine"                 => 16525,
                         "pennines"                => 21264,
                         "pennsylvania"            => 675,
                         "pennsylvanian"           => 20932,
                         "penobscot"               => 16135,
                         "penrith"                 => 11175,
                         "penryn"                  => 29076,
                         "pensacola"               => 8515,
                         "pension"                 => 4143,
                         "pensioner"               => 22787,
                         "pensioners"              => 16887,
                         "pensions"                => 8069,
                         "pentagonal"              => 17415,
                         "pentateuch"              => 21177,
                         "pentathlete"             => 21851,
                         "pentathlon"              => 12535,
                         "pentatonic"              => 26011,
                         "pentecostal"             => 9267,
                         "pentecostals"            => 28492,
                         "penticton"               => 26984,
                         "penultimate"             => 8651,
                         "penzance"                => 13664,
                         "people"                  => 93,
                         "peppered"                => 24291,
                         "peptide"                 => 8330,
                         "peptides"                => 11547,
                         "pequeno"                 => 23004,
                         "pequot"                  => 20982,
                         "per"                     => 299,
                         "perak"                   => 11082,
                         "perce"                   => 15160,
                         "perceived"               => 3042,
                         "perceives"               => 15927,
                         "perceiving"              => 18981,
                         "percent"                 => 982,
                         "percentage"              => 2259,
                         "percentages"             => 11646,
                         "perceptible"             => 27341,
                         "perception"              => 3975,
                         "perceptions"             => 8365,
                         "perceptual"              => 12516,
                         "perceval"                => 18692,
                         "perch"                   => 9711,
                         "perching"                => 22445,
                         "perchlorate"             => 25076,
                         "percussion"              => 4441,
                         "percussionist"           => 10709,
                         "percussionists"          => 26553,
                         "percussive"              => 17367,
                         "peregrine"               => 13208,
                         "perennial"               => 5241,
                         "perennials"              => 27484,
                         "perestroika"             => 20705,
                         "perfective"              => 28812,
                         "perforated"              => 13969,
                         "perforation"             => 23471,
                         "perforations"            => 24916,
                         "perform"                 => 1338,
                         "performance"             => 426,
                         "performances"            => 1142,
                         "performed"               => 444,
                         "performer"               => 3608,
                         "performers"              => 3224,
                         "performing"              => 1170,
                         "performs"                => 3602,
                         "perfusion"               => 22914,
                         "pergamon"                => 22047,
                         "perigee"                 => 28021,
                         "perihelion"              => 19849,
                         "perinatal"               => 29994,
                         "period"                  => 268,
                         "periodic"                => 5534,
                         "periodical"              => 7283,
                         "periodically"            => 6611,
                         "periodicals"             => 7168,
                         "periodicity"             => 23876,
                         "periodontal"             => 22738,
                         "periods"                 => 2242,
                         "peripheral"              => 6256,
                         "peripherals"             => 16026,
                         "periphery"               => 8516,
                         "perished"                => 8494,
                         "peristome"               => 26458,
                         "peritoneal"              => 27496,
                         "periyar"                 => 18349,
                         "perlis"                  => 24087,
                         "permafrost"              => 19071,
                         "permanence"              => 22202,
                         "permanent"               => 1320,
                         "permanente"              => 24637,
                         "permanently"             => 3238,
                         "permeability"            => 13115,
                         "permeable"               => 17316,
                         "permeate"                => 29285,
                         "permeated"               => 24308,
                         "permian"                 => 10420,
                         "permissible"             => 12019,
                         "permissions"             => 17848,
                         "permissive"              => 19591,
                         "permit"                  => 3408,
                         "permits"                 => 5119,
                         "permitted"               => 2766,
                         "permitting"              => 8270,
                         "permittivity"            => 26291,
                         "permutation"             => 12446,
                         "permutations"            => 13000,
                         "pernambuco"              => 14267,
                         "pernicious"              => 25475,
                         "peron"                   => 10940,
                         "peronist"                => 23724,
                         "perot"                   => 19351,
                         "perpendicular"           => 6329,
                         "perpetrators"            => 9785,
                         "perpetual"               => 7609,
                         "perpetuated"             => 15648,
                         "perpetuity"              => 16539,
                         "perpignan"               => 17278,
                         "perrot"                  => 24575,
                         "perryville"              => 21328,
                         "persecution"             => 5010,
                         "persecutions"            => 14216,
                         "persephone"              => 19942,
                         "persepolis"              => 14096,
                         "persevered"              => 26569,
                         "persia"                  => 5828,
                         "persian"                 => 2303,
                         "persians"                => 8588,
                         "persisted"               => 7703,
                         "persistence"             => 10281,
                         "persistently"            => 17860,
                         "persisting"              => 24472,
                         "persists"                => 12735,
                         "personage"               => 27679,
                         "personages"              => 21323,
                         "personal"                => 446,
                         "personalised"            => 27936,
                         "personalities"           => 4401,
                         "personas"                => 22436,
                         "personification"         => 15355,
                         "personnel"               => 1408,
                         "persons"                 => 1673,
                         "perspectives"            => 6312,
                         "persuaded"               => 4295,
                         "persuades"               => 11235,
                         "persuading"              => 12640,
                         "pertain"                 => 19756,
                         "pertaining"              => 7093,
                         "perth"                   => 3211,
                         "perthshire"              => 16071,
                         "pertuan"                 => 24664,
                         "perturbation"            => 15917,
                         "perturbations"           => 19647,
                         "pertwee"                 => 27068,
                         "peru"                    => 2505,
                         "perugia"                 => 12049,
                         "perumal"                 => 17343,
                         "peruvian"                => 5328,
                         "peruvians"               => 26434,
                         "pervez"                  => 17858,
                         "pesaro"                  => 18770,
                         "pescara"                 => 16625,
                         "peshawar"                => 9714,
                         "peshwa"                  => 19565,
                         "pesos"                   => 10672,
                         "pessimism"               => 21581,
                         "pesticide"               => 12675,
                         "pesticides"              => 10211,
                         "pests"                   => 10452,
                         "petah"                   => 19963,
                         "petain"                  => 18624,
                         "petaling"                => 24699,
                         "petaluma"                => 25933,
                         "petar"                   => 11712,
                         "peten"                   => 21674,
                         "peterborough"            => 6110,
                         "peterhead"               => 24908,
                         "peterhouse"              => 25743,
                         "petersburg"              => 2835,
                         "petersfield"             => 28959,
                         "petersham"               => 25693,
                         "petiole"                 => 19966,
                         "petioles"                => 19195,
                         "petipa"                  => 25551,
                         "petition"                => 3558,
                         "petitioned"              => 7568,
                         "petitioners"             => 18489,
                         "petitions"               => 8343,
                         "petkovic"                => 25661,
                         "petraeus"                => 26546,
                         "petrarch"                => 18910,
                         "petrel"                  => 15586,
                         "petrels"                 => 15279,
                         "petrobras"               => 26946,
                         "petrochemical"           => 14495,
                         "petrochemicals"          => 25797,
                         "petroglyphs"             => 17666,
                         "petrograd"               => 14420,
                         "petrol"                  => 6354,
                         "petroleum"               => 3984,
                         "petronas"                => 21510,
                         "petrovic"                => 14315,
                         "petru"                   => 25876,
                         "petula"                  => 27533,
                         "petworth"                => 27886,
                         "pevsner"                 => 17537,
                         "pfalz"                   => 20246,
                         "pfizer"                  => 15448,
                         "pforzheim"               => 24250,
                         "ph.d."                   => 3217,
                         "phaeton"                 => 25666,
                         "phage"                   => 16806,
                         "phalanx"                 => 14042,
                         "phallic"                 => 23955,
                         "phallus"                 => 24200,
                         "pharaoh"                 => 7826,
                         "pharisees"               => 26217,
                         "pharma"                  => 18112,
                         "pharmaceutical"          => 5056,
                         "pharmacies"              => 14746,
                         "pharmacists"             => 15418,
                         "pharmacokinetics"        => 26265,
                         "pharmacological"         => 14571,
                         "pharmacology"            => 10340,
                         "pharrell"                => 18064,
                         "pharyngeal"              => 20068,
                         "pharynx"                 => 23959,
                         "phase"                   => 1303,
                         "phased"                  => 7396,
                         "phases"                  => 4265,
                         "phasing"                 => 16715,
                         "phenol"                  => 19171,
                         "phenolic"                => 21255,
                         "phenomena"               => 4759,
                         "phenomenological"        => 20661,
                         "phenomenology"           => 16281,
                         "phenomenon"              => 3336,
                         "phenotype"               => 11898,
                         "phenotypes"              => 19176,
                         "phenotypic"              => 16496,
                         "phenyl"                  => 25163,
                         "phenylalanine"           => 24756,
                         "philadelphia"            => 1181,
                         "philanthropic"           => 8219,
                         "philanthropist"          => 6046,
                         "philanthropists"         => 18936,
                         "philanthropy"            => 7025,
                         "philatelic"              => 11673,
                         "philatelist"             => 24947,
                         "philatelists"            => 28999,
                         "philately"               => 22084,
                         "philharmonia"            => 19556,
                         "philharmonic"            => 4609,
                         "philippa"                => 15378,
                         "philippine"              => 2637,
                         "philippines"             => 1530,
                         "philo"                   => 14320,
                         "philological"            => 19266,
                         "philologist"             => 14254,
                         "philology"               => 10074,
                         "philosopher"             => 3667,
                         "philosophers"            => 6137,
                         "philosophic"             => 21721,
                         "philosophical"           => 3438,
                         "philosophically"         => 22662,
                         "philosophie"             => 27723,
                         "philosophies"            => 10712,
                         "philosophy"              => 1309,
                         "phineas"                 => 14738,
                         "phitsanulok"             => 28010,
                         "phlox"                   => 29945,
                         "phnom"                   => 12191,
                         "phoenicia"               => 25391,
                         "phoenician"              => 12361,
                         "phoenicians"             => 19194,
                         "phoneme"                 => 16057,
                         "phonemes"                => 13334,
                         "phonemic"                => 16112,
                         "phonetic"                => 8531,
                         "phonetically"            => 19133,
                         "phonetics"               => 19501,
                         "phonograph"              => 15900,
                         "phonographic"            => 16314,
                         "phonological"            => 12072,
                         "phonology"               => 10266,
                         "phonon"                  => 26592,
                         "phool"                   => 29927,
                         "phosphatase"             => 17146,
                         "phosphate"               => 6192,
                         "phosphates"              => 21054,
                         "phospholipids"           => 27951,
                         "phosphor"                => 24136,
                         "phosphoric"              => 27696,
                         "phosphorus"              => 8396,
                         "phosphorylated"          => 20899,
                         "phosphorylation"         => 11335,
                         "photoelectric"           => 28409,
                         "photographed"            => 5763,
                         "photographers"           => 6547,
                         "photographic"            => 4722,
                         "photographs"             => 2631,
                         "photography"             => 2412,
                         "photojournalism"         => 23527,
                         "photojournalist"         => 17014,
                         "photometric"             => 23680,
                         "photonic"                => 24357,
                         "photonics"               => 24455,
                         "photons"                 => 10383,
                         "photoshoot"              => 26090,
                         "photoshop"               => 17924,
                         "photosynthesis"          => 12865,
                         "photosynthetic"          => 17020,
                         "photovoltaic"            => 12127,
                         "photovoltaics"           => 25369,
                         "phrase"                  => 2703,
                         "phrases"                 => 5897,
                         "phrasing"                => 16738,
                         "phraya"                  => 17458,
                         "phrygia"                 => 25081,
                         "phrygian"                => 20937,
                         "phuoc"                   => 21813,
                         "phyla"                   => 24129,
                         "phyllonorycter"          => 19701,
                         "phylloxera"              => 27923,
                         "phylogenetic"            => 8201,
                         "phylogeny"               => 10661,
                         "phylum"                  => 14828,
                         "physical"                => 914,
                         "physician"               => 2744,
                         "physicians"              => 4106,
                         "physicist"               => 5446,
                         "physicists"              => 10331,
                         "physics"                 => 1867,
                         "physiographic"           => 27424,
                         "physiologic"             => 29394,
                         "physiological"           => 6842,
                         "physiologist"            => 18109,
                         "physiology"              => 6083,
                         "physiotherapist"         => 23745,
                         "physiotherapy"           => 16584,
                         "phytoplankton"           => 19454,
                         "piacenza"                => 13930,
                         "piaget"                  => 21099,
                         "pianist"                 => 3348,
                         "pianists"                => 12973,
                         "piano"                   => 1472,
                         "piaseczno"               => 29039,
                         "piast"                   => 17640,
                         "piaui"                   => 23822,
                         "piave"                   => 29001,
                         "picardie"                => 20014,
                         "picardy"                 => 15345,
                         "picayune"                => 24877,
                         "piccadilly"              => 10119,
                         "picea"                   => 24137,
                         "pichilemu"               => 24111,
                         "pickets"                 => 20787,
                         "pickups"                 => 11820,
                         "picnicking"              => 19848,
                         "pictish"                 => 17523,
                         "picton"                  => 17371,
                         "pictorial"               => 9376,
                         "pictou"                  => 21313,
                         "picts"                   => 20071,
                         "picturesque"             => 7814,
                         "pidgin"                  => 18111,
                         "piecemeal"               => 19643,
                         "pieces"                  => 1413,
                         "piedmont"                => 6232,
                         "piedmontese"             => 20079,
                         "piedras"                 => 17170,
                         "piero"                   => 11835,
                         "pierrepont"              => 22941,
                         "piers"                   => 6302,
                         "pieta"                   => 19840,
                         "pieter"                  => 8649,
                         "pietermaritzburg"        => 25291,
                         "pietersen"               => 23462,
                         "piety"                   => 10539,
                         "pieve"                   => 26582,
                         "piezoelectric"           => 20163,
                         "pigment"                 => 9246,
                         "pigmentation"            => 18750,
                         "pigmented"               => 21076,
                         "pigments"                => 11101,
                         "pigot"                   => 27940,
                         "pilasters"               => 9654,
                         "pilate"                  => 17997,
                         "pilbara"                 => 20760,
                         "pilgrimage"              => 5312,
                         "pilgrimages"             => 16147,
                         "pilgrims"                => 6378,
                         "pilings"                 => 29162,
                         "pilipinas"               => 14529,
                         "pilipino"                => 26511,
                         "pillaged"                => 17603,
                         "pillaging"               => 21037,
                         "pillai"                  => 10632,
                         "pillar"                  => 6294,
                         "pillared"                => 28834,
                         "pillars"                 => 5676,
                         "pillbox"                 => 28096,
                         "pillboxes"               => 24396,
                         "pilot"                   => 1363,
                         "piloted"                 => 9232,
                         "piloting"                => 14047,
                         "pilots"                  => 2843,
                         "pilsen"                  => 24045,
                         "pilsudski"               => 14540,
                         "pimlico"                 => 18293,
                         "pimpernel"               => 28896,
                         "pinar"                   => 21901,
                         "pinas"                   => 29091,
                         "pinchot"                 => 23171,
                         "pindar"                  => 25416,
                         "pinellas"                => 20076,
                         "pines"                   => 7869,
                         "pineville"               => 21928,
                         "piney"                   => 19092,
                         "pinfall"                 => 17354,
                         "pininfarina"             => 26826,
                         "pinkish"                 => 13379,
                         "pinnacles"               => 16250,
                         "pinnate"                 => 24003,
                         "pinochet"                => 14972,
                         "pinus"                   => 11659,
                         "pinyin"                  => 9404,
                         "pinyon"                  => 25362,
                         "pioneered"               => 5416,
                         "pioneering"              => 4665,
                         "pioneers"                => 4627,
                         "piotr"                   => 11900,
                         "piotrkow"                => 19321,
                         "pious"                   => 8650,
                         "piped"                   => 16074,
                         "pipelines"               => 10437,
                         "piping"                  => 11351,
                         "piquet"                  => 14038,
                         "piracy"                  => 7770,
                         "piraeus"                 => 13066,
                         "piran"                   => 28777,
                         "pirie"                   => 18036,
                         "pirin"                   => 26785,
                         "piscataway"              => 26005,
                         "pisgah"                  => 25412,
                         "pissarro"                => 28191,
                         "pistoia"                 => 24536,
                         "pistols"                 => 7389,
                         "pitcairn"                => 16136,
                         "pitch"                   => 2366,
                         "pitched"                 => 2802,
                         "pitcher"                 => 2938,
                         "pitches"                 => 6732,
                         "pitchfork"               => 8495,
                         "pitching"                => 4834,
                         "pitesti"                 => 27270,
                         "pits"                    => 5624,
                         "pitted"                  => 8875,
                         "pittsburg"               => 14171,
                         "pittsburgh"              => 1993,
                         "pittsfield"              => 16429,
                         "pituitary"               => 14084,
                         "pius"                    => 4958,
                         "pivot"                   => 10702,
                         "pivotal"                 => 7006,
                         "pivoting"                => 26058,
                         "pixar"                   => 13064,
                         "pixel"                   => 7858,
                         "pixels"                  => 9348,
                         "placards"                => 27152,
                         "place"                   => 153,
                         "placed"                  => 566,
                         "placeholder"             => 25431,
                         "placekicker"             => 18704,
                         "placement"               => 3830,
                         "placements"              => 12444,
                         "placename"               => 21326,
                         "placenames"              => 19824,
                         "placental"               => 20445,
                         "placentia"               => 26652,
                         "placer"                  => 14742,
                         "places"                  => 614,
                         "placido"                 => 16841,
                         "placing"                 => 2849,
                         "placings"                => 16474,
                         "plagiarism"              => 12297,
                         "plagiarized"             => 26714,
                         "plagued"                 => 6927,
                         "plaine"                  => 27149,
                         "plaines"                 => 25105,
                         "plainfield"              => 15097,
                         "plains"                  => 3103,
                         "plaintext"               => 20507,
                         "plaintiffs"              => 8130,
                         "plainview"               => 25868,
                         "plana"                   => 26483,
                         "planar"                  => 9497,
                         "planck"                  => 9020,
                         "planes"                  => 3568,
                         "planetary"               => 6382,
                         "planets"                 => 4576,
                         "planking"                => 26833,
                         "planks"                  => 14388,
                         "planktonic"              => 22354,
                         "planned"                 => 1044,
                         "planners"                => 8751,
                         "plano"                   => 14807,
                         "plant"                   => 634,
                         "plantagenet"             => 19303,
                         "plantain"                => 19800,
                         "plantar"                 => 22955,
                         "plantarum"               => 25279,
                         "plantation"              => 3600,
                         "plantations"             => 5214,
                         "planter"                 => 11450,
                         "planters"                => 10890,
                         "planting"                => 6143,
                         "plantings"               => 12785,
                         "plants"                  => 1103,
                         "plaque"                  => 4561,
                         "plaques"                 => 9550,
                         "plasmas"                 => 26896,
                         "plasmid"                 => 19174,
                         "plasmids"                => 25865,
                         "plasmodium"              => 14121,
                         "plasterwork"             => 29050,
                         "plasticity"              => 13355,
                         "plateau"                 => 3502,
                         "plateaus"                => 16208,
                         "platelet"                => 16278,
                         "platform"                => 1160,
                         "platformer"              => 26809,
                         "platforms"               => 2421,
                         "plating"                 => 13795,
                         "platoon"                 => 5439,
                         "platoons"                => 14210,
                         "platte"                  => 11045,
                         "platted"                 => 10959,
                         "plattsburgh"             => 18525,
                         "plausibility"            => 28022,
                         "plautus"                 => 29673,
                         "play"                    => 229,
                         "playable"                => 6652,
                         "playback"                => 7348,
                         "played"                  => 117,
                         "players"                 => 427,
                         "playfair"                => 21959,
                         "playfield"               => 26046,
                         "playfully"               => 24604,
                         "playgrounds"             => 12714,
                         "playhouse"               => 6517,
                         "playing"                 => 346,
                         "playlist"                => 11408,
                         "playlists"               => 19365,
                         "playmaker"               => 20131,
                         "playoff"                 => 2661,
                         "playoffs"                => 2348,
                         "plays"                   => 612,
                         "playwright"              => 4282,
                         "playwrights"             => 9915,
                         "playwriting"             => 18485,
                         "plaza"                   => 2956,
                         "plazas"                  => 15410,
                         "pleaded"                 => 6671,
                         "pleads"                  => 13128,
                         "pleas"                   => 8522,
                         "pleated"                 => 29274,
                         "plebeians"               => 28188,
                         "plebiscite"              => 11748,
                         "pledged"                 => 6362,
                         "pleiades"                => 25160,
                         "plein"                   => 20995,
                         "pleistocene"             => 8915,
                         "plenary"                 => 11664,
                         "plenipotentiary"         => 12864,
                         "plentiful"               => 10412,
                         "plenum"                  => 19945,
                         "plessis"                 => 19199,
                         "plethora"                => 14415,
                         "pleura"                  => 16462,
                         "pleural"                 => 20469,
                         "pleven"                  => 29197,
                         "plexus"                  => 16373,
                         "plical"                  => 26934,
                         "plied"                   => 24277,
                         "plinth"                  => 14465,
                         "pliny"                   => 9902,
                         "pliocene"                => 14677,
                         "plock"                   => 15155,
                         "ploiesti"                => 19765,
                         "plonsk"                  => 26196,
                         "plot"                    => 809,
                         "plotinus"                => 28689,
                         "plotline"                => 22392,
                         "plotlines"               => 29794,
                         "plots"                   => 5256,
                         "plotters"                => 18233,
                         "plough"                  => 11950,
                         "ploughed"                => 26279,
                         "ploughing"               => 20192,
                         "ploughs"                 => 23390,
                         "plovdiv"                 => 11980,
                         "plovers"                 => 23910,
                         "plugin"                  => 15869,
                         "plugins"                 => 15637,
                         "plumage"                 => 7315,
                         "plume"                   => 10538,
                         "plumes"                  => 18068,
                         "plunder"                 => 12452,
                         "plundered"               => 10986,
                         "plundering"              => 16734,
                         "plunges"                 => 25145,
                         "plunket"                 => 24724,
                         "plural"                  => 5007,
                         "pluralism"               => 14637,
                         "pluralistic"             => 24237,
                         "plurality"               => 9472,
                         "plurals"                 => 29404,
                         "plush"                   => 16833,
                         "plutarch"                => 12238,
                         "plympton"                => 23185,
                         "plywood"                 => 11011,
                         "plzen"                   => 13953,
                         "pneumatic"               => 10597,
                         "pneumoniae"              => 29831,
                         "poaceae"                 => 27247,
                         "poblacion"               => 18254,
                         "pocahontas"              => 14445,
                         "pocatello"               => 28549,
                         "pocklington"             => 27473,
                         "pocono"                  => 15295,
                         "podcast"                 => 6564,
                         "podcasting"              => 29434,
                         "podcasts"                => 12648,
                         "poddebice"               => 28829,
                         "podgorica"               => 16220,
                         "podium"                  => 6102,
                         "podiums"                 => 17611,
                         "podkarpackie"            => 23285,
                         "podlaska"                => 22086,
                         "podlaski"                => 21580,
                         "podlaskie"               => 8843,
                         "poem"                    => 1902,
                         "poems"                   => 2105,
                         "poet"                    => 1464,
                         "poetic"                  => 5097,
                         "poetical"                => 16106,
                         "poetics"                 => 15898,
                         "poetry"                  => 1340,
                         "poets"                   => 3391,
                         "pogrom"                  => 16396,
                         "pogroms"                 => 17079,
                         "pohang"                  => 26535,
                         "poignant"                => 13289,
                         "poincare"                => 12761,
                         "point"                   => 266,
                         "pointe"                  => 8563,
                         "pointed"                 => 2685,
                         "pointedly"               => 28634,
                         "points"                  => 414,
                         "poirot"                  => 12982,
                         "poitiers"                => 13768,
                         "poitou"                  => 15759,
                         "pokal"                   => 14023,
                         "poland"                  => 757,
                         "polar"                   => 4239,
                         "polarity"                => 13257,
                         "polarization"            => 9407,
                         "polarized"               => 11131,
                         "polarizing"              => 24622,
                         "polder"                  => 26388,
                         "pole"                    => 2503,
                         "polemic"                 => 17237,
                         "polemical"               => 18368,
                         "polemics"                => 22777,
                         "poles"                   => 3703,
                         "policies"                => 1897,
                         "policing"                => 7400,
                         "policy"                  => 662,
                         "policymakers"            => 15692,
                         "polio"                   => 11580,
                         "polis"                   => 18153,
                         "polisario"               => 20384,
                         "polish"                  => 955,
                         "polistes"                => 25529,
                         "politburo"               => 10111,
                         "political"               => 265,
                         "politically"             => 3552,
                         "politician"              => 852,
                         "politicians"             => 3084,
                         "politicized"             => 23891,
                         "politico"                => 16426,
                         "politics"                => 999,
                         "polities"                => 24529,
                         "politiques"              => 23972,
                         "polity"                  => 13316,
                         "polje"                   => 17181,
                         "poll"                    => 2854,
                         "polled"                  => 9143,
                         "pollen"                  => 6207,
                         "pollinated"              => 16878,
                         "pollinates"              => 17774,
                         "pollination"             => 13414,
                         "pollinators"             => 19300,
                         "pollutant"               => 20439,
                         "pollutants"              => 10939,
                         "pollution"               => 3814,
                         "polonia"                 => 14719,
                         "polonium"                => 25371,
                         "polotsk"                 => 26387,
                         "polski"                  => 21975,
                         "polybius"                => 21242,
                         "polycarbonate"           => 27038,
                         "polychrome"              => 18044,
                         "polycyclic"              => 29750,
                         "polydor"                 => 12624,
                         "polyethylene"            => 15137,
                         "polygamous"              => 23122,
                         "polygamy"                => 12630,
                         "polyglot"                => 24362,
                         "polygon"                 => 10496,
                         "polygonal"               => 14108,
                         "polygons"                => 15202,
                         "polygram"                => 16302,
                         "polyhedra"               => 15553,
                         "polyhedral"              => 27109,
                         "polyhedron"              => 15409,
                         "polymath"                => 21481,
                         "polymer"                 => 6356,
                         "polymerase"              => 10915,
                         "polymeric"               => 21914,
                         "polymerization"          => 12417,
                         "polymers"                => 8853,
                         "polymorphic"             => 22969,
                         "polymorphism"            => 16786,
                         "polymorphisms"           => 22807,
                         "polynesia"               => 11059,
                         "polynesian"              => 10300,
                         "polynomial"              => 6009,
                         "polynomials"             => 8636,
                         "polypeptide"             => 19028,
                         "polyphonic"              => 14839,
                         "polyphony"               => 17612,
                         "polyphyletic"            => 27856,
                         "polypropylene"           => 22554,
                         "polysaccharides"         => 28932,
                         "polystyrene"             => 21115,
                         "polytechnic"             => 5243,
                         "polytechnical"           => 29424,
                         "polytechnique"           => 16999,
                         "polytope"                => 16201,
                         "polytopes"               => 17552,
                         "polyurethane"            => 18664,
                         "polyvinyl"               => 27078,
                         "pomerania"               => 5610,
                         "pomeranian"              => 4466,
                         "pomfret"                 => 29463,
                         "pommel"                  => 23289,
                         "pomona"                  => 11448,
                         "pompadour"               => 29601,
                         "pompeii"                 => 15743,
                         "pompeius"                => 24186,
                         "pompeo"                  => 25642,
                         "pompidou"                => 16810,
                         "ponca"                   => 24260,
                         "ponderosa"               => 17109,
                         "ponders"                 => 27781,
                         "pondicherry"             => 14658,
                         "ponds"                   => 5913,
                         "poniatowski"             => 21233,
                         "ponsonby"                => 16914,
                         "ponta"                   => 15676,
                         "pontchartrain"           => 22019,
                         "pontefract"              => 18309,
                         "pontevedra"              => 25312,
                         "pontic"                  => 18926,
                         "pontifex"                => 29309,
                         "pontifical"              => 7553,
                         "pontificate"             => 19500,
                         "ponting"                 => 17017,
                         "pontoons"                => 26403,
                         "pontus"                  => 14565,
                         "ponty"                   => 25385,
                         "pontypool"               => 22224,
                         "pontypridd"              => 18865,
                         "pooja"                   => 12096,
                         "pooled"                  => 18833,
                         "pools"                   => 5110,
                         "poona"                   => 22623,
                         "poorest"                 => 9862,
                         "poorly"                  => 3707,
                         "pop/rock"                => 17271,
                         "popes"                   => 10455,
                         "popish"                  => 29484,
                         "popmatters"              => 13080,
                         "popstars"                => 24089,
                         "populace"                => 6647,
                         "populaire"               => 25135,
                         "popular"                 => 336,
                         "popularised"             => 14180,
                         "popularity"              => 1769,
                         "popularization"          => 19227,
                         "popularize"              => 15423,
                         "popularized"             => 6686,
                         "popularizing"            => 16510,
                         "popularly"               => 5335,
                         "populate"                => 17624,
                         "populated"               => 3604,
                         "population"              => 135,
                         "populations"             => 2278,
                         "populism"                => 24020,
                         "populist"                => 9774,
                         "populous"                => 6802,
                         "populus"                 => 20348,
                         "porcelain"               => 7790,
                         "porches"                 => 15221,
                         "porgy"                   => 21927,
                         "pornography"             => 6542,
                         "poroshenko"              => 29844,
                         "porosity"                => 19802,
                         "porous"                  => 11725,
                         "porphyry"                => 19992,
                         "porpoises"               => 26174,
                         "port"                    => 714,
                         "porta"                   => 10763,
                         "portability"             => 16442,
                         "portable"                => 4559,
                         "portadown"               => 20355,
                         "portage"                 => 8177,
                         "porte"                   => 9594,
                         "ported"                  => 8804,
                         "porters"                 => 16045,
                         "portfolio"               => 3968,
                         "portfolios"              => 10273,
                         "portico"                 => 8462,
                         "porting"                 => 20730,
                         "portion"                 => 1300,
                         "portions"                => 2950,
                         "portmanteau"             => 12911,
                         "porto"                   => 5127,
                         "portobello"              => 23033,
                         "portola"                 => 23381,
                         "portrait"                => 2467,
                         "portraitist"             => 24984,
                         "portraits"               => 3622,
                         "portraiture"             => 14162,
                         "portray"                 => 6274,
                         "portrayal"               => 4747,
                         "portrayals"              => 11427,
                         "portrayed"               => 2203,
                         "portraying"              => 6266,
                         "portrays"                => 6498,
                         "ports"                   => 2999,
                         "portsmouth"              => 3804,
                         "portuguesa"              => 18526,
                         "portuguese"              => 1533,
                         "posed"                   => 5445,
                         "posht"                   => 20531,
                         "posit"                   => 25071,
                         "posited"                 => 14824,
                         "position"                => 343,
                         "positional"              => 14993,
                         "positioned"              => 4893,
                         "positioning"             => 7448,
                         "positions"               => 1179,
                         "positive"                => 1017,
                         "positivism"              => 19326,
                         "positivist"              => 25626,
                         "positivity"              => 26523,
                         "positron"                => 18094,
                         "posits"                  => 14228,
                         "posix"                   => 23074,
                         "possess"                 => 4276,
                         "possesses"               => 5470,
                         "possessing"              => 7118,
                         "possession"              => 2333,
                         "possessions"             => 5184,
                         "possessor"               => 18901,
                         "possums"                 => 29069,
                         "post"                    => 349,
                         "postage"                 => 7144,
                         "postbellum"              => 27621,
                         "postcode"                => 13074,
                         "postcolonial"            => 23339,
                         "postdoctoral"            => 10352,
                         "poste"                   => 29359,
                         "posted"                  => 2309,
                         "posterior"               => 5207,
                         "posteriorly"             => 16102,
                         "postgraduate"            => 5477,
                         "posthumous"              => 6818,
                         "posthumously"            => 4718,
                         "posting"                 => 5404,
                         "postings"                => 14212,
                         "postmaster"              => 7445,
                         "postmedial"              => 21364,
                         "postmodern"              => 11359,
                         "postmodernism"           => 18751,
                         "posts"                   => 3089,
                         "postscript"              => 16476,
                         "postseason"              => 6004,
                         "postsecondary"           => 23245,
                         "postsynaptic"            => 21514,
                         "postulate"               => 17707,
                         "postulated"              => 11294,
                         "postulates"              => 17317,
                         "postures"                => 21780,
                         "postwar"                 => 6178,
                         "potable"                 => 14796,
                         "potash"                  => 17901,
                         "potassium"               => 6306,
                         "potawatomi"              => 16597,
                         "potemkin"                => 23446,
                         "potency"                 => 13783,
                         "potent"                  => 7449,
                         "potential"               => 1069,
                         "potentially"             => 3458,
                         "potentials"              => 10426,
                         "potez"                   => 29267,
                         "potok"                   => 20546,
                         "potomac"                 => 6389,
                         "potosi"                  => 11793,
                         "potrero"                 => 26708,
                         "potro"                   => 26014,
                         "potsdam"                 => 8234,
                         "potteries"               => 19894,
                         "potters"                 => 12835,
                         "pottery"                 => 4057,
                         "pottsville"              => 21556,
                         "pouches"                 => 19250,
                         "poulenc"                 => 21273,
                         "poultry"                 => 7693,
                         "pounder"                 => 7201,
                         "poverty"                 => 1610,
                         "povoa"                   => 19851,
                         "powdery"                 => 22535,
                         "power"                   => 239,
                         "powerball"               => 28112,
                         "powerbook"               => 28736,
                         "powered"                 => 2028,
                         "powerfully"              => 16477,
                         "powerhouse"              => 8199,
                         "powerhouses"             => 29588,
                         "powering"                => 15643,
                         "powerlifting"            => 15614,
                         "powerline"               => 29996,
                         "powerplant"              => 14276,
                         "powerplants"             => 27899,
                         "powerpoint"              => 24463,
                         "powertrain"              => 16930,
                         "powhatan"                => 16857,
                         "powiat"                  => 28705,
                         "powys"                   => 11473,
                         "poznan"                  => 6296,
                         "prabang"                 => 26990,
                         "prabhakar"               => 23585,
                         "prabhu"                  => 14252,
                         "praca"                   => 28486,
                         "practicable"             => 18944,
                         "practical"               => 2350,
                         "practice"                => 647,
                         "practiced"               => 3414,
                         "practices"               => 1918,
                         "practise"                => 10474,
                         "practised"               => 6966,
                         "practises"               => 25904,
                         "practitioner"            => 6843,
                         "practitioners"           => 5002,
                         "pradesh"                 => 2695,
                         "praetor"                 => 19745,
                         "praetorian"              => 16813,
                         "praga"                   => 25226,
                         "pragmatic"               => 10482,
                         "pragmatism"              => 19520,
                         "prague"                  => 3118,
                         "praha"                   => 21360,
                         "prahran"                 => 26235,
                         "praia"                   => 16564,
                         "prairie"                 => 3928,
                         "prairies"                => 13162,
                         "praise"                  => 3253,
                         "praised"                 => 1953,
                         "praising"                => 6126,
                         "prakrit"                 => 24322,
                         "prasanna"                => 27046,
                         "pratap"                  => 13738,
                         "pratchett"               => 21266,
                         "prawn"                   => 20945,
                         "prawns"                  => 24458,
                         "preached"                => 7473,
                         "preachers"               => 10187,
                         "preah"                   => 29671,
                         "preakness"               => 14249,
                         "preamble"                => 13341,
                         "prebend"                 => 24243,
                         "prebendary"              => 20457,
                         "precambrian"             => 17732,
                         "precast"                 => 26562,
                         "precede"                 => 14735,
                         "preceded"                => 4197,
                         "precedence"              => 8121,
                         "precedent"               => 7039,
                         "preceding"               => 3856,
                         "precept"                 => 20646,
                         "preceptor"               => 25826,
                         "precepts"                => 14538,
                         "precession"              => 18108,
                         "precincts"               => 13036,
                         "precipitate"             => 16015,
                         "precipitated"            => 11488,
                         "precipitates"            => 29744,
                         "precipitating"           => 21756,
                         "precipitation"           => 4701,
                         "precipitous"             => 23072,
                         "precise"                 => 4209,
                         "precision"               => 4644,
                         "preclassic"              => 25380,
                         "preclinical"             => 27859,
                         "preclude"                => 17016,
                         "precluded"               => 15866,
                         "precondition"            => 25479,
                         "precursor"               => 5146,
                         "precursors"              => 10312,
                         "predate"                 => 16894,
                         "predated"                => 15607,
                         "predates"                => 12643,
                         "predating"               => 17219,
                         "predation"               => 9761,
                         "predators"               => 4640,
                         "predatory"               => 8883,
                         "predeceased"             => 13622,
                         "predecessor"             => 2914,
                         "predecessors"            => 5598,
                         "predefined"              => 19038,
                         "predestination"          => 22637,
                         "predetermined"           => 12414,
                         "predicate"               => 11975,
                         "predicated"              => 22818,
                         "predicates"              => 20432,
                         "predictability"          => 24754,
                         "predictably"             => 21609,
                         "predicted"               => 3821,
                         "predicting"              => 10094,
                         "prediction"              => 6443,
                         "predictions"             => 7193,
                         "predictive"              => 11129,
                         "predictor"               => 16230,
                         "predictors"              => 25334,
                         "predicts"                => 11001,
                         "predilection"            => 28627,
                         "predominance"            => 18458,
                         "predominant"             => 6867,
                         "predominantly"           => 3130,
                         "predominate"             => 16577,
                         "predominated"            => 23065,
                         "predominately"           => 11759,
                         "predominates"            => 24941,
                         "predrag"                 => 25178,
                         "preeminent"              => 14299,
                         "preempted"               => 23965,
                         "preemption"              => 29126,
                         "preexisting"             => 20577,
                         "prefabricated"           => 15206,
                         "preface"                 => 7420,
                         "prefaced"                => 25668,
                         "prefaces"                => 29456,
                         "prefect"                 => 7097,
                         "prefects"                => 15431,
                         "prefectural"             => 10842,
                         "prefecture"              => 2521,
                         "prefectures"             => 11716,
                         "preference"              => 4492,
                         "preferences"             => 6910,
                         "preferential"            => 11905,
                         "preferentially"          => 17034,
                         "preferred"               => 2651,
                         "preferring"              => 7701,
                         "prefix"                  => 6019,
                         "prefixed"                => 14474,
                         "prefixes"                => 11155,
                         "prefontaine"             => 29903,
                         "prefrontal"              => 16405,
                         "pregame"                 => 16688,
                         "prehistoric"             => 5006,
                         "prehistory"              => 10602,
                         "prekmurje"               => 29605,
                         "prelate"                 => 10995,
                         "prelates"                => 18828,
                         "prelature"               => 26923,
                         "preliminaries"           => 16973,
                         "preliminary"             => 3133,
                         "prelims"                 => 26957,
                         "preludes"                => 18168,
                         "prema"                   => 24856,
                         "premier"                 => 1123,
                         "premiere"                => 2324,
                         "premiered"               => 1963,
                         "premieres"               => 9537,
                         "premiering"              => 15569,
                         "premiers"                => 9859,
                         "premiership"             => 3915,
                         "premierships"            => 12612,
                         "preminger"               => 26079,
                         "premio"                  => 10612,
                         "premios"                 => 19231,
                         "premise"                 => 5691,
                         "premises"                => 3808,
                         "premiums"                => 13483,
                         "prensa"                  => 27989,
                         "prepaid"                 => 16490,
                         "preparation"             => 2523,
                         "preparations"            => 4668,
                         "preparatory"             => 4575,
                         "preparedness"            => 11902,
                         "prepares"                => 7243,
                         "preponderance"           => 22486,
                         "prepositions"            => 20074,
                         "prequel"                 => 9825,
                         "prerequisite"            => 13402,
                         "prerequisites"           => 21558,
                         "prerogatives"            => 22087,
                         "presbyter"               => 29172,
                         "presbyterian"            => 3397,
                         "presbyterianism"         => 29924,
                         "presbyterians"           => 14593,
                         "presbyteries"            => 28488,
                         "presbytery"              => 10872,
                         "prescot"                 => 25670,
                         "prescriptive"            => 22158,
                         "preseason"               => 6655,
                         "preselection"            => 22830,
                         "presence"                => 1141,
                         "present"                 => 308,
                         "presentation"            => 2998,
                         "presentations"           => 6193,
                         "presented"               => 822,
                         "presenter"               => 3811,
                         "presenters"              => 7691,
                         "presenting"              => 3917,
                         "presently"               => 4678,
                         "preservation"            => 2767,
                         "preservationists"        => 27431,
                         "preservative"            => 21801,
                         "preserve"                => 2804,
                         "preserved"               => 2155,
                         "preserves"               => 6252,
                         "preserving"              => 5510,
                         "preside"                 => 14392,
                         "presided"                => 5461,
                         "presidencies"            => 28377,
                         "presidency"              => 2927,
                         "president"               => 193,
                         "presidential"            => 1411,
                         "presidents"              => 3677,
                         "presides"                => 16418,
                         "presiding"               => 6349,
                         "presidio"                => 12937,
                         "presidium"               => 12866,
                         "presov"                  => 16958,
                         "presque"                 => 21707,
                         "press"                   => 654,
                         "pressburg"               => 24507,
                         "presse"                  => 16344,
                         "pressings"               => 15103,
                         "pressures"               => 5472,
                         "pressurised"             => 25968,
                         "pressurized"             => 12239,
                         "prestige"                => 5628,
                         "prestigious"             => 2862,
                         "prestwick"               => 24936,
                         "presumably"              => 4078,
                         "presumed"                => 5542,
                         "presumption"             => 13797,
                         "presumptive"             => 14619,
                         "presynaptic"             => 26045,
                         "preta"                   => 29170,
                         "pretence"                => 28699,
                         "pretender"               => 12638,
                         "pretenders"              => 17716,
                         "pretensions"             => 21269,
                         "pretext"                 => 10592,
                         "preto"                   => 20088,
                         "pretoria"                => 8791,
                         "prevailed"               => 6941,
                         "prevailing"              => 6619,
                         "prevalence"              => 6783,
                         "prevalent"               => 4978,
                         "prevent"                 => 1383,
                         "preventable"             => 23359,
                         "prevented"               => 3136,
                         "preventing"              => 4012,
                         "prevention"              => 3457,
                         "preventive"              => 10029,
                         "prevents"                => 5937,
                         "previewed"               => 16513,
                         "previn"                  => 27142,
                         "previous"                => 534,
                         "previously"              => 578,
                         "prewar"                  => 16723,
                         "prey"                    => 3522,
                         "priam"                   => 27112,
                         "pribram"                 => 28335,
                         "prices"                  => 2507,
                         "pricewaterhousecoopers"  => 27320,
                         "pricing"                 => 7031,
                         "priestesses"             => 29645,
                         "priesthood"              => 6027,
                         "priests"                 => 3198,
                         "prieta"                  => 26610,
                         "primacy"                 => 12551,
                         "primaries"               => 9041,
                         "primarily"               => 879,
                         "primary"                 => 543,
                         "primate"                 => 8924,
                         "primates"                => 9221,
                         "prime"                   => 800,
                         "primeira"                => 15246,
                         "primera"                 => 5854,
                         "primers"                 => 21468,
                         "primes"                  => 11068,
                         "primetime"               => 6432,
                         "primeval"                => 19122,
                         "priming"                 => 18597,
                         "primitive"               => 4188,
                         "primitives"              => 18656,
                         "primogeniture"           => 18222,
                         "primorsky"               => 25705,
                         "princely"                => 7494,
                         "princeps"                => 22007,
                         "princeton"               => 3444,
                         "principal"               => 1086,
                         "principalities"          => 12367,
                         "principality"            => 6064,
                         "principally"             => 5508,
                         "principals"              => 8428,
                         "principia"               => 21814,
                         "principle"               => 2223,
                         "principles"              => 2057,
                         "printed"                 => 2117,
                         "printers"                => 7947,
                         "printing"                => 2769,
                         "printings"               => 18416,
                         "printmaker"              => 17404,
                         "printmaking"             => 14101,
                         "prion"                   => 25776,
                         "prior"                   => 590,
                         "prioress"                => 27913,
                         "priori"                  => 16194,
                         "prioritized"             => 22478,
                         "priory"                  => 4789,
                         "priscus"                 => 27469,
                         "prism"                   => 8870,
                         "prismatic"               => 20785,
                         "prisms"                  => 18810,
                         "prisoners"               => 1970,
                         "prisons"                 => 5893,
                         "pristimantis"            => 20900,
                         "pristina"                => 13123,
                         "pritam"                  => 28667,
                         "prithvi"                 => 20809,
                         "prithviraj"              => 22097,
                         "pritzker"                => 19978,
                         "prius"                   => 17885,
                         "privateer"               => 9169,
                         "privateering"            => 25964,
                         "privateers"              => 12270,
                         "privately"               => 3240,
                         "privatisation"           => 11369,
                         "privatised"              => 18128,
                         "privatization"           => 8183,
                         "privatized"              => 15674,
                         "privy"                   => 5359,
                         "prix"                    => 1785,
                         "priya"                   => 11971,
                         "prize"                   => 885,
                         "prized"                  => 9504,
                         "prizes"                  => 3870,
                         "prizren"                 => 18565,
                         "pro12"                   => 27438,
                         "probabilistic"           => 14163,
                         "probabilities"           => 10994,
                         "probability"             => 3447,
                         "probable"                => 5868,
                         "problematic"             => 6581,
                         "proboscis"               => 22859,
                         "procedural"              => 7841,
                         "procedures"              => 3129,
                         "proceeded"               => 3469,
                         "proceedings"             => 3656,
                         "proceeds"                => 3829,
                         "process"                 => 437,
                         "processed"               => 5340,
                         "processes"               => 2002,
                         "processing"              => 2088,
                         "procession"              => 5541,
                         "processions"             => 12200,
                         "processor"               => 4699,
                         "processors"              => 6195,
                         "proclaimed"              => 3730,
                         "proclaiming"             => 10891,
                         "proclaims"               => 14745,
                         "proclamation"            => 5927,
                         "proconsul"               => 24790,
                         "procopius"               => 20404,
                         "procurator"              => 19067,
                         "procured"                => 10874,
                         "procurement"             => 7786,
                         "procuring"               => 17895,
                         "prodi"                   => 24415,
                         "prodigious"              => 16620,
                         "produce"                 => 931,
                         "produced"                => 277,
                         "producer"                => 838,
                         "producers"               => 2121,
                         "produces"                => 2270,
                         "producing"               => 1448,
                         "product"                 => 966,
                         "production"              => 263,
                         "productions"             => 1608,
                         "productivity"            => 5620,
                         "products"                => 754,
                         "prof."                   => 5459,
                         "profane"                 => 16866,
                         "profesional"             => 22728,
                         "professed"               => 10785,
                         "professes"               => 23031,
                         "professing"              => 22892,
                         "profession"              => 3474,
                         "professional"            => 311,
                         "professionally"          => 4464,
                         "professionals"           => 2761,
                         "professionnelle"         => 24814,
                         "professions"             => 7709,
                         "professor"               => 565,
                         "professorial"            => 19641,
                         "professors"              => 4596,
                         "professorship"           => 7822,
                         "professorships"          => 18457,
                         "proficiency"             => 8768,
                         "proficient"              => 9120,
                         "profile"                 => 2142,
                         "profiled"                => 10639,
                         "profiler"                => 27933,
                         "profiles"                => 6497,
                         "profiling"               => 11941,
                         "profit"                  => 1696,
                         "profitability"           => 10694,
                         "profitable"              => 5489,
                         "profitably"              => 26212,
                         "profited"                => 18151,
                         "profiting"               => 25374,
                         "profits"                 => 4095,
                         "profusion"               => 23869,
                         "progenitor"              => 12423,
                         "progenitors"             => 22204,
                         "progeny"                 => 10782,
                         "progesterone"            => 18668,
                         "program"                 => 279,
                         "programing"              => 16931,
                         "programmable"            => 12394,
                         "programmatic"            => 19215,
                         "programme"               => 1259,
                         "programmer"              => 7353,
                         "programmers"             => 9030,
                         "programmes"              => 2644,
                         "programming"             => 1366,
                         "programs"                => 624,
                         "progreso"                => 27371,
                         "progress"                => 1718,
                         "progressed"              => 4603,
                         "progresses"              => 7676,
                         "progression"             => 5200,
                         "progressions"            => 20166,
                         "progressive"             => 2042,
                         "progressively"           => 7094,
                         "progressives"            => 14691,
                         "prohibit"                => 7860,
                         "prohibited"              => 3868,
                         "prohibiting"             => 8721,
                         "prohibition"             => 4815,
                         "prohibitions"            => 14437,
                         "prohibitive"             => 18665,
                         "prohibitively"           => 26720,
                         "prohibits"               => 8483,
                         "project"                 => 331,
                         "projected"               => 4327,
                         "projectile"              => 9149,
                         "projectiles"             => 11372,
                         "projecting"              => 7320,
                         "projection"              => 5302,
                         "projective"              => 8813,
                         "projectors"              => 12826,
                         "projects"                => 864,
                         "projekt"                 => 27618,
                         "prokaryotes"             => 22527,
                         "prokaryotic"             => 22707,
                         "prokofiev"               => 14422,
                         "prolactin"               => 29319,
                         "proletarian"             => 14199,
                         "proletariat"             => 15765,
                         "proliferate"             => 25268,
                         "proliferated"            => 22888,
                         "proliferation"           => 6975,
                         "prolific"                => 4223,
                         "prolifically"            => 24711,
                         "prologue"                => 8833,
                         "prolongation"            => 29112,
                         "prolonged"               => 5796,
                         "prome"                   => 29229,
                         "promenade"               => 9607,
                         "prometheus"              => 11913,
                         "prominence"              => 3959,
                         "prominent"               => 956,
                         "prominently"             => 5081,
                         "promiscuity"             => 23204,
                         "promissory"              => 26277,
                         "promo"                   => 8082,
                         "promontory"              => 11805,
                         "promote"                 => 1581,
                         "promoted"                => 934,
                         "promoter"                => 5623,
                         "promoters"               => 8594,
                         "promotes"                => 4861,
                         "promoting"               => 2551,
                         "promotion"               => 1262,
                         "promotion/relegation"    => 24293,
                         "promotional"             => 3653,
                         "promotions"              => 5117,
                         "prompted"                => 3614,
                         "prompting"               => 5950,
                         "promptly"                => 5884,
                         "prompts"                 => 14126,
                         "promulgated"             => 9164,
                         "promulgation"            => 19455,
                         "prone"                   => 5239,
                         "pronged"                 => 18476,
                         "pronominal"              => 28128,
                         "pronotum"                => 26587,
                         "pronoun"                 => 10355,
                         "pronounced"              => 3147,
                         "pronouncements"          => 23457,
                         "pronouns"                => 8157,
                         "pronunciation"           => 5666,
                         "pronunciations"          => 17555,
                         "proofs"                  => 9900,
                         "propaganda"              => 3720,
                         "propagandist"            => 24517,
                         "propagate"               => 11576,
                         "propagated"              => 11255,
                         "propagates"              => 23992,
                         "propagating"             => 14449,
                         "propagation"             => 6825,
                         "propel"                  => 12058,
                         "propellant"              => 9874,
                         "propellants"             => 21964,
                         "propelled"               => 6416,
                         "propeller"               => 5842,
                         "propellers"              => 9648,
                         "propelling"              => 18869,
                         "properties"              => 1304,
                         "property"                => 635,
                         "prophetic"               => 12255,
                         "prophets"                => 8608,
                         "prophylaxis"             => 27706,
                         "propodeum"               => 17735,
                         "proponent"               => 7395,
                         "proponents"              => 6474,
                         "proportion"              => 3837,
                         "proportional"            => 4971,
                         "proportionality"         => 19024,
                         "proportionally"          => 16632,
                         "proportionate"           => 21403,
                         "proportionately"         => 23944,
                         "proportions"             => 7341,
                         "proposal"                => 2119,
                         "proposals"               => 3520,
                         "proposed"                => 882,
                         "proposes"                => 6074,
                         "propositional"           => 17922,
                         "propositions"            => 10889,
                         "propounded"              => 25444,
                         "proprietary"             => 5535,
                         "proprietor"              => 8119,
                         "proprietors"             => 11858,
                         "propulsion"              => 5605,
                         "propulsive"              => 28477,
                         "propylene"               => 27154,
                         "proscenium"              => 20930,
                         "proscribed"              => 20386,
                         "prose"                   => 4642,
                         "prosecutions"            => 10525,
                         "prosecutor"              => 4962,
                         "prosecutors"             => 6936,
                         "proselytizing"           => 26053,
                         "prosody"                 => 24001,
                         "prospect"                => 4116,
                         "prospecting"             => 16863,
                         "prospective"             => 6345,
                         "prospector"              => 16679,
                         "prospectors"             => 16284,
                         "prospekt"                => 29890,
                         "prospered"               => 10103,
                         "prosperity"              => 5115,
                         "prosperous"              => 6450,
                         "prostate"                => 8434,
                         "prosthesis"              => 22136,
                         "prosthetics"             => 23970,
                         "prostitutes"             => 7771,
                         "prostitution"            => 5495,
                         "prostrate"               => 20559,
                         "protagonist"             => 3865,
                         "protagonists"            => 7579,
                         "proteaceae"              => 29261,
                         "protease"                => 14718,
                         "proteases"               => 20727,
                         "proteasome"              => 20323,
                         "protected"               => 1881,
                         "protection"              => 1070,
                         "protectionism"           => 23566,
                         "protectionist"           => 19198,
                         "protections"             => 9919,
                         "protectorate"            => 7292,
                         "protege"                 => 9302,
                         "proteges"                => 25088,
                         "protein"                 => 1606,
                         "proteins"                => 2877,
                         "proteolytic"             => 23848,
                         "proteomics"              => 27065,
                         "protest"                 => 2383,
                         "protestant"              => 2710,
                         "protestantism"           => 10122,
                         "protestants"             => 6463,
                         "protested"               => 5905,
                         "protester"               => 21146,
                         "protesters"              => 4652,
                         "protests"                => 2740,
                         "proto"                   => 5476,
                         "protocol"                => 3104,
                         "protocols"               => 5979,
                         "protons"                 => 11589,
                         "prototype"               => 3122,
                         "prototypes"              => 6745,
                         "prototypical"            => 21189,
                         "prototyping"             => 19296,
                         "protour"                 => 23778,
                         "protracted"              => 10430,
                         "protrude"                => 21908,
                         "protrudes"               => 26078,
                         "protruding"              => 11489,
                         "protrusion"              => 26687,
                         "proudhon"                => 24332,
                         "provable"                => 29828,
                         "proved"                  => 1457,
                         "provence"                => 7274,
                         "provide"                 => 541,
                         "provided"                => 506,
                         "providence"              => 4149,
                         "provident"               => 17962,
                         "provider"                => 3787,
                         "providers"               => 3950,
                         "provides"                => 753,
                         "providing"               => 1136,
                         "province"                => 380,
                         "provinces"               => 2161,
                         "provincetown"            => 17976,
                         "provincia"               => 24314,
                         "provincial"              => 1372,
                         "provincially"            => 20307,
                         "provision"               => 3292,
                         "provisional"             => 4017,
                         "provisionally"           => 15526,
                         "provisioning"            => 17658,
                         "provisions"              => 3095,
                         "proviso"                 => 19395,
                         "provokes"                => 23029,
                         "prowess"                 => 9444,
                         "proxies"                 => 21512,
                         "proximal"                => 12570,
                         "proximate"               => 23454,
                         "proximity"               => 3715,
                         "prudential"              => 14132,
                         "prunus"                  => 15654,
                         "prussia"                 => 3548,
                         "prussian"                => 3704,
                         "prussians"               => 13719,
                         "przemysl"                => 16406,
                         "ps1,000"                 => 15093,
                         "ps1.5"                   => 28385,
                         "ps10,000"                => 13083,
                         "ps100"                   => 12395,
                         "ps100,000"               => 14190,
                         "ps1000"                  => 21929,
                         "ps15,000"                => 23417,
                         "ps150"                   => 27569,
                         "ps150,000"               => 25168,
                         "ps2,000"                 => 19437,
                         "ps20,000"                => 16634,
                         "ps200"                   => 16322,
                         "ps200,000"               => 21075,
                         "ps25,000"                => 20056,
                         "ps250"                   => 26616,
                         "ps250,000"               => 20298,
                         "ps3,000"                 => 22461,
                         "ps30,000"                => 19319,
                         "ps300"                   => 19982,
                         "ps300,000"               => 23701,
                         "ps4,000"                 => 27537,
                         "ps40,000"                => 23997,
                         "ps400"                   => 25549,
                         "ps5,000"                 => 16934,
                         "ps50,000"                => 16458,
                         "ps500"                   => 14606,
                         "ps500,000"               => 18298,
                         "ps60,000"                => 28455,
                         "psalm"                   => 9428,
                         "psalter"                 => 16567,
                         "psers"                   => 21880,
                         "pseudo"                  => 6688,
                         "pseudomonas"             => 18277,
                         "pseudonym"               => 4926,
                         "pseudonymous"            => 28080,
                         "pseudonyms"              => 11978,
                         "pseudoscience"           => 22580,
                         "psilocybe"               => 20872,
                         "psilocybin"              => 23565,
                         "psionic"                 => 21317,
                         "pskov"                   => 13850,
                         "psoriasis"               => 22690,
                         "pssas"                   => 17131,
                         "psychedelia"             => 21032,
                         "psychedelic"             => 6466,
                         "psychical"               => 22933,
                         "psychoactive"            => 18449,
                         "psychoanalysis"          => 10681,
                         "psychoanalyst"           => 17667,
                         "psychoanalytic"          => 13187,
                         "psychological"           => 2985,
                         "psychologists"           => 8248,
                         "psychology"              => 2365,
                         "psychometric"            => 29103,
                         "psychopathology"         => 23411,
                         "psychopathy"             => 29314,
                         "psychosocial"            => 19043,
                         "psychotherapy"           => 10043,
                         "psychotropic"            => 27263,
                         "pterophoridae"           => 19694,
                         "pterosaur"               => 26370,
                         "pterosaurs"              => 25963,
                         "pterostichinae"          => 22147,
                         "ptolemaic"               => 16368,
                         "ptolemy"                 => 7872,
                         "pubescens"               => 27681,
                         "public"                  => 146,
                         "publica"                 => 21379,
                         "publican"                => 23915,
                         "publication"             => 1243,
                         "publications"            => 1474,
                         "publicise"               => 28977,
                         "publicised"              => 13996,
                         "publicize"               => 17281,
                         "publicized"              => 8007,
                         "publicizing"             => 26643,
                         "publicly"                => 2416,
                         "publish"                 => 3563,
                         "published"               => 208,
                         "publisher"               => 2290,
                         "publishers"              => 3373,
                         "publishes"               => 4156,
                         "publishing"              => 1431,
                         "publius"                 => 14298,
                         "pubmed"                  => 29428,
                         "pudong"                  => 27058,
                         "puducherry"              => 19295,
                         "pudukkottai"             => 24843,
                         "puebla"                  => 9007,
                         "pueblo"                  => 6548,
                         "pueblos"                 => 21084,
                         "puerto"                  => 1813,
                         "puget"                   => 8789,
                         "pugin"                   => 21224,
                         "pulau"                   => 17397,
                         "pulawy"                  => 28094,
                         "pulitzer"                => 6458,
                         "pulleys"                 => 25367,
                         "pulmonary"               => 7611,
                         "pulmonate"               => 11990,
                         "pulpit"                  => 8309,
                         "pulsars"                 => 29662,
                         "pulsed"                  => 17250,
                         "pulses"                  => 9240,
                         "pulteney"                => 27374,
                         "pultusk"                 => 28639,
                         "pumas"                   => 16631,
                         "punctuated"              => 13491,
                         "punctuation"             => 13058,
                         "pundit"                  => 15491,
                         "pundits"                 => 14853,
                         "punic"                   => 13261,
                         "punishments"             => 10460,
                         "punitive"                => 10501,
                         "punjab"                  => 3392,
                         "punjabi"                 => 6493,
                         "punjabis"                => 21448,
                         "punk"                    => 2374,
                         "punta"                   => 9228,
                         "punted"                  => 21290,
                         "punting"                 => 20112,
                         "puntland"                => 16724,
                         "punts"                   => 13811,
                         "pupae"                   => 22831,
                         "pupal"                   => 27973,
                         "pupation"                => 17821,
                         "pupil"                   => 3871,
                         "pupils"                  => 2545,
                         "puppeteers"              => 27539,
                         "puppetry"                => 18586,
                         "purana"                  => 10502,
                         "puranas"                 => 18176,
                         "purbeck"                 => 23704,
                         "purchase"                => 1700,
                         "purchased"               => 1063,
                         "purchaser"               => 13946,
                         "purchasers"              => 15458,
                         "purchases"               => 6605,
                         "purchasing"              => 4693,
                         "purebred"                => 20400,
                         "purefoods"               => 21059,
                         "purge"                   => 9161,
                         "purged"                  => 14665,
                         "purges"                  => 16801,
                         "purification"            => 9284,
                         "purified"                => 12251,
                         "purify"                  => 17632,
                         "purifying"               => 24183,
                         "purim"                   => 27997,
                         "purine"                  => 27316,
                         "purists"                 => 26852,
                         "puritan"                 => 9983,
                         "puritans"                => 14973,
                         "purley"                  => 28290,
                         "purnima"                 => 26595,
                         "purplish"                => 13307,
                         "purported"               => 8824,
                         "purportedly"             => 10900,
                         "purporting"              => 21939,
                         "purports"                => 20395,
                         "purpose"                 => 1041,
                         "purposed"                => 27102,
                         "purposeful"              => 19817,
                         "purposes"                => 1765,
                         "purpurea"                => 28986,
                         "pursuant"                => 8998,
                         "pursue"                  => 2525,
                         "pursued"                 => 3427,
                         "pursuers"                => 19348,
                         "pursues"                 => 11025,
                         "pursuing"                => 4480,
                         "pursuit"                 => 3487,
                         "pursuits"                => 7685,
                         "purulia"                 => 27912,
                         "pushcart"                => 27668,
                         "putative"                => 13758,
                         "putin"                   => 8075,
                         "putouts"                 => 27760,
                         "putra"                   => 20847,
                         "putsch"                  => 18765,
                         "pyaar"                   => 24084,
                         "pygmy"                   => 11562,
                         "pylon"                   => 16100,
                         "pylons"                  => 15383,
                         "pyongyang"               => 12860,
                         "pyotr"                   => 12391,
                         "pyramidal"               => 12026,
                         "pyramidellidae"          => 14956,
                         "pyrams"                  => 15306,
                         "pyrausta"                => 24412,
                         "pyrenees"                => 7251,
                         "pyridine"                => 22733,
                         "pyrite"                  => 20613,
                         "pyrmont"                 => 24758,
                         "pyroclastic"             => 19139,
                         "pyrolysis"               => 25773,
                         "pyrophosphate"           => 28733,
                         "pyrotechnic"             => 26955,
                         "pyrrhus"                 => 21866,
                         "pyruvate"                => 17249,
                         "pythagoras"              => 20954,
                         "pythagorean"             => 16263,
                         "pythons"                 => 24041,
                         "qadir"                   => 17147,
                         "qadri"                   => 24720,
                         "qaeda"                   => 6513,
                         "qaida"                   => 26075,
                         "qajar"                   => 15201,
                         "qal'eh"                  => 15583,
                         "qaleh"                   => 9320,
                         "qamar"                   => 27872,
                         "qanat"                   => 27857,
                         "qarah"                   => 14143,
                         "qarase"                  => 28491,
                         "qareh"                   => 20997,
                         "qasim"                   => 11435,
                         "qassam"                  => 28423,
                         "qatar"                   => 4951,
                         "qatari"                  => 14950,
                         "qazvin"                  => 13332,
                         "qeshlaq"                 => 10102,
                         "qianlong"                => 18367,
                         "qigong"                  => 22927,
                         "qingdao"                 => 15116,
                         "qinghai"                 => 14943,
                         "qmjhl"                   => 17647,
                         "qu'appelle"              => 22852,
                         "quadrangle"              => 10200,
                         "quadrangular"            => 20119,
                         "quadratic"               => 9638,
                         "quadrature"              => 23833,
                         "quadrennial"             => 26472,
                         "quadrilateral"           => 16720,
                         "quadruple"               => 10679,
                         "quadrupled"              => 24281,
                         "quails"                  => 28437,
                         "quakers"                 => 8812,
                         "quakes"                  => 26745,
                         "qualcomm"                => 17757,
                         "qualification"           => 2666,
                         "qualifications"          => 5303,
                         "qualified"               => 1596,
                         "qualifier"               => 6273,
                         "qualifiers"              => 6850,
                         "qualify"                 => 2682,
                         "qualifying"              => 1977,
                         "qualitative"             => 9701,
                         "qualitatively"           => 25511,
                         "quality"                 => 880,
                         "quang"                   => 10508,
                         "quanta"                  => 27574,
                         "quantification"          => 18076,
                         "quantified"              => 16062,
                         "quantifiers"             => 29801,
                         "quantify"                => 14721,
                         "quantifying"             => 27782,
                         "quantitative"            => 7017,
                         "quantitatively"          => 23733,
                         "quantities"              => 4313,
                         "quantity"                => 4201,
                         "quantization"            => 17282,
                         "quantized"               => 25692,
                         "quanzhong"               => 26901,
                         "quanzhou"                => 27619,
                         "quarks"                  => 16064,
                         "quarrelled"              => 28132,
                         "quarrels"                => 17246,
                         "quarried"                => 12323,
                         "quarries"                => 8670,
                         "quarry"                  => 4879,
                         "quarrying"               => 13835,
                         "quarter"                 => 1135,
                         "quarterback"             => 2975,
                         "quarterbacks"            => 11167,
                         "quarterdeck"             => 26940,
                         "quarterfinal"            => 9674,
                         "quarterfinals"           => 4989,
                         "quarterly"               => 4763,
                         "quartermaster"           => 9669,
                         "quartet"                 => 3549,
                         "quartets"                => 12344,
                         "quartier"                => 24263,
                         "quarto"                  => 16034,
                         "quartzite"               => 17743,
                         "quashed"                 => 18160,
                         "quasi"                   => 6501,
                         "quatermass"              => 22538,
                         "quaternary"              => 12818,
                         "quaternion"              => 24820,
                         "quaternions"             => 23209,
                         "quatre"                  => 19137,
                         "quays"                   => 18906,
                         "queanbeyan"              => 25641,
                         "quebec"                  => 1579,
                         "quebecois"               => 11229,
                         "quechua"                 => 9190,
                         "queen"                   => 690,
                         "queensberry"             => 27646,
                         "queensland"              => 1733,
                         "queensryche"             => 26840,
                         "queenstown"              => 14936,
                         "queensway"               => 23816,
                         "queiroz"                 => 26793,
                         "quell"                   => 12878,
                         "quelled"                 => 23615,
                         "quenching"               => 26331,
                         "quercus"                 => 9452,
                         "queretaro"               => 15476,
                         "queried"                 => 26042,
                         "queries"                 => 10776,
                         "query"                   => 8558,
                         "questionnaires"          => 19627,
                         "quests"                  => 13231,
                         "quetta"                  => 13980,
                         "queue"                   => 9522,
                         "queues"                  => 18651,
                         "queuing"                 => 25697,
                         "quezon"                  => 9074,
                         "quickly"                 => 927,
                         "quickness"               => 29932,
                         "quicktime"               => 22921,
                         "quidditch"               => 26391,
                         "quilmes"                 => 24755,
                         "quilon"                  => 29697,
                         "quimper"                 => 28980,
                         "quine"                   => 19577,
                         "quinnipiac"              => 23056,
                         "quintet"                 => 7889,
                         "quintus"                 => 13585,
                         "quipped"                 => 19323,
                         "quisling"                => 24760,
                         "quito"                   => 10296,
                         "qumran"                  => 24684,
                         "quoins"                  => 27375,
                         "quonset"                 => 27061,
                         "quorum"                  => 10260,
                         "quota"                   => 7594,
                         "quotas"                  => 11263,
                         "quotation"               => 9929,
                         "quotations"              => 10294,
                         "quoted"                  => 3157,
                         "quotes"                  => 5689,
                         "quotient"                => 10829,
                         "qur'an"                  => 7877,
                         "qur'anic"                => 24339,
                         "quran"                   => 7559,
                         "quranic"                 => 21504,
                         "quraysh"                 => 24978,
                         "qureshi"                 => 16291,
                         "qwest"                   => 27422,
                         "r.e.m"                   => 17800,
                         "rabat"                   => 15269,
                         "rabaul"                  => 15794,
                         "rabbah"                  => 25942,
                         "rabbani"                 => 29057,
                         "rabbi"                   => 2719,
                         "rabbinate"               => 23554,
                         "rabbinic"                => 10723,
                         "rabbinical"              => 10365,
                         "rabbis"                  => 8041,
                         "rabbitohs"               => 16338,
                         "rabelais"                => 29715,
                         "rabindra"                => 25800,
                         "rabindranath"            => 17137,
                         "race"                    => 374,
                         "racecourse"              => 6010,
                         "raced"                   => 4842,
                         "racehorse"               => 8255,
                         "racehorses"              => 17728,
                         "raceme"                  => 28675,
                         "racemes"                 => 26085,
                         "racemic"                 => 29684,
                         "races"                   => 869,
                         "racetrack"               => 9218,
                         "racetracks"              => 28548,
                         "raceway"                 => 7818,
                         "rachmaninoff"            => 15500,
                         "racial"                  => 1624,
                         "racially"                => 9880,
                         "raciborz"                => 27210,
                         "racism"                  => 5190,
                         "radars"                  => 10577,
                         "radek"                   => 23817,
                         "radha"                   => 10210,
                         "radhakrishnan"           => 22648,
                         "radhika"                 => 22950,
                         "radial"                  => 5970,
                         "radially"                => 21725,
                         "radians"                 => 29066,
                         "radiata"                 => 29198,
                         "radiate"                 => 17479,
                         "radiated"                => 12989,
                         "radiates"                => 25872,
                         "radiating"               => 12823,
                         "radiation"               => 2901,
                         "radiative"               => 18734,
                         "radiators"               => 19051,
                         "radical"                 => 2462,
                         "radicalism"              => 16460,
                         "radically"               => 8479,
                         "radicals"                => 7777,
                         "radii"                   => 16905,
                         "radio"                   => 287,
                         "radioactivity"           => 14774,
                         "radiocarbon"             => 14516,
                         "radiography"             => 25738,
                         "radioisotope"            => 28008,
                         "radioisotopes"           => 29842,
                         "radiological"            => 17029,
                         "radiometric"             => 28907,
                         "radiotherapy"            => 18540,
                         "radium"                  => 14106,
                         "radius"                  => 4629,
                         "radix"                   => 22660,
                         "radnicki"                => 20140,
                         "radnor"                  => 20912,
                         "radom"                   => 16438,
                         "radomsko"                => 23602,
                         "radon"                   => 15954,
                         "radula"                  => 28458,
                         "radwanska"               => 23101,
                         "radyo"                   => 26477,
                         "radziwill"               => 17501,
                         "raeburn"                 => 27218,
                         "raeder"                  => 18950,
                         "raekwon"                 => 28020,
                         "rafah"                   => 26343,
                         "rafts"                   => 14552,
                         "ragam"                   => 18571,
                         "ragas"                   => 19720,
                         "raged"                   => 14867,
                         "raghavan"                => 22363,
                         "raghavendra"             => 29432,
                         "raghu"                   => 18763,
                         "raglan"                  => 19465,
                         "ragtime"                 => 13789,
                         "rahul"                   => 11515,
                         "raid"                    => 2858,
                         "raided"                  => 6855,
                         "raiding"                 => 8292,
                         "raids"                   => 3887,
                         "raikkonen"               => 13762,
                         "rail"                    => 1084,
                         "railcar"                 => 16148,
                         "railcars"                => 13401,
                         "railed"                  => 28923,
                         "railhead"                => 22793,
                         "railings"                => 14767,
                         "railroad"                => 1027,
                         "railroads"               => 5283,
                         "rails"                   => 5767,
                         "railway"                 => 334,
                         "railways"                => 2234,
                         "raimi"                   => 20970,
                         "raimundo"                => 27971,
                         "rainfall"                => 3442,
                         "rainforest"              => 6779,
                         "rainforests"             => 12183,
                         "raion"                   => 7143,
                         "raipur"                  => 18231,
                         "raised"                  => 817,
                         "raith"                   => 17293,
                         "raja"                    => 4003,
                         "rajab"                   => 27003,
                         "rajah"                   => 13915,
                         "rajahmundry"             => 29226,
                         "rajan"                   => 14389,
                         "rajapaksa"               => 20626,
                         "rajas"                   => 23323,
                         "rajasthan"               => 5907,
                         "rajasthani"              => 23613,
                         "rajat"                   => 28963,
                         "rajendra"                => 12098,
                         "rajinikanth"             => 18636,
                         "rajiv"                   => 11940,
                         "rajkot"                  => 22879,
                         "rajkumar"                => 14998,
                         "rajput"                  => 10743,
                         "rajputana"               => 26066,
                         "rajputs"                 => 14280,
                         "rajshahi"                => 18941,
                         "rajya"                   => 12631,
                         "rakhine"                 => 26199,
                         "rakim"                   => 29919,
                         "rakoczi"                 => 21840,
                         "rakyat"                  => 18768,
                         "rallied"                 => 8433,
                         "rallies"                 => 7590,
                         "rally"                   => 2836,
                         "rallycross"              => 27221,
                         "rallying"                => 10981,
                         "rama"                    => 5419,
                         "ramachandra"             => 24146,
                         "ramachandran"            => 16858,
                         "ramadan"                 => 12442,
                         "ramadi"                  => 25726,
                         "ramakrishna"             => 10421,
                         "ramallah"                => 18610,
                         "raman"                   => 11484,
                         "ramanathan"              => 29863,
                         "ramanujan"               => 21628,
                         "ramapo"                  => 24352,
                         "ramaswamy"               => 28926,
                         "ramat"                   => 14572,
                         "ramayana"                => 11546,
                         "ramblers"                => 15511,
                         "ramblin"                 => 27842,
                         "ramen"                   => 22697,
                         "ramesses"                => 15114,
                         "ramla"                   => 26443,
                         "rampal"                  => 25931,
                         "rampant"                 => 9719,
                         "rampart"                 => 13392,
                         "ramparts"                => 13411,
                         "ramps"                   => 8408,
                         "rampur"                  => 20968,
                         "rams"                    => 4786,
                         "ramsar"                  => 14960,
                         "ramsgate"                => 18306,
                         "rancheria"               => 24596,
                         "ranches"                 => 13046,
                         "ranchi"                  => 16882,
                         "ranching"                => 12294,
                         "rancho"                  => 5775,
                         "randomized"              => 12180,
                         "randomly"                => 7376,
                         "randomness"              => 19080,
                         "randwick"                => 19793,
                         "ranga"                   => 15490,
                         "range"                   => 417,
                         "ranged"                  => 5789,
                         "rangefinder"             => 20150,
                         "ranges"                  => 2737,
                         "rangi"                   => 26806,
                         "ranging"                 => 2389,
                         "rangoon"                 => 13412,
                         "rangpur"                 => 24816,
                         "ranji"                   => 15749,
                         "ranjit"                  => 13959,
                         "ranjith"                 => 27708,
                         "rank"                    => 1331,
                         "ranked"                  => 1172,
                         "rankine"                 => 23748,
                         "ranking"                 => 1925,
                         "rankings"                => 3564,
                         "ranks"                   => 2226,
                         "ransacked"               => 18652,
                         "ransomed"                => 26635,
                         "ranulf"                  => 23311,
                         "raphaelite"              => 23427,
                         "raphitomidae"            => 29280,
                         "rapid"                   => 1969,
                         "rapides"                 => 21658,
                         "rapidity"                => 27183,
                         "rapidly"                 => 2123,
                         "rapids"                  => 4758,
                         "rappahannock"            => 19173,
                         "rapped"                  => 27335,
                         "rapper"                  => 3929,
                         "rappers"                 => 8966,
                         "rapperswil"              => 20311,
                         "rapping"                 => 11325,
                         "rapporteur"              => 18102,
                         "rapprochement"           => 21127,
                         "rare"                    => 1468,
                         "rarely"                  => 2450,
                         "rarer"                   => 13282,
                         "raritan"                 => 16342,
                         "rarities"                => 13595,
                         "rarity"                  => 10392,
                         "rashi"                   => 17540,
                         "rashidun"                => 28525,
                         "rasht"                   => 25850,
                         "rashtriya"               => 20033,
                         "raspberries"             => 28801,
                         "ratan"                   => 24005,
                         "rate"                    => 747,
                         "rated"                   => 2170,
                         "ratepayers"              => 28750,
                         "rates"                   => 1935,
                         "ratha"                   => 27579,
                         "rathaus"                 => 29736,
                         "rather"                  => 504,
                         "rathore"                 => 24829,
                         "ratification"            => 8788,
                         "ratified"                => 6020,
                         "ratify"                  => 14224,
                         "ratifying"               => 24653,
                         "rating"                  => 1943,
                         "ratings"                 => 2625,
                         "ratio"                   => 2218,
                         "rationale"               => 9314,
                         "rationalisation"         => 25802,
                         "rationalism"             => 17850,
                         "rationalist"             => 17770,
                         "rationality"             => 14020,
                         "rationing"               => 13511,
                         "rations"                 => 11182,
                         "ratios"                  => 7370,
                         "ratna"                   => 17100,
                         "ratnagiri"               => 27765,
                         "ratnam"                  => 22681,
                         "raton"                   => 14281,
                         "ratzinger"               => 23931,
                         "raucous"                 => 20008,
                         "rauma"                   => 28925,
                         "ravaged"                 => 10325,
                         "ravaging"                => 28936,
                         "ravana"                  => 15965,
                         "ravel"                   => 13609,
                         "ravenna"                 => 10902,
                         "ravensbruck"             => 28914,
                         "ravenswood"              => 25250,
                         "ravindra"                => 27487,
                         "ravines"                 => 16759,
                         "rawal"                   => 26275,
                         "rawalpindi"              => 12217,
                         "rawat"                   => 23518,
                         "raycom"                  => 27966,
                         "rayleigh"                => 16794,
                         "rayon"                   => 7925,
                         "raytheon"                => 16855,
                         "razak"                   => 16829,
                         "razavi"                  => 9296,
                         "razed"                   => 9870,
                         "razorback"               => 24878,
                         "razorbacks"              => 14886,
                         "reachable"               => 19466,
                         "reached"                 => 554,
                         "reaches"                 => 2620,
                         "reaching"                => 1535,
                         "reacquired"              => 23037,
                         "reactant"                => 28780,
                         "reactants"               => 22744,
                         "reaction"                => 1618,
                         "reactionary"             => 13015,
                         "reactions"               => 3273,
                         "reactivate"              => 29164,
                         "reactivated"             => 8922,
                         "reactivation"            => 20255,
                         "reactive"                => 7807,
                         "reactivity"              => 13825,
                         "reactor"                 => 4653,
                         "reactors"                => 7311,
                         "readability"             => 23126,
                         "readable"                => 12059,
                         "readers"                 => 2867,
                         "readership"              => 9779,
                         "readied"                 => 24751,
                         "readily"                 => 4581,
                         "readiness"               => 7460,
                         "reading/literature"      => 29989,
                         "readings"                => 5848,
                         "readmitted"              => 23486,
                         "reaffirm"                => 26825,
                         "reaffirmed"              => 11091,
                         "reaffirming"             => 19880,
                         "reagent"                 => 12611,
                         "reagents"                => 14376,
                         "reales"                  => 26778,
                         "realigned"               => 12665,
                         "realignment"             => 9968,
                         "realisation"             => 14441,
                         "realises"                => 8098,
                         "realising"               => 10338,
                         "realism"                 => 5474,
                         "realists"                => 26564,
                         "realization"             => 7286,
                         "realms"                  => 6957,
                         "reals"                   => 24910,
                         "reanimated"              => 28930,
                         "reappearance"            => 20199,
                         "reappeared"              => 10359,
                         "reappears"               => 12108,
                         "reappointed"             => 13159,
                         "reapportionment"         => 23334,
                         "rear"                    => 1417,
                         "reared"                  => 11829,
                         "rearguard"               => 15938,
                         "rearing"                 => 12941,
                         "rearmament"              => 24887,
                         "rearrangement"           => 13188,
                         "rearrangements"          => 26872,
                         "rearward"                => 23296,
                         "reasonably"              => 6823,
                         "reasoned"                => 11552,
                         "reasoning"               => 5482,
                         "reassembled"             => 17000,
                         "reassert"                => 26190,
                         "reasserted"              => 29565,
                         "reassessment"            => 28259,
                         "reassigned"              => 6259,
                         "reassures"               => 23132,
                         "reauthorization"         => 28119,
                         "rebadged"                => 21334,
                         "rebates"                 => 25084,
                         "rebbe"                   => 11006,
                         "rebelled"                => 8713,
                         "rebellion"               => 2490,
                         "rebellions"              => 10101,
                         "rebooted"                => 29718,
                         "rebounded"               => 11691,
                         "rebounding"              => 15509,
                         "rebounds"                => 4403,
                         "rebrand"                 => 19939,
                         "rebranded"               => 6795,
                         "rebranding"              => 12721,
                         "rebroadcast"             => 15303,
                         "rebuffed"                => 14380,
                         "rebuffs"                 => 28230,
                         "rebuilding"              => 5090,
                         "rebuilds"                => 27868,
                         "rebuilt"                 => 2361,
                         "rebuke"                  => 21066,
                         "rebuked"                 => 18431,
                         "reburied"                => 19389,
                         "rebus"                   => 22674,
                         "recalled"                => 3016,
                         "recalling"               => 9372,
                         "recalls"                 => 6200,
                         "recapitulation"          => 23605,
                         "recaptured"              => 8163,
                         "recapturing"             => 24595,
                         "recast"                  => 12848,
                         "receded"                 => 18622,
                         "receive"                 => 1205,
                         "received"                => 194,
                         "receiver"                => 3241,
                         "receivers"               => 6541,
                         "receivership"            => 13196,
                         "receives"                => 2755,
                         "receiving"               => 1467,
                         "recension"               => 29701,
                         "recent"                  => 673,
                         "recently"                => 825,
                         "recep"                   => 23188,
                         "reception"               => 1043,
                         "receptions"              => 6235,
                         "receptor"                => 3855,
                         "receptors"               => 5079,
                         "recessed"                => 11899,
                         "recesses"                => 23577,
                         "recession"               => 6478,
                         "recessive"               => 12219,
                         "rechargeable"            => 19070,
                         "recharged"               => 27084,
                         "recharging"              => 27807,
                         "recherche"               => 16502,
                         "rechristened"            => 21017,
                         "recidivism"              => 28467,
                         "recife"                  => 15072,
                         "recipient"               => 2865,
                         "recipients"              => 5074,
                         "reciprocal"              => 9091,
                         "reciprocating"           => 17226,
                         "reciprocity"             => 13222,
                         "recitals"                => 10696,
                         "recitative"              => 20458,
                         "recited"                 => 9852,
                         "recites"                 => 20013,
                         "reclaimed"               => 8054,
                         "reclamation"             => 8889,
                         "reclassification"        => 27726,
                         "reclassified"            => 9592,
                         "recognisable"            => 12948,
                         "recognise"               => 6092,
                         "recognised"              => 2674,
                         "recognises"              => 11149,
                         "recognising"             => 11602,
                         "recognition"             => 1393,
                         "recognitions"            => 12426,
                         "recognizable"            => 7450,
                         "recognized"              => 1087,
                         "recognizes"              => 5301,
                         "recognizing"             => 6001,
                         "recoilless"              => 26776,
                         "recollections"           => 13456,
                         "recombinant"             => 15722,
                         "recombination"           => 12122,
                         "recommenced"             => 24361,
                         "recommendations"         => 4055,
                         "recommended"             => 2247,
                         "recommends"              => 8592,
                         "recommissioned"          => 10892,
                         "recompense"              => 29571,
                         "reconciles"              => 22883,
                         "reconciliation"          => 5850,
                         "reconfiguration"         => 24328,
                         "reconfigured"            => 15507,
                         "reconnaissance"          => 3379,
                         "reconquered"             => 23139,
                         "reconquest"              => 18835,
                         "reconquista"             => 18688,
                         "reconsideration"         => 25737,
                         "reconstituted"           => 10487,
                         "reconstitution"          => 29908,
                         "reconstruct"             => 10446,
                         "reconstructed"           => 5321,
                         "reconstructing"          => 16949,
                         "reconstruction"          => 3021,
                         "reconstructionist"       => 25233,
                         "reconstructions"         => 13193,
                         "reconvened"              => 23262,
                         "record"                  => 250,
                         "recorded"                => 347,
                         "recorders"               => 10647,
                         "recording"               => 706,
                         "recordings"              => 1658,
                         "records"                 => 352,
                         "recounted"               => 8341,
                         "recounting"              => 14492,
                         "recounts"                => 7927,
                         "recoverable"             => 19830,
                         "recovered"               => 2398,
                         "recoveries"              => 17422,
                         "recreated"               => 9479,
                         "recreates"               => 25862,
                         "recreation"              => 2655,
                         "recreational"            => 3619,
                         "recreations"             => 22327,
                         "recreativo"              => 28957,
                         "recruit"                 => 4961,
                         "recruited"               => 2982,
                         "recruiters"              => 20121,
                         "recruiting"              => 5098,
                         "recruitment"             => 5556,
                         "recruits"                => 5797,
                         "rectangle"               => 12067,
                         "rectangular"             => 4263,
                         "rectification"           => 23836,
                         "rectified"               => 16096,
                         "rectifier"               => 21692,
                         "rectilinear"             => 24863,
                         "recto"                   => 28251,
                         "rectors"                 => 19655,
                         "rectory"                 => 8474,
                         "recumbent"               => 23263,
                         "recuperation"            => 22930,
                         "recur"                   => 21800,
                         "recurrence"              => 11195,
                         "recurrent"               => 8603,
                         "recurring"               => 3699,
                         "recursion"               => 16922,
                         "recursive"               => 11641,
                         "recursively"             => 19950,
                         "recurve"                 => 18204,
                         "recurved"                => 26441,
                         "recyclable"              => 25781,
                         "recycled"                => 7830,
                         "recycling"               => 6392,
                         "red"                     => 348,
                         "redacted"                => 25643,
                         "redbridge"               => 15889,
                         "redcliffe"               => 18412,
                         "reddish"                 => 5875,
                         "reddit"                  => 21955,
                         "redditch"                => 21358,
                         "rededicated"             => 19943,
                         "redefined"               => 12831,
                         "redefining"              => 24223,
                         "redeployed"              => 16660,
                         "redeployment"            => 26019,
                         "redesign"                => 8261,
                         "redesignated"            => 5613,
                         "redesigned"              => 6045,
                         "redesigning"             => 27113,
                         "redevelop"               => 15762,
                         "redeveloped"             => 8841,
                         "redevelopment"           => 5133,
                         "redgrave"                => 15412,
                         "rediff"                  => 25151,
                         "rediff.com"              => 29874,
                         "rediffusion"             => 29268,
                         "redirected"              => 13965,
                         "redirecting"             => 28904,
                         "redirects"               => 26113,
                         "rediscovered"            => 8888,
                         "rediscovery"             => 15132,
                         "redistribute"            => 27386,
                         "redistributed"           => 14147,
                         "redistribution"          => 8321,
                         "redistricting"           => 10261,
                         "redland"                 => 26699,
                         "redoubt"                 => 12365,
                         "redoubts"                => 24630,
                         "redox"                   => 16303,
                         "redrawn"                 => 16971,
                         "redress"                 => 14409,
                         "redruth"                 => 29559,
                         "redshirt"                => 15310,
                         "redshirted"              => 20992,
                         "reduce"                  => 1722,
                         "reduced"                 => 1171,
                         "reduces"                 => 4755,
                         "reducible"               => 29219,
                         "reducing"                => 2768,
                         "reductase"               => 12076,
                         "reduction"               => 2448,
                         "reductions"              => 8125,
                         "reductive"               => 19260,
                         "redundancy"              => 11999,
                         "redundant"               => 7537,
                         "reduplication"           => 23974,
                         "redux"                   => 28311,
                         "redwoods"                => 21566,
                         "reeds"                   => 11871,
                         "reef"                    => 4586,
                         "reefs"                   => 7268,
                         "reelected"               => 6942,
                         "reelection"              => 6065,
                         "reentered"               => 21395,
                         "reentry"                 => 17001,
                         "reestablish"             => 17068,
                         "reestablished"           => 11755,
                         "reestablishment"         => 28059,
                         "refectory"               => 19533,
                         "refer"                   => 428,
                         "referee"                 => 3925,
                         "refereed"                => 13003,
                         "refereeing"              => 17882,
                         "referees"                => 9323,
                         "reference"               => 1237,
                         "referenced"              => 5434,
                         "references"              => 830,
                         "referencing"             => 10020,
                         "referendum"              => 3326,
                         "referendums"             => 13047,
                         "referent"                => 23530,
                         "referential"             => 20036,
                         "referral"                => 11277,
                         "referred"                => 749,
                         "refers"                  => 1352,
                         "refine"                  => 13385,
                         "refined"                 => 5844,
                         "refinement"              => 10948,
                         "refinements"             => 18644,
                         "refineries"              => 11981,
                         "refinery"                => 7062,
                         "refining"                => 9099,
                         "refit"                   => 8486,
                         "refitted"                => 12626,
                         "refitting"               => 21176,
                         "reflect"                 => 2926,
                         "reflectance"             => 26465,
                         "reflected"               => 3112,
                         "reflecting"              => 4266,
                         "reflections"             => 7269,
                         "reflective"              => 8109,
                         "reflectivity"            => 25888,
                         "reflector"               => 13012,
                         "reflectors"              => 20898,
                         "reflects"                => 3951,
                         "reflexive"               => 15390,
                         "refloated"               => 22138,
                         "reflux"                  => 22102,
                         "refocused"               => 27845,
                         "reforestation"           => 20153,
                         "reform"                  => 1502,
                         "reforma"                 => 24251,
                         "reformation"             => 4519,
                         "reformatory"             => 21039,
                         "reformatted"             => 27608,
                         "reformed"                => 3014,
                         "reformer"                => 8473,
                         "reformers"               => 9673,
                         "reforming"               => 9457,
                         "reformist"               => 10899,
                         "reformists"              => 22894,
                         "reforms"                 => 2923,
                         "reformulated"            => 27680,
                         "refounded"               => 20339,
                         "refraction"              => 15166,
                         "refractive"              => 12074,
                         "refractory"              => 15379,
                         "refrained"               => 17953,
                         "refrains"                => 28544,
                         "refrigerant"             => 25512,
                         "refrigeration"           => 12494,
                         "refueling"               => 7993,
                         "refuelling"              => 18194,
                         "refuge"                  => 3300,
                         "refugee"                 => 5064,
                         "refugees"                => 3193,
                         "refuges"                 => 19073,
                         "refurbish"               => 21300,
                         "refurbished"             => 6529,
                         "refurbishing"            => 20981,
                         "refurbishment"           => 8073,
                         "refusal"                 => 5383,
                         "refused"                 => 1317,
                         "refuses"                 => 3682,
                         "refutation"              => 21318,
                         "refuted"                 => 12832,
                         "refuting"                => 27441,
                         "regain"                  => 5285,
                         "regained"                => 4709,
                         "regaining"               => 10968,
                         "regalia"                 => 13792,
                         "regard"                  => 2828,
                         "regarded"                => 1560,
                         "regarding"               => 1518,
                         "regardless"              => 3081,
                         "regatta"                 => 9027,
                         "regattas"                => 21423,
                         "regency"                 => 5353,
                         "regenerating"            => 24537,
                         "regeneration"            => 6978,
                         "regenerative"            => 13425,
                         "regensburg"              => 11774,
                         "regent"                  => 4178,
                         "regents"                 => 7378,
                         "reggaeton"               => 14918,
                         "reggina"                 => 26107,
                         "reggio"                  => 12063,
                         "regia"                   => 13014,
                         "regicide"                => 29402,
                         "regierungsbezirk"        => 27401,
                         "regime"                  => 2202,
                         "regimens"                => 25635,
                         "regiment"                => 898,
                         "regimental"              => 6503,
                         "regiments"               => 3673,
                         "regimes"                 => 8378,
                         "regio"                   => 15358,
                         "region"                  => 260,
                         "regional"                => 567,
                         "regionalbahn"            => 25858,
                         "regionalism"             => 25857,
                         "regionalist"             => 24747,
                         "regionalliga"            => 11349,
                         "regionally"              => 10631,
                         "regionals"               => 16602,
                         "regions"                 => 1221,
                         "register"                => 1064,
                         "registered"              => 1562,
                         "registering"             => 9846,
                         "registers"               => 6763,
                         "registrar"               => 8702,
                         "registrars"              => 23449,
                         "registration"            => 3192,
                         "registrations"           => 14214,
                         "registries"              => 16989,
                         "registry"                => 5568,
                         "regius"                  => 16455,
                         "regnal"                  => 20943,
                         "regression"              => 9034,
                         "regressive"              => 27049,
                         "regrouped"               => 13787,
                         "regrouping"              => 28726,
                         "regular"                 => 591,
                         "regularity"              => 14657,
                         "regularly"               => 1697,
                         "regulars"                => 8896,
                         "regulate"                => 5499,
                         "regulated"               => 4299,
                         "regulates"               => 8803,
                         "regulating"              => 7578,
                         "regulation"              => 2649,
                         "regulations"             => 2339,
                         "regulator"               => 7684,
                         "regulators"              => 8770,
                         "regulatory"              => 3780,
                         "regulus"                 => 22477,
                         "rehabilitate"            => 15044,
                         "rehabilitating"          => 25384,
                         "rehabilitation"          => 4047,
                         "rehearsals"              => 8571,
                         "rehired"                 => 26225,
                         "rehnquist"               => 19517,
                         "rehoboth"                => 21001,
                         "reichsbahn"              => 17484,
                         "reichstag"               => 11897,
                         "reichswehr"              => 21602,
                         "reigate"                 => 21521,
                         "reign"                   => 1734,
                         "reigned"                 => 7573,
                         "reigning"                => 5647,
                         "reigns"                  => 8350,
                         "reimbursement"           => 14570,
                         "reims"                   => 10810,
                         "reincorporated"          => 26696,
                         "reine"                   => 18748,
                         "reinforce"               => 7010,
                         "reinforced"              => 4102,
                         "reinforcement"           => 8175,
                         "reinforcements"          => 5215,
                         "reinforces"              => 18175,
                         "reinforcing"             => 11053,
                         "reinstalled"             => 28152,
                         "reinstated"              => 6515,
                         "reinstatement"           => 13962,
                         "reinsurance"             => 22700,
                         "reintegration"           => 22430,
                         "reinterpretation"        => 24487,
                         "reinterpreted"           => 22946,
                         "reinterred"              => 28016,
                         "reintroduce"             => 21230,
                         "reintroduced"            => 9097,
                         "reintroduction"          => 14509,
                         "reinvention"             => 27684,
                         "reinvestment"            => 19464,
                         "reinvigorated"           => 27819,
                         "reissue"                 => 7541,
                         "reissued"                => 5758,
                         "reissues"                => 14372,
                         "reiterated"              => 10609,
                         "rejected"                => 1851,
                         "rejects"                 => 6868,
                         "rejoin"                  => 9017,
                         "rejoined"                => 5300,
                         "rejoining"               => 12585,
                         "rejoins"                 => 19291,
                         "rejuvenation"            => 21309,
                         "rekha"                   => 19090,
                         "rekord"                  => 28282,
                         "relatable"               => 29632,
                         "related"                 => 550,
                         "relatedness"             => 21878,
                         "relates"                 => 5066,
                         "relating"                => 3082,
                         "relation"                => 2353,
                         "relational"              => 9152,
                         "relations"               => 1003,
                         "relative"                => 1872,
                         "relatively"              => 1253,
                         "relatives"               => 3357,
                         "relativism"              => 22054,
                         "relativistic"            => 11516,
                         "relativity"              => 6973,
                         "relaunch"                => 11952,
                         "relaunched"              => 8623,
                         "relay"                   => 3000,
                         "relayed"                 => 12329,
                         "relaying"                => 21589,
                         "relays"                  => 10109,
                         "release"                 => 359,
                         "released"                => 118,
                         "releases"                => 2109,
                         "releasing"               => 3213,
                         "relegated"               => 2731,
                         "relegating"              => 27211,
                         "relegation"              => 3623,
                         "relented"                => 14988,
                         "relents"                 => 24122,
                         "relevance"               => 7351,
                         "relevant"                => 2784,
                         "reliability"             => 5289,
                         "reliably"                => 10856,
                         "reliance"                => 6287,
                         "relic"                   => 9585,
                         "relics"                  => 6161,
                         "relict"                  => 25782,
                         "relied"                  => 5018,
                         "relief"                  => 1790,
                         "reliefs"                 => 9518,
                         "relies"                  => 5808,
                         "reliever"                => 13507,
                         "relieves"                => 29557,
                         "relieving"               => 12791,
                         "religion"                => 1247,
                         "religions"               => 4205,
                         "religiosity"             => 22797,
                         "religious"               => 669,
                         "religiously"             => 13051,
                         "relinquished"            => 9338,
                         "reliquary"               => 21246,
                         "reloading"               => 22050,
                         "relocate"                => 7220,
                         "relocated"               => 2509,
                         "relocating"              => 8985,
                         "relocation"              => 6224,
                         "reluctance"              => 9691,
                         "reluctant"               => 5197,
                         "reluctantly"             => 6982,
                         "relying"                 => 6916,
                         "remade"                  => 9492,
                         "remain"                  => 1115,
                         "remainder"               => 2277,
                         "remained"                => 469,
                         "remaining"               => 846,
                         "remains"                 => 729,
                         "remake"                  => 4550,
                         "remakes"                 => 14898,
                         "remand"                  => 19334,
                         "remarked"                => 4874,
                         "remarking"               => 12564,
                         "remarriage"              => 22280,
                         "remaster"                => 25421,
                         "remastered"              => 7113,
                         "rematch"                 => 6480,
                         "rembrandt"               => 11694,
                         "remediation"             => 11752,
                         "remedies"                => 10082,
                         "remembrance"             => 7453,
                         "reminiscence"            => 25760,
                         "reminiscences"           => 16466,
                         "reminiscent"             => 5247,
                         "reminisces"              => 29896,
                         "remit"                   => 13533,
                         "remittance"              => 27996,
                         "remittances"             => 19561,
                         "remix"                   => 3585,
                         "remixed"                 => 6486,
                         "remixes"                 => 5561,
                         "remixing"                => 23006,
                         "remnant"                 => 7307,
                         "remnants"                => 4499,
                         "remodeled"               => 9062,
                         "remodelled"              => 13059,
                         "remote"                  => 2489,
                         "remoteness"              => 19605,
                         "removable"               => 10789,
                         "removal"                 => 2829,
                         "removals"                => 29933,
                         "removed"                 => 1052,
                         "removes"                 => 7943,
                         "removing"                => 3828,
                         "remuneration"            => 15853,
                         "renaissance"             => 2752,
                         "renal"                   => 8253,
                         "rename"                  => 11471,
                         "renamed"                 => 994,
                         "renaming"                => 7862,
                         "renan"                   => 25399,
                         "rendered"                => 3797,
                         "rendering"               => 5286,
                         "renderings"              => 20710,
                         "renders"                 => 11176,
                         "rendezvoused"            => 22706,
                         "rendition"               => 6935,
                         "renditions"              => 13876,
                         "rendsburg"               => 28435,
                         "renegades"               => 14702,
                         "renewable"               => 4994,
                         "renewables"              => 21439,
                         "renewal"                 => 5134,
                         "renewed"                 => 3401,
                         "renfrewshire"            => 16272,
                         "rennes"                  => 11492,
                         "renomination"            => 12753,
                         "renounced"               => 9755,
                         "renouncing"              => 21711,
                         "renovate"                => 11383,
                         "renovated"               => 3765,
                         "renovation"              => 3686,
                         "renovations"             => 5452,
                         "renown"                  => 10924,
                         "renowned"                => 2563,
                         "rensselaer"              => 11499,
                         "rentals"                 => 12227,
                         "renters"                 => 13569,
                         "renumbered"              => 8997,
                         "renumbering"             => 11472,
                         "renunciation"            => 16514,
                         "reoccupied"              => 22400,
                         "reopened"                => 4406,
                         "reopening"               => 9802,
                         "reorganisation"          => 8783,
                         "reorganised"             => 10936,
                         "reorganization"          => 5736,
                         "reorganized"             => 5080,
                         "repackaged"              => 17797,
                         "repainted"               => 11830,
                         "repair"                  => 2621,
                         "repaired"                => 5158,
                         "repairing"               => 9521,
                         "repairs"                 => 3716,
                         "reparation"              => 19881,
                         "repatriated"             => 12999,
                         "repatriation"            => 11386,
                         "repayment"               => 13584,
                         "repeal"                  => 7539,
                         "repealed"                => 7133,
                         "repealing"               => 23500,
                         "repeated"                => 2488,
                         "repeatedly"              => 3248,
                         "repeater"                => 13785,
                         "repeaters"               => 18963,
                         "repeats"                 => 7810,
                         "repechage"               => 14301,
                         "repelled"                => 10590,
                         "repelling"               => 19890,
                         "repentance"              => 13888,
                         "repertoire"              => 4599,
                         "repertory"               => 7082,
                         "repetition"              => 8386,
                         "repetitions"             => 19509,
                         "repetitive"              => 8591,
                         "replace"                 => 1822,
                         "replaced"                => 523,
                         "replacement"             => 1952,
                         "replacements"            => 8389,
                         "replaces"                => 7469,
                         "replacing"               => 2156,
                         "replanted"               => 29397,
                         "replay"                  => 5957,
                         "replayed"                => 17333,
                         "replays"                 => 13277,
                         "replenished"             => 19384,
                         "replenishment"           => 15237,
                         "replete"                 => 19277,
                         "replica"                 => 5722,
                         "replicas"                => 10725,
                         "replicate"               => 9865,
                         "replicated"              => 11273,
                         "replicates"              => 25243,
                         "replication"             => 7327,
                         "replied"                 => 4309,
                         "replies"                 => 7754,
                         "reply"                   => 5805,
                         "replying"                => 23314,
                         "repopulated"             => 29858,
                         "report"                  => 680,
                         "reportage"               => 20821,
                         "reported"                => 489,
                         "reportedly"              => 2408,
                         "reporting"               => 2570,
                         "reports"                 => 1167,
                         "repose"                  => 21225,
                         "repositioned"            => 24983,
                         "repositioning"           => 28895,
                         "repositories"            => 16053,
                         "repository"              => 7901,
                         "represent"               => 1454,
                         "representation"          => 2107,
                         "representational"        => 15959,
                         "representations"         => 5275,
                         "representative"          => 1231,
                         "representatives"         => 1143,
                         "represented"             => 674,
                         "representing"            => 1494,
                         "represents"              => 1773,
                         "repression"              => 7530,
                         "repressions"             => 25397,
                         "repressive"              => 13549,
                         "repressor"               => 29704,
                         "reprint"                 => 11643,
                         "reprinted"               => 5572,
                         "reprinting"              => 22819,
                         "reprints"                => 11768,
                         "reprisal"                => 15115,
                         "reprisals"               => 13992,
                         "reprise"                 => 8034,
                         "reprised"                => 7863,
                         "reprises"                => 21031,
                         "reprising"               => 13548,
                         "reprocessing"            => 21728,
                         "reproduce"               => 7569,
                         "reproduced"              => 8380,
                         "reproduces"              => 17044,
                         "reproducible"            => 29400,
                         "reproducing"             => 13629,
                         "reproduction"            => 4714,
                         "reproductions"           => 13354,
                         "reproductive"            => 5549,
                         "reptiles"                => 7076,
                         "repton"                  => 19415,
                         "repubblica"              => 24119,
                         "republic"                => 539,
                         "republica"               => 16043,
                         "republican"              => 961,
                         "republicanism"           => 15987,
                         "republicans"             => 3719,
                         "republics"               => 7888,
                         "republika"               => 11327,
                         "republique"              => 20628,
                         "republished"             => 8976,
                         "repudiated"              => 15121,
                         "repudiation"             => 23686,
                         "repulsed"                => 9134,
                         "repulsion"               => 19910,
                         "repurposed"              => 23014,
                         "reputed"                 => 7165,
                         "reputedly"               => 11022,
                         "request"                 => 1802,
                         "requested"               => 2656,
                         "requests"                => 4235,
                         "require"                 => 1767,
                         "required"                => 641,
                         "requirement"             => 3207,
                         "requirements"            => 1823,
                         "requires"                => 1895,
                         "requiring"               => 3190,
                         "requisitioned"           => 12790,
                         "rerecorded"              => 25513,
                         "reredos"                 => 20028,
                         "rereleased"              => 20333,
                         "rerouted"                => 11823,
                         "rerum"                   => 24703,
                         "rescinded"               => 11931,
                         "rescuers"                => 15748,
                         "rescues"                 => 8735,
                         "research"                => 252,
                         "researched"              => 7002,
                         "researcher"              => 4093,
                         "researchers"             => 2276,
                         "researches"              => 9516,
                         "resection"               => 23699,
                         "resellers"               => 28130,
                         "resemblances"            => 29734,
                         "resemble"                => 4447,
                         "resembled"               => 7346,
                         "resembles"               => 4546,
                         "resembling"              => 5880,
                         "reserve"                 => 997,
                         "reserved"                => 3781,
                         "reserves"                => 2796,
                         "reservist"               => 24587,
                         "reservists"              => 14332,
                         "reservoir"               => 2642,
                         "reservoirs"              => 7333,
                         "resettle"                => 22668,
                         "resettled"               => 11848,
                         "resettlement"            => 10901,
                         "reshape"                 => 26768,
                         "reshaped"                => 21330,
                         "reshaping"               => 23442,
                         "reshuffle"               => 13192,
                         "reside"                  => 4897,
                         "resided"                 => 4641,
                         "residence"               => 1587,
                         "residences"              => 4875,
                         "residencies"             => 15388,
                         "residency"               => 5358,
                         "resident"                => 2077,
                         "residential"             => 1703,
                         "residents"               => 859,
                         "resides"                 => 3805,
                         "residing"                => 2072,
                         "residual"                => 8296,
                         "residuals"               => 29193,
                         "residues"                => 7895,
                         "resign"                  => 4583,
                         "resignation"             => 2859,
                         "resignations"            => 16987,
                         "resigned"                => 1679,
                         "resigns"                 => 16904,
                         "resilience"              => 11878,
                         "resin"                   => 7592,
                         "resins"                  => 15735,
                         "resistance"              => 1534,
                         "resistant"               => 4812,
                         "resisted"                => 6322,
                         "resistive"               => 21036,
                         "resistivity"             => 23022,
                         "resistor"                => 15668,
                         "resistors"               => 18466,
                         "resold"                  => 18281,
                         "resolutely"              => 25552,
                         "resolution"              => 1727,
                         "resolutions"             => 6360,
                         "resolved"                => 3985,
                         "resolves"                => 11880,
                         "resolving"               => 9911,
                         "resonance"               => 6394,
                         "resonances"              => 21900,
                         "resonant"                => 11711,
                         "resonate"                => 20888,
                         "resonated"               => 26352,
                         "resonator"               => 16838,
                         "resonators"              => 25561,
                         "resort"                  => 2419,
                         "resorted"                => 11599,
                         "resorts"                 => 5660,
                         "resource"                => 2645,
                         "resources"               => 1111,
                         "respective"              => 2712,
                         "respectively"            => 1158,
                         "respiratory"             => 5967,
                         "responded"               => 2514,
                         "respondent"              => 13952,
                         "respondents"             => 8669,
                         "responder"               => 20480,
                         "responders"              => 16035,
                         "responds"                => 7145,
                         "responsa"                => 23242,
                         "response"                => 844,
                         "responses"               => 4056,
                         "responsible"             => 865,
                         "responsiveness"          => 19064,
                         "restarted"               => 8928,
                         "restarting"              => 22514,
                         "restated"                => 23401,
                         "restatement"             => 25517,
                         "restaurants"             => 2636,
                         "restitution"             => 11891,
                         "restoration"             => 2027,
                         "restorations"            => 14098,
                         "restore"                 => 3362,
                         "restored"                => 1874,
                         "restorer"                => 22837,
                         "restoring"               => 6024,
                         "restrained"              => 9494,
                         "restrict"                => 7462,
                         "restricted"              => 2594,
                         "restricting"             => 9165,
                         "restriction"             => 6037,
                         "restrictions"            => 3153,
                         "restrictive"             => 8633,
                         "restricts"               => 14222,
                         "restructure"             => 14405,
                         "restructured"            => 9928,
                         "restructuring"           => 6216,
                         "restyled"                => 20832,
                         "result"                  => 384,
                         "resultant"               => 9063,
                         "resulted"                => 1157,
                         "resulting"               => 1196,
                         "results"                 => 600,
                         "resume"                  => 5578,
                         "resumed"                 => 2891,
                         "resuming"                => 12170,
                         "resumption"              => 12497,
                         "resupply"                => 11937,
                         "resurfaced"              => 11771,
                         "resurfacing"             => 23326,
                         "resurgence"              => 8267,
                         "resurgent"               => 21185,
                         "resurrected"             => 8057,
                         "resurrecting"            => 25424,
                         "resurrection"            => 6016,
                         "resuscitation"           => 19686,
                         "retail"                  => 2224,
                         "retailed"                => 26271,
                         "retailer"                => 6983,
                         "retailers"               => 5600,
                         "retailing"               => 14073,
                         "retain"                  => 3288,
                         "retained"                => 1879,
                         "retainers"               => 16650,
                         "retaining"               => 4590,
                         "retains"                 => 5172,
                         "retake"                  => 10932,
                         "retaken"                 => 18388,
                         "retaking"                => 23426,
                         "retaliated"              => 14054,
                         "retaliation"             => 6991,
                         "retardant"               => 27026,
                         "retardation"             => 16168,
                         "retelling"               => 13961,
                         "retention"               => 6997,
                         "retford"                 => 27866,
                         "reticulata"              => 29720,
                         "reticulum"               => 17419,
                         "retina"                  => 11211,
                         "retinue"                 => 16145,
                         "retired"                 => 744,
                         "retirees"                => 17207,
                         "retirement"              => 1380,
                         "retirements"             => 21354,
                         "retiring"                => 3139,
                         "retiro"                  => 25068,
                         "retitled"                => 10728,
                         "retold"                  => 20320,
                         "retook"                  => 13752,
                         "retooled"                => 29578,
                         "retorted"                => 25394,
                         "retorts"                 => 27669,
                         "retractable"             => 10480,
                         "retracted"               => 10506,
                         "retraining"              => 26959,
                         "retreat"                 => 2973,
                         "retreated"               => 5288,
                         "retreating"              => 7832,
                         "retreats"                => 10529,
                         "retrieved"               => 6923,
                         "retrieves"               => 17725,
                         "retroactive"             => 17737,
                         "retroactively"           => 14185,
                         "retrofitted"             => 18462,
                         "retroflex"               => 24974,
                         "retrospective"           => 6039,
                         "retrospectively"         => 16815,
                         "retrospectives"          => 27269,
                         "return"                  => 438,
                         "returned"                => 313,
                         "returner"                => 16684,
                         "returning"               => 1236,
                         "returns"                 => 1850,
                         "reunification"           => 8815,
                         "reunified"               => 29259,
                         "reunited"                => 4081,
                         "reunites"                => 14856,
                         "reuniting"               => 11809,
                         "reuptake"                => 19409,
                         "reusable"                => 14381,
                         "reuse"                   => 9907,
                         "reused"                  => 8705,
                         "reuters"                 => 9282,
                         "reuven"                  => 29590,
                         "revamped"                => 9995,
                         "revealed"                => 1045,
                         "revealing"               => 4514,
                         "reveals"                 => 2552,
                         "revelation"              => 4987,
                         "revelations"             => 8647,
                         "revenue"                 => 2146,
                         "revenues"                => 4277,
                         "reverberation"           => 29532,
                         "revered"                 => 8579,
                         "reverence"               => 12304,
                         "reverie"                 => 29535,
                         "reversal"                => 7992,
                         "reversals"               => 23594,
                         "reversed"                => 4460,
                         "reverses"                => 14645,
                         "reversible"              => 10076,
                         "reversing"               => 10403,
                         "reversion"               => 21085,
                         "reverted"                => 5976,
                         "reverting"               => 14707,
                         "review"                  => 746,
                         "reviewed"                => 2944,
                         "reviewer"                => 4462,
                         "reviewers"               => 5811,
                         "reviewing"               => 6017,
                         "reviews"                 => 1187,
                         "reviled"                 => 29464,
                         "revised"                 => 2919,
                         "revising"                => 15362,
                         "revision"                => 4891,
                         "revisionism"             => 23668,
                         "revisionist"             => 14962,
                         "revisions"               => 7966,
                         "revisited"               => 9538,
                         "revista"                 => 17425,
                         "revitalization"          => 10905,
                         "revitalize"              => 14260,
                         "revitalized"             => 17149,
                         "revitalizing"            => 24181,
                         "revival"                 => 2000,
                         "revivalist"              => 23919,
                         "revivals"                => 12373,
                         "revive"                  => 6504,
                         "revived"                 => 3640,
                         "revives"                 => 21194,
                         "reviving"                => 11061,
                         "revocation"              => 15775,
                         "revolt"                  => 3441,
                         "revolted"                => 11564,
                         "revolts"                 => 11102,
                         "revolucion"              => 24180,
                         "revolution"              => 1120,
                         "revolutionaries"         => 8040,
                         "revolutionary"           => 1900,
                         "revolutionized"          => 14585,
                         "revolutions"             => 8459,
                         "revolved"                => 11863,
                         "revolvers"               => 14034,
                         "revolves"                => 6694,
                         "revolving"               => 9136,
                         "revue"                   => 6989,
                         "revues"                  => 19952,
                         "rewarded"                => 5867,
                         "rewards"                 => 7214,
                         "rewari"                  => 26362,
                         "rework"                  => 23753,
                         "reworked"                => 9111,
                         "reworking"               => 14043,
                         "rewritten"               => 10024,
                         "rhaetian"                => 26520,
                         "rheims"                  => 22438,
                         "rheinland"               => 27914,
                         "rhenish"                 => 15304,
                         "rhesus"                  => 24044,
                         "rhetoric"                => 6533,
                         "rheumatic"               => 23203,
                         "rheumatism"              => 22167,
                         "rheumatoid"              => 17467,
                         "rhine"                   => 3788,
                         "rhineland"               => 7087,
                         "rhinoceros"              => 12156,
                         "rhizomatous"             => 29616,
                         "rhizome"                 => 17739,
                         "rhizomes"                => 16576,
                         "rhode"                   => 3385,
                         "rhodesia"                => 7127,
                         "rhodesian"               => 10955,
                         "rhodium"                 => 28220,
                         "rhododendron"            => 15012,
                         "rhodri"                  => 29174,
                         "rhondda"                 => 14980,
                         "rhymney"                 => 28754,
                         "rhyolite"                => 25392,
                         "rhythm"                  => 3132,
                         "rhythmic"                => 5909,
                         "rhythmically"            => 23106,
                         "rhythms"                 => 6507,
                         "riata"                   => 29089,
                         "ribbed"                  => 14822,
                         "ribbentrop"              => 14569,
                         "ribeira"                 => 21384,
                         "ribose"                  => 27362,
                         "ribosomal"               => 15949,
                         "ribosome"                => 19372,
                         "rica"                    => 4418,
                         "rican"                   => 4719,
                         "ricans"                  => 13721,
                         "richardsonian"           => 28655,
                         "richelieu"               => 11994,
                         "richfield"               => 19828,
                         "richland"                => 10852,
                         "richly"                  => 9546,
                         "richness"                => 11365,
                         "richthofen"              => 19544,
                         "rickshaws"               => 21100,
                         "ricoh"                   => 24995,
                         "ridden"                  => 6707,
                         "rideau"                  => 14003,
                         "riders"                  => 3026,
                         "ridership"               => 11401,
                         "ridged"                  => 27724,
                         "ridgefield"              => 20827,
                         "ridgeline"               => 27022,
                         "ridgely"                 => 29438,
                         "ridges"                  => 5455,
                         "ridgewood"               => 19820,
                         "riemann"                 => 10635,
                         "riemannian"              => 16037,
                         "rieti"                   => 29545,
                         "riffs"                   => 11048,
                         "rifle"                   => 2577,
                         "rifled"                  => 15764,
                         "riflemen"                => 16020,
                         "rifles"                  => 3801,
                         "rifting"                 => 26478,
                         "rifts"                   => 24318,
                         "rigging"                 => 10689,
                         "rightist"                => 22199,
                         "rights"                  => 464,
                         "rigid"                   => 5705,
                         "rigidity"                => 14117,
                         "rigidly"                 => 19713,
                         "rigor"                   => 14701,
                         "rigorous"                => 6726,
                         "rigorously"              => 17095,
                         "rigveda"                 => 22561,
                         "rihanna"                 => 8574,
                         "rijeka"                  => 12071,
                         "rijksmuseum"             => 29531,
                         "riksdag"                 => 15156,
                         "rilke"                   => 23890,
                         "rimfire"                 => 29517,
                         "rimini"                  => 14834,
                         "rimmed"                  => 22419,
                         "rimouski"                => 26864,
                         "rimsky"                  => 17115,
                         "ringed"                  => 14161,
                         "ringling"                => 19445,
                         "ringtone"                => 27894,
                         "rinpoche"                => 11425,
                         "rinzai"                  => 29323,
                         "rioters"                 => 13475,
                         "rioting"                 => 11508,
                         "riots"                   => 4448,
                         "riparian"                => 11561,
                         "ripen"                   => 23777,
                         "ripening"                => 17867,
                         "ripon"                   => 12502,
                         "rise"                    => 1299,
                         "risen"                   => 6181,
                         "rises"                   => 3687,
                         "rishi"                   => 12958,
                         "rishon"                  => 24327,
                         "rising"                  => 2048,
                         "risque"                  => 18687,
                         "rite"                    => 5462,
                         "rites"                   => 6278,
                         "ritually"                => 22066,
                         "rituals"                 => 5107,
                         "rivadavia"               => 20231,
                         "rival"                   => 2089,
                         "rivaled"                 => 21380,
                         "rivaling"                => 27391,
                         "rivalries"               => 9069,
                         "rivalry"                 => 3478,
                         "rivals"                  => 3173,
                         "rivals.com"              => 14803,
                         "river"                   => 150,
                         "riverbanks"              => 26117,
                         "riverbed"                => 18797,
                         "riverboat"               => 17975,
                         "riverdale"               => 14129,
                         "riverfront"              => 12580,
                         "riverhead"               => 28609,
                         "riverina"                => 20242,
                         "riverine"                => 14863,
                         "riverside"               => 4540,
                         "riverton"                => 21438,
                         "riverview"               => 15406,
                         "rivets"                  => 23130,
                         "riviere"                 => 10532,
                         "rivieres"                => 14629,
                         "rivington"               => 26722,
                         "rivoli"                  => 25045,
                         "riyadh"                  => 12376,
                         "rizal"                   => 10456,
                         "rizzoli"                 => 28783,
                         "rnzaf"                   => 21768,
                         "road"                    => 209,
                         "roadbed"                 => 28983,
                         "roadmap"                 => 18528,
                         "roadrunners"             => 20428,
                         "roads"                   => 1412,
                         "roadside"                => 9642,
                         "roadsides"               => 24944,
                         "roadways"                => 10215,
                         "roald"                   => 18124,
                         "roamed"                  => 18825,
                         "roanoke"                 => 8658,
                         "robespierre"             => 18887,
                         "robotic"                 => 7856,
                         "robots"                  => 5679,
                         "robust"                  => 5484,
                         "robusta"                 => 21464,
                         "robustness"              => 17937,
                         "rochdale"                => 8230,
                         "rochester"               => 3698,
                         "rock"                    => 358,
                         "rock'n'roll"             => 20552,
                         "rockabilly"              => 13286,
                         "rockaway"                => 14078,
                         "rockdale"                => 25351,
                         "rockefeller"             => 6231,
                         "rockers"                 => 10958,
                         "rocketry"                => 23923,
                         "rockhampton"             => 15543,
                         "rockingham"              => 11389,
                         "rockland"                => 12256,
                         "rockne"                  => 24860,
                         "rockville"               => 14432,
                         "rococo"                  => 12924,
                         "rocroi"                  => 25750,
                         "roddick"                 => 17091,
                         "rodents"                 => 8845,
                         "rodez"                   => 29711,
                         "rodham"                  => 20003,
                         "rodolphe"                => 28110,
                         "roehampton"              => 28792,
                         "roethlisberger"          => 20360,
                         "rogaland"                => 20764,
                         "rohini"                  => 28612,
                         "rohit"                   => 17171,
                         "rohtak"                  => 29760,
                         "role"                    => 276,
                         "roleplaying"             => 14687,
                         "roles"                   => 1133,
                         "rolleston"               => 28942,
                         "romagna"                 => 13227,
                         "romanesque"              => 6333,
                         "romani"                  => 8304,
                         "romania"                 => 1990,
                         "romanian"                => 2390,
                         "romanians"               => 10202,
                         "romanization"            => 14620,
                         "romanized"               => 2122,
                         "romanos"                 => 22563,
                         "romansh"                 => 15914,
                         "romanticism"             => 10663,
                         "romanticized"            => 27311,
                         "romanus"                 => 28313,
                         "rome"                    => 1193,
                         "romford"                 => 19662,
                         "romney"                  => 6555,
                         "romsdal"                 => 18327,
                         "romsey"                  => 27703,
                         "romulo"                  => 23268,
                         "ronde"                   => 18285,
                         "rondo"                   => 16165,
                         "ronne"                   => 20765,
                         "ronson"                  => 16156,
                         "ronstadt"                => 17485,
                         "roofed"                  => 9258,
                         "roofline"                => 20026,
                         "roofs"                   => 6265,
                         "rookery"                 => 28971,
                         "rookies"                 => 13573,
                         "rooms"                   => 1730,
                         "roosting"                => 22764,
                         "roosts"                  => 27468,
                         "rooted"                  => 6439,
                         "rootes"                  => 26791,
                         "roots"                   => 2100,
                         "roping"                  => 29573,
                         "rorschach"               => 25585,
                         "rosamund"                => 27091,
                         "rosberg"                 => 14403,
                         "roscommon"               => 13607,
                         "rosebery"                => 21869,
                         "rosemont"                => 19208,
                         "rosenborg"               => 15771,
                         "rosenheim"               => 25712,
                         "rosettes"                => 20617,
                         "roseville"               => 18990,
                         "roskilde"                => 14977,
                         "rossellini"              => 25137,
                         "rossendale"              => 25952,
                         "rossini"                 => 11773,
                         "rostam"                  => 18615,
                         "roster"                  => 3161,
                         "rosters"                 => 12055,
                         "rostock"                 => 11894,
                         "rostral"                 => 23308,
                         "rostropovich"            => 29966,
                         "rostrum"                 => 17782,
                         "rosyth"                  => 24489,
                         "rotate"                  => 8627,
                         "rotated"                 => 8118,
                         "rotates"                 => 12029,
                         "rotating"                => 5012,
                         "rotation"                => 3588,
                         "rotational"              => 9299,
                         "rotations"               => 11560,
                         "rotator"                 => 24082,
                         "rotax"                   => 16831,
                         "rotem"                   => 28889,
                         "rothbard"                => 26037,
                         "rotherham"               => 8731,
                         "rothesay"                => 22682,
                         "rothko"                  => 22613,
                         "rotor"                   => 7037,
                         "rotors"                  => 15684,
                         "rotorua"                 => 18777,
                         "rotterdam"               => 5822,
                         "rotulorum"               => 27766,
                         "rotunda"                 => 11117,
                         "roubaix"                 => 17132,
                         "rouen"                   => 9378,
                         "rouge"                   => 4791,
                         "roughly"                 => 1780,
                         "roughness"               => 19087,
                         "roughriders"             => 12176,
                         "round"                   => 327,
                         "roundabout"              => 8090,
                         "roundabouts"             => 26328,
                         "rounded"                 => 3786,
                         "roundel"                 => 26039,
                         "rounder"                 => 11787,
                         "roundhouse"              => 13473,
                         "roundly"                 => 27236,
                         "roundtable"              => 15029,
                         "roused"                  => 25856,
                         "roussillon"              => 17121,
                         "route"                   => 367,
                         "routed"                  => 6705,
                         "routers"                 => 14784,
                         "routes"                  => 1649,
                         "routinely"               => 6993,
                         "routines"                => 8453,
                         "routing"                 => 5659,
                         "routledge"               => 14455,
                         "rouvas"                  => 25518,
                         "rovere"                  => 24736,
                         "rowdies"                 => 21958,
                         "rowed"                   => 12932,
                         "rower"                   => 8279,
                         "rowers"                  => 16424,
                         "rowing"                  => 4600,
                         "rowling"                 => 14518,
                         "rowntree"                => 22314,
                         "rows"                    => 4975,
                         "roxburgh"                => 20447,
                         "royal"                   => 307,
                         "royalist"                => 6813,
                         "royalists"               => 10750,
                         "royalties"               => 8187,
                         "royle"                   => 21502,
                         "rsfsr"                   => 20658,
                         "rspca"                   => 27887,
                         "rubens"                  => 10465,
                         "rubiaceae"               => 19471,
                         "rubik"                   => 23167,
                         "rubles"                  => 13945,
                         "rubra"                   => 24977,
                         "rubric"                  => 25356,
                         "rubus"                   => 15968,
                         "rudbar"                  => 18626,
                         "rudders"                 => 23327,
                         "rudimentary"             => 11555,
                         "rudiments"               => 28087,
                         "rudra"                   => 18519,
                         "rudyard"                 => 16837,
                         "rufous"                  => 11965,
                         "rugby"                   => 897,
                         "rugen"                   => 16772,
                         "rugged"                  => 7099,
                         "ruinous"                 => 21203,
                         "ruins"                   => 3312,
                         "ruislip"                 => 25247,
                         "ruizong"                 => 29176,
                         "rule"                    => 857,
                         "ruled"                   => 1665,
                         "ruler"                   => 2776,
                         "rulers"                  => 3627,
                         "rulership"               => 28628,
                         "ruling"                  => 2299,
                         "rulings"                 => 10464,
                         "rumford"                 => 25565,
                         "rumored"                 => 8097,
                         "rumoured"                => 10568,
                         "rumours"                 => 6764,
                         "rumped"                  => 26077,
                         "rumsfeld"                => 18203,
                         "runciman"                => 27250,
                         "runcorn"                 => 17472,
                         "rundfunk"                => 20712,
                         "rundgren"                => 20441,
                         "runestone"               => 16180,
                         "runestones"              => 21072,
                         "runic"                   => 14588,
                         "runners"                 => 3196,
                         "runoff"                  => 6772,
                         "runs"                    => 589,
                         "runtime"                 => 11264,
                         "runway"                  => 3479,
                         "runways"                 => 7672,
                         "rupaul"                  => 21226,
                         "rupee"                   => 18074,
                         "rupees"                  => 11587,
                         "rupiah"                  => 28738,
                         "rupture"                 => 10737,
                         "rural"                   => 645,
                         "rushden"                 => 18742,
                         "rushes"                  => 8036,
                         "ruskin"                  => 11682,
                         "russa"                   => 27522,
                         "russellville"            => 26691,
                         "russes"                  => 27825,
                         "russian"                 => 519,
                         "russula"                 => 29547,
                         "rustic"                  => 10265,
                         "rusticated"              => 21400,
                         "rutgers"                 => 6586,
                         "ruthenia"                => 23958,
                         "ruthenian"               => 17763,
                         "ruthenium"               => 25729,
                         "rutherglen"              => 26296,
                         "rwanda"                  => 6340,
                         "rwandan"                 => 11758,
                         "ryanair"                 => 22464,
                         "ryazan"                  => 18342,
                         "ryoko"                   => 26752,
                         "ryszard"                 => 25372,
                         "ryuichi"                 => 29217,
                         "ryuji"                   => 29238,
                         "ryukyu"                  => 13052,
                         "rzeszow"                 => 13213,
                         "s.h.i.e.l.d"             => 13207,
                         "s.league"                => 22450,
                         "s.p.a."                  => 22583,
                         "sa'id"                   => 19924,
                         "saadi"                   => 28298,
                         "saakashvili"             => 23248,
                         "saale"                   => 18300,
                         "saalfeld"                => 27395,
                         "saanich"                 => 28579,
                         "saarbrucken"             => 13506,
                         "saarc"                   => 26306,
                         "saare"                   => 22857,
                         "saarinen"                => 21346,
                         "saarland"                => 15524,
                         "saatchi"                 => 16295,
                         "sabadell"                => 24753,
                         "sabah"                   => 8356,
                         "sabercats"               => 24546,
                         "sabha"                   => 3538,
                         "sabor"                   => 29068,
                         "saboteurs"               => 25863,
                         "sabretooth"              => 26374,
                         "sabri"                   => 25043,
                         "saccharomyces"           => 24467,
                         "sachsen"                 => 25010,
                         "sachsenhausen"           => 24566,
                         "sacked"                  => 4922,
                         "sacking"                 => 11707,
                         "sacks"                   => 5739,
                         "sackville"               => 12541,
                         "sacra"                   => 20680,
                         "sacral"                  => 18585,
                         "sacrament"               => 9526,
                         "sacramental"             => 19485,
                         "sacramento"              => 4352,
                         "sacraments"              => 12393,
                         "sacred"                  => 2478,
                         "sacrificial"             => 12524,
                         "sacristy"                => 15923,
                         "sacrum"                  => 26115,
                         "sadar"                   => 17920,
                         "sadat"                   => 13073,
                         "saddleback"              => 26925,
                         "saddles"                 => 16859,
                         "sadhana"                 => 22578,
                         "sadhu"                   => 22472,
                         "sadiq"                   => 15935,
                         "saeed"                   => 11388,
                         "saens"                   => 19441,
                         "safar"                   => 26494,
                         "safavid"                 => 13420,
                         "safavids"                => 28611,
                         "safed"                   => 19949,
                         "safeguard"               => 10170,
                         "safeguarded"             => 29655,
                         "safeguarding"            => 16325,
                         "safeguards"              => 14481,
                         "safety"                  => 1079,
                         "saffir"                  => 21173,
                         "saga"                    => 4773,
                         "sagaing"                 => 19040,
                         "sagami"                  => 26945,
                         "sagamore"                => 27514,
                         "sagan"                   => 13141,
                         "sagar"                   => 11357,
                         "sagara"                  => 29257,
                         "sagarmatha"              => 27652,
                         "sagas"                   => 15691,
                         "sagebrush"               => 17142,
                         "sages"                   => 12886,
                         "saginaw"                 => 11217,
                         "sagrada"                 => 24681,
                         "saguenay"                => 22046,
                         "saharan"                 => 8127,
                         "saharanpur"              => 29005,
                         "saheb"                   => 20779,
                         "sahel"                   => 16843,
                         "sahib"                   => 8209,
                         "sahih"                   => 25971,
                         "sahitya"                 => 11785,
                         "sahrawi"                 => 19674,
                         "sailed"                  => 2569,
                         "sailors"                 => 4378,
                         "sailplane"               => 25901,
                         "sails"                   => 7365,
                         "sainsbury"               => 13434,
                         "saint"                   => 593,
                         "sainte"                  => 7026,
                         "saintes"                 => 22747,
                         "saipan"                  => 10011,
                         "saitama"                 => 12354,
                         "sajid"                   => 26599,
                         "sakha"                   => 16137,
                         "sakhalin"                => 14502,
                         "sakharov"                => 28079,
                         "sakya"                   => 23070,
                         "salado"                  => 27150,
                         "salafi"                  => 26082,
                         "salah"                   => 13870,
                         "salamanders"             => 17194,
                         "salamis"                 => 18778,
                         "salar"                   => 19187,
                         "salaried"                => 18999,
                         "salaries"                => 7129,
                         "salat"                   => 28693,
                         "saldanha"                => 24062,
                         "sale"                    => 1556,
                         "sales"                   => 1104,
                         "salesian"                => 20744,
                         "salford"                 => 7626,
                         "salient"                 => 10499,
                         "salih"                   => 16699,
                         "salim"                   => 10196,
                         "salinity"                => 10869,
                         "salivary"                => 20511,
                         "salix"                   => 16203,
                         "salle"                   => 6723,
                         "salmond"                 => 22900,
                         "salon"                   => 4889,
                         "salon.com"               => 25407,
                         "salonika"                => 21935,
                         "salons"                  => 13360,
                         "saloon"                  => 6685,
                         "saloons"                 => 14519,
                         "salt"                    => 1890,
                         "salta"                   => 16788,
                         "salted"                  => 14470,
                         "saltillo"                => 24285,
                         "saltire"                 => 19168,
                         "salto"                   => 20501,
                         "salts"                   => 8091,
                         "saltwater"               => 12289,
                         "salutes"                 => 24727,
                         "salvadoran"              => 11719,
                         "salvaged"                => 10740,
                         "salvation"               => 5093,
                         "salve"                   => 22974,
                         "salyut"                  => 22291,
                         "salzburg"                => 6636,
                         "samad"                   => 22326,
                         "samaj"                   => 13652,
                         "samajwadi"               => 29504,
                         "saman"                   => 26969,
                         "samar"                   => 12451,
                         "samaras"                 => 27833,
                         "samaria"                 => 20169,
                         "samaritans"              => 21985,
                         "samarra"                 => 24935,
                         "sambalpur"               => 23852,
                         "sambar"                  => 28116,
                         "sambre"                  => 26939,
                         "same"                    => 127,
                         "samhita"                 => 25492,
                         "samiti"                  => 16257,
                         "sammarinese"             => 26619,
                         "samnites"                => 29753,
                         "samoa"                   => 5493,
                         "samoan"                  => 9841,
                         "samoans"                 => 27729,
                         "samos"                   => 18463,
                         "sampdoria"               => 16277,
                         "sampled"                 => 7152,
                         "sampler"                 => 12936,
                         "samplers"                => 24951,
                         "sampling"                => 5987,
                         "sampradaya"              => 28878,
                         "samtgemeinde"            => 27803,
                         "san"                     => 330,
                         "san'a"                   => 24866,
                         "sana'a"                  => 18057,
                         "sanada"                  => 27655,
                         "sanam"                   => 27240,
                         "sanatorium"              => 12159,
                         "sancti"                  => 20267,
                         "sanctification"          => 24215,
                         "sanctified"              => 24259,
                         "sanction"                => 10164,
                         "sanctioned"              => 5721,
                         "sanctioning"             => 15218,
                         "sanctions"               => 6229,
                         "sanctorum"               => 21587,
                         "sanctuaries"             => 14149,
                         "sanctuary"               => 3425,
                         "sanctus"                 => 22217,
                         "sandefjord"              => 21322,
                         "sandgate"                => 27127,
                         "sandhills"               => 27260,
                         "sandhurst"               => 12478,
                         "sandinista"              => 19118,
                         "sandnes"                 => 28330,
                         "sandomierz"              => 17533,
                         "sandown"                 => 14480,
                         "sandpiper"               => 25061,
                         "sandpipers"              => 24500,
                         "sandringham"             => 18650,
                         "sandstone"               => 4251,
                         "sandstones"              => 14814,
                         "sandwell"                => 27667,
                         "sandwiched"              => 17531,
                         "sanfl"                   => 12863,
                         "sanga"                   => 24453,
                         "sangam"                  => 14173,
                         "sangamon"                => 27266,
                         "sangeet"                 => 14930,
                         "sangeetha"               => 29475,
                         "sangguniang"             => 26166,
                         "sangh"                   => 15681,
                         "sangha"                  => 14001,
                         "sangli"                  => 28540,
                         "sangre"                  => 17788,
                         "sanhedrin"               => 21181,
                         "sanitary"                => 8744,
                         "sanitation"              => 6540,
                         "sanjak"                  => 14064,
                         "sank"                    => 4479,
                         "sankt"                   => 11819,
                         "sanok"                   => 29528,
                         "sanremo"                 => 15394,
                         "sanskrit"                => 4104,
                         "sant'angelo"             => 22920,
                         "santander"               => 10417,
                         "santarem"                => 29143,
                         "sante"                   => 20732,
                         "santorum"                => 19422,
                         "santurce"                => 25309,
                         "sanyo"                   => 22924,
                         "saone"                   => 12032,
                         "sapieha"                 => 29696,
                         "sapir"                   => 24857,
                         "saplings"                => 27459,
                         "sappers"                 => 20100,
                         "sapporo"                 => 11739,
                         "saprissa"                => 28632,
                         "sarab"                   => 19382,
                         "sarabande"               => 28804,
                         "saracens"                => 13313,
                         "sarada"                  => 27045,
                         "saranac"                 => 26238,
                         "sarandon"                => 25784,
                         "sarasvati"               => 27328,
                         "saraswati"               => 12897,
                         "sarat"                   => 29961,
                         "sarath"                  => 24460,
                         "sarawak"                 => 7999,
                         "sarcastically"           => 20713,
                         "sarcoma"                 => 22033,
                         "sarcophagi"              => 25659,
                         "sardar"                  => 10002,
                         "sardasht"                => 22357,
                         "sardinia"                => 7371,
                         "sardinian"               => 14733,
                         "sardis"                  => 25230,
                         "sardonic"                => 25386,
                         "sargodha"                => 25482,
                         "sarin"                   => 23881,
                         "sarkar"                  => 15034,
                         "sarkozy"                 => 13896,
                         "sarma"                   => 26169,
                         "saros"                   => 24578,
                         "sarpsborg"               => 23651,
                         "sarsfield"               => 17888,
                         "sarthe"                  => 20420,
                         "sarum"                   => 24672,
                         "sarwar"                  => 29507,
                         "sasanian"                => 18138,
                         "sasebo"                  => 14367,
                         "sashes"                  => 26757,
                         "saskatchewan"            => 3226,
                         "saskatoon"               => 8268,
                         "sassafras"               => 27179,
                         "sassanid"                => 12410,
                         "sassanids"               => 29922,
                         "sassari"                 => 24374,
                         "sassoon"                 => 17345,
                         "sassou"                  => 28359,
                         "sastri"                  => 23938,
                         "sastry"                  => 29630,
                         "satanism"                => 25176,
                         "satara"                  => 22581,
                         "satellite"               => 1869,
                         "satellites"              => 5203,
                         "satie"                   => 20418,
                         "satire"                  => 6307,
                         "satires"                 => 19394,
                         "satiric"                 => 23205,
                         "satirical"               => 5982,
                         "satirist"                => 18019,
                         "satirized"               => 22247,
                         "satisfactorily"          => 18745,
                         "satisfactory"            => 8394,
                         "satisfies"               => 9982,
                         "satish"                  => 19570,
                         "satoru"                  => 25463,
                         "satrap"                  => 24826,
                         "sattar"                  => 28320,
                         "saturated"               => 8981,
                         "saturation"              => 11269,
                         "saturdays"               => 6776,
                         "satya"                   => 16397,
                         "satyagraha"              => 21209,
                         "satyajit"                => 22610,
                         "saudi"                   => 2986,
                         "sault"                   => 12332,
                         "saumarez"                => 28075,
                         "saumur"                  => 29377,
                         "saurashtra"              => 21374,
                         "sauropod"                => 22030,
                         "sauropods"               => 24485,
                         "sausalito"               => 26440,
                         "saussure"                => 23835,
                         "sauvignon"               => 13715,
                         "savannas"                => 22842,
                         "savar"                   => 28440,
                         "savile"                  => 14811,
                         "savings"                 => 4167,
                         "savinja"                 => 22069,
                         "savio"                   => 23755,
                         "saviour"                 => 10897,
                         "savitri"                 => 24589,
                         "savoia"                  => 23856,
                         "savona"                  => 21367,
                         "savoury"                 => 29433,
                         "sawai"                   => 24303,
                         "sawan"                   => 29518,
                         "sawmill"                 => 8360,
                         "sawmills"                => 15016,
                         "sawtooth"                => 16331,
                         "saxons"                  => 9066,
                         "saxony"                  => 4326,
                         "saxophone"               => 5939,
                         "saxophones"              => 18858,
                         "saxophonist"             => 7231,
                         "saxophonists"            => 29038,
                         "saybrook"                => 28839,
                         "sayed"                   => 16463,
                         "sayid"                   => 21631,
                         "sayings"                 => 13432,
                         "sayyid"                  => 12412,
                         "scaffold"                => 15086,
                         "scalability"             => 20806,
                         "scalable"                => 15447,
                         "scalar"                  => 9620,
                         "scalars"                 => 29156,
                         "scale"                   => 1071,
                         "scaled"                  => 7276,
                         "scaling"                 => 8943,
                         "scandal"                 => 3274,
                         "scandals"                => 9243,
                         "scandinavia"             => 6734,
                         "scandinavian"            => 6078,
                         "scandinavians"           => 28212,
                         "scanning"                => 7828,
                         "scant"                   => 15247,
                         "scanty"                  => 24056,
                         "scapa"                   => 17598,
                         "scape"                   => 23396,
                         "scapula"                 => 24325,
                         "scapular"                => 22731,
                         "scarcity"                => 10587,
                         "scaritinae"              => 26908,
                         "scarlatti"               => 28631,
                         "scarp"                   => 20994,
                         "scathing"                => 14408,
                         "scattered"               => 3676,
                         "scattering"              => 7244,
                         "scavengers"              => 21671,
                         "scenarios"               => 6744,
                         "scene"                   => 907,
                         "scenes"                  => 1543,
                         "scenic"                  => 4431,
                         "sceptical"               => 16371,
                         "scepticism"              => 19210,
                         "schaffhausen"            => 23525,
                         "scharnhorst"             => 21817,
                         "scheckter"               => 28793,
                         "scheduled"               => 1538,
                         "scheduler"               => 21846,
                         "scheduling"              => 6714,
                         "scheldt"                 => 20425,
                         "schema"                  => 10143,
                         "schemas"                 => 23532,
                         "schematic"               => 17639,
                         "schembechler"            => 27169,
                         "scheme"                  => 1774,
                         "schemes"                 => 4142,
                         "schenectady"             => 12305,
                         "schengen"                => 17158,
                         "scherzinger"             => 19369,
                         "scherzo"                 => 21197,
                         "schiphol"                => 28162,
                         "schism"                  => 9410,
                         "schist"                  => 21969,
                         "schistura"               => 29827,
                         "schizophrenia"           => 8155,
                         "schlafli"                => 28952,
                         "schleswig"               => 7399,
                         "schlumberger"            => 28567,
                         "schneerson"              => 26464,
                         "schoharie"               => 24933,
                         "schola"                  => 23337,
                         "scholar"                 => 2185,
                         "scholarly"               => 4385,
                         "scholars"                => 1757,
                         "scholarship"             => 2208,
                         "scholarships"            => 5365,
                         "scholastic"              => 8328,
                         "schomberg"               => 28931,
                         "school"                  => 44,
                         "schoolboys"              => 17330,
                         "schoolchildren"          => 13707,
                         "schoolhouse"             => 8797,
                         "schooling"               => 5021,
                         "schoolmaster"            => 12903,
                         "schoolmate"              => 27404,
                         "schoolmates"             => 25875,
                         "schools"                 => 370,
                         "schoolteacher"           => 11049,
                         "schooner"                => 7289,
                         "schooners"               => 17964,
                         "schopenhauer"            => 18495,
                         "schrodinger"             => 14085,
                         "schuylkill"              => 12216,
                         "schwa"                   => 27036,
                         "schwaben"                => 28881,
                         "schwarzburg"             => 27342,
                         "schwarzenberg"           => 23178,
                         "schwarzenegger"          => 11545,
                         "schwarzkopf"             => 25521,
                         "schwarzschild"           => 25093,
                         "schweinfurt"             => 25547,
                         "schwerin"                => 14453,
                         "schwyz"                  => 24975,
                         "science"                 => 391,
                         "sciences"                => 1217,
                         "scientific"              => 1028,
                         "scientifically"          => 9807,
                         "scientist"               => 2770,
                         "scientists"              => 2193,
                         "scientologists"          => 24043,
                         "scientology"             => 7457,
                         "scilly"                  => 17906,
                         "scindia"                 => 25837,
                         "scion"                   => 13773,
                         "scioto"                  => 21850,
                         "sclerosis"               => 10567,
                         "scolaire"                => 26916,
                         "scolds"                  => 24992,
                         "scoparia"                => 26120,
                         "scope"                   => 3388,
                         "scopula"                 => 13858,
                         "scopus"                  => 17619,
                         "score"                   => 797,
                         "scoreboard"              => 11458,
                         "scorecards"              => 21646,
                         "scored"                  => 620,
                         "scoreless"               => 8969,
                         "scoreline"               => 14543,
                         "scorer"                  => 4058,
                         "scorers"                 => 8808,
                         "scores"                  => 2530,
                         "scoring"                 => 1139,
                         "scorsese"                => 13172,
                         "scotia"                  => 2959,
                         "scotiabank"              => 27314,
                         "scotrail"                => 26694,
                         "scots"                   => 4332,
                         "scotties"                => 20309,
                         "scottish"                => 1004,
                         "scottsdale"              => 13635,
                         "scotus"                  => 28767,
                         "scout.com"               => 27323,
                         "scouted"                 => 13934,
                         "scouting"                => 5000,
                         "scouts"                  => 3769,
                         "scrapers"                => 27488,
                         "scrapped"                => 5101,
                         "scrapping"               => 10997,
                         "scree"                   => 29137,
                         "screen"                  => 1351,
                         "screened"                => 4523,
                         "screening"               => 4037,
                         "screenings"              => 8488,
                         "screenplay"              => 3554,
                         "screenplays"             => 11178,
                         "screens"                 => 5157,
                         "screenshots"             => 25437,
                         "screenwriter"            => 4624,
                         "screenwriters"           => 17469,
                         "screenwriting"           => 13163,
                         "scriabin"                => 24784,
                         "scribes"                 => 15231,
                         "scrimmage"               => 13971,
                         "scripps"                 => 11034,
                         "script"                  => 1988,
                         "scripted"                => 7958,
                         "scripting"               => 11247,
                         "scripts"                 => 5086,
                         "scriptural"              => 14819,
                         "scripture"               => 6992,
                         "scriptures"              => 7688,
                         "scriptwriter"            => 15336,
                         "scrivener"               => 15606,
                         "scrobipalpa"             => 25960,
                         "scrolling"               => 11141,
                         "scrolls"                 => 9536,
                         "scrope"                  => 23117,
                         "scrum"                   => 12812,
                         "scrutiny"                => 7096,
                         "sculls"                  => 13319,
                         "sculpin"                 => 29759,
                         "sculpted"                => 8469,
                         "sculpting"               => 16176,
                         "sculptor"                => 3771,
                         "sculptors"               => 9260,
                         "sculptural"              => 10771,
                         "sculpture"               => 2382,
                         "sculptured"              => 18451,
                         "sculptures"              => 3949,
                         "scunthorpe"              => 11440,
                         "scuola"                  => 19657,
                         "scutari"                 => 27095,
                         "scutellum"               => 16817,
                         "scutes"                  => 29181,
                         "scuttle"                 => 27507,
                         "scuttled"                => 12533,
                         "scythian"                => 18320,
                         "scythians"               => 19461,
                         "sea"                     => 410,
                         "seabed"                  => 12899,
                         "seabees"                 => 29976,
                         "seabird"                 => 18360,
                         "seabirds"                => 11976,
                         "seaborne"                => 23978,
                         "seacoast"                => 25520,
                         "seacrest"                => 22105,
                         "seafarers"               => 18580,
                         "seafaring"               => 18356,
                         "seafloor"                => 20244,
                         "seaford"                 => 18917,
                         "seaforth"                => 20523,
                         "seafront"                => 20722,
                         "seagoing"                => 20097,
                         "seagram"                 => 27097,
                         "seagrass"                => 23902,
                         "sealers"                 => 26380,
                         "sealift"                 => 23061,
                         "sealing"                 => 8772,
                         "seamanship"              => 26731,
                         "seamen"                  => 9949,
                         "seamless"                => 13658,
                         "seamlessly"              => 16027,
                         "seamount"                => 18179,
                         "seamounts"               => 27704,
                         "seanad"                  => 12717,
                         "seances"                 => 29346,
                         "seaplane"                => 9680,
                         "seaplanes"               => 17542,
                         "seaport"                 => 10766,
                         "seaports"                => 20938,
                         "searchable"              => 18550,
                         "searchers"               => 21656,
                         "searches"                => 6585,
                         "searchlight"             => 14139,
                         "searchlights"            => 23356,
                         "seas"                    => 4623,
                         "season"                  => 73,
                         "seasonal"                => 4340,
                         "seasonally"              => 9294,
                         "seasoning"               => 21276,
                         "seasons"                 => 801,
                         "seat"                    => 646,
                         "seater"                  => 8018,
                         "seaters"                 => 24427,
                         "seating"                 => 4010,
                         "seats"                   => 1277,
                         "seaview"                 => 26719,
                         "seawall"                 => 24560,
                         "seaward"                 => 17275,
                         "seawater"                => 11138,
                         "seaway"                  => 16662,
                         "seawolves"               => 26375,
                         "seaworld"                => 22909,
                         "seaworthy"               => 27870,
                         "sebastiao"               => 23598,
                         "sebastopol"              => 26518,
                         "secede"                  => 18133,
                         "seceded"                 => 16489,
                         "secession"               => 7550,
                         "secessionist"            => 17489,
                         "second"                  => 79,
                         "seconda"                 => 21079,
                         "secondarily"             => 25241,
                         "secondary"               => 895,
                         "seconded"                => 12370,
                         "secretariat"             => 5356,
                         "secretary"               => 678,
                         "secrete"                 => 16129,
                         "secreted"                => 12705,
                         "secretion"               => 10836,
                         "secretory"               => 22044,
                         "sectarian"               => 9515,
                         "sectarianism"            => 27196,
                         "section"                 => 485,
                         "sectional"               => 9603,
                         "sectioned"               => 28397,
                         "sections"                => 1615,
                         "sector"                  => 1302,
                         "sectoral"                => 23407,
                         "sectors"                 => 3864,
                         "sects"                   => 10004,
                         "secular"                 => 3629,
                         "secularism"              => 15897,
                         "secularization"          => 20290,
                         "secularized"             => 24623,
                         "secunda"                 => 24957,
                         "secunderabad"            => 17589,
                         "secured"                 => 2575,
                         "secures"                 => 20959,
                         "securing"                => 4795,
                         "securitate"              => 24805,
                         "securities"              => 4202,
                         "sedaka"                  => 25594,
                         "sedan"                   => 6575,
                         "sedans"                  => 14877,
                         "sedentary"               => 14373,
                         "sedge"                   => 14238,
                         "sedges"                  => 26460,
                         "sediment"                => 6880,
                         "sedimentary"             => 8493,
                         "sedimentation"           => 15456,
                         "sediments"               => 7236,
                         "sedis"                   => 17471,
                         "sedition"                => 13694,
                         "seditious"               => 19614,
                         "seed"                    => 2338,
                         "seeded"                  => 5517,
                         "seeding"                 => 11226,
                         "seedling"                => 21196,
                         "seedlings"               => 13449,
                         "seeds"                   => 2678,
                         "seek"                    => 2275,
                         "seekers"                 => 8965,
                         "seeking"                 => 2289,
                         "seeks"                   => 3897,
                         "seemingly"               => 4150,
                         "seepage"                 => 24610,
                         "sefer"                   => 17388,
                         "sefid"                   => 17887,
                         "sega"                    => 5793,
                         "segment"                 => 2343,
                         "segmental"               => 19653,
                         "segmentation"            => 15501,
                         "segmented"               => 13292,
                         "segments"                => 3061,
                         "segre"                   => 28739,
                         "segregate"               => 27718,
                         "segregated"              => 8359,
                         "segregation"             => 6627,
                         "segregationist"          => 26282,
                         "segunda"                 => 7593,
                         "seibu"                   => 17103,
                         "seigneur"                => 16266,
                         "seiji"                   => 23079,
                         "seine"                   => 6311,
                         "seinen"                  => 27694,
                         "seismic"                 => 7732,
                         "seismology"              => 25824,
                         "seiya"                   => 27864,
                         "seized"                  => 3355,
                         "sejong"                  => 25675,
                         "sekolah"                 => 18461,
                         "selangor"                => 10618,
                         "selassie"                => 14439,
                         "seldom"                  => 6798,
                         "selectable"              => 22068,
                         "selected"                => 719,
                         "selecting"               => 6565,
                         "selection"               => 1517,
                         "selections"              => 6112,
                         "selective"               => 4724,
                         "selectively"             => 11057,
                         "selectivity"             => 13757,
                         "selectmen"               => 23569,
                         "selector"                => 11886,
                         "selectors"               => 11610,
                         "selects"                 => 9215,
                         "selenium"                => 15173,
                         "seleucia"                => 26754,
                         "seleucid"                => 15750,
                         "seleucus"                => 20876,
                         "self"                    => 619,
                         "selim"                   => 13007,
                         "seljuk"                  => 15804,
                         "seljuq"                  => 22287,
                         "selkirk"                 => 13134,
                         "seller"                  => 5538,
                         "selling"                 => 1406,
                         "selva"                   => 19804,
                         "selwyn"                  => 13488,
                         "semantic"                => 7219,
                         "semantically"            => 22300,
                         "semaphore"               => 19364,
                         "semarang"                => 21823,
                         "sembilan"                => 18772,
                         "semesters"               => 12418,
                         "semi"                    => 1090,
                         "semicircle"              => 23370,
                         "semicircular"            => 14050,
                         "semiconductor"           => 6863,
                         "semiconductors"          => 13893,
                         "semifinal"               => 5891,
                         "semifinalist"            => 19069,
                         "semifinalists"           => 20342,
                         "semifinals"              => 3615,
                         "semigroup"               => 20351,
                         "seminaire"               => 26393,
                         "seminal"                 => 6789,
                         "seminarians"             => 19687,
                         "seminaries"              => 13662,
                         "seminars"                => 5787,
                         "seminary"                => 2911,
                         "semiotic"                => 28411,
                         "semiotics"               => 19859,
                         "semisimple"              => 26239,
                         "semitic"                 => 6918,
                         "semitism"                => 9834,
                         "semitone"                => 24661,
                         "semitones"               => 29269,
                         "semnan"                  => 18877,
                         "semyon"                  => 21355,
                         "senate"                  => 952,
                         "senator"                 => 1783,
                         "senatorial"              => 9831,
                         "sendai"                  => 13421,
                         "sender"                  => 11838,
                         "senecio"                 => 24145,
                         "senegal"                 => 6035,
                         "senegalese"              => 12663,
                         "seneschal"               => 26488,
                         "sengoku"                 => 14749,
                         "senhora"                 => 17101,
                         "senior"                  => 557,
                         "seniority"               => 9126,
                         "seniors"                 => 5690,
                         "sensibilities"           => 15429,
                         "sensibility"             => 11718,
                         "sensitivities"           => 26048,
                         "sensor"                  => 5268,
                         "sensors"                 => 5523,
                         "sensory"                 => 6146,
                         "sensu"                   => 20094,
                         "sent"                    => 503,
                         "sentai"                  => 12746,
                         "sentenced"               => 2483,
                         "sentences"               => 4506,
                         "sentient"                => 11704,
                         "senussi"                 => 26753,
                         "seong"                   => 21244,
                         "seoul"                   => 4043,
                         "sepahan"                 => 25685,
                         "sepals"                  => 13117,
                         "separable"               => 17139,
                         "separate"                => 818,
                         "separated"               => 1852,
                         "separately"              => 3685,
                         "separates"               => 6603,
                         "separating"              => 6023,
                         "separation"              => 3163,
                         "separations"             => 22871,
                         "separatism"              => 19810,
                         "separatist"              => 9527,
                         "separatists"             => 13727,
                         "separator"               => 17277,
                         "separators"              => 28186,
                         "sephardi"                => 18241,
                         "sephardic"               => 12228,
                         "sepia"                   => 20595,
                         "sepinwall"               => 23943,
                         "sepoys"                  => 25344,
                         "sept."                   => 9293,
                         "septa"                   => 11222,
                         "septal"                  => 25943,
                         "september"               => 143,
                         "septimius"               => 23081,
                         "septimus"                => 23562,
                         "septuagint"              => 16343,
                         "sepulchre"               => 15083,
                         "sequel"                  => 2932,
                         "sequels"                 => 7714,
                         "sequence"                => 1744,
                         "sequenced"               => 13393,
                         "sequencer"               => 21021,
                         "sequences"               => 3598,
                         "sequencing"              => 8584,
                         "sequential"              => 8415,
                         "sequentially"            => 15005,
                         "sequestration"           => 17772,
                         "sequoyah"                => 24861,
                         "serbia"                  => 2463,
                         "serbian"                 => 2362,
                         "serbo"                   => 13356,
                         "serbs"                   => 5964,
                         "seremban"                => 28351,
                         "serer"                   => 17254,
                         "serfdom"                 => 17915,
                         "serfs"                   => 15432,
                         "sergeants"               => 13666,
                         "sergeyevich"             => 20619,
                         "sergius"                 => 16572,
                         "serhiy"                  => 20035,
                         "seria"                   => 23517,
                         "serial"                  => 2782,
                         "serialised"              => 19572,
                         "serialization"           => 15693,
                         "serialized"              => 8753,
                         "serials"                 => 8754,
                         "serie"                   => 3086,
                         "series"                  => 100,
                         "serif"                   => 16563,
                         "serine"                  => 14648,
                         "serjeant"                => 17073,
                         "serling"                 => 23641,
                         "sermons"                 => 7563,
                         "serotonin"               => 11426,
                         "serpentine"              => 11895,
                         "serpents"                => 18374,
                         "serrated"                => 16271,
                         "serre"                   => 21452,
                         "servant"                 => 3587,
                         "serve"                   => 901,
                         "served"                  => 192,
                         "servers"                 => 5402,
                         "serves"                  => 1031,
                         "service"                 => 173,
                         "serviced"                => 7620,
                         "serviceman"              => 23660,
                         "servicemen"              => 8774,
                         "services"                => 296,
                         "servicing"               => 8867,
                         "serving"                 => 766,
                         "servius"                 => 29461,
                         "sesquicentennial"        => 26026,
                         "sessile"                 => 19039,
                         "session"                 => 1691,
                         "sessions"                => 2189,
                         "sesto"                   => 28281,
                         "set"                     => 200,
                         "setae"                   => 21729,
                         "setanta"                 => 19268,
                         "setif"                   => 29329,
                         "setlist"                 => 13419,
                         "seton"                   => 9414,
                         "sets"                    => 1373,
                         "setting"                 => 1357,
                         "settings"                => 3878,
                         "settled"                 => 1290,
                         "settlement"              => 958,
                         "settlements"             => 2424,
                         "settler"                 => 6757,
                         "settlers"                => 2313,
                         "setubal"                 => 20803,
                         "setups"                  => 22386,
                         "seung"                   => 13090,
                         "seven"                   => 405,
                         "sevenfold"               => 27780,
                         "sevenoaks"               => 19805,
                         "seventeenth"             => 5699,
                         "seventh"                 => 1532,
                         "several"                 => 114,
                         "severe"                  => 1840,
                         "severely"                => 3169,
                         "severing"                => 16940,
                         "severity"                => 7077,
                         "severn"                  => 8207,
                         "sevres"                  => 16345,
                         "sewage"                  => 7126,
                         "sewerage"                => 13908,
                         "sexes"                   => 7259,
                         "sexism"                  => 14537,
                         "sextet"                  => 15875,
                         "sextus"                  => 19733,
                         "sexuality"               => 5309,
                         "seychelles"              => 9397,
                         "seyyed"                  => 14300,
                         "shaanxi"                 => 10514,
                         "shabaab"                 => 17744,
                         "shabab"                  => 22643,
                         "shabbat"                 => 12193,
                         "shackleton"              => 12396,
                         "shacks"                  => 24094,
                         "shaded"                  => 10416,
                         "shading"                 => 13730,
                         "shadowed"                => 20554,
                         "shafi"                   => 24774,
                         "shafi'i"                 => 28564,
                         "shaftesbury"             => 13600,
                         "shafts"                  => 7656,
                         "shahab"                  => 27802,
                         "shahar"                  => 27364,
                         "shahbaz"                 => 28056,
                         "shaheed"                 => 15661,
                         "shahi"                   => 15075,
                         "shahin"                  => 19969,
                         "shahr"                   => 13711,
                         "shahrak"                 => 15172,
                         "shaivism"                => 27946,
                         "shakespeare"             => 2996,
                         "shakespearean"           => 13423,
                         "shakhtar"                => 17352,
                         "shale"                   => 6255,
                         "shales"                  => 16311,
                         "shalit"                  => 26618,
                         "shallower"               => 15981,
                         "shamanic"                => 24290,
                         "shamanism"               => 17899,
                         "shamans"                 => 17459,
                         "shamir"                  => 21679,
                         "shamokin"                => 24055,
                         "shamrocks"               => 18726,
                         "shandong"                => 8527,
                         "shanghai"                => 2983,
                         "shankar"                 => 6787,
                         "shankara"                => 20006,
                         "shankill"                => 21253,
                         "shankly"                 => 27259,
                         "shanxi"                  => 10543,
                         "shape"                   => 1512,
                         "shaped"                  => 1749,
                         "shapes"                  => 4357,
                         "shapur"                  => 19557,
                         "sharad"                  => 26985,
                         "sharada"                 => 28507,
                         "sharaf"                  => 28139,
                         "sharapova"               => 16204,
                         "shard"                   => 19819,
                         "sharecroppers"           => 29745,
                         "shared"                  => 1428,
                         "shareholder"             => 6704,
                         "shareholders"            => 5458,
                         "shareholding"            => 14255,
                         "shares"                  => 2188,
                         "shareware"               => 21542,
                         "sharia"                  => 9980,
                         "shariah"                 => 27520,
                         "sharif"                  => 7495,
                         "sharjah"                 => 15000,
                         "sharply"                 => 5991,
                         "sharpness"               => 21155,
                         "sharpshooter"            => 23276,
                         "sharqi"                  => 11921,
                         "shastri"                 => 15481,
                         "shaukat"                 => 27037,
                         "shawinigan"              => 28105,
                         "shaykh"                  => 13824,
                         "she"                     => 36,
                         "sheaf"                   => 15480,
                         "sheamus"                 => 24369,
                         "shear"                   => 6346,
                         "sheared"                 => 28226,
                         "shearing"                => 14921,
                         "shearwater"              => 19971,
                         "sheath"                  => 12218,
                         "sheathed"                => 18808,
                         "sheaths"                 => 22972,
                         "sheaves"                 => 22076,
                         "sheboygan"               => 18039,
                         "shedding"                => 13366,
                         "sheds"                   => 9297,
                         "sheep"                   => 3218,
                         "sheerness"               => 20407,
                         "sheeting"                => 21772,
                         "shehu"                   => 28038,
                         "sheik"                   => 13989,
                         "sheikh"                  => 4917,
                         "shekhar"                 => 16769,
                         "shelbourne"              => 16652,
                         "shelling"                => 10825,
                         "shells"                  => 4151,
                         "sheltered"               => 7796,
                         "sheltering"              => 16273,
                         "shelters"                => 6313,
                         "shelved"                 => 9765,
                         "shenandoah"              => 9933,
                         "shenhua"                 => 25239,
                         "shenyang"                => 15065,
                         "shenzhen"                => 9601,
                         "shepparton"              => 24567,
                         "shepperton"              => 26357,
                         "sherbrooke"              => 13240,
                         "sherds"                  => 29420,
                         "sheriffs"                => 13881,
                         "sheringham"              => 21903,
                         "shetland"                => 8448,
                         "shetty"                  => 14755,
                         "sheung"                  => 26127,
                         "sheva"                   => 20278,
                         "shevardnadze"            => 28743,
                         "shewa"                   => 25595,
                         "sheykh"                  => 16832,
                         "shi'a"                   => 13874,
                         "shi'ar"                  => 26479,
                         "shi'ite"                 => 24660,
                         "shias"                   => 24704,
                         "shibuya"                 => 17272,
                         "shield"                  => 2671,
                         "shielded"                => 14917,
                         "shifted"                 => 3350,
                         "shifting"                => 5486,
                         "shiga"                   => 18553,
                         "shigeru"                 => 19288,
                         "shiite"                  => 16126,
                         "shiji"                   => 29748,
                         "shijiazhuang"            => 21445,
                         "shikai"                  => 27600,
                         "shiki"                   => 26447,
                         "shikoku"                 => 16604,
                         "shillong"                => 19954,
                         "shilton"                 => 28149,
                         "shimane"                 => 26044,
                         "shimazu"                 => 25251,
                         "shimbun"                 => 18982,
                         "shimin"                  => 22482,
                         "shimla"                  => 19529,
                         "shimoga"                 => 29415,
                         "shimon"                  => 15395,
                         "shinawatra"              => 24590,
                         "shinde"                  => 24898,
                         "shing"                   => 18132,
                         "shingle"                 => 12204,
                         "shingled"                => 24624,
                         "shingles"                => 13873,
                         "shingon"                 => 29187,
                         "shinjuku"                => 16523,
                         "shinkansen"              => 14568,
                         "shinto"                  => 11169,
                         "shinty"                  => 20218,
                         "shinya"                  => 28781,
                         "ship"                    => 542,
                         "shipboard"               => 20191,
                         "shipbuilder"             => 19140,
                         "shipbuilders"            => 16977,
                         "shipbuilding"            => 5573,
                         "shipments"               => 8403,
                         "shipowner"               => 25523,
                         "shippers"                => 26171,
                         "shipping"                => 2668,
                         "ships"                   => 849,
                         "shipwreck"               => 10841,
                         "shipwrecks"              => 11918,
                         "shipyard"                => 4832,
                         "shipyards"               => 9602,
                         "shirai"                  => 29459,
                         "shirazi"                 => 22672,
                         "shire"                   => 4618,
                         "shirvan"                 => 21971,
                         "shiva"                   => 4428,
                         "shivaji"                 => 12104,
                         "shizuoka"                => 13842,
                         "shkoder"                 => 17995,
                         "shmuel"                  => 16945,
                         "shoal"                   => 13070,
                         "shoals"                  => 10775,
                         "shockwave"               => 14781,
                         "shoestring"              => 28728,
                         "shogakukan"              => 20321,
                         "shoghi"                  => 25744,
                         "shogi"                   => 20484,
                         "shogunate"               => 10335,
                         "shoji"                   => 22525,
                         "shojo"                   => 15766,
                         "sholom"                  => 29185,
                         "shomali"                 => 14913,
                         "shonen"                  => 10851,
                         "shootings"               => 10528,
                         "shooto"                  => 18335,
                         "shootout"                => 6489,
                         "shops"                   => 2560,
                         "shore"                   => 1843,
                         "shorea"                  => 27123,
                         "shorebirds"              => 21733,
                         "shoreditch"              => 20430,
                         "shoreham"                => 17738,
                         "shoreline"               => 6807,
                         "shorelines"              => 23537,
                         "short"                   => 304,
                         "shortage"                => 5749,
                         "shortages"               => 7628,
                         "shorten"                 => 13315,
                         "shortened"               => 4473,
                         "shortening"              => 12001,
                         "shortest"                => 7235,
                         "shortfall"               => 16908,
                         "shortfalls"              => 27074,
                         "shortland"               => 18689,
                         "shortlist"               => 12670,
                         "shortlisted"             => 8586,
                         "shortly"                 => 950,
                         "shortstop"               => 8233,
                         "shortwave"               => 14253,
                         "shoshone"                => 14997,
                         "shostakovich"            => 13862,
                         "shoten"                  => 21232,
                         "shouldered"              => 18934,
                         "show"                    => 169,
                         "showa"                   => 16459,
                         "showcase"                => 4885,
                         "showcased"               => 7724,
                         "showcases"               => 8906,
                         "showcasing"              => 9312,
                         "showdown"                => 8831,
                         "showground"              => 24688,
                         "showgrounds"             => 26414,
                         "showings"                => 15443,
                         "shown"                   => 752,
                         "showrooms"               => 20808,
                         "showrunner"              => 18527,
                         "shows"                   => 520,
                         "shrank"                  => 18456,
                         "shree"                   => 12861,
                         "shrestha"                => 27656,
                         "shreveport"              => 8322,
                         "shrews"                  => 18629,
                         "shrewsbury"              => 6268,
                         "shri"                    => 5712,
                         "shrikes"                 => 24050,
                         "shrimps"                 => 25560,
                         "shrine"                  => 3482,
                         "shrines"                 => 7598,
                         "shrub"                   => 6324,
                         "shrubby"                 => 24797,
                         "shrubland"               => 11951,
                         "shrublands"              => 25449,
                         "shrubs"                  => 7250,
                         "shruti"                  => 24667,
                         "shueisha"                => 20826,
                         "shugo"                   => 29239,
                         "shuja"                   => 24809,
                         "shunting"                => 14636,
                         "shura"                   => 18352,
                         "shusha"                  => 22773,
                         "shutdown"                => 9824,
                         "shutout"                 => 9139,
                         "shutouts"                => 11227,
                         "shutter"                 => 10621,
                         "shuttered"               => 20497,
                         "shuttle"                 => 4136,
                         "shuttled"                => 29735,
                         "shyam"                   => 14591,
                         "sialkot"                 => 17806,
                         "siang"                   => 29740,
                         "siauliai"                => 23950,
                         "sibenik"                 => 21962,
                         "siberia"                 => 6152,
                         "siberian"                => 7630,
                         "sibiu"                   => 18232,
                         "siblings"                => 3832,
                         "sibylla"                 => 27707,
                         "sichuan"                 => 7474,
                         "sicilian"                => 7723,
                         "sicilies"                => 17444,
                         "sicily"                  => 4214,
                         "sickle"                  => 11841,
                         "siculus"                 => 28007,
                         "siddeley"                => 15612,
                         "siddha"                  => 23888,
                         "siddharth"               => 18938,
                         "siddhartha"              => 22639,
                         "side"                    => 230,
                         "sided"                   => 4317,
                         "sideline"                => 11379,
                         "sidelined"               => 9921,
                         "sideman"                 => 14581,
                         "sidereal"                => 28170,
                         "sides"                   => 1250,
                         "sidings"                 => 10189,
                         "sidon"                   => 17426,
                         "siecle"                  => 20471,
                         "siedlce"                 => 20470,
                         "siege"                   => 2160,
                         "siegen"                  => 19683,
                         "sieges"                  => 16752,
                         "siena"                   => 8110,
                         "sieradz"                 => 21014,
                         "sieur"                   => 21227,
                         "sighted"                 => 7223,
                         "sigint"                  => 23214,
                         "sigismund"               => 8884,
                         "siglo"                   => 29470,
                         "sigmaringen"             => 26624,
                         "signage"                 => 9403,
                         "signal"                  => 1486,
                         "signaled"                => 12010,
                         "signaling"               => 6036,
                         "signalled"               => 13387,
                         "signalling"              => 7642,
                         "signalman"               => 24508,
                         "signals"                 => 2842,
                         "signatories"             => 10006,
                         "signatory"               => 12057,
                         "signatures"              => 6238,
                         "signed"                  => 406,
                         "signer"                  => 19211,
                         "signers"                 => 19856,
                         "signet"                  => 22362,
                         "significance"            => 2393,
                         "significant"             => 616,
                         "significantly"           => 1866,
                         "signified"               => 13688,
                         "signifies"               => 10871,
                         "signify"                 => 10479,
                         "signifying"              => 11198,
                         "signing"                 => 2194,
                         "signings"                => 11000,
                         "signposted"              => 28472,
                         "sigur"                   => 29384,
                         "sigurd"                  => 12485,
                         "sihanouk"                => 17076,
                         "sikandar"                => 26182,
                         "sikh"                    => 5817,
                         "sikhism"                 => 15275,
                         "sikhs"                   => 8172,
                         "sikkim"                  => 9877,
                         "sikorsky"                => 14158,
                         "silat"                   => 25576,
                         "silencing"               => 17190,
                         "silesia"                 => 7085,
                         "silesian"                => 5684,
                         "silhouette"              => 10937,
                         "silhouettes"             => 21263,
                         "silica"                  => 10515,
                         "silicate"                => 16160,
                         "silicon"                 => 4901,
                         "siliguri"                => 25973,
                         "silkworm"                => 29942,
                         "silla"                   => 11406,
                         "silmarillion"            => 29755,
                         "silted"                  => 29867,
                         "silting"                 => 28286,
                         "siltstone"               => 26561,
                         "silurian"                => 14368,
                         "silverbacks"             => 23182,
                         "silverstone"             => 12382,
                         "silverton"               => 20987,
                         "silvery"                 => 11949,
                         "simca"                   => 22755,
                         "simcoe"                  => 12881,
                         "similar"                 => 365,
                         "similarities"            => 4392,
                         "similarity"              => 5137,
                         "similarly"               => 2173,
                         "similis"                 => 29395,
                         "simla"                   => 24471,
                         "simmern"                 => 29421,
                         "simplex"                 => 11234,
                         "simplicial"              => 24707,
                         "simplicity"              => 6712,
                         "simplification"          => 14318,
                         "simplified"              => 5397,
                         "simplifies"              => 17434,
                         "simplify"                => 10827,
                         "simplifying"             => 16961,
                         "simply"                  => 1102,
                         "simulate"                => 8700,
                         "simulated"               => 8061,
                         "simulating"              => 14896,
                         "simulation"              => 4740,
                         "simulations"             => 8625,
                         "simulators"              => 15222,
                         "simulcast"               => 7310,
                         "simulcasting"            => 15178,
                         "simulcasts"              => 19474,
                         "simultaneous"            => 6291,
                         "simultaneously"          => 2724,
                         "sinai"                   => 7112,
                         "sinaloa"                 => 12867,
                         "sinan"                   => 17946,
                         "since"                   => 103,
                         "sindh"                   => 6746,
                         "sindhi"                  => 11840,
                         "sinensis"                => 21000,
                         "sinestro"                => 19061,
                         "sinfonietta"             => 22021,
                         "singapore"               => 1586,
                         "singaporean"             => 9347,
                         "singaporeans"            => 19868,
                         "singer"                  => 697,
                         "singer/guitarist"        => 23798,
                         "singer/songwriter"       => 9923,
                         "singers"                 => 2941,
                         "singha"                  => 18258,
                         "single"                  => 182,
                         "singled"                 => 8861,
                         "singles"                 => 748,
                         "singlet"                 => 26895,
                         "singly"                  => 13570,
                         "sings"                   => 4243,
                         "singular"                => 5019,
                         "singularities"           => 21267,
                         "singularity"             => 13330,
                         "sinhala"                 => 12456,
                         "sinhalese"               => 12489,
                         "sinkhole"                => 24510,
                         "sinuous"                 => 21049,
                         "sinusoidal"              => 22649,
                         "siochana"                => 27275,
                         "sioux"                   => 6042,
                         "siphuncle"               => 29703,
                         "siraj"                   => 27761,
                         "sired"                   => 9898,
                         "sirjan"                  => 25799,
                         "sirte"                   => 27232,
                         "siskel"                  => 28358,
                         "siskiyou"                => 23064,
                         "sistan"                  => 11251,
                         "sitar"                   => 15737,
                         "sitcom"                  => 4450,
                         "sitcoms"                 => 12266,
                         "site"                    => 301,
                         "sited"                   => 9036,
                         "sites"                   => 1131,
                         "siting"                  => 21353,
                         "sitio"                   => 24483,
                         "sitka"                   => 16569,
                         "sittings"                => 23059,
                         "situated"                => 1053,
                         "situational"             => 14515,
                         "situations"              => 2993,
                         "sivaji"                  => 19368,
                         "sivan"                   => 21250,
                         "sivas"                   => 27798,
                         "six"                     => 245,
                         "sixteenth"               => 5550,
                         "sixth"                   => 1185,
                         "sixtieth"                => 28031,
                         "sixtus"                  => 17478,
                         "siyuan"                  => 21557,
                         "size"                    => 483,
                         "sizeable"                => 10698,
                         "sized"                   => 2773,
                         "sizes"                   => 3994,
                         "skagit"                  => 23553,
                         "skanda"                  => 28719,
                         "skanderbeg"              => 15860,
                         "skane"                   => 17752,
                         "skateboarder"            => 20555,
                         "skateboarders"           => 28034,
                         "skateboarding"           => 11453,
                         "skatepark"               => 26905,
                         "skaters"                 => 7883,
                         "skating"                 => 3179,
                         "skegness"                => 29104,
                         "skeletal"                => 8143,
                         "skeleton"                => 5425,
                         "skene"                   => 21953,
                         "skepticism"              => 10310,
                         "skeptics"                => 15792,
                         "skerries"                => 28893,
                         "skien"                   => 23665,
                         "skier"                   => 7565,
                         "skiers"                  => 11642,
                         "skilful"                 => 18237,
                         "skill"                   => 3310,
                         "skilled"                 => 4158,
                         "skillful"                => 12437,
                         "skills"                  => 1542,
                         "skinheads"               => 27975,
                         "skink"                   => 14732,
                         "skinks"                  => 28014,
                         "skippers"                => 19863,
                         "skipton"                 => 19667,
                         "skirmish"                => 9432,
                         "skirmishers"             => 26605,
                         "skirmishes"              => 10673,
                         "skirmishing"             => 23545,
                         "skirted"                 => 29031,
                         "skirting"                => 23410,
                         "skits"                   => 14122,
                         "skoda"                   => 12438,
                         "skopje"                  => 10173,
                         "skrull"                  => 19462,
                         "skrulls"                 => 29954,
                         "skyhawks"                => 26000,
                         "skylab"                  => 22895,
                         "skylights"               => 24739,
                         "skype"                   => 14830,
                         "skyrocketed"             => 24143,
                         "skyscraper"              => 8186,
                         "skyscrapers"             => 11216,
                         "skytrain"                => 19487,
                         "skyway"                  => 18898,
                         "slabs"                   => 10963,
                         "slain"                   => 7971,
                         "slalom"                  => 6406,
                         "slang"                   => 7287,
                         "slapstick"               => 14675,
                         "slashes"                 => 29613,
                         "slaskie"                 => 29292,
                         "slated"                  => 6430,
                         "slatina"                 => 25499,
                         "slats"                   => 22198,
                         "slaveholders"            => 25955,
                         "slavery"                 => 3180,
                         "slaves"                  => 2669,
                         "slavia"                  => 15878,
                         "slavic"                  => 4643,
                         "slavonia"                => 13690,
                         "slavonic"                => 12492,
                         "slavs"                   => 9703,
                         "sleaford"                => 21619,
                         "sleeved"                 => 22077,
                         "slender"                 => 5662,
                         "slieve"                  => 29393,
                         "slightly"                => 1450,
                         "sligo"                   => 9659,
                         "slims"                   => 22531,
                         "slingsby"                => 28063,
                         "slipstream"              => 25908,
                         "slipway"                 => 24896,
                         "slits"                   => 14967,
                         "slobodan"                => 14852,
                         "slogan"                  => 4998,
                         "slogans"                 => 10160,
                         "sloop"                   => 8545,
                         "sloops"                  => 18912,
                         "slope"                   => 4101,
                         "sloped"                  => 15933,
                         "slopes"                  => 3692,
                         "sloping"                 => 9605,
                         "slot"                    => 3902,
                         "sloths"                  => 27350,
                         "slotted"                 => 17008,
                         "slovak"                  => 4667,
                         "slovakia"                => 3933,
                         "slovakian"               => 18604,
                         "slovaks"                 => 17153,
                         "slovan"                  => 17652,
                         "slovene"                 => 7303,
                         "slovenes"                => 13353,
                         "slovenia"                => 3547,
                         "slovenian"               => 5786,
                         "slovenska"               => 28501,
                         "slowdown"                => 20696,
                         "slowed"                  => 6786,
                         "slower"                  => 5255,
                         "slugging"                => 12226,
                         "sluice"                  => 16877,
                         "slums"                   => 11887,
                         "slupsk"                  => 18744,
                         "slurry"                  => 18099,
                         "slurs"                   => 25664,
                         "smaland"                 => 26099,
                         "small"                   => 185,
                         "smaller"                 => 947,
                         "smallest"                => 3982,
                         "smallholders"            => 24967,
                         "smallmouth"              => 25064,
                         "smallpox"                => 8629,
                         "smalltalk"               => 25096,
                         "smartphone"              => 10085,
                         "smartphones"             => 11347,
                         "smeaton"                 => 24958,
                         "smederevo"               => 26382,
                         "smelter"                 => 14535,
                         "smelters"                => 27653,
                         "smelting"                => 11627,
                         "smethwick"               => 26448,
                         "smithfield"              => 12953,
                         "smithsonian"             => 6180,
                         "smokehouse"              => 21420,
                         "smokeless"               => 20102,
                         "smoky"                   => 10142,
                         "smoothbore"              => 25091,
                         "smoothness"              => 22353,
                         "smriti"                  => 28274,
                         "smuts"                   => 18289,
                         "smyrna"                  => 11511,
                         "snail"                   => 3595,
                         "snails"                  => 4252,
                         "snapdragon"              => 28275,
                         "sneha"                   => 29884,
                         "snippet"                 => 21668,
                         "snippets"                => 18137,
                         "snohomish"               => 21984,
                         "snoqualmie"              => 27492,
                         "snorna"                  => 25498,
                         "snorri"                  => 17702,
                         "snout"                   => 6715,
                         "snowboarder"             => 23448,
                         "snowboarding"            => 12166,
                         "snowdonia"               => 25360,
                         "snowfall"                => 9208,
                         "snowfalls"               => 29815,
                         "soames"                  => 28499,
                         "soane"                   => 25691,
                         "soared"                  => 15611,
                         "sobibor"                 => 28379,
                         "sobre"                   => 24300,
                         "sobriquet"               => 20708,
                         "sochaczew"               => 27521,
                         "sochaux"                 => 26360,
                         "sochi"                   => 10812,
                         "social"                  => 320,
                         "sociale"                 => 29300,
                         "socialism"               => 5149,
                         "socialist"               => 1864,
                         "socialists"              => 7237,
                         "socialite"               => 12083,
                         "socialization"           => 16729,
                         "socially"                => 5306,
                         "sociedad"                => 12244,
                         "sociedade"               => 25941,
                         "societa"                 => 17701,
                         "societal"                => 8145,
                         "societe"                 => 7431,
                         "societies"               => 2774,
                         "society"                 => 305,
                         "socio"                   => 6262,
                         "sociocultural"           => 26977,
                         "socioeconomic"           => 9584,
                         "sociological"            => 8617,
                         "sociologist"             => 8736,
                         "sociologists"            => 15296,
                         "sociology"               => 4284,
                         "sociopolitical"          => 24762,
                         "sockers"                 => 26926,
                         "socon"                   => 26519,
                         "socratic"                => 22593,
                         "soderbergh"              => 25110,
                         "sodermanland"            => 26257,
                         "sodertalje"              => 28009,
                         "sodium"                  => 4697,
                         "sodom"                   => 19317,
                         "sodomy"                  => 14208,
                         "sodor"                   => 24428,
                         "sodra"                   => 19525,
                         "sofer"                   => 24153,
                         "sofie"                   => 25497,
                         "sofla"                   => 6380,
                         "softbank"                => 29747,
                         "sohail"                  => 28197,
                         "sohrab"                  => 25126,
                         "soil"                    => 1919,
                         "soils"                   => 4845,
                         "soissons"                => 20664,
                         "sojourn"                 => 16183,
                         "sokolka"                 => 22133,
                         "sokolow"                 => 23152,
                         "sokoto"                  => 20495,
                         "solanum"                 => 21386,
                         "solapur"                 => 24555,
                         "solar"                   => 1961,
                         "sold"                    => 430,
                         "soldered"                => 28561,
                         "soldering"               => 22106,
                         "soldiers"                => 943,
                         "sole"                    => 2471,
                         "solely"                  => 3467,
                         "solemnity"               => 27617,
                         "solent"                  => 18438,
                         "soleyman"                => 24627,
                         "solicited"               => 13737,
                         "solicitor"               => 5755,
                         "solicitors"              => 13201,
                         "solidarity"              => 5475,
                         "solidified"              => 12458,
                         "solidifying"             => 26358,
                         "solidly"                 => 15592,
                         "solids"                  => 8967,
                         "solihull"                => 16016,
                         "solms"                   => 29252,
                         "solo"                    => 1056,
                         "soloist"                 => 6261,
                         "soloists"                => 10099,
                         "solomons"                => 14618,
                         "solon"                   => 15835,
                         "solos"                   => 8599,
                         "solothurn"               => 20211,
                         "soltan"                  => 28846,
                         "solti"                   => 28874,
                         "solubility"              => 13774,
                         "soluble"                 => 7933,
                         "solute"                  => 19053,
                         "solution"                => 1825,
                         "solutions"               => 2359,
                         "solvable"                => 21626,
                         "solvay"                  => 25335,
                         "solvency"                => 29837,
                         "solvent"                 => 7819,
                         "solvents"                => 11567,
                         "solver"                  => 22612,
                         "solvers"                 => 25786,
                         "solving"                 => 5169,
                         "solway"                  => 21060,
                         "solzhenitsyn"            => 25389,
                         "somali"                  => 6242,
                         "somalia"                 => 5173,
                         "somaliland"              => 13040,
                         "somalis"                 => 21536,
                         "somatic"                 => 14017,
                         "sombre"                  => 23165,
                         "some"                    => 55,
                         "somerset"                => 3087,
                         "somerton"                => 27304,
                         "somewhat"                => 1865,
                         "somme"                   => 8364,
                         "somoza"                  => 20960,
                         "sonam"                   => 29119,
                         "sonatas"                 => 11705,
                         "sondheim"                => 14737,
                         "song"                    => 160,
                         "songbirds"               => 23567,
                         "songbook"                => 14926,
                         "songs"                   => 383,
                         "songwriter"              => 2302,
                         "songwriters"             => 7337,
                         "songwriting"             => 5376,
                         "songz"                   => 26229,
                         "sonically"               => 27411,
                         "sonoran"                 => 18886,
                         "sons"                    => 1121,
                         "soong"                   => 23304,
                         "sophocles"               => 19560,
                         "sophomores"              => 17305,
                         "sopot"                   => 22713,
                         "sopra"                   => 26286,
                         "sopron"                  => 25651,
                         "sopwith"                 => 15297,
                         "sorbonne"                => 9838,
                         "sorbus"                  => 28483,
                         "sorceress"               => 16551,
                         "sorcery"                 => 12463,
                         "soren"                   => 13450,
                         "sorghum"                 => 14647,
                         "sorin"                   => 24399,
                         "sorkh"                   => 23229,
                         "sortable"                => 25149,
                         "sortie"                  => 14021,
                         "sortied"                 => 20756,
                         "sorties"                 => 9969,
                         "sotheby"                 => 14646,
                         "sothern"                 => 29980,
                         "sotho"                   => 27180,
                         "sought"                  => 1510,
                         "soulcalibur"             => 28968,
                         "soulful"                 => 12559,
                         "soult"                   => 20955,
                         "soundboard"              => 29816,
                         "soundcloud"              => 18766,
                         "sounders"                => 12918,
                         "soundgarden"             => 19980,
                         "soundness"               => 27122,
                         "soundscan"               => 16494,
                         "soundscape"              => 24966,
                         "soundscapes"             => 23156,
                         "soundtrack"              => 1760,
                         "soundtracks"             => 7356,
                         "soundwave"               => 20525,
                         "souness"                 => 27096,
                         "source"                  => 701,
                         "sourcebook"              => 27739,
                         "sourced"                 => 8122,
                         "sources"                 => 968,
                         "sourcing"                => 14740,
                         "south"                   => 81,
                         "southampton"             => 3988,
                         "southbank"               => 22467,
                         "southbound"              => 6900,
                         "southeast"               => 1296,
                         "southeasterly"           => 22791,
                         "southeastern"            => 2657,
                         "southeastward"           => 22874,
                         "southend"                => 8347,
                         "southerly"               => 11651,
                         "southern"                => 333,
                         "southerner"              => 29551,
                         "southerners"             => 14344,
                         "southernmost"            => 7372,
                         "southfield"              => 22875,
                         "southgate"               => 15289,
                         "southland"               => 9704,
                         "southport"               => 8923,
                         "southsea"                => 28996,
                         "southward"               => 7498,
                         "southwards"              => 9823,
                         "southwark"               => 10079,
                         "southwest"               => 1439,
                         "southwesterly"           => 25187,
                         "southwestern"            => 2857,
                         "southwestward"           => 24057,
                         "sovereign"               => 3873,
                         "sovereigns"              => 17294,
                         "sovereignty"             => 4381,
                         "soviet"                  => 650,
                         "soviets"                 => 5139,
                         "sowerby"                 => 25112,
                         "soweto"                  => 18700,
                         "soybean"                 => 15346,
                         "soybeans"                => 16081,
                         "soyuz"                   => 8844,
                         "space"                   => 449,
                         "spacecraft"              => 4117,
                         "spaced"                  => 7866,
                         "spaceflight"             => 11856,
                         "spaceport"               => 23795,
                         "spaces"                  => 2617,
                         "spaceships"              => 23603,
                         "spacetime"               => 11674,
                         "spacewalk"               => 21683,
                         "spacex"                  => 16449,
                         "spacing"                 => 9734,
                         "spacious"                => 9460,
                         "spadina"                 => 21923,
                         "spain"                   => 812,
                         "span"                    => 3109,
                         "spaniards"               => 7016,
                         "spanish"                 => 536,
                         "spanned"                 => 6649,
                         "spanning"                => 4927,
                         "spans"                   => 5181,
                         "sparc"                   => 23145,
                         "spares"                  => 15822,
                         "sparingly"               => 15152,
                         "sparked"                 => 5839,
                         "sparking"                => 12798,
                         "sparrows"                => 11743,
                         "spars"                   => 17768,
                         "sparse"                  => 7969,
                         "sparsely"                => 8666,
                         "spartanburg"             => 16511,
                         "spassky"                 => 26076,
                         "spatial"                 => 4931,
                         "spatially"               => 17680,
                         "spawned"                 => 6070,
                         "spawning"                => 8890,
                         "speakers"                => 2643,
                         "spearhead"               => 14486,
                         "spearheaded"             => 8730,
                         "spearheading"            => 24133,
                         "special"                 => 353,
                         "specialisation"          => 20851,
                         "specialised"             => 6000,
                         "specialises"             => 10225,
                         "specialising"            => 7940,
                         "specialist"              => 2929,
                         "specialists"             => 5619,
                         "specialities"            => 19967,
                         "specialization"          => 9079,
                         "specializations"         => 18595,
                         "specialized"             => 2537,
                         "specializes"             => 5700,
                         "specializing"            => 4882,
                         "specially"               => 4153,
                         "specialties"             => 9463,
                         "speciation"              => 17597,
                         "specie"                  => 23428,
                         "species"                 => 204,
                         "specific"                => 804,
                         "specifically"            => 1426,
                         "specification"           => 4363,
                         "specifications"          => 4764,
                         "specificity"             => 10290,
                         "specified"               => 3431,
                         "specifies"               => 8806,
                         "specify"                 => 7117,
                         "specifying"              => 11083,
                         "specimen"                => 4476,
                         "specimens"               => 3432,
                         "speciosa"                => 29382,
                         "speckled"                => 14695,
                         "specks"                  => 27749,
                         "spectators"              => 4501,
                         "spectral"                => 6398,
                         "spectrograph"            => 29536,
                         "spectrometer"            => 14751,
                         "spectrometry"            => 14029,
                         "spectroscopic"           => 16529,
                         "spectroscopy"            => 8507,
                         "speculated"              => 5498,
                         "speculates"              => 15060,
                         "speculation"             => 4388,
                         "speculations"            => 13902,
                         "speculative"             => 8464,
                         "speculator"              => 22606,
                         "speculators"             => 18096,
                         "speechwriter"            => 25842,
                         "speed"                   => 755,
                         "speeds"                  => 3912,
                         "speedway"                => 3606,
                         "speke"                   => 24583,
                         "spellbound"              => 29086,
                         "spelled"                 => 3992,
                         "spelling"                => 3732,
                         "spellings"               => 9735,
                         "spelt"                   => 9866,
                         "spent"                   => 652,
                         "speyer"                  => 13333,
                         "spezia"                  => 17934,
                         "sphagnum"                => 28121,
                         "sphere"                  => 4019,
                         "spheres"                 => 7516,
                         "spherical"               => 6508,
                         "sphingidae"              => 16565,
                         "spikelets"               => 27332,
                         "spillway"                => 13744,
                         "spindle"                 => 10027,
                         "spindles"                => 20868,
                         "spines"                  => 7397,
                         "spinnaker"               => 28553,
                         "spinners"                => 14626,
                         "spinoff"                 => 12891,
                         "spinola"                 => 22443,
                         "spinose"                 => 17574,
                         "spiny"                   => 11527,
                         "spirally"                => 26201,
                         "spire"                   => 7451,
                         "spiritual"               => 2067,
                         "spiritualism"            => 18532,
                         "spiritualist"            => 20553,
                         "spirituality"            => 7381,
                         "spirituals"              => 22889,
                         "spitfires"               => 13266,
                         "spithead"                => 28617,
                         "spitsbergen"             => 17338,
                         "splendour"               => 17360,
                         "spline"                  => 27673,
                         "split"                   => 1145,
                         "splits"                  => 6912,
                         "spoiler"                 => 14087,
                         "spoilers"                => 22331,
                         "spoilt"                  => 29004,
                         "spokane"                 => 7506,
                         "spokesman"               => 4982,
                         "spokesperson"            => 5914,
                         "spokeswoman"             => 15081,
                         "spoleto"                 => 16779,
                         "sponheim"                => 24100,
                         "sponsor"                 => 3750,
                         "sponsored"               => 2001,
                         "sponsors"                => 4274,
                         "sponsorship"             => 3958,
                         "sponsorships"            => 15459,
                         "spoof"                   => 10692,
                         "spoofed"                 => 23775,
                         "spoofing"                => 23662,
                         "spoofs"                  => 27474,
                         "spoonbills"              => 22845,
                         "sporadic"                => 8460,
                         "sporadically"            => 9867,
                         "sporangia"               => 29637,
                         "spore"                   => 10914,
                         "spores"                  => 8190,
                         "sport"                   => 1134,
                         "sported"                 => 14987,
                         "sportif"                 => 25155,
                         "sporting"                => 2506,
                         "sportiva"                => 26606,
                         "sportive"                => 16316,
                         "sportivo"                => 24959,
                         "sports"                  => 482,
                         "sportscar"               => 15561,
                         "sportscaster"            => 14246,
                         "sportscenter"            => 21621,
                         "sportsman"               => 8933,
                         "sportsmen"               => 15181,
                         "sportsnet"               => 14584,
                         "sportsperson"            => 18107,
                         "sportswriter"            => 16010,
                         "sportswriters"           => 21213,
                         "spotify"                 => 20069,
                         "spots"                   => 3028,
                         "spotsylvania"            => 21134,
                         "sprang"                  => 11205,
                         "sprawling"               => 12235,
                         "spread"                  => 1073,
                         "spreads"                 => 8952,
                         "spring/summer"           => 24299,
                         "springboard"             => 11847,
                         "springbok"               => 18975,
                         "springboks"              => 17092,
                         "springdale"              => 20571,
                         "springhill"              => 27604,
                         "springs"                 => 2004,
                         "springsteen"             => 8693,
                         "springvale"              => 27970,
                         "springville"             => 26422,
                         "sprinters"               => 18820,
                         "sprinting"               => 20581,
                         "sprints"                 => 14690,
                         "sprites"                 => 15994,
                         "spruce"                  => 7297,
                         "spur"                    => 4821,
                         "spurious"                => 15067,
                         "spurned"                 => 25326,
                         "spurred"                 => 8441,
                         "spurring"                => 26254,
                         "sputnikmusic"            => 25994,
                         "spvgg"                   => 20155,
                         "spyware"                 => 22512,
                         "squad"                   => 1368,
                         "squadron"                => 980,
                         "squadrons"               => 3848,
                         "squads"                  => 6376,
                         "squamish"                => 23654,
                         "squamous"                => 20887,
                         "square"                  => 525,
                         "squarepants"             => 20161,
                         "squares"                 => 5531,
                         "srebrenica"              => 18543,
                         "sreekumar"               => 29691,
                         "sreenivasan"             => 28825,
                         "sridevi"                 => 25346,
                         "srinagar"                => 14539,
                         "srinivasa"               => 18278,
                         "srivijaya"               => 24903,
                         "sroda"                   => 23786,
                         "srpska"                  => 10975,
                         "ssris"                   => 28967,
                         "st."                     => 325,
                         "staatsoper"              => 26588,
                         "stabaek"                 => 24926,
                         "stabilisation"           => 22519,
                         "stabilise"               => 21892,
                         "stabilised"              => 19718,
                         "stability"               => 3299,
                         "stabilization"           => 9392,
                         "stabilizer"              => 14771,
                         "stabilizers"             => 22440,
                         "stabilizes"              => 26787,
                         "stable"                  => 2331,
                         "stablemate"              => 27748,
                         "stabling"                => 27564,
                         "staccato"                => 22329,
                         "stade"                   => 6852,
                         "stadia"                  => 18280,
                         "stadio"                  => 15017,
                         "stadion"                 => 9257,
                         "stadium"                 => 707,
                         "stadiums"                => 7976,
                         "stadt"                   => 14594,
                         "stadtbahn"               => 18721,
                         "stadtholder"             => 21741,
                         "staff"                   => 608,
                         "staffed"                 => 7413,
                         "staffel"                 => 23930,
                         "staffing"                => 11670,
                         "staffordshire"           => 5869,
                         "staffs"                  => 12201,
                         "stage"                   => 442,
                         "stagecoach"              => 8498,
                         "staged"                  => 3436,
                         "stages"                  => 1791,
                         "staggered"               => 11035,
                         "staging"                 => 5560,
                         "stagnant"                => 15426,
                         "stagnated"               => 25242,
                         "stagnation"              => 14446,
                         "stags"                   => 17078,
                         "stained"                 => 5045,
                         "staines"                 => 16883,
                         "staining"                => 13859,
                         "stainless"               => 7717,
                         "staircase"               => 6111,
                         "staircases"              => 14125,
                         "stairways"               => 20918,
                         "stakeholder"             => 15872,
                         "stakeholders"            => 8084,
                         "stakes"                  => 2904,
                         "stalactites"             => 29883,
                         "stalag"                  => 19665,
                         "stalemate"               => 12100,
                         "stalinism"               => 21779,
                         "stalinist"               => 13291,
                         "stallions"               => 12172,
                         "stalls"                  => 8266,
                         "stalwarts"               => 21202,
                         "stalybridge"             => 21473,
                         "stamens"                 => 11635,
                         "stampeders"              => 12635,
                         "stamping"                => 16213,
                         "stance"                  => 4689,
                         "stances"                 => 15364,
                         "standalone"              => 9337,
                         "standard"                => 563,
                         "standardisation"         => 20116,
                         "standardised"            => 13185,
                         "standardization"         => 9090,
                         "standardize"             => 18114,
                         "standardized"            => 5587,
                         "standardizing"           => 28840,
                         "standards"               => 1307,
                         "standings"               => 4211,
                         "standout"                => 9328,
                         "stands"                  => 1670,
                         "standstill"              => 16609,
                         "stane"                   => 29466,
                         "stanislas"               => 18307,
                         "stanislaus"              => 13130,
                         "stanislaw"               => 8220,
                         "stankovic"               => 26493,
                         "stanmore"                => 25935,
                         "stansted"                => 20697,
                         "stanwyck"                => 25715,
                         "stanza"                  => 9778,
                         "stanzas"                 => 12459,
                         "staphylococcus"          => 19715,
                         "staple"                  => 6465,
                         "stara"                   => 11917,
                         "starch"                  => 10492,
                         "stardom"                 => 11030,
                         "starfighter"             => 27871,
                         "stargard"                => 22646,
                         "stari"                   => 22520,
                         "starlings"               => 22712,
                         "starogard"               => 28376,
                         "starred"                 => 1667,
                         "starrer"                 => 25303,
                         "starring"                => 1321,
                         "stars"                   => 779,
                         "starscream"              => 16308,
                         "starstruck"              => 26198,
                         "started"                 => 271,
                         "startup"                 => 8216,
                         "startups"                => 14000,
                         "starvation"              => 8572,
                         "stary"                   => 14897,
                         "stasi"                   => 17868,
                         "state"                   => 60,
                         "state-of-the-art"        => 7639,
                         "stated"                  => 579,
                         "statehood"               => 8620,
                         "statehouse"              => 27829,
                         "stateless"               => 17607,
                         "stately"                 => 12767,
                         "statements"              => 3022,
                         "states"                  => 83,
                         "statesman"               => 6330,
                         "statesmen"               => 14940,
                         "statewide"               => 4827,
                         "stating"                 => 1725,
                         "station"                 => 130,
                         "stationary"              => 6401,
                         "stationed"               => 3216,
                         "stationers"              => 24025,
                         "stationing"              => 29275,
                         "stations"                => 769,
                         "statistic"               => 11210,
                         "statistical"             => 2429,
                         "statistically"           => 9532,
                         "statistician"            => 14859,
                         "statisticians"           => 23911,
                         "statistics"              => 1807,
                         "statny"                  => 22992,
                         "stato"                   => 22515,
                         "statoil"                 => 25730,
                         "stator"                  => 23392,
                         "statue"                  => 2328,
                         "statues"                 => 4566,
                         "statuette"               => 20622,
                         "statuettes"              => 26717,
                         "stature"                 => 8003,
                         "status"                  => 721,
                         "statuses"                => 27589,
                         "statute"                 => 3980,
                         "statutes"                => 6226,
                         "statutory"               => 5165,
                         "stauffenberg"            => 27777,
                         "staunch"                 => 8832,
                         "staunchly"               => 17935,
                         "staunton"                => 12337,
                         "stavanger"               => 11221,
                         "stave"                   => 13342,
                         "staveley"                => 28842,
                         "staves"                  => 22923,
                         "stavropol"               => 23191,
                         "stawell"                 => 29845,
                         "steadfastly"             => 25815,
                         "steadily"                => 4991,
                         "steam"                   => 1835,
                         "steamboat"               => 8021,
                         "steamboats"              => 15323,
                         "steamer"                 => 6550,
                         "steamers"                => 10863,
                         "steampunk"               => 19887,
                         "steamship"               => 7663,
                         "steamships"              => 16245,
                         "steel"                   => 1230,
                         "steelhead"               => 19219,
                         "steelworkers"            => 29067,
                         "steelworks"              => 19045,
                         "steep"                   => 3866,
                         "steeped"                 => 17641,
                         "steeper"                 => 17359,
                         "steepest"                => 21449,
                         "steeple"                 => 12405,
                         "steeplechase"            => 10542,
                         "steeply"                 => 10794,
                         "steerable"               => 28845,
                         "steering"                => 4459,
                         "steinitz"                => 23627,
                         "stela"                   => 15131,
                         "stelae"                  => 20527,
                         "stele"                   => 13451,
                         "stellenbosch"            => 18870,
                         "stem"                    => 2818,
                         "stemmed"                 => 10058,
                         "stemming"                => 9365,
                         "stems"                   => 4118,
                         "stena"                   => 19659,
                         "stencil"                 => 22151,
                         "stenosis"                => 18918,
                         "stent"                   => 23218,
                         "stepchildren"            => 27571,
                         "stephanus"               => 28623,
                         "steppenwolf"             => 22040,
                         "steppes"                 => 15669,
                         "stereochemistry"         => 28454,
                         "stereophonic"            => 29537,
                         "stereoscopic"            => 17984,
                         "stereotyped"             => 19931,
                         "stereotypes"             => 8035,
                         "stereotypical"           => 11007,
                         "steric"                  => 23696,
                         "sterility"               => 28629,
                         "sterilization"           => 13465,
                         "sternites"               => 12384,
                         "stettin"                 => 14316,
                         "steuben"                 => 17727,
                         "steubenville"            => 23504,
                         "stevan"                  => 25622,
                         "stevenage"               => 10744,
                         "stewards"                => 12990,
                         "stewardship"             => 9914,
                         "stews"                   => 27337,
                         "steyn"                   => 22564,
                         "steyr"                   => 19425,
                         "stichting"               => 27178,
                         "stiffened"               => 25831,
                         "stiffness"               => 12817,
                         "stifled"                 => 26636,
                         "stiftung"                => 20793,
                         "stiglitz"                => 28663,
                         "stigma"                  => 9750,
                         "stigmatized"             => 29324,
                         "stigmella"               => 20461,
                         "stikine"                 => 28263,
                         "stillborn"               => 18609,
                         "stilt"                   => 23313,
                         "stimulants"              => 24138,
                         "stimulate"               => 7941,
                         "stimulated"              => 8416,
                         "stimulates"              => 14557,
                         "stimulation"             => 7408,
                         "stimuli"                 => 7546,
                         "stimulus"                => 6326,
                         "stinging"                => 14513,
                         "stingrays"               => 18787,
                         "stint"                   => 4033,
                         "stints"                  => 9485,
                         "stipend"                 => 14102,
                         "stipends"                => 29529,
                         "stipulated"              => 8562,
                         "stipulates"              => 16192,
                         "stipulating"             => 26950,
                         "stipulations"            => 21530,
                         "stirling"                => 5669,
                         "stirlingshire"           => 20177,
                         "stirner"                 => 22667,
                         "stjepan"                 => 20848,
                         "stobart"                 => 24199,
                         "stochastic"              => 10269,
                         "stock"                   => 1276,
                         "stockade"                => 14902,
                         "stockhausen"             => 14975,
                         "stockholm"               => 3237,
                         "stockpiles"              => 25706,
                         "stockport"               => 8193,
                         "stockyards"              => 25002,
                         "stoichiometric"          => 26676,
                         "stojanovic"              => 27672,
                         "stoke"                   => 4283,
                         "stokowski"               => 24821,
                         "stolberg"                => 22368,
                         "stonehenge"              => 15772,
                         "stonemason"              => 20046,
                         "stonemasons"             => 29738,
                         "stoneware"               => 26956,
                         "stonework"               => 15020,
                         "stoning"                 => 23043,
                         "stonington"              => 25922,
                         "stony"                   => 7216,
                         "stopford"                => 28710,
                         "stopover"                => 18008,
                         "stoppage"                => 11648,
                         "stoppard"                => 24316,
                         "stora"                   => 21676,
                         "storage"                 => 1855,
                         "stored"                  => 3052,
                         "storefronts"             => 21210,
                         "storehouse"              => 18338,
                         "storehouses"             => 29493,
                         "storekeeper"             => 26534,
                         "stores"                  => 1570,
                         "storeyed"                => 17616,
                         "storeys"                 => 9936,
                         "storia"                  => 25402,
                         "storied"                 => 12758,
                         "stories"                 => 876,
                         "storing"                 => 8568,
                         "storks"                  => 16423,
                         "stormont"                => 20657,
                         "stormwater"              => 17747,
                         "stornoway"               => 26184,
                         "stortford"               => 24335,
                         "storting"                => 29218,
                         "story"                   => 315,
                         "storyboard"              => 18164,
                         "storyboards"             => 26649,
                         "storyline"               => 3321,
                         "storylines"              => 6332,
                         "storyteller"             => 13395,
                         "storytellers"            => 21008,
                         "storytelling"            => 7795,
                         "stosur"                  => 20790,
                         "stouffville"             => 27693,
                         "stour"                   => 19009,
                         "stourbridge"             => 18027,
                         "stourton"                => 29914,
                         "stoves"                  => 15393,
                         "strabane"                => 26292,
                         "strabo"                  => 12482,
                         "strachey"                => 22065,
                         "strada"                  => 22650,
                         "straddled"               => 27080,
                         "straddles"               => 14596,
                         "stradivarius"            => 26657,
                         "strafed"                 => 25329,
                         "strafford"               => 20538,
                         "strafing"                => 18713,
                         "stragglers"              => 28134,
                         "strains"                 => 6968,
                         "straits"                 => 6625,
                         "stralsund"               => 19370,
                         "stranding"               => 27460,
                         "strands"                 => 8893,
                         "stranglers"              => 28725,
                         "stranraer"               => 19835,
                         "strasberg"               => 23250,
                         "strasbourg"              => 6616,
                         "strasse"                 => 11689,
                         "strata"                  => 8093,
                         "strategic"               => 1944,
                         "strategically"           => 8610,
                         "strategies"              => 3576,
                         "strategist"              => 11818,
                         "strategists"             => 25315,
                         "strategos"               => 28490,
                         "strategy"                => 1862,
                         "stratford"               => 6424,
                         "strathclyde"             => 13615,
                         "strathcona"              => 17545,
                         "strathearn"              => 27527,
                         "strathmore"              => 20206,
                         "stratification"          => 15229,
                         "stratified"              => 16124,
                         "stratigraphic"           => 15325,
                         "stratigraphy"            => 18070,
                         "stratosphere"            => 19580,
                         "stratovolcano"           => 22078,
                         "stratum"                 => 16546,
                         "stravinsky"              => 10893,
                         "strayed"                 => 21568,
                         "streak"                  => 3575,
                         "streaked"                => 18142,
                         "streaks"                 => 11109,
                         "stream"                  => 2124,
                         "streamed"                => 10876,
                         "streamer"                => 25024,
                         "streamline"              => 13678,
                         "streamlined"             => 9317,
                         "streamlining"            => 19837,
                         "streams"                 => 3439,
                         "streatham"               => 19860,
                         "street"                  => 256,
                         "streetcar"               => 7211,
                         "streetcars"              => 12765,
                         "streets"                 => 1594,
                         "streetscape"             => 25029,
                         "strelitz"                => 27599,
                         "strengthen"              => 4790,
                         "strengthened"            => 5004,
                         "strengthening"           => 5966,
                         "strengths"               => 7531,
                         "strenuous"               => 14628,
                         "streptococcus"           => 20926,
                         "streptomyces"            => 28786,
                         "stresses"                => 7884,
                         "stressors"               => 25777,
                         "stretched"               => 5934,
                         "stretches"               => 5548,
                         "stretching"              => 5946,
                         "stretford"               => 26249,
                         "stretton"                => 20843,
                         "striae"                  => 25812,
                         "striated"                => 23756,
                         "strict"                  => 3464,
                         "stricter"                => 12543,
                         "strictures"              => 29182,
                         "strident"                => 22939,
                         "strikeforce"             => 16393,
                         "strikeout"               => 16282,
                         "strikeouts"              => 5318,
                         "strikers"                => 8439,
                         "striking"                => 3463,
                         "strikingly"              => 14494,
                         "strindberg"              => 21634,
                         "string"                  => 2101,
                         "stringed"                => 14573,
                         "stringent"               => 10448,
                         "strip"                   => 2233,
                         "stripes"                 => 5304,
                         "stripped"                => 4865,
                         "strips"                  => 4997,
                         "strived"                 => 27207,
                         "strives"                 => 11033,
                         "striving"                => 11807,
                         "stroma"                  => 27958,
                         "stronghold"              => 6276,
                         "strongholds"             => 11862,
                         "strongly"                => 2021,
                         "strongman"               => 14517,
                         "strontium"               => 19116,
                         "stroudsburg"             => 24534,
                         "strove"                  => 15293,
                         "struck"                  => 2059,
                         "structural"              => 2816,
                         "structuralism"           => 22108,
                         "structuralist"           => 27370,
                         "structurally"            => 9471,
                         "structure"               => 587,
                         "structured"              => 5031,
                         "structures"              => 1459,
                         "structuring"             => 16464,
                         "struggle"                => 2245,
                         "struggled"               => 3700,
                         "struggles"               => 4567,
                         "struts"                  => 10996,
                         "strutt"                  => 26467,
                         "strzelce"                => 23956,
                         "stubbornly"              => 24552,
                         "stucco"                  => 10134,
                         "stuccoed"                => 21476,
                         "studded"                 => 13579,
                         "student"                 => 538,
                         "students"                => 241,
                         "studi"                   => 26670,
                         "studied"                 => 733,
                         "studies"                 => 480,
                         "studio"                  => 526,
                         "studios"                 => 1427,
                         "study"                   => 454,
                         "stuka"                   => 24743,
                         "stumpings"               => 28308,
                         "stumps"                  => 11632,
                         "stunting"                => 23288,
                         "stupa"                   => 13633,
                         "stupas"                  => 24326,
                         "sture"                   => 28640,
                         "sturluson"               => 28509,
                         "sturt"                   => 14500,
                         "stuttgart"               => 5315,
                         "stuyvesant"              => 15033,
                         "style"                   => 400,
                         "styled"                  => 5040,
                         "styles"                  => 2087,
                         "styling"                 => 7141,
                         "stylised"                => 15135,
                         "stylistic"               => 8096,
                         "stylistically"           => 12910,
                         "stylized"                => 7429,
                         "styrene"                 => 26455,
                         "styria"                  => 9961,
                         "subalpine"               => 19746,
                         "subang"                  => 28341,
                         "subantarctic"            => 29392,
                         "subarctic"               => 21457,
                         "subcarpathian"           => 15187,
                         "subchannel"              => 11190,
                         "subchannels"             => 23582,
                         "subclass"                => 14045,
                         "subclasses"              => 26810,
                         "subcommittee"            => 7529,
                         "subcommittees"           => 20976,
                         "subcontinent"            => 8714,
                         "subcontractor"           => 28997,
                         "subcontractors"          => 26486,
                         "subcostal"               => 29155,
                         "subculture"              => 11885,
                         "subcultures"             => 22339,
                         "subcutaneous"            => 18470,
                         "subdistrict"             => 8661,
                         "subdistricts"            => 12952,
                         "subdivided"              => 4932,
                         "subdivision"             => 4528,
                         "subdivisions"            => 6421,
                         "subduction"              => 14503,
                         "subdue"                  => 12731,
                         "subdued"                 => 9539,
                         "subduing"                => 24105,
                         "subfamilies"             => 13514,
                         "subfamily"               => 4175,
                         "subfield"                => 27987,
                         "subgenera"               => 22903,
                         "subgenre"                => 12633,
                         "subgenres"               => 19619,
                         "subgenus"                => 9981,
                         "subgraph"                => 24745,
                         "subgroup"                => 7421,
                         "subgroups"               => 10386,
                         "subhas"                  => 23940,
                         "subhash"                 => 18459,
                         "subiaco"                 => 18022,
                         "subic"                   => 10617,
                         "subject"                 => 799,
                         "subjected"               => 5035,
                         "subjection"              => 27339,
                         "subjective"              => 7135,
                         "subjectively"            => 28599,
                         "subjectivity"            => 18837,
                         "subjects"                => 1779,
                         "subjugate"               => 28233,
                         "subjugated"              => 17602,
                         "subjunctive"             => 18958,
                         "sublimation"             => 26276,
                         "submachine"              => 14234,
                         "submarginal"             => 13808,
                         "submarine"               => 2207,
                         "submarines"              => 4301,
                         "submerged"               => 5111,
                         "submission"              => 4860,
                         "submissions"             => 8405,
                         "submits"                 => 19897,
                         "submitted"               => 2628,
                         "submitting"              => 10056,
                         "suborbital"              => 28748,
                         "suborder"                => 14798,
                         "subordinate"             => 5394,
                         "subordinated"            => 11288,
                         "subordinates"            => 9970,
                         "subordination"           => 17519,
                         "subotica"                => 20197,
                         "subplot"                 => 14805,
                         "subplots"                => 24597,
                         "subprefecture"           => 24656,
                         "subprime"                => 18195,
                         "subramaniam"             => 24824,
                         "subregion"               => 17224,
                         "subroutine"              => 23479,
                         "subscribed"              => 12168,
                         "subscriber"              => 10700,
                         "subscribers"             => 5818,
                         "subscribes"              => 27164,
                         "subscribing"             => 25411,
                         "subscript"               => 27245,
                         "subscription"            => 5473,
                         "subscriptions"           => 10138,
                         "subsea"                  => 24775,
                         "subsection"              => 15884,
                         "subsections"             => 24605,
                         "subsequent"              => 1245,
                         "subsequently"            => 723,
                         "subset"                  => 5988,
                         "subsets"                 => 10604,
                         "subsidence"              => 14836,
                         "subsidiaries"            => 6343,
                         "subsidiary"              => 2451,
                         "subsidies"               => 7366,
                         "subsidised"              => 18798,
                         "subsidized"              => 10541,
                         "subsidy"                 => 9583,
                         "subsistence"             => 8863,
                         "subsoil"                 => 27957,
                         "subsonic"                => 19428,
                         "subsp"                   => 14220,
                         "subspace"                => 13556,
                         "subspaces"               => 25804,
                         "subspecies"              => 3874,
                         "substance"               => 3664,
                         "substances"              => 5057,
                         "substandard"             => 18966,
                         "substantial"             => 2209,
                         "substantially"           => 4267,
                         "substantive"             => 8882,
                         "substation"              => 13189,
                         "substations"             => 22285,
                         "substituent"             => 25087,
                         "substituents"            => 21188,
                         "substitute"              => 2715,
                         "substituted"             => 6059,
                         "substitutes"             => 10405,
                         "substituting"            => 10800,
                         "substitution"            => 7081,
                         "substitutions"           => 16624,
                         "substrate"               => 5708,
                         "substrates"              => 7608,
                         "substratum"              => 25638,
                         "substructure"            => 27194,
                         "subsumed"                => 14233,
                         "subsurface"              => 14450,
                         "subsystem"               => 14015,
                         "subsystems"              => 15598,
                         "subterminal"             => 16754,
                         "subterranean"            => 10697,
                         "subtitle"                => 12249,
                         "subtitled"               => 10656,
                         "subtract"                => 23440,
                         "subtracted"              => 17853,
                         "subtracting"             => 20285,
                         "subtraction"             => 17949,
                         "subtribe"                => 23705,
                         "subtropical"             => 3612,
                         "subtype"                 => 13551,
                         "subtypes"                => 14893,
                         "subunit"                 => 8352,
                         "subunits"                => 9965,
                         "suburb"                  => 2352,
                         "suburban"                => 3233,
                         "suburbs"                 => 3137,
                         "subversion"              => 15446,
                         "subversive"              => 11625,
                         "succeeded"               => 1256,
                         "succeeding"              => 4710,
                         "succeeds"                => 8213,
                         "successes"               => 4655,
                         "successful"              => 530,
                         "successfully"            => 1487,
                         "succession"              => 2751,
                         "successive"              => 3776,
                         "successively"            => 7951,
                         "successor"               => 1964,
                         "successors"              => 6125,
                         "succinctly"              => 28375,
                         "succumbed"               => 9931,
                         "succumbing"              => 17289,
                         "succumbs"                => 22124,
                         "suceava"                 => 23666,
                         "such"                    => 61,
                         "suchet"                  => 27055,
                         "suckling"                => 24098,
                         "sucre"                   => 15538,
                         "sucrose"                 => 18310,
                         "sudamericana"            => 14331,
                         "sudan"                   => 3708,
                         "sudanese"                => 8335,
                         "sudbury"                 => 8440,
                         "sudetenland"             => 22947,
                         "sudha"                   => 28357,
                         "sudhir"                  => 26041,
                         "sudwest"                 => 25409,
                         "sued"                    => 4621,
                         "sueno"                   => 28427,
                         "suetonius"               => 20700,
                         "suffered"                => 1153,
                         "sufferer"                => 24884,
                         "sufferers"               => 16048,
                         "sufferings"              => 16708,
                         "suffices"                => 27745,
                         "sufficiency"             => 14058,
                         "sufficient"              => 2496,
                         "sufficiently"            => 4906,
                         "suffield"                => 25258,
                         "suffix"                  => 5922,
                         "suffixed"                => 23505,
                         "suffixes"                => 10707,
                         "suffolk"                 => 4298,
                         "suffragan"               => 10547,
                         "suffrage"                => 5714,
                         "suffragette"             => 23645,
                         "suffragist"              => 24147,
                         "suffused"                => 13857,
                         "suffusion"               => 21688,
                         "sufis"                   => 22626,
                         "sufism"                  => 14493,
                         "sugababes"               => 21482,
                         "sugarcane"               => 9652,
                         "sugarloaf"               => 20503,
                         "suggested"               => 1255,
                         "suggestive"              => 11114,
                         "suggests"                => 1912,
                         "suharto"                 => 13380,
                         "suisse"                  => 12879,
                         "suisun"                  => 27299,
                         "suitability"             => 13457,
                         "suitable"                => 2515,
                         "suitably"                => 14951,
                         "suited"                  => 4551,
                         "suites"                  => 7302,
                         "suiza"                   => 22517,
                         "sukarno"                 => 13979,
                         "sukhoi"                  => 20170,
                         "sukhothai"               => 23547,
                         "sukhumi"                 => 25413,
                         "sukumaran"               => 23382,
                         "sulaiman"                => 16653,
                         "sulawesi"                => 10319,
                         "sulayman"                => 22769,
                         "sulcus"                  => 21453,
                         "suleiman"                => 11932,
                         "suleyman"                => 17292,
                         "sulfate"                 => 8763,
                         "sulfide"                 => 10341,
                         "sulfides"                => 26585,
                         "sulfur"                  => 6562,
                         "sulfuric"                => 13993,
                         "sulla"                   => 14227,
                         "sulphur"                 => 9759,
                         "sulpice"                 => 24488,
                         "sultanate"               => 7517,
                         "sultanates"              => 26484,
                         "sultans"                 => 13829,
                         "sumatra"                 => 7015,
                         "sumatran"                => 19632,
                         "sumer"                   => 24744,
                         "sumerian"                => 12398,
                         "summaries"               => 10552,
                         "summarised"              => 13978,
                         "summarises"              => 26332,
                         "summarized"              => 7727,
                         "summarizes"              => 13553,
                         "summarizing"             => 18957,
                         "summary"                 => 2363,
                         "summed"                  => 10023,
                         "summerside"              => 28680,
                         "summerslam"              => 16937,
                         "summing"                 => 17085,
                         "summits"                 => 9105,
                         "sunaina"                 => 25879,
                         "sunbury"                 => 15631,
                         "suncorp"                 => 29533,
                         "sunda"                   => 14559,
                         "sundanese"               => 20179,
                         "sundar"                  => 21158,
                         "sundaram"                => 22380,
                         "sundays"                 => 5444,
                         "sundry"                  => 23015,
                         "sundsvall"               => 25314,
                         "sungai"                  => 15616,
                         "sunil"                   => 12209,
                         "sunk"                    => 4308,
                         "sunken"                  => 10522,
                         "sunnah"                  => 20778,
                         "sunnis"                  => 18188,
                         "sunnyside"               => 15673,
                         "sunnyvale"               => 22103,
                         "sunroof"                 => 28635,
                         "suntory"                 => 29273,
                         "suomen"                  => 25572,
                         "superannuation"          => 22702,
                         "superbike"               => 12496,
                         "superbly"                => 22617,
                         "supercars"               => 19937,
                         "supercell"               => 25555,
                         "supercharged"            => 14324,
                         "supercharger"            => 17993,
                         "supercomputer"           => 15094,
                         "supercomputers"          => 22551,
                         "supercomputing"          => 26574,
                         "superconducting"         => 17332,
                         "superconductivity"       => 22758,
                         "superconductor"          => 28789,
                         "superconductors"         => 24769,
                         "supercontinent"          => 25614,
                         "supercopa"               => 25224,
                         "supercritical"           => 25496,
                         "supercup"                => 14467,
                         "superdome"               => 21639,
                         "superdraft"              => 18921,
                         "superettan"              => 28338,
                         "superfamily"             => 9065,
                         "superfast"               => 18411,
                         "superficially"           => 13368,
                         "superfortress"           => 18781,
                         "superfund"               => 18192,
                         "supergiant"              => 26662,
                         "supergroup"              => 11859,
                         "superheated"             => 24440,
                         "superhuman"              => 9271,
                         "superieur"               => 22194,
                         "superieure"              => 11936,
                         "superimposed"            => 12274,
                         "superintendent"          => 3540,
                         "superintendents"         => 16694,
                         "superior"                => 2051,
                         "superiore"               => 26354,
                         "superiority"             => 7188,
                         "superlative"             => 22399,
                         "superleague"             => 12912,
                         "superliga"               => 8835,
                         "supermarine"             => 15667,
                         "supermarkets"            => 8278,
                         "supernovae"              => 20219,
                         "supernumerary"           => 29347,
                         "superoxide"              => 27576,
                         "superposition"           => 19696,
                         "supersede"               => 24616,
                         "superseded"              => 6725,
                         "superseding"             => 28797,
                         "supersonics"             => 17196,
                         "superspeedway"           => 23864,
                         "supersport"              => 16589,
                         "superstars"              => 10498,
                         "superstructure"          => 9578,
                         "supersymmetry"           => 27252,
                         "supervillain"            => 15208,
                         "supervised"              => 4983,
                         "supervises"              => 17671,
                         "supervising"             => 8171,
                         "supervision"             => 3820,
                         "supervisors"             => 7765,
                         "supervisory"             => 9662,
                         "suplex"                  => 27611,
                         "supplant"                => 25542,
                         "supplanted"              => 11477,
                         "supplement"              => 4666,
                         "supplemental"            => 8786,
                         "supplementary"           => 8654,
                         "supplementation"         => 18900,
                         "supplemented"            => 6797,
                         "supplementing"           => 19322,
                         "supplements"             => 8314,
                         "supplied"                => 2837,
                         "supplier"                => 6179,
                         "suppliers"               => 6896,
                         "supplies"                => 2199,
                         "supply"                  => 1265,
                         "supplying"               => 6271,
                         "support"                 => 261,
                         "supported"               => 771,
                         "supporter"               => 3443,
                         "supporters"              => 2095,
                         "supporting"              => 1362,
                         "supports"                => 2215,
                         "suppress"                => 6876,
                         "suppressed"              => 5919,
                         "suppresses"              => 24532,
                         "suppression"             => 5664,
                         "suppressor"              => 14961,
                         "supranational"           => 21832,
                         "supremacist"             => 20638,
                         "supremacy"               => 7585,
                         "supreme"                 => 1100,
                         "supremes"                => 15532,
                         "surabaya"                => 14265,
                         "surah"                   => 25333,
                         "suraj"                   => 18583,
                         "surakarta"               => 23990,
                         "surat"                   => 11206,
                         "surbiton"                => 26300,
                         "surcharge"               => 19799,
                         "surendra"                => 27052,
                         "surety"                  => 22756,
                         "surface"                 => 794,
                         "surfaced"                => 6335,
                         "surfaces"                => 3578,
                         "surfacing"               => 19224,
                         "surfactant"              => 22432,
                         "surfactants"             => 25489,
                         "surge"                   => 6237,
                         "surged"                  => 17141,
                         "surgeries"               => 10816,
                         "surigao"                 => 20431,
                         "surinam"                 => 19596,
                         "suriname"                => 8929,
                         "surinamese"              => 20925,
                         "surmised"                => 18783,
                         "surmounted"              => 10271,
                         "surmounting"             => 27001,
                         "surname"                 => 1452,
                         "surnamed"                => 25603,
                         "surnames"                => 7715,
                         "surpass"                 => 12399,
                         "surpassed"               => 5795,
                         "surpasses"               => 23507,
                         "surpassing"              => 9266,
                         "surplus"                 => 5582,
                         "surpluses"               => 22757,
                         "surrealism"              => 13206,
                         "surrealist"              => 11306,
                         "surrealistic"            => 24516,
                         "surrealists"             => 27654,
                         "surrender"               => 2972,
                         "surrendered"             => 3898,
                         "surrenders"              => 20313,
                         "surreptitiously"         => 22794,
                         "surrey"                  => 3450,
                         "surrogacy"               => 26706,
                         "surrounded"              => 2055,
                         "surrounding"             => 1169,
                         "surroundings"            => 5640,
                         "surrounds"               => 7607,
                         "surry"                   => 20000,
                         "surtees"                 => 22589,
                         "survey"                  => 1590,
                         "surveyed"                => 5748,
                         "surveying"               => 7921,
                         "surveyors"               => 12689,
                         "surveys"                 => 4364,
                         "survivability"           => 22358,
                         "survived"                => 1707,
                         "survives"                => 4952,
                         "surviving"               => 2134,
                         "survivors"               => 3195,
                         "surya"                   => 11537,
                         "susceptibility"          => 11479,
                         "susceptible"             => 6679,
                         "suspended"               => 2411,
                         "suspension"              => 2964,
                         "suspensions"             => 14221,
                         "susquehanna"             => 8319,
                         "sussex"                  => 3235,
                         "sustainability"          => 5432,
                         "sustainable"             => 3314,
                         "sustained"               => 3150,
                         "sustaining"              => 8044,
                         "sustainment"             => 20817,
                         "sustains"                => 20190,
                         "susumu"                  => 28185,
                         "sutil"                   => 27815,
                         "sutlej"                  => 28421,
                         "sutra"                   => 9301,
                         "sutras"                  => 14595,
                         "sutta"                   => 20463,
                         "suwalki"                 => 20958,
                         "suwon"                   => 19287,
                         "suzerainty"              => 13728,
                         "suzhou"                  => 13581,
                         "suzong"                  => 29304,
                         "suzuka"                  => 20482,
                         "svalbard"                => 12695,
                         "svein"                   => 28586,
                         "svend"                   => 25156,
                         "svenska"                 => 13216,
                         "svensson"                => 18563,
                         "sverdlovsk"              => 19514,
                         "sverdrup"                => 22587,
                         "sveriges"                => 19143,
                         "sverre"                  => 18834,
                         "sveti"                   => 20303,
                         "sviatoslav"              => 28633,
                         "swabia"                  => 15078,
                         "swabian"                 => 15180,
                         "swahili"                 => 12940,
                         "swale"                   => 24278,
                         "swallowtail"             => 22407,
                         "swami"                   => 6738,
                         "swamiji"                 => 24722,
                         "swaminarayan"            => 17801,
                         "swamps"                  => 7623,
                         "swamy"                   => 13364,
                         "swanage"                 => 29778,
                         "swansea"                 => 5630,
                         "swapo"                   => 17836,
                         "swapped"                 => 10610,
                         "swaps"                   => 15539,
                         "swaraj"                  => 26349,
                         "swarms"                  => 20265,
                         "swarthmore"              => 17534,
                         "swastika"                => 14883,
                         "swath"                   => 20649,
                         "swazi"                   => 24765,
                         "swaziland"               => 10385,
                         "sweden"                  => 1286,
                         "swedenborg"              => 26645,
                         "swedes"                  => 9467,
                         "swedish"                 => 1190,
                         "sweetened"               => 18670,
                         "sweetener"               => 28151,
                         "sweetwater"              => 17576,
                         "sweyn"                   => 25177,
                         "swiecie"                 => 29356,
                         "swietokrzyskie"          => 10772,
                         "swiftly"                 => 9182,
                         "swifts"                  => 12770,
                         "swimmers"                => 6944,
                         "swimwear"                => 22630,
                         "swinburne"               => 18385,
                         "swindon"                 => 7298,
                         "swiss"                   => 1566,
                         "switches"                => 6122,
                         "switchover"              => 27203,
                         "switzerland"             => 1607,
                         "swordsman"               => 16701,
                         "swordsmanship"           => 28647,
                         "sybra"                   => 19587,
                         "sydenham"                => 13913,
                         "sylar"                   => 17252,
                         "sylhet"                  => 15844,
                         "syllabary"               => 28046,
                         "syllabic"                => 17494,
                         "syllable"                => 6525,
                         "syllables"               => 7838,
                         "symbian"                 => 21405,
                         "symbiosis"               => 18127,
                         "symbiotic"               => 14340,
                         "symbol"                  => 2237,
                         "symbolic"                => 4527,
                         "symbolically"            => 12520,
                         "symbolise"               => 21402,
                         "symbolised"              => 26028,
                         "symbolises"              => 22197,
                         "symbolising"             => 22290,
                         "symbolism"               => 7187,
                         "symbolist"               => 17486,
                         "symbolize"               => 10512,
                         "symbolized"              => 12929,
                         "symbolizes"              => 10381,
                         "symbolizing"             => 12326,
                         "symbols"                 => 3387,
                         "symeon"                  => 28301,
                         "symington"               => 25481,
                         "symmetric"               => 6576,
                         "symmetrical"             => 8419,
                         "symmetrically"           => 19473,
                         "symmetries"              => 17043,
                         "symmetry"                => 5269,
                         "symon"                   => 29567,
                         "sympathetically"         => 29591,
                         "sympathisers"            => 27298,
                         "sympathized"             => 25028,
                         "sympathizer"             => 23309,
                         "sympathizers"            => 13995,
                         "sympatric"               => 28527,
                         "symphonic"               => 6805,
                         "symphonies"              => 9391,
                         "symphony"                => 2157,
                         "symplectic"              => 18708,
                         "symposia"                => 15339,
                         "symposium"               => 7387,
                         "synagogue"               => 4405,
                         "synagogues"              => 10470,
                         "synaptic"                => 11437,
                         "synchronised"            => 17596,
                         "synchronization"         => 10747,
                         "synchronized"            => 8180,
                         "synchronous"             => 11452,
                         "synchrotron"             => 18419,
                         "syncopated"              => 22489,
                         "syncretic"               => 24470,
                         "syncretism"              => 26151,
                         "syndicalism"             => 24229,
                         "syndicalist"             => 18807,
                         "syndicate"               => 6163,
                         "syndicated"              => 4632,
                         "syndicates"              => 20668,
                         "syndication"             => 8000,
                         "syndrome"                => 2980,
                         "syndromes"               => 16022,
                         "synergistic"             => 26555,
                         "synesthesia"             => 26897,
                         "synge"                   => 29638,
                         "synod"                   => 5258,
                         "synods"                  => 17912,
                         "synonym"                 => 7485,
                         "synonymous"              => 7465,
                         "synonyms"                => 9154,
                         "synonymy"                => 24021,
                         "synopsis"                => 3903,
                         "synoptic"                => 20620,
                         "syntactic"               => 11927,
                         "syntax"                  => 6612,
                         "synth"                   => 10629,
                         "synthase"                => 10033,
                         "syntheses"               => 27927,
                         "synthesis"               => 3592,
                         "synthesised"             => 23810,
                         "synthesiser"             => 28237,
                         "synthesize"              => 14179,
                         "synthesized"             => 7879,
                         "synthesizer"             => 8001,
                         "synthesizers"            => 9473,
                         "synthesizing"            => 22664,
                         "synthetase"              => 20844,
                         "synthetic"               => 4612,
                         "synthpop"                => 13914,
                         "synths"                  => 15326,
                         "syria"                   => 2758,
                         "syriac"                  => 9000,
                         "syrian"                  => 3264,
                         "syrians"                 => 15556,
                         "syrmia"                  => 24109,
                         "system"                  => 152,
                         "systema"                 => 27616,
                         "systematic"              => 4216,
                         "systematically"          => 8050,
                         "systematics"             => 12949,
                         "systemic"                => 7934,
                         "systems"                 => 491,
                         "szczecin"                => 9502,
                         "szczecinek"              => 27355,
                         "szeged"                  => 19597,
                         "szlachta"                => 19649,
                         "tabari"                  => 24008,
                         "tabernacle"              => 10393,
                         "tabla"                   => 16153,
                         "tableau"                 => 15817,
                         "tableaux"                => 21893,
                         "tabled"                  => 17099,
                         "tableland"               => 29543,
                         "tablelands"              => 21967,
                         "tablet"                  => 5888,
                         "tablets"                 => 6485,
                         "tableware"               => 24004,
                         "taboo"                   => 9856,
                         "taboos"                  => 19159,
                         "tabriz"                  => 13081,
                         "tabular"                 => 24429,
                         "tabulated"               => 19440,
                         "tabulation"              => 28000,
                         "tachi"                   => 29435,
                         "tachinidae"              => 23767,
                         "tacitly"                 => 29360,
                         "tacitus"                 => 13471,
                         "tackle"                  => 4199,
                         "tackles"                 => 4002,
                         "tackling"                => 11603,
                         "taconic"                 => 25074,
                         "tactical"                => 3296,
                         "tactically"              => 22180,
                         "tactician"               => 25925,
                         "tactics"                 => 3594,
                         "tactile"                 => 14194,
                         "tadashi"                 => 28241,
                         "tadeusz"                 => 13114,
                         "tadic"                   => 29728,
                         "tafsir"                  => 25545,
                         "tagalog"                 => 11299,
                         "tagline"                 => 11946,
                         "tagore"                  => 10759,
                         "taguig"                  => 27101,
                         "tagus"                   => 21691,
                         "taher"                   => 29953,
                         "tahir"                   => 14959,
                         "tahrir"                  => 19411,
                         "taichung"                => 17557,
                         "taifa"                   => 26981,
                         "taiga"                   => 17929,
                         "taiji"                   => 19645,
                         "taiko"                   => 17722,
                         "tailback"                => 23998,
                         "tailed"                  => 5433,
                         "tailings"                => 18630,
                         "taillights"              => 24497,
                         "tailored"                => 9234,
                         "tailoring"               => 17470,
                         "tailplane"               => 16730,
                         "tailwheel"               => 22698,
                         "tainan"                  => 17832,
                         "taino"                   => 18574,
                         "taipei"                  => 5589,
                         "taiping"                 => 14577,
                         "taisho"                  => 21157,
                         "taito"                   => 19105,
                         "taiwan"                  => 2205,
                         "taiwanese"               => 6066,
                         "taiyo"                   => 29203,
                         "taiyuan"                 => 17150,
                         "taizong"                 => 12822,
                         "taizu"                   => 25740,
                         "tajik"                   => 13713,
                         "tajikistan"              => 8166,
                         "tajiri"                  => 24710,
                         "takao"                   => 22093,
                         "takara"                  => 28706,
                         "takeaway"                => 24539,
                         "takeda"                  => 14555,
                         "taken"                   => 433,
                         "takeo"                   => 20788,
                         "takeover"                => 5436,
                         "takht"                   => 19450,
                         "takings"                 => 23991,
                         "takoma"                  => 27587,
                         "takumi"                  => 25906,
                         "takuya"                  => 28798,
                         "talal"                   => 24101,
                         "talat"                   => 27974,
                         "taleb"                   => 28277,
                         "tales"                   => 2925,
                         "talib"                   => 15600,
                         "taliban"                 => 5820,
                         "talladega"               => 13988,
                         "tallaght"                => 24702,
                         "tallahassee"             => 10459,
                         "tallest"                 => 4433,
                         "talleyrand"              => 26335,
                         "tallied"                 => 13526,
                         "tallies"                 => 27583,
                         "tallinn"                 => 7836,
                         "tallying"                => 20934,
                         "talmud"                  => 7759,
                         "talmudic"                => 13722,
                         "taluk"                   => 7185,
                         "taluka"                  => 9944,
                         "taluks"                  => 28850,
                         "tamaki"                  => 20699,
                         "taman"                   => 16161,
                         "tamarack"                => 29754,
                         "tamarind"                => 21734,
                         "tamaulipas"              => 12659,
                         "tambo"                   => 22785,
                         "tambon"                  => 8777,
                         "tambov"                  => 23616,
                         "tamil"                   => 1898,
                         "tamils"                  => 13484,
                         "taming"                  => 18315,
                         "tammany"                 => 15240,
                         "tampa"                   => 3428,
                         "tampere"                 => 13458,
                         "tampines"                => 25728,
                         "tamworth"                => 10931,
                         "tanah"                   => 24939,
                         "tanahashi"               => 27821,
                         "tanakh"                  => 22425,
                         "tanana"                  => 25571,
                         "tancred"                 => 22220,
                         "tandem"                  => 6815,
                         "tandon"                  => 26144,
                         "tanganyika"              => 13591,
                         "tangent"                 => 9242,
                         "tangential"              => 19784,
                         "tangier"                 => 14586,
                         "tanglewood"              => 18323,
                         "tangut"                  => 28136,
                         "tanjong"                 => 26983,
                         "tanjore"                 => 24443,
                         "tanjung"                 => 17873,
                         "tank"                    => 1729,
                         "tanka"                   => 25701,
                         "tankers"                 => 10291,
                         "tankobon"                => 15551,
                         "tanks"                   => 2485,
                         "tannery"                 => 17580,
                         "tannhauser"              => 26882,
                         "tannin"                  => 27998,
                         "tannins"                 => 20837,
                         "tantalum"                => 20871,
                         "tantric"                 => 14934,
                         "tanzania"                => 4454,
                         "tanzanian"               => 13329,
                         "taoiseach"               => 13653,
                         "taoism"                  => 15462,
                         "taoist"                  => 13386,
                         "taoyuan"                 => 22526,
                         "taper"                   => 14848,
                         "tapered"                 => 11245,
                         "tapering"                => 14366,
                         "tapers"                  => 23488,
                         "tapestries"              => 14952,
                         "tapestry"                => 11185,
                         "tapings"                 => 19494,
                         "tappeh"                  => 15022,
                         "taran"                   => 19025,
                         "taranaki"                => 12698,
                         "tarek"                   => 27005,
                         "targeted"                => 3422,
                         "targeting"               => 5443,
                         "targets"                 => 2825,
                         "targu"                   => 20675,
                         "tariff"                  => 7885,
                         "tariffs"                 => 8624,
                         "tarik"                   => 29410,
                         "tarim"                   => 19353,
                         "tariq"                   => 14019,
                         "tarkovsky"               => 28348,
                         "tarlac"                  => 21705,
                         "tarnovo"                 => 20840,
                         "tarnow"                  => 18785,
                         "tarquini"                => 26749,
                         "tarragona"               => 15096,
                         "tarrytown"               => 27107,
                         "tarsal"                  => 27687,
                         "tarsi"                   => 15953,
                         "tarski"                  => 26526,
                         "tarsus"                  => 13642,
                         "tartu"                   => 11241,
                         "tarun"                   => 28234,
                         "tashi"                   => 28650,
                         "task"                    => 1563,
                         "tasked"                  => 5142,
                         "taskforce"               => 20796,
                         "tasks"                   => 3183,
                         "tasman"                  => 10801,
                         "tasmania"                => 4311,
                         "tasmanian"               => 7059,
                         "tatar"                   => 9957,
                         "tatars"                  => 11270,
                         "tatarstan"               => 19289,
                         "tatler"                  => 29350,
                         "tatra"                   => 16286,
                         "tatsuya"                 => 26148,
                         "tattooing"               => 23231,
                         "taught"                  => 1146,
                         "taunton"                 => 8840,
                         "taunts"                  => 16130,
                         "taunus"                  => 19331,
                         "taupo"                   => 22283,
                         "tauranga"                => 19498,
                         "tavern"                  => 5612,
                         "taverns"                 => 16360,
                         "tavistock"               => 16447,
                         "taxable"                 => 13634,
                         "taxation"                => 5223,
                         "taxed"                   => 11930,
                         "taxes"                   => 2623,
                         "taxis"                   => 8859,
                         "taxiway"                 => 22233,
                         "taxiways"                => 23261,
                         "taxon"                   => 9115,
                         "taxonomic"               => 8243,
                         "taxonomists"             => 26047,
                         "taxonomy"                => 4412,
                         "taxpayer"                => 8673,
                         "taylors"                 => 17729,
                         "tayyip"                  => 25366,
                         "tazeh"                   => 28314,
                         "tbilisi"                 => 7894,
                         "tchaikovsky"             => 8951,
                         "tcp/ip"                  => 17437,
                         "teachers"                => 1528,
                         "teaches"                 => 4141,
                         "teaching"                => 1116,
                         "teachings"               => 4181,
                         "teachta"                 => 20216,
                         "team"                    => 74,
                         "teamed"                  => 4245,
                         "teaming"                 => 8596,
                         "teammate"                => 4394,
                         "teammates"               => 5240,
                         "teams"                   => 390,
                         "teamsters"               => 15122,
                         "teaneck"                 => 23350,
                         "tearfully"               => 23226,
                         "teasers"                 => 29658,
                         "teases"                  => 27633,
                         "teatro"                  => 6305,
                         "tebow"                   => 25926,
                         "tech"                    => 2310,
                         "techcrunch"              => 26909,
                         "technetium"              => 29866,
                         "technical"               => 1057,
                         "technician"              => 7488,
                         "technicians"             => 7490,
                         "technicolor"             => 11997,
                         "technion"                => 22328,
                         "technique"               => 1844,
                         "techniques"              => 1580,
                         "technische"              => 18967,
                         "technological"           => 3785,
                         "technologies"            => 2177,
                         "technologist"            => 20965,
                         "technologists"           => 19883,
                         "technology"              => 497,
                         "tecmo"                   => 29154,
                         "tecnico"                 => 21968,
                         "tectonic"                => 10311,
                         "tectonics"               => 17675,
                         "teddington"              => 23601,
                         "teesside"                => 20524,
                         "tegucigalpa"             => 22003,
                         "tehran"                  => 4976,
                         "tehsil"                  => 7175,
                         "tehsils"                 => 20291,
                         "tehuantepec"             => 26738,
                         "tejano"                  => 20058,
                         "tejas"                   => 26471,
                         "telangana"               => 8318,
                         "telecasts"               => 13129,
                         "telecommunication"       => 8668,
                         "telecommunications"      => 4062,
                         "telecoms"                => 21223,
                         "telefilm"                => 26481,
                         "telefonica"              => 22645,
                         "telegraph"               => 3620,
                         "telegraphic"             => 26122,
                         "telegraphs"              => 25281,
                         "telegraphy"              => 18566,
                         "telemundo"               => 13845,
                         "telenor"                 => 24553,
                         "telenovela"              => 8104,
                         "telenovelas"             => 16432,
                         "telepathic"              => 15224,
                         "telephony"               => 12254,
                         "teleplay"                => 20542,
                         "teleported"              => 24991,
                         "teleports"               => 26489,
                         "telescope"               => 4695,
                         "telescopes"              => 8836,
                         "telescopic"              => 15591,
                         "telescoping"             => 29859,
                         "teletext"                => 24749,
                         "teletoon"                => 26671,
                         "televisa"                => 13416,
                         "televised"               => 4756,
                         "television"              => 258,
                         "televisions"             => 11672,
                         "televoting"              => 21297,
                         "telkom"                  => 28995,
                         "telluride"               => 17518,
                         "tellurium"               => 26910,
                         "telstra"                 => 15380,
                         "telugu"                  => 4607,
                         "telus"                   => 21169,
                         "temasek"                 => 28807,
                         "temecula"                => 27279,
                         "tempe"                   => 13559,
                         "tempelhof"               => 29848,
                         "tempera"                 => 22798,
                         "temperament"             => 8949,
                         "temperaments"            => 27508,
                         "temperance"              => 8787,
                         "temperate"               => 5565,
                         "temperature"             => 1473,
                         "temperatures"            => 2573,
                         "templars"                => 16737,
                         "template"                => 8471,
                         "templates"               => 13259,
                         "temple"                  => 762,
                         "temples"                 => 3205,
                         "tempo"                   => 5342,
                         "temporal"                => 5794,
                         "temporally"              => 25892,
                         "temporarily"             => 3009,
                         "temporary"               => 1979,
                         "tempore"                 => 13290,
                         "tempos"                  => 19927,
                         "temur"                   => 21474,
                         "tenancy"                 => 15753,
                         "tenant"                  => 6176,
                         "tenants"                 => 5272,
                         "tended"                  => 4772,
                         "tendencies"              => 7357,
                         "tendency"                => 4374,
                         "tendered"                => 13298,
                         "tendering"               => 27797,
                         "tenders"                 => 11598,
                         "tendon"                  => 10126,
                         "tendrils"                => 27559,
                         "tends"                   => 4397,
                         "tendulkar"               => 18050,
                         "tenebrionoidea"          => 28898,
                         "tenements"               => 18760,
                         "tenet"                   => 15995,
                         "tenets"                  => 11985,
                         "tengku"                  => 20908,
                         "tenn."                   => 18499,
                         "tennessee"               => 1489,
                         "tenochtitlan"            => 18972,
                         "tenor"                   => 4950,
                         "tenryu"                  => 27143,
                         "tens"                    => 5546,
                         "tenses"                  => 19681,
                         "tensile"                 => 14251,
                         "tensions"                => 4613,
                         "tensor"                  => 7645,
                         "tensors"                 => 25628,
                         "tentacles"               => 10457,
                         "tentative"               => 10096,
                         "tentatively"             => 10638,
                         "tenth"                   => 2753,
                         "tenure"                  => 2369,
                         "tenured"                 => 14036,
                         "tenures"                 => 21419,
                         "tenzin"                  => 26690,
                         "teochew"                 => 25504,
                         "teofilo"                 => 28988,
                         "teotihuacan"             => 20998,
                         "tepals"                  => 21043,
                         "tepco"                   => 24686,
                         "tephritid"               => 22663,
                         "tephritidae"             => 19914,
                         "terai"                   => 23124,
                         "teramo"                  => 26029,
                         "terceira"                => 24221,
                         "tercera"                 => 14271,
                         "terek"                   => 23097,
                         "terengganu"              => 15129,
                         "tergum"                  => 17433,
                         "terje"                   => 23792,
                         "term"                    => 363,
                         "terme"                   => 21704,
                         "termed"                  => 4111,
                         "termen"                  => 15647,
                         "terminal"                => 1781,
                         "terminals"               => 6153,
                         "terminated"              => 4734,
                         "terminates"              => 8905,
                         "terminating"             => 8161,
                         "termination"             => 6572,
                         "termini"                 => 14429,
                         "terminology"             => 5494,
                         "terminus"                => 2319,
                         "terms"                   => 693,
                         "ternary"                 => 18613,
                         "ternate"                 => 28740,
                         "ternopil"                => 22720,
                         "terns"                   => 14670,
                         "terraced"                => 11916,
                         "terraces"                => 8695,
                         "terracing"               => 23967,
                         "terracotta"              => 11984,
                         "terrain"                 => 3445,
                         "terrains"                => 24582,
                         "terrane"                 => 26655,
                         "terrapins"               => 17816,
                         "terre"                   => 9300,
                         "terrestrial"             => 4233,
                         "territorial"             => 2680,
                         "territories"             => 2058,
                         "territory"               => 867,
                         "terrorism"               => 3752,
                         "terrorist"               => 3675,
                         "terse"                   => 28030,
                         "tertiary"                => 4475,
                         "tertullian"              => 23366,
                         "teruel"                  => 22241,
                         "teschen"                 => 25166,
                         "tesco"                   => 11180,
                         "tesla"                   => 10067,
                         "testament"               => 3281,
                         "testaments"              => 23293,
                         "testator"                => 27321,
                         "testbed"                 => 25370,
                         "testers"                 => 20388,
                         "testes"                  => 20139,
                         "testified"               => 5279,
                         "testimonial"             => 13418,
                         "testimonials"            => 23588,
                         "testimonies"             => 13454,
                         "testis"                  => 22953,
                         "tethys"                  => 23144,
                         "teton"                   => 14536,
                         "tetra"                   => 17535,
                         "tetrahedra"              => 26743,
                         "tetrahedral"             => 16985,
                         "tetrahedron"             => 20359,
                         "tetrapods"               => 21170,
                         "tetsuya"                 => 19620,
                         "teutonic"                => 9794,
                         "tewkesbury"              => 21314,
                         "texan"                   => 12869,
                         "texarkana"               => 18691,
                         "texas"                   => 549,
                         "texcoco"                 => 29081,
                         "texel"                   => 28140,
                         "texian"                  => 27397,
                         "texians"                 => 29077,
                         "text"                    => 1026,
                         "textbooks"               => 6812,
                         "textile"                 => 4437,
                         "textiles"                => 6549,
                         "texting"                 => 25534,
                         "texts"                   => 2492,
                         "textual"                 => 7968,
                         "texture"                 => 5949,
                         "textured"                => 14831,
                         "textures"                => 10169,
                         "tezuka"                  => 20530,
                         "thabo"                   => 23415,
                         "thai"                    => 3034,
                         "thais"                   => 18432,
                         "thaksin"                 => 15191,
                         "thakur"                  => 12466,
                         "thalamus"                => 19379,
                         "thalberg"                => 25487,
                         "thallium"                => 26656,
                         "thallus"                 => 28791,
                         "thame"                   => 28450,
                         "thameslink"              => 21708,
                         "thampi"                  => 27031,
                         "than"                    => 77,
                         "thana"                   => 21116,
                         "thane"                   => 13770,
                         "thanet"                  => 19670,
                         "thanhouser"              => 23815,
                         "thani"                   => 13480,
                         "thanjavur"               => 12916,
                         "thapa"                   => 20956,
                         "thatched"                => 13640,
                         "the"                     => 1,
                         "theater"                 => 1180,
                         "theaters"                => 4333,
                         "theatre"                 => 537,
                         "theatres"                => 4515,
                         "theatrical"              => 3064,
                         "theatrically"            => 11446,
                         "theban"                  => 18799,
                         "their"                   => 28,
                         "theism"                  => 28979,
                         "theistic"                => 22853,
                         "thelonious"              => 20612,
                         "them"                    => 99,
                         "thematic"                => 7944,
                         "thematically"            => 16849,
                         "theme"                   => 1191,
                         "themed"                  => 4256,
                         "themes"                  => 2078,
                         "themselves"              => 761,
                         "then"                    => 62,
                         "thence"                  => 8334,
                         "thenceforth"             => 25127,
                         "theocracy"               => 28207,
                         "theocratic"              => 27858,
                         "theodor"                 => 7624,
                         "theodoric"               => 20073,
                         "theodoros"               => 24979,
                         "theodorus"               => 26485,
                         "theodosius"              => 12859,
                         "theologian"              => 6512,
                         "theologians"             => 9339,
                         "theological"             => 3191,
                         "theologically"           => 23018,
                         "theology"                => 2711,
                         "theophanes"              => 29223,
                         "theophile"               => 22089,
                         "theophilus"              => 14181,
                         "theorem"                 => 3059,
                         "theorems"                => 12313,
                         "theoretic"               => 15680,
                         "theoretical"             => 3234,
                         "theoretician"            => 24789,
                         "theories"                => 2672,
                         "theorist"                => 8332,
                         "theorists"               => 8747,
                         "theorize"                => 28782,
                         "theorized"               => 11256,
                         "theorizes"               => 26782,
                         "theorizing"              => 29474,
                         "theory"                  => 684,
                         "theosophical"            => 15944,
                         "theosophy"               => 21340,
                         "theotokos"               => 20380,
                         "thera"                   => 23826,
                         "therapeutic"             => 6208,
                         "therapeutics"            => 15926,
                         "therapies"               => 9784,
                         "theravada"               => 14104,
                         "there"                   => 42,
                         "thereafter"              => 2178,
                         "thereby"                 => 2937,
                         "therefore"               => 795,
                         "theremin"                => 25101,
                         "thereon"                 => 23946,
                         "theresienstadt"          => 27610,
                         "thereto"                 => 25263,
                         "thereupon"               => 17019,
                         "thermal"                 => 3494,
                         "thermally"               => 20797,
                         "thermodynamic"           => 10719,
                         "thermodynamics"          => 11250,
                         "thermoelectric"          => 27140,
                         "thermometers"            => 29468,
                         "thermoplastic"           => 28560,
                         "thermopylae"             => 25484,
                         "theropod"                => 17406,
                         "theropods"               => 23189,
                         "thesaban"                => 21404,
                         "these"                   => 75,
                         "theses"                  => 12263,
                         "theseus"                 => 16531,
                         "thesis"                  => 3503,
                         "thessalonica"            => 19100,
                         "thessaloniki"            => 7953,
                         "thessaly"                => 14795,
                         "theta"                   => 8518,
                         "thetis"                  => 22360,
                         "thevar"                  => 28637,
                         "they"                    => 33,
                         "thiamine"                => 25524,
                         "thickened"               => 16159,
                         "thickest"                => 29990,
                         "thickets"                => 18842,
                         "thickly"                 => 19251,
                         "thickness"               => 5704,
                         "thicknesses"             => 24868,
                         "thien"                   => 18591,
                         "thiers"                  => 25427,
                         "thieu"                   => 22143,
                         "thimphu"                 => 27663,
                         "thinkers"                => 8173,
                         "thinly"                  => 12073,
                         "thinned"                 => 25866,
                         "third"                   => 199,
                         "thirdly"                 => 17012,
                         "thirds"                  => 4430,
                         "thirsk"                  => 24400,
                         "thirteenth"              => 5467,
                         "thirunal"                => 21703,
                         "thiruvananthapuram"      => 11548,
                         "thistles"                => 28766,
                         "thomasville"             => 25031,
                         "thomond"                 => 23420,
                         "thoracic"                => 11833,
                         "thorax"                  => 9997,
                         "thorium"                 => 15154,
                         "thornycroft"             => 24480,
                         "thoroughbred"            => 6071,
                         "thoroughbreds"           => 20103,
                         "thoroughfare"            => 10630,
                         "thoroughfares"           => 17718,
                         "though"                  => 298,
                         "thousands"               => 1721,
                         "thrace"                  => 9977,
                         "thracian"                => 13601,
                         "thracians"               => 29807,
                         "thrashed"                => 24680,
                         "thrashers"               => 16619,
                         "threaded"                => 13685,
                         "threading"               => 21736,
                         "threads"                 => 7540,
                         "threatens"               => 6404,
                         "three"                   => 59,
                         "three-and-a-half"        => 18423,
                         "threefold"               => 18037,
                         "threonine"               => 26007,
                         "threshing"               => 21329,
                         "threshold"               => 5224,
                         "thresholds"              => 16120,
                         "thrice"                  => 12539,
                         "thriller"                => 4125,
                         "thrillers"               => 14617,
                         "thrissur"                => 11667,
                         "thrived"                 => 11813,
                         "thriving"                => 7038,
                         "throated"                => 12577,
                         "thrombosis"              => 16534,
                         "throne"                  => 2269,
                         "thrones"                 => 13340,
                         "throng"                  => 29101,
                         "through"                 => 85,
                         "throughout"              => 398,
                         "throughput"              => 10646,
                         "thrushes"                => 23078,
                         "thrust"                  => 4916,
                         "thruway"                 => 15685,
                         "thuan"                   => 24235,
                         "thucydides"              => 20081,
                         "thule"                   => 16986,
                         "thunderbirds"            => 12681,
                         "thunderbolt"             => 11915,
                         "thunderbolts"            => 14992,
                         "thunderstorms"           => 10555,
                         "thurgau"                 => 27303,
                         "thuringia"               => 9599,
                         "thuringian"              => 20318,
                         "thurles"                 => 23091,
                         "thurrock"                => 22685,
                         "thus"                    => 447,
                         "thutmose"                => 21796,
                         "thwart"                  => 14070,
                         "thwarted"                => 9916,
                         "thwarting"               => 28181,
                         "thymus"                  => 22679,
                         "thynne"                  => 29763,
                         "thyssen"                 => 28347,
                         "tiago"                   => 19845,
                         "tiananmen"               => 15493,
                         "tianjin"                 => 9010,
                         "tiber"                   => 18871,
                         "tiberias"                => 18304,
                         "tibet"                   => 4708,
                         "tibetan"                 => 4285,
                         "tibetans"                => 14052,
                         "tibeto"                  => 28006,
                         "tibor"                   => 18116,
                         "ticino"                  => 13544,
                         "ticketing"               => 13041,
                         "ticonderoga"             => 18205,
                         "tidal"                   => 5725,
                         "tide"                    => 4092,
                         "tides"                   => 8390,
                         "tidewater"               => 16954,
                         "tiebreak"                => 24364,
                         "tiebreaker"              => 15625,
                         "tiebreakers"             => 27134,
                         "tiempo"                  => 19549,
                         "tientsin"                => 27063,
                         "tier"                    => 2788,
                         "tiered"                  => 12550,
                         "tiers"                   => 10429,
                         "ties"                    => 2522,
                         "tiflis"                  => 20054,
                         "tightly"                 => 7203,
                         "tigranes"                => 28762,
                         "tigray"                  => 24287,
                         "tikal"                   => 21217,
                         "tikrit"                  => 29135,
                         "tikva"                   => 18696,
                         "tilak"                   => 17120,
                         "tilapia"                 => 23676,
                         "tilburg"                 => 18433,
                         "tiled"                   => 13145,
                         "tiles"                   => 5606,
                         "tiling"                  => 11738,
                         "tilings"                 => 21874,
                         "tillage"                 => 29668,
                         "tillamook"               => 23397,
                         "tillandsia"              => 15440,
                         "tilling"                 => 29899,
                         "tilted"                  => 12840,
                         "tilting"                 => 14379,
                         "timaru"                  => 24955,
                         "timbaland"               => 14510,
                         "timbered"                => 17862,
                         "timbers"                 => 9286,
                         "timberwolves"            => 16128,
                         "timbre"                  => 15932,
                         "time"                    => 40,
                         "timeform"                => 20755,
                         "timeframe"               => 16975,
                         "timekeeping"             => 29876,
                         "timeline"                => 4549,
                         "timelines"               => 18621,
                         "timely"                  => 8313,
                         "times"                   => 232,
                         "timescale"               => 24140,
                         "timeslot"                => 10212,
                         "timeslots"               => 28523,
                         "timestamp"               => 23657,
                         "timings"                 => 21154,
                         "timisoara"               => 14534,
                         "timor"                   => 6915,
                         "timorese"                => 20831,
                         "timurid"                 => 28687,
                         "tincture"                => 26094,
                         "tinge"                   => 17423,
                         "tinged"                  => 11052,
                         "tinian"                  => 19710,
                         "tinnitus"                => 29133,
                         "tinto"                   => 16603,
                         "tioga"                   => 16557,
                         "tippecanoe"              => 24728,
                         "tippeligaen"             => 20324,
                         "tipperary"               => 6399,
                         "tirana"                  => 8897,
                         "tiraspol"                => 25717,
                         "tirelessly"              => 17601,
                         "tirol"                   => 24922,
                         "tirtha"                  => 29570,
                         "tiruchirappalli"         => 19870,
                         "tirumala"                => 27387,
                         "tirunelveli"             => 17248,
                         "tirupati"                => 20357,
                         "tissue"                  => 3126,
                         "tissues"                 => 5634,
                         "tisza"                   => 22439,
                         "tithe"                   => 14890,
                         "tithes"                  => 15818,
                         "titian"                  => 16683,
                         "title"                   => 270,
                         "titled"                  => 1076,
                         "titleholder"             => 13045,
                         "titleholders"            => 23945,
                         "titles"                  => 1112,
                         "titular"                 => 5594,
                         "titusville"              => 25100,
                         "tiverton"                => 18539,
                         "tiwari"                  => 21747,
                         "tlaxcala"                => 22195,
                         "tlemcen"                 => 29589,
                         "tlingit"                 => 18587,
                         "to/from"                 => 17266,
                         "tobacco"                 => 3339,
                         "tobago"                  => 6260,
                         "tobruk"                  => 14722,
                         "tocantins"               => 22761,
                         "tochigi"                 => 21205,
                         "todor"                   => 28250,
                         "todos"                   => 21387,
                         "togolese"                => 23047,
                         "tohoku"                  => 11442,
                         "tokai"                   => 22542,
                         "tokaido"                 => 19970,
                         "tokelau"                 => 23611,
                         "tokens"                  => 10886,
                         "tokio"                   => 26798,
                         "tokugawa"                => 7959,
                         "tokusatsu"               => 25877,
                         "tokushima"               => 21553,
                         "tokyo"                   => 1920,
                         "tokyopop"                => 19553,
                         "tokyu"                   => 27014,
                         "tolerance"               => 5248,
                         "tolerances"              => 20016,
                         "tolerant"                => 8344,
                         "tolerates"               => 26309,
                         "toleration"              => 16098,
                         "toll"                    => 3433,
                         "tolled"                  => 24351,
                         "tolling"                 => 25766,
                         "tolls"                   => 9564,
                         "tollway"                 => 21212,
                         "tollywood"               => 26289,
                         "tolombeh"                => 10773,
                         "toluca"                  => 15341,
                         "toluene"                 => 26417,
                         "tomar"                   => 25395,
                         "tomasz"                  => 14682,
                         "tomaszow"                => 17117,
                         "tomatoes"                => 5225,
                         "tomb"                    => 3046,
                         "tombs"                   => 6062,
                         "tombstones"              => 18775,
                         "tomic"                   => 24948,
                         "tomislav"                => 21074,
                         "tomography"              => 13958,
                         "tomorrowland"            => 26723,
                         "tonal"                   => 10207,
                         "tonality"                => 18881,
                         "tonawanda"               => 21251,
                         "tonbridge"               => 16309,
                         "tondo"                   => 22336,
                         "tones"                   => 6058,
                         "tonga"                   => 7262,
                         "tongan"                  => 13828,
                         "tongued"                 => 29108,
                         "tonnage"                 => 11397,
                         "tonne"                   => 12644,
                         "tonnes"                  => 4661,
                         "tonopah"                 => 24523,
                         "tonsberg"                => 22337,
                         "took"                    => 172,
                         "toolbar"                 => 28752,
                         "toolkit"                 => 13734,
                         "tools"                   => 1998,
                         "toorak"                  => 27861,
                         "toothed"                 => 10682,
                         "toowong"                 => 26975,
                         "toowoomba"               => 11074,
                         "top"                     => 222,
                         "topical"                 => 8331,
                         "topics"                  => 2582,
                         "topmost"                 => 25607,
                         "topographic"             => 11144,
                         "topographical"           => 12296,
                         "topography"              => 7003,
                         "topological"             => 7903,
                         "topologically"           => 24796,
                         "topologies"              => 24355,
                         "topology"                => 6608,
                         "toponym"                 => 17375,
                         "toponyms"                => 20506,
                         "toponymy"                => 16395,
                         "topped"                  => 3557,
                         "toppers"                 => 26837,
                         "toppled"                 => 14868,
                         "toppling"                => 25919,
                         "topsoil"                 => 25305,
                         "torah"                   => 5596,
                         "torbat"                  => 28808,
                         "torbay"                  => 20891,
                         "torchwood"               => 14768,
                         "tories"                  => 12290,
                         "torii"                   => 25161,
                         "torme"                   => 25288,
                         "tornadoes"               => 7218,
                         "torneo"                  => 9863,
                         "tornus"                  => 20596,
                         "toroidal"                => 29084,
                         "toros"                   => 15589,
                         "torpedo"                 => 3480,
                         "torpedoed"               => 10908,
                         "torpedoes"               => 6505,
                         "torquay"                 => 8993,
                         "torque"                  => 5809,
                         "torrential"              => 14700,
                         "torrington"              => 17195,
                         "torshavn"                => 25900,
                         "torsion"                 => 12779,
                         "tortoises"               => 17229,
                         "tortricidae"             => 7857,
                         "torts"                   => 24030,
                         "torun"                   => 11490,
                         "torus"                   => 14468,
                         "toshack"                 => 28543,
                         "toshio"                  => 23722,
                         "total"                   => 282,
                         "totaled"                 => 7916,
                         "totaling"                => 7249,
                         "totalitarian"            => 13027,
                         "totalitarianism"         => 21272,
                         "totality"                => 15471,
                         "totalled"                => 13296,
                         "totalling"               => 9718,
                         "totals"                  => 6948,
                         "totnes"                  => 20462,
                         "tottori"                 => 23715,
                         "touchdown"               => 2268,
                         "touchdowns"              => 3410,
                         "touchscreen"             => 16234,
                         "toughness"               => 16553,
                         "toulon"                  => 9325,
                         "toungoo"                 => 19423,
                         "tour"                    => 413,
                         "touraine"                => 29584,
                         "toure"                   => 15754,
                         "toured"                  => 2263,
                         "tourer"                  => 23368,
                         "tourette"                => 21720,
                         "touring"                 => 2094,
                         "tourism"                 => 2073,
                         "tourist"                 => 2519,
                         "touristic"               => 19705,
                         "tourists"                => 3383,
                         "tournai"                 => 20602,
                         "tournament"              => 546,
                         "tournaments"             => 2840,
                         "tourney"                 => 29286,
                         "tours"                   => 2399,
                         "touted"                  => 11010,
                         "toward"                  => 1477,
                         "towards"                 => 631,
                         "towed"                   => 6888,
                         "tower"                   => 871,
                         "towers"                  => 2789,
                         "town"                    => 133,
                         "townhouses"              => 17996,
                         "townland"                => 9972,
                         "townlands"               => 15496,
                         "towns"                   => 1222,
                         "townshend"               => 9927,
                         "township"                => 664,
                         "townships"               => 4221,
                         "townsite"                => 13583,
                         "townsquare"              => 28173,
                         "townsville"              => 10760,
                         "towpath"                 => 21864,
                         "toxicity"                => 7098,
                         "toyah"                   => 29186,
                         "toyama"                  => 16299,
                         "toyline"                 => 27392,
                         "toynbee"                 => 25132,
                         "toyotomi"                => 18223,
                         "trabzon"                 => 20413,
                         "trabzonspor"             => 21848,
                         "tracery"                 => 16517,
                         "traces"                  => 4024,
                         "track"                   => 388,
                         "trackage"                => 13897,
                         "trackbed"                => 18236,
                         "tracklist"               => 14604,
                         "tracklisting"            => 16762,
                         "tracks"                  => 780,
                         "tract"                   => 4520,
                         "tractate"                => 25012,
                         "tractatus"               => 29918,
                         "traction"                => 5860,
                         "tractive"                => 26871,
                         "tractors"                => 9245,
                         "tracts"                  => 7383,
                         "trade"                   => 586,
                         "traded"                  => 2531,
                         "trademark"               => 3942,
                         "trademarked"             => 14932,
                         "trademarks"              => 11194,
                         "traders"                 => 4664,
                         "trades"                  => 5296,
                         "tradesman"               => 27511,
                         "tradesmen"               => 18010,
                         "trading"                 => 1946,
                         "tradition"               => 1189,
                         "traditional"             => 585,
                         "traditionalist"          => 12679,
                         "traditionalists"         => 19630,
                         "traditionally"           => 2104,
                         "traditions"              => 2327,
                         "trafalgar"               => 10171,
                         "traffic"                 => 1095,
                         "trafficked"              => 14638,
                         "traffickers"             => 14520,
                         "trafficking"             => 4164,
                         "traian"                  => 25575,
                         "trail"                   => 1531,
                         "trailblazer"             => 27141,
                         "trailed"                 => 10553,
                         "trailhead"               => 17244,
                         "trailing"                => 6352,
                         "trails"                  => 3648,
                         "train"                   => 786,
                         "trained"                 => 1541,
                         "trainees"                => 11722,
                         "trainers"                => 8123,
                         "training"                => 399,
                         "trainings"               => 17410,
                         "trains"                  => 1195,
                         "trainsets"               => 19751,
                         "traite"                  => 27546,
                         "traits"                  => 4844,
                         "trajectories"            => 16354,
                         "tralee"                  => 19347,
                         "tram"                    => 4440,
                         "tramcars"                => 29083,
                         "trams"                   => 6301,
                         "tramway"                 => 5815,
                         "tramways"                => 10172,
                         "tranquillity"            => 28365,
                         "trans"                   => 3590,
                         "transaction"             => 4753,
                         "transactional"           => 18533,
                         "transactions"            => 4389,
                         "transatlantic"           => 8802,
                         "transcaucasia"           => 28873,
                         "transcaucasian"          => 28303,
                         "transceiver"             => 23746,
                         "transcended"             => 26154,
                         "transcendence"           => 17723,
                         "transcendental"          => 11469,
                         "transcending"            => 27839,
                         "transcontinental"        => 10633,
                         "transcribe"              => 23988,
                         "transcribed"             => 8944,
                         "transcription"           => 5125,
                         "transcriptional"         => 14813,
                         "transcriptions"          => 14416,
                         "transdev"                => 25889,
                         "transducer"              => 20611,
                         "transducers"             => 25272,
                         "transduction"            => 15554,
                         "transept"                => 10739,
                         "transepts"               => 18564,
                         "transfer"                => 1291,
                         "transferable"            => 14712,
                         "transferase"             => 23062,
                         "transferases"            => 23723,
                         "transferred"             => 992,
                         "transferring"            => 5249,
                         "transfers"               => 4625,
                         "transfiguration"         => 18386,
                         "transform"               => 4018,
                         "transformation"          => 3294,
                         "transformational"        => 20205,
                         "transformations"         => 7679,
                         "transformative"          => 17319,
                         "transformed"             => 3252,
                         "transformer"             => 9956,
                         "transformers"            => 6691,
                         "transforming"            => 6929,
                         "transforms"              => 7680,
                         "transgender"             => 7107,
                         "transient"               => 8881,
                         "transistor"              => 9614,
                         "transistors"             => 12011,
                         "transit"                 => 2103,
                         "transited"               => 17026,
                         "transiting"              => 19177,
                         "transition"              => 2210,
                         "transitional"            => 6063,
                         "transitioned"            => 8501,
                         "transitioning"           => 12615,
                         "transitions"             => 7722,
                         "transitive"              => 12512,
                         "transitway"              => 28784,
                         "transjordan"             => 20906,
                         "transkei"                => 29389,
                         "translated"              => 1833,
                         "translates"              => 5806,
                         "translating"             => 8214,
                         "translation"             => 1847,
                         "translational"           => 13008,
                         "translations"            => 4007,
                         "translators"             => 8872,
                         "translink"               => 23653,
                         "translit"                => 22659,
                         "transliterated"          => 11303,
                         "transliteration"         => 11526,
                         "translocation"           => 18771,
                         "translucent"             => 10427,
                         "transmembrane"           => 12871,
                         "transmission"            => 2164,
                         "transmissions"           => 7436,
                         "transmit"                => 7088,
                         "transmits"               => 12820,
                         "transmitted"             => 4293,
                         "transmitter"             => 3991,
                         "transmitters"            => 8413,
                         "transmitting"            => 8016,
                         "transmutation"           => 26334,
                         "transnational"           => 11258,
                         "transnistria"            => 15697,
                         "transom"                 => 19302,
                         "transparency"            => 6403,
                         "transpires"              => 28398,
                         "transplantation"         => 10792,
                         "transplanted"            => 14576,
                         "transponders"            => 21093,
                         "transport"               => 862,
                         "transportable"           => 27352,
                         "transportation"          => 1301,
                         "transported"             => 3514,
                         "transporter"             => 10962,
                         "transporters"            => 17840,
                         "transporting"            => 6602,
                         "transports"              => 6690,
                         "transpose"               => 22905,
                         "transposed"              => 19392,
                         "transposition"           => 18009,
                         "transshipment"           => 27302,
                         "transvaal"               => 9389,
                         "transversal"             => 26943,
                         "transverse"              => 6591,
                         "transversely"            => 23129,
                         "transylvania"            => 7233,
                         "transylvanian"           => 15302,
                         "traore"                  => 21005,
                         "trapezoid"               => 27133,
                         "trapezoidal"             => 21432,
                         "trapping"                => 9219,
                         "travancore"              => 9627,
                         "traveled"                => 2243,
                         "travelers"               => 5995,
                         "travelled"               => 2652,
                         "traveller"               => 8117,
                         "travellers"              => 7313,
                         "travelling"              => 3322,
                         "travelogue"              => 18947,
                         "travels"                 => 2860,
                         "traversal"               => 27986,
                         "traverse"                => 7562,
                         "traversed"               => 9860,
                         "traverses"               => 11143,
                         "traversing"              => 12934,
                         "travertine"              => 26622,
                         "trawler"                 => 14963,
                         "trawlers"                => 17504,
                         "trawling"                => 26176,
                         "treason"                 => 5566,
                         "treasurer"               => 3782,
                         "treasury"                => 3618,
                         "treaties"                => 5520,
                         "treatise"                => 5671,
                         "treatises"               => 10600,
                         "treatment"               => 964,
                         "treatments"              => 4868,
                         "treaty"                  => 1358,
                         "trebinje"                => 28718,
                         "trebizond"               => 18653,
                         "treblinka"               => 21937,
                         "trechus"                 => 20193,
                         "tredegar"                => 24671,
                         "trees"                   => 1348,
                         "trefoil"                 => 21776,
                         "trekking"                => 14545,
                         "trelawny"                => 25320,
                         "treme"                   => 25368,
                         "tremolo"                 => 19144,
                         "trench"                  => 5984,
                         "trenchard"               => 19552,
                         "trenches"                => 7339,
                         "trencin"                 => 22369,
                         "trend"                   => 3341,
                         "trending"                => 13912,
                         "trends"                  => 4502,
                         "trentino"                => 14786,
                         "trestle"                 => 16154,
                         "trevally"                => 28028,
                         "trevelyan"               => 21497,
                         "treviso"                 => 13616,
                         "trialled"                => 21562,
                         "trials"                  => 2296,
                         "triangles"               => 9287,
                         "triangular"              => 5271,
                         "triangulation"           => 17349,
                         "trianon"                 => 18059,
                         "triassic"                => 9189,
                         "triathlete"              => 22374,
                         "triathlon"               => 9359,
                         "tribal"                  => 3119,
                         "tribals"                 => 23735,
                         "tribe"                   => 1976,
                         "tribeca"                 => 14443,
                         "tribes"                  => 2217,
                         "tribesmen"               => 13487,
                         "tribulation"             => 26308,
                         "tribunal"                => 4489,
                         "tribunals"               => 11611,
                         "tribune"                 => 4039,
                         "tribunes"                => 24246,
                         "tributaries"             => 5124,
                         "tributary"               => 2949,
                         "tribute"                 => 2494,
                         "tributes"                => 10227,
                         "triceratops"             => 28568,
                         "trichy"                  => 22218,
                         "tricolour"               => 22579,
                         "tricycle"                => 12276,
                         "tridentine"              => 25042,
                         "triennial"               => 17372,
                         "trier"                   => 8746,
                         "tries"                   => 1809,
                         "trieste"                 => 8659,
                         "trigeminal"              => 27195,
                         "triggered"               => 5431,
                         "triggering"              => 10583,
                         "triglycerides"           => 29157,
                         "trigonometric"           => 17665,
                         "trilobite"               => 24040,
                         "trilobites"              => 18631,
                         "trilogy"                 => 4157,
                         "trim"                    => 5121,
                         "trimmed"                 => 10745,
                         "trims"                   => 20296,
                         "trinamool"               => 22827,
                         "trincomalee"             => 18513,
                         "tring"                   => 26092,
                         "trinidadian"             => 18474,
                         "trinitarian"             => 20913,
                         "trio"                    => 2709,
                         "triomphe"                => 15514,
                         "trios"                   => 12548,
                         "tripartite"              => 12473,
                         "tripathi"                => 26568,
                         "triphosphate"            => 24614,
                         "triple"                  => 2112,
                         "tripled"                 => 13779,
                         "triplemania"             => 21416,
                         "triples"                 => 9722,
                         "tripoli"                 => 7428,
                         "tripolitania"            => 29419,
                         "tripos"                  => 23925,
                         "trips"                   => 3460,
                         "triptych"                => 15245,
                         "tripura"                 => 12388,
                         "tritium"                 => 18897,
                         "triumphal"               => 14914,
                         "triumphantly"            => 26894,
                         "triumvirate"             => 16265,
                         "trivandrum"              => 14313,
                         "trnava"                  => 19340,
                         "trobe"                   => 20598,
                         "trochidae"               => 29002,
                         "trofeo"                  => 21057,
                         "troilus"                 => 23473,
                         "trois"                   => 10708,
                         "trolley"                 => 7560,
                         "trolleybus"              => 13140,
                         "trolleybuses"            => 14287,
                         "trolleys"                => 18316,
                         "trollope"                => 20009,
                         "trombones"               => 17126,
                         "trombonist"              => 16077,
                         "trompe"                  => 26857,
                         "troms"                   => 21742,
                         "tromso"                  => 12246,
                         "trondelag"               => 13067,
                         "trondheim"               => 8484,
                         "troon"                   => 23402,
                         "troop"                   => 3924,
                         "troops"                  => 810,
                         "troopship"               => 21710,
                         "trope"                   => 23650,
                         "tropes"                  => 20063,
                         "trophee"                 => 23170,
                         "trophic"                 => 20475,
                         "trophy"                  => 1766,
                         "tropical"                => 1306,
                         "tropics"                 => 10277,
                         "troposphere"             => 27445,
                         "trotskyist"              => 16101,
                         "troubadours"             => 23782,
                         "troublesome"             => 11665,
                         "trough"                  => 8308,
                         "troughs"                 => 20849,
                         "troughton"               => 29183,
                         "troupes"                 => 15241,
                         "trovatore"               => 26330,
                         "troyes"                  => 15966,
                         "truckee"                 => 23404,
                         "trulli"                  => 20733,
                         "trumpeter"               => 9489,
                         "truncated"               => 8346,
                         "truncation"              => 23200,
                         "trung"                   => 21144,
                         "trunkline"               => 23920,
                         "truro"                   => 11680,
                         "trusses"                 => 16181,
                         "trustee"                 => 4809,
                         "trustees"                => 3174,
                         "trusteeship"             => 24448,
                         "truthfulness"            => 29331,
                         "trygve"                  => 29992,
                         "trypeta"                 => 28192,
                         "tryptophan"              => 19330,
                         "tsarist"                 => 14681,
                         "tsing"                   => 18985,
                         "tsinghua"                => 18876,
                         "tsingtao"                => 23721,
                         "tsonga"                  => 19333,
                         "tsuen"                   => 20877,
                         "tsugaru"                 => 25765,
                         "tsukasa"                 => 27808,
                         "tsukuba"                 => 27588,
                         "tsunamis"                => 23555,
                         "tsung"                   => 25808,
                         "tsushima"                => 18811,
                         "tsuyoshi"                => 28334,
                         "tsvangirai"              => 26686,
                         "tualatin"                => 26242,
                         "tuanku"                  => 24156,
                         "tuareg"                  => 16876,
                         "tubal"                   => 28727,
                         "tube"                    => 2817,
                         "tuber"                   => 23113,
                         "tubercle"                => 23901,
                         "tubercles"               => 11996,
                         "tuberculosis"            => 5682,
                         "tuberous"                => 28712,
                         "tubes"                   => 4232,
                         "tubing"                  => 10734,
                         "tubingen"                => 11650,
                         "tubular"                 => 8575,
                         "tubule"                  => 29643,
                         "tubules"                 => 25158,
                         "tubulin"                 => 29297,
                         "tucuman"                 => 14345,
                         "tudman"                  => 22557,
                         "tudors"                  => 29695,
                         "tufted"                  => 19691,
                         "tuileries"               => 21723,
                         "tuition"                 => 5400,
                         "tujue"                   => 29098,
                         "tulagi"                  => 24740,
                         "tulare"                  => 20901,
                         "tulsi"                   => 22304,
                         "tumbled"                 => 29865,
                         "tumblr"                  => 22628,
                         "tumors"                  => 7617,
                         "tumour"                  => 12338,
                         "tumours"                 => 20423,
                         "tumuli"                  => 27605,
                         "tumultuous"              => 13053,
                         "tumulus"                 => 23811,
                         "tunbridge"               => 13976,
                         "tuners"                  => 20377,
                         "tunes"                   => 4986,
                         "tungsten"                => 11364,
                         "tunica"                  => 22395,
                         "tunings"                 => 19489,
                         "tunis"                   => 9273,
                         "tunisia"                 => 5176,
                         "tunisian"                => 8358,
                         "tunku"                   => 17585,
                         "tunnel"                  => 1974,
                         "tunneling"               => 15425,
                         "tunnelling"              => 14410,
                         "tunnels"                 => 4631,
                         "tuoba"                   => 24414,
                         "tuolumne"                => 26944,
                         "tuple"                   => 22778,
                         "tuples"                  => 28529,
                         "tupolev"                 => 16522,
                         "tupou"                   => 26736,
                         "turan"                   => 17904,
                         "turbidity"               => 24065,
                         "turbine"                 => 5003,
                         "turbines"                => 6049,
                         "turbocharged"            => 11455,
                         "turbocharger"            => 19054,
                         "turbofan"                => 21119,
                         "turbojet"                => 18908,
                         "turbonilla"              => 13827,
                         "turboprop"               => 14196,
                         "turboprops"              => 27467,
                         "turbulent"               => 8217,
                         "turenne"                 => 27849,
                         "turgenev"                => 27994,
                         "turin"                   => 5011,
                         "turing"                  => 9322,
                         "turkana"                 => 27834,
                         "turkestan"               => 15118,
                         "turki"                   => 20743,
                         "turkic"                  => 7455,
                         "turkish"                 => 1578,
                         "turkmen"                 => 12606,
                         "turkmenistan"            => 8722,
                         "turks"                   => 4486,
                         "turku"                   => 10887,
                         "turlough"                => 29923,
                         "turmeric"                => 20974,
                         "turnout"                 => 5202,
                         "turnover"                => 7055,
                         "turnovers"               => 13490,
                         "turnpike"                => 5761,
                         "turnstile"               => 27470,
                         "turnstiles"              => 21757,
                         "turntable"               => 12969,
                         "turntables"              => 19731,
                         "turret"                  => 5447,
                         "turrets"                 => 7334,
                         "turridae"                => 27657,
                         "tuscaloosa"              => 13179,
                         "tusculum"                => 29782,
                         "tuskegee"                => 13718,
                         "tuskers"                 => 26937,
                         "tusks"                   => 20337,
                         "tussock"                 => 26392,
                         "tutankhamun"             => 24484,
                         "tutelage"                => 9974,
                         "tutored"                 => 14739,
                         "tutorials"               => 17313,
                         "tutors"                  => 11992,
                         "tutsi"                   => 17178,
                         "tutte"                   => 20379,
                         "tuvalu"                  => 10839,
                         "tuzla"                   => 20429,
                         "twang"                   => 29626,
                         "tweaks"                  => 29549,
                         "tweeted"                 => 14107,
                         "tweets"                  => 16952,
                         "twelfth"                 => 4086,
                         "twelver"                 => 25436,
                         "twente"                  => 16498,
                         "twentieth"               => 3162,
                         "twenty20"                => 7674,
                         "twickenham"              => 12056,
                         "twigs"                   => 10155,
                         "twin"                    => 1930,
                         "twinned"                 => 7776,
                         "twinning"                => 15979,
                         "twitter"                 => 4138,
                         "two"                     => 34,
                         "two-and-a-half"          => 16103,
                         "twofold"                 => 18517,
                         "tycho"                   => 19488,
                         "tydfil"                  => 19538,
                         "tyldesley"               => 23557,
                         "tymoshenko"              => 17554,
                         "tympanum"                => 19688,
                         "tyndale"                 => 20375,
                         "tynemouth"               => 29741,
                         "tyneside"                => 14743,
                         "type"                    => 471,
                         "typecast"                => 26739,
                         "typeface"                => 11282,
                         "typefaces"               => 16770,
                         "types"                   => 940,
                         "typesetting"             => 20669,
                         "typhoons"                => 17945,
                         "typhus"                  => 15740,
                         "typical"                 => 1546,
                         "typically"               => 948,
                         "typified"                => 13683,
                         "typographic"             => 24564,
                         "typographical"           => 21828,
                         "typography"              => 14679,
                         "typology"                => 17773,
                         "tyrannical"              => 17268,
                         "tyrannosaurus"           => 17151,
                         "tyres"                   => 9077,
                         "tyrol"                   => 8553,
                         "tyrolean"                => 20522,
                         "tyrosine"                => 12143,
                         "tyrrhenian"              => 25215,
                         "tyumen"                  => 23439,
                         "u.s."                    => 249,
                         "u.s.."                   => 22245,
                         "u.s.a"                   => 15728,
                         "u.s.a."                  => 9380,
                         "u.s.c"                   => 13731,
                         "u.s.s"                   => 20478,
                         "ubiquitin"               => 18025,
                         "ubiquitous"              => 9571,
                         "ubiquity"                => 25476,
                         "ubisoft"                 => 15837,
                         "ubuntu"                  => 13043,
                         "ucla"                    => 4278,
                         "udaipur"                 => 17604,
                         "udine"                   => 17988,
                         "udinese"                 => 16197,
                         "udupi"                   => 18961,
                         "uefa"                    => 2440,
                         "uematsu"                 => 26163,
                         "uesugi"                  => 27010,
                         "uffizi"                  => 27922,
                         "uganda"                  => 3754,
                         "ugandan"                 => 10091,
                         "ugric"                   => 29129,
                         "uhuru"                   => 26430,
                         "ujjain"                  => 22806,
                         "ujpest"                  => 27017,
                         "ukiyo"                   => 23142,
                         "ukraine"                 => 1957,
                         "ukrainian"               => 2084,
                         "ukrainians"              => 9939,
                         "ukulele"                 => 16369,
                         "ulaanbaatar"             => 23019,
                         "ulama"                   => 20120,
                         "ulema"                   => 22734,
                         "ulidiid"                 => 28669,
                         "ulithi"                  => 12605,
                         "ulmus"                   => 15163,
                         "ulnar"                   => 23100,
                         "uloom"                   => 26222,
                         "ulrik"                   => 26747,
                         "ulsan"                   => 20465,
                         "ulster"                  => 3852,
                         "ultimately"              => 1396,
                         "ultralight"              => 12727,
                         "ultrasonic"              => 15004,
                         "ultraviolet"             => 8898,
                         "ultron"                  => 25713,
                         "ulyanovsk"               => 28984,
                         "umaga"                   => 28822,
                         "umass"                   => 15328,
                         "umatilla"                => 26858,
                         "umayyad"                 => 12190,
                         "umayyads"                => 27456,
                         "umbilicus"               => 18187,
                         "umbra"                   => 29130,
                         "umbria"                  => 16711,
                         "umlaut"                  => 29260,
                         "umpired"                 => 17726,
                         "umpires"                 => 10832,
                         "umpiring"                => 17565,
                         "umpqua"                  => 26247,
                         "unabated"                => 26637,
                         "unable"                  => 1315,
                         "unabridged"              => 27641,
                         "unaccompanied"           => 18097,
                         "unadorned"               => 26158,
                         "unaffected"              => 10350,
                         "unaffiliated"            => 14785,
                         "unaided"                 => 23752,
                         "unaired"                 => 22111,
                         "unaltered"               => 15865,
                         "unambiguous"             => 17328,
                         "unambiguously"           => 21434,
                         "unanimous"               => 5020,
                         "unanimously"             => 5519,
                         "unapologetic"            => 29881,
                         "unassigned"              => 29100,
                         "unassisted"              => 26919,
                         "unassuming"              => 22010,
                         "unauthorised"            => 16585,
                         "unavailability"          => 26366,
                         "unaware"                 => 5015,
                         "unbeaten"                => 6682,
                         "unbeknownst"             => 12279,
                         "unbound"                 => 19397,
                         "unbounded"               => 19875,
                         "unbranched"              => 27733,
                         "unbroken"                => 11069,
                         "unbuilt"                 => 27505,
                         "uncaf"                   => 25277,
                         "uncensored"              => 15161,
                         "uncertain"               => 4084,
                         "uncertainties"           => 15619,
                         "uncertainty"             => 5563,
                         "unchained"               => 26015,
                         "unchanged"               => 5685,
                         "unchanging"              => 23718,
                         "uncial"                  => 15528,
                         "unclassified"            => 16335,
                         "unclear"                 => 3756,
                         "uncommon"                => 4955,
                         "uncompleted"             => 23234,
                         "uncompressed"            => 28473,
                         "uncompromising"          => 14741,
                         "unconnected"             => 16953,
                         "unconstitutional"        => 7064,
                         "uncontested"             => 17311,
                         "uncontrolled"            => 12491,
                         "unconventional"          => 8256,
                         "unconvinced"             => 25769,
                         "unconvincing"            => 23669,
                         "uncountable"             => 29477,
                         "uncovered"               => 5928,
                         "uncovers"                => 19001,
                         "uncredited"              => 8475,
                         "uncultivated"            => 29375,
                         "undamaged"               => 16854,
                         "undated"                 => 19783,
                         "undaunted"               => 20588,
                         "undeclared"              => 24683,
                         "undefeated"              => 5105,
                         "undefended"              => 26646,
                         "undefined"               => 15373,
                         "undemocratic"            => 24693,
                         "under"                   => 67,
                         "underboss"               => 24218,
                         "undercard"               => 18784,
                         "undercarriage"           => 10690,
                         "underclass"              => 28539,
                         "underdeveloped"          => 14717,
                         "underdogs"               => 20059,
                         "undergo"                 => 4878,
                         "undergoes"               => 9385,
                         "undergoing"              => 5277,
                         "undergone"               => 6055,
                         "undergraduate"           => 2679,
                         "undergraduates"          => 9700,
                         "underground"             => 1717,
                         "undergrowth"             => 20049,
                         "underlain"               => 28814,
                         "underlie"                => 20090,
                         "underlies"               => 19413,
                         "underlying"              => 3728,
                         "undermined"              => 10078,
                         "underparts"              => 12137,
                         "underpass"               => 15810,
                         "underpinned"             => 24405,
                         "underpinning"            => 21917,
                         "underpinnings"           => 21537,
                         "underpowered"            => 22904,
                         "underrepresented"        => 24270,
                         "underscore"              => 22293,
                         "underscored"             => 23110,
                         "undersea"                => 13469,
                         "undersecretary"          => 15747,
                         "underserved"             => 18902,
                         "underside"               => 7115,
                         "undersides"              => 21104,
                         "understandings"          => 17942,
                         "understory"              => 17883,
                         "undertake"               => 6041,
                         "undertaken"              => 3654,
                         "undertakes"              => 14293,
                         "undertaking"             => 6717,
                         "undertakings"            => 16578,
                         "undertones"              => 19704,
                         "undertook"               => 4390,
                         "underwater"              => 4547,
                         "underway"                => 4799,
                         "underwent"               => 3289,
                         "underwing"               => 23255,
                         "underwriters"            => 26742,
                         "underwriting"            => 17436,
                         "undescribed"             => 21833,
                         "undesignated"            => 18268,
                         "undesirable"             => 9793,
                         "undesired"               => 24556,
                         "undetermined"            => 15778,
                         "undeterred"              => 21567,
                         "undeveloped"             => 9264,
                         "undifferentiated"        => 23484,
                         "undirected"              => 25232,
                         "undisclosed"             => 6846,
                         "undisputed"              => 10563,
                         "undistinguished"         => 22965,
                         "undisturbed"             => 13077,
                         "undocumented"            => 13338,
                         "undrafted"               => 7293,
                         "undulating"              => 13244,
                         "unearned"                => 28887,
                         "unearthed"               => 9364,
                         "unease"                  => 25907,
                         "uneconomic"              => 29021,
                         "unedited"                => 20083,
                         "unemployment"            => 4160,
                         "unenforceable"           => 29940,
                         "unequal"                 => 9984,
                         "unesco"                  => 4628,
                         "uneven"                  => 7816,
                         "unevenly"                => 28200,
                         "unexpectedly"            => 6325,
                         "unexpired"               => 24059,
                         "unexploded"              => 21086,
                         "unfavorable"             => 10749,
                         "unfavorably"             => 27016,
                         "unfavourable"            => 15788,
                         "unfolded"                => 15145,
                         "unfunded"                => 29048,
                         "unguided"                => 28698,
                         "ungulates"               => 17682,
                         "unhcr"                   => 16792,
                         "unhindered"              => 27449,
                         "unhurt"                  => 27932,
                         "uniao"                   => 18601,
                         "unicameral"              => 15281,
                         "unicef"                  => 9481,
                         "unicode"                 => 8366,
                         "unicron"                 => 17505,
                         "unidirectional"          => 26915,
                         "unido"                   => 23924,
                         "unification"             => 5803,
                         "unified"                 => 3574,
                         "unifil"                  => 29341,
                         "uniformity"              => 12039,
                         "uniformly"               => 9200,
                         "unify"                   => 11924,
                         "unifying"                => 11592,
                         "unilateral"              => 11385,
                         "unilaterally"            => 14044,
                         "unilever"                => 15313,
                         "unimpressive"            => 28955,
                         "unimproved"              => 24164,
                         "unincorporated"          => 2482,
                         "uninhabitable"           => 23918,
                         "uninhabited"             => 8300,
                         "uninjured"               => 24696,
                         "unintended"              => 13236,
                         "uninterested"            => 17884,
                         "union"                   => 288,
                         "unione"                  => 29160,
                         "unionism"                => 15375,
                         "unionist"                => 5926,
                         "unionists"               => 10443,
                         "unionized"               => 23265,
                         "unions"                  => 3060,
                         "uniontown"               => 25133,
                         "unionville"              => 24048,
                         "unique"                  => 1099,
                         "uniquely"                => 7103,
                         "uniqueness"              => 11756,
                         "unison"                  => 12507,
                         "unit"                    => 603,
                         "unita"                   => 15663,
                         "unitarian"               => 8215,
                         "unitarians"              => 24538,
                         "unitary"                 => 7173,
                         "unitas"                  => 22258,
                         "unite"                   => 6119,
                         "united"                  => 70,
                         "unites"                  => 15164,
                         "uniting"                 => 8793,
                         "units"                   => 556,
                         "unity"                   => 2957,
                         "univac"                  => 26667,
                         "universal"               => 1748,
                         "universalism"            => 24227,
                         "universalist"            => 14514,
                         "universality"            => 17015,
                         "universally"             => 6985,
                         "universals"              => 26629,
                         "universelle"             => 20085,
                         "universes"               => 12987,
                         "universiade"             => 8068,
                         "universidad"             => 6563,
                         "universidade"            => 17750,
                         "universita"              => 24938,
                         "universitaria"           => 29291,
                         "universitario"           => 15903,
                         "universitat"             => 12450,
                         "universitatea"           => 27742,
                         "universite"              => 8555,
                         "universiteit"            => 21192,
                         "universiti"              => 23591,
                         "universities"            => 1540,
                         "university"              => 69,
                         "universo"                => 25406,
                         "univision"               => 11578,
                         "unjustified"             => 21153,
                         "unknowingly"             => 13926,
                         "unknown"                 => 1280,
                         "unlawful"                => 8014,
                         "unlawfully"              => 19637,
                         "unleashes"               => 26899,
                         "unlicensed"              => 13831,
                         "unlike"                  => 1297,
                         "unlimited"               => 5737,
                         "unlockable"              => 21061,
                         "unmanned"                => 7831,
                         "unmarried"               => 6623,
                         "unmasked"                => 17532,
                         "unmatched"               => 19059,
                         "unmodified"              => 20243,
                         "unnamed"                 => 5058,
                         "unnumbered"              => 22595,
                         "unobstructed"            => 25835,
                         "unoccupied"              => 13667,
                         "unofficial"              => 4044,
                         "unofficially"            => 9326,
                         "unopposed"               => 6884,
                         "unorganized"             => 11653,
                         "unpaid"                  => 8362,
                         "unpainted"               => 27977,
                         "unpaired"                => 29102,
                         "unpaved"                 => 14623,
                         "unplaced"                => 17803,
                         "unpopular"               => 6632,
                         "unpopularity"            => 19708,
                         "unpopulated"             => 27105,
                         "unpowered"               => 24817,
                         "unprecedented"           => 5637,
                         "unproductive"            => 12146,
                         "unprofitable"            => 16114,
                         "unproven"                => 18436,
                         "unpublished"             => 7166,
                         "unquestionably"          => 21161,
                         "unranked"                => 19827,
                         "unrecognized"            => 16983,
                         "unrecorded"              => 20241,
                         "unregistered"            => 16910,
                         "unregulated"             => 17288,
                         "unrelated"               => 5143,
                         "unreleased"              => 5135,
                         "unrelenting"             => 23803,
                         "unreliability"           => 25426,
                         "unreported"              => 23045,
                         "unreserved"              => 17627,
                         "unrest"                  => 5877,
                         "unrestrained"            => 27427,
                         "unrestricted"            => 9896,
                         "unrwa"                   => 23378,
                         "unsafe"                  => 9181,
                         "unsatisfactory"          => 12628,
                         "unsaturated"             => 17807,
                         "unscientific"            => 28352,
                         "unscripted"              => 28809,
                         "unseated"                => 15170,
                         "unseeded"                => 21489,
                         "unser"                   => 14421,
                         "unsigned"                => 8819,
                         "unskilled"               => 15928,
                         "unsold"                  => 19103,
                         "unsound"                 => 22017,
                         "unspecified"             => 8913,
                         "unstaffed"               => 24691,
                         "unstressed"              => 18843,
                         "unstructured"            => 20865,
                         "unsuccessful"            => 2472,
                         "unsuccessfully"          => 4020,
                         "unsuitable"              => 8528,
                         "unsuited"                => 22004,
                         "unsupported"             => 16777,
                         "unsurpassed"             => 25376,
                         "unsurprisingly"          => 21399,
                         "unsustainable"           => 15893,
                         "untenable"               => 16116,
                         "unter"                   => 20835,
                         "unterberger"             => 27171,
                         "until"                   => 102,
                         "untitled"                => 10970,
                         "untreated"               => 13107,
                         "unusable"                => 14360,
                         "unused"                  => 6459,
                         "unusually"               => 4940,
                         "unveiled"                => 4208,
                         "unwell"                  => 24899,
                         "unwilling"               => 6913,
                         "unwillingly"             => 26337,
                         "unwillingness"           => 14885,
                         "unwin"                   => 18190,
                         "unworkable"              => 28790,
                         "upanishad"               => 14457,
                         "upanishads"              => 18711,
                         "upazila"                 => 11116,
                         "upcoming"                => 3239,
                         "updated"                 => 3131,
                         "updates"                 => 5372,
                         "updating"                => 10828,
                         "upendra"                 => 23422,
                         "upgrade"                 => 4377,
                         "upgraded"                => 3437,
                         "upgrades"                => 6483,
                         "upgrading"               => 8472,
                         "upheaval"                => 12692,
                         "upheavals"               => 19298,
                         "upheld"                  => 5990,
                         "upholding"               => 13860,
                         "upholds"                 => 29710,
                         "upjohn"                  => 27327,
                         "upkeep"                  => 10741,
                         "upland"                  => 8373,
                         "uplands"                 => 12103,
                         "uplift"                  => 11521,
                         "uplifted"                => 19899,
                         "upload"                  => 11726,
                         "uploaded"                => 7972,
                         "upmarket"                => 18956,
                         "upon"                    => 379,
                         "upper"                   => 730,
                         "uppercase"               => 24224,
                         "uppermost"               => 16247,
                         "upperparts"              => 17081,
                         "upperside"               => 13815,
                         "uppland"                 => 24993,
                         "uppsala"                 => 8708,
                         "uprated"                 => 28648,
                         "upright"                 => 6142,
                         "uprising"                => 3420,
                         "uprisings"               => 10589,
                         "upriver"                 => 13670,
                         "upsilon"                 => 19111,
                         "upstream"                => 4999,
                         "upsurge"                 => 22885,
                         "uptake"                  => 11764,
                         "uptempo"                 => 15877,
                         "upturned"                => 24677,
                         "upward"                  => 7065,
                         "upwards"                 => 6590,
                         "upwelling"               => 24338,
                         "uralic"                  => 20854,
                         "urals"                   => 18555,
                         "urania"                  => 27201,
                         "uranium"                 => 4900,
                         "urban"                   => 932,
                         "urbana"                  => 9408,
                         "urbanisation"            => 19426,
                         "urbanised"               => 28280,
                         "urbanism"                => 15863,
                         "urbanization"            => 11137,
                         "urbanized"               => 13775,
                         "urbino"                  => 18020,
                         "urchins"                 => 19200,
                         "urdu"                    => 5326,
                         "urged"                   => 4296,
                         "urgell"                  => 29276,
                         "urging"                  => 6280,
                         "uriah"                   => 19738,
                         "uriel"                   => 25544,
                         "urinary"                 => 11582,
                         "urmia"                   => 17714,
                         "urology"                 => 19218,
                         "urquiza"                 => 27116,
                         "urraca"                  => 24897,
                         "ursuline"                => 22629,
                         "ursus"                   => 22184,
                         "uruguay"                 => 4192,
                         "uruguayan"               => 7627,
                         "urumqi"                  => 23027,
                         "usaaf"                   => 10665,
                         "usability"               => 14764,
                         "usable"                  => 8189,
                         "usafe"                   => 22039,
                         "usage"                   => 2318,
                         "usages"                  => 16351,
                         "usaid"                   => 13155,
                         "uscgc"                   => 16143,
                         "use"                     => 129,
                         "used"                    => 64,
                         "useful"                  => 2220,
                         "usefulness"              => 10952,
                         "usenet"                  => 17448,
                         "user"                    => 1567,
                         "users"                   => 1463,
                         "uses"                    => 713,
                         "ushered"                 => 13885,
                         "using"                   => 274,
                         "usisl"                   => 19555,
                         "usman"                   => 18359,
                         "uspto"                   => 26131,
                         "ussr"                    => 3741,
                         "ustad"                   => 15271,
                         "ustase"                  => 17028,
                         "ustinov"                 => 23362,
                         "usually"                 => 432,
                         "usurpation"              => 22980,
                         "usurped"                 => 15820,
                         "usurper"                 => 17217,
                         "usury"                   => 25203,
                         "utada"                   => 21247,
                         "utah"                    => 2152,
                         "utama"                   => 29906,
                         "uterine"                 => 14720,
                         "uther"                   => 29611,
                         "uthman"                  => 16052,
                         "utica"                   => 10729,
                         "utilisation"             => 22080,
                         "utilise"                 => 14826,
                         "utilised"                => 9897,
                         "utilises"                => 20474,
                         "utilising"               => 13890,
                         "utilitarian"             => 13351,
                         "utilitarianism"          => 23936,
                         "utilities"               => 5707,
                         "utility"                 => 3468,
                         "utilization"             => 9125,
                         "utilize"                 => 5782,
                         "utilized"                => 4310,
                         "utilizes"                => 7230,
                         "utilizing"               => 5932,
                         "utopian"                 => 11852,
                         "utrecht"                 => 6524,
                         "utricularia"             => 20086,
                         "uttar"                   => 5424,
                         "uttara"                  => 23076,
                         "uttarakhand"             => 12189,
                         "utterance"               => 18013,
                         "utterances"              => 20556,
                         "uttering"                => 23846,
                         "uxbridge"                => 12147,
                         "uyezd"                   => 15942,
                         "uyezds"                  => 28514,
                         "uyghur"                  => 11289,
                         "uyghurs"                 => 16623,
                         "uzbek"                   => 10374,
                         "uzbekistan"              => 6556,
                         "uzbeks"                  => 24934,
                         "uzice"                   => 27968,
                         "v/line"                  => 26954,
                         "vaasa"                   => 25965,
                         "vacancies"               => 10153,
                         "vacancy"                 => 5242,
                         "vacant"                  => 4269,
                         "vacated"                 => 5847,
                         "vacationers"             => 29383,
                         "vaccination"             => 10364,
                         "vaccinations"            => 23187,
                         "vaccines"                => 9434,
                         "vaccinium"               => 25206,
                         "vaclav"                  => 13537,
                         "vacuum"                  => 4496,
                         "vadodara"                => 20343,
                         "vagrant"                 => 16268,
                         "vagrants"                => 26240,
                         "vagueness"               => 29683,
                         "vagus"                   => 27793,
                         "vaikundar"               => 27267,
                         "vaillant"                => 26137,
                         "vaishali"                => 29385,
                         "vaishnava"               => 17767,
                         "vaishnavism"             => 24253,
                         "vajpayee"                => 24280,
                         "vajrayana"               => 21989,
                         "vakhtang"                => 25505,
                         "valais"                  => 15213,
                         "valar"                   => 29418,
                         "valdosta"                => 21362,
                         "vale"                    => 3826,
                         "valea"                   => 8750,
                         "valence"                 => 10685,
                         "valencian"               => 11338,
                         "valenciennes"            => 18529,
                         "valens"                  => 19964,
                         "valentinian"             => 21429,
                         "valerenga"               => 22025,
                         "valerian"                => 16068,
                         "valiants"                => 27823,
                         "valid"                   => 3409,
                         "validated"               => 10622,
                         "validating"              => 24550,
                         "validation"              => 9379,
                         "validity"                => 5785,
                         "validly"                 => 25674,
                         "valladolid"              => 11008,
                         "vallecano"               => 28671,
                         "valley"                  => 510,
                         "valleys"                 => 4468,
                         "valli"                   => 16671,
                         "vallis"                  => 28325,
                         "valmiki"                 => 27457,
                         "valour"                  => 14025,
                         "valparaiso"              => 10389,
                         "valuation"               => 8766,
                         "valuations"              => 25588,
                         "value"                   => 850,
                         "valued"                  => 4075,
                         "values"                  => 1557,
                         "valuing"                 => 22511,
                         "valve"                   => 3839,
                         "valves"                  => 6169,
                         "vampiric"                => 29298,
                         "vanadium"                => 18732,
                         "vanbrugh"                => 26321,
                         "vancouver"               => 2229,
                         "vandalised"              => 25810,
                         "vandals"                 => 11018,
                         "vanden"                  => 29062,
                         "vanderbilt"              => 5858,
                         "vandross"                => 25401,
                         "vannes"                  => 29132,
                         "vantaa"                  => 29973,
                         "vanuatu"                 => 9361,
                         "vapor"                   => 7544,
                         "vapour"                  => 15666,
                         "varanasi"                => 11780,
                         "varazdin"                => 24889,
                         "vardar"                  => 18092,
                         "varese"                  => 12800,
                         "variability"             => 9308,
                         "variable"                => 2677,
                         "variables"               => 3783,
                         "variably"                => 27033,
                         "variance"                => 7662,
                         "variances"               => 22821,
                         "variant"                 => 2962,
                         "variants"                => 3200,
                         "variation"               => 2890,
                         "variational"             => 26373,
                         "variations"              => 2670,
                         "varied"                  => 3175,
                         "variegated"              => 21543,
                         "varies"                  => 3249,
                         "varietal"                => 22638,
                         "varieties"               => 3298,
                         "variety"                 => 726,
                         "various"                 => 272,
                         "variously"               => 5885,
                         "varma"                   => 10327,
                         "varman"                  => 28604,
                         "varmland"                => 29925,
                         "varna"                   => 11284,
                         "varro"                   => 25445,
                         "varsity"                 => 4147,
                         "varun"                   => 24808,
                         "varuna"                  => 25235,
                         "vary"                    => 2595,
                         "varying"                 => 3360,
                         "varzim"                  => 20338,
                         "vasant"                  => 25937,
                         "vasari"                  => 18753,
                         "vasco"                   => 10000,
                         "vasconcelos"             => 21987,
                         "vascular"                => 7526,
                         "vases"                   => 12875,
                         "vashem"                  => 21635,
                         "vasily"                  => 11085,
                         "vasilyevich"             => 29094,
                         "vaslui"                  => 23088,
                         "vassal"                  => 8026,
                         "vassals"                 => 11594,
                         "vast"                    => 2435,
                         "vasteras"                => 23176,
                         "vastly"                  => 8817,
                         "vastra"                  => 18052,
                         "vasudeva"                => 28961,
                         "vasyl"                   => 24862,
                         "vatican"                 => 4345,
                         "vauban"                  => 24875,
                         "vaucluse"                => 21603,
                         "vaudeville"              => 7798,
                         "vaudreuil"               => 25899,
                         "vaulted"                 => 10670,
                         "vaulter"                 => 26832,
                         "vaulting"                => 17769,
                         "vaults"                  => 10203,
                         "vaxjo"                   => 29265,
                         "veblen"                  => 28436,
                         "vectors"                 => 6435,
                         "vedanta"                 => 12766,
                         "vedas"                   => 13232,
                         "vedic"                   => 8275,
                         "veena"                   => 18925,
                         "veera"                   => 21447,
                         "veers"                   => 20586,
                         "vegan"                   => 12991,
                         "vegetarianism"           => 19690,
                         "vegetated"               => 21863,
                         "vegetation"              => 3661,
                         "vegetative"              => 14256,
                         "vehement"                => 21719,
                         "vehemently"              => 13072,
                         "vehicle"                 => 1334,
                         "vehicles"                => 1344,
                         "vehicular"               => 11046,
                         "veikkausliiga"           => 24201,
                         "vein"                    => 5509,
                         "veined"                  => 25687,
                         "vejle"                   => 24574,
                         "velar"                   => 17370,
                         "velde"                   => 22431,
                         "veldenz"                 => 24770,
                         "velho"                   => 29044,
                         "velika"                  => 18971,
                         "veliki"                  => 21408,
                         "veliko"                  => 24931,
                         "vellore"                 => 17926,
                         "vellum"                  => 22236,
                         "velocities"              => 11713,
                         "velocity"                => 3626,
                         "velodrome"               => 14874,
                         "veloso"                  => 25022,
                         "velvety"                 => 25920,
                         "venables"                => 20749,
                         "vendee"                  => 17522,
                         "vendome"                 => 18493,
                         "vendors"                 => 6054,
                         "venerable"               => 9412,
                         "venerated"               => 10527,
                         "veneration"              => 10318,
                         "veneta"                  => 25562,
                         "venetia"                 => 21359,
                         "venetian"                => 5683,
                         "venetians"               => 13541,
                         "veneto"                  => 9978,
                         "venezuela"               => 3043,
                         "venezuelan"              => 5497,
                         "venezuelans"             => 27446,
                         "venizelos"               => 19806,
                         "venkata"                 => 19692,
                         "venkatesh"               => 19223,
                         "venkateswara"            => 22098,
                         "venlo"                   => 22034,
                         "venomous"                => 10720,
                         "venous"                  => 13459,
                         "venta"                   => 28324,
                         "venter"                  => 20062,
                         "ventilation"             => 7385,
                         "ventral"                 => 8112,
                         "ventrally"               => 20703,
                         "ventricles"              => 23510,
                         "ventricular"             => 12685,
                         "ventrites"               => 18230,
                         "ventspils"               => 22725,
                         "venture"                 => 2373,
                         "ventured"                => 9947,
                         "ventures"                => 4469,
                         "venturing"               => 16767,
                         "venue"                   => 2293,
                         "venues"                  => 2971,
                         "veolia"                  => 23017,
                         "veracruz"                => 7998,
                         "verandah"                => 12687,
                         "verandahs"               => 21291,
                         "verano"                  => 20449,
                         "verb"                    => 4335,
                         "verbally"                => 11510,
                         "verband"                 => 26920,
                         "verbandsgemeinde"        => 11203,
                         "verbandsliga"            => 21010,
                         "verbs"                   => 5730,
                         "vercelli"                => 19631,
                         "verde"                   => 6285,
                         "verdean"                 => 21390,
                         "verden"                  => 21808,
                         "verdes"                  => 18654,
                         "verdicts"                => 18434,
                         "verein"                  => 20352,
                         "veria"                   => 25966,
                         "verifiable"              => 18348,
                         "verification"            => 7994,
                         "verified"                => 7246,
                         "verite"                  => 23503,
                         "verkhovna"               => 18515,
                         "verlag"                  => 12320,
                         "verlaine"                => 26197,
                         "vermilion"               => 13184,
                         "vernacular"              => 6440,
                         "vernal"                  => 17791,
                         "vernet"                  => 25308,
                         "verney"                  => 21496,
                         "veronese"                => 21466,
                         "versailles"              => 6622,
                         "versatile"               => 7683,
                         "versatility"             => 10818,
                         "verse"                   => 2874,
                         "verses"                  => 4163,
                         "version"                 => 306,
                         "versions"                => 1117,
                         "verso"                   => 25193,
                         "versus"                  => 1903,
                         "vertebra"                => 17633,
                         "vertebrae"               => 9073,
                         "vertebral"               => 15368,
                         "vertebrate"              => 10436,
                         "vertebrates"             => 9575,
                         "vertex"                  => 6767,
                         "vertical"                => 2601,
                         "vertically"              => 7169,
                         "vertices"                => 6526,
                         "verve"                   => 13305,
                         "verwaltungsgemeinschaft" => 24876,
                         "vesicle"                 => 20038,
                         "vesicles"                => 14549,
                         "vespasian"               => 18291,
                         "vessel"                  => 2143,
                         "vessels"                 => 2091,
                         "vestfold"                => 21486,
                         "vestibular"              => 19480,
                         "vestige"                 => 27976,
                         "vestiges"                => 15290,
                         "vestments"               => 17900,
                         "vestry"                  => 11474,
                         "veszprem"                => 26579,
                         "vetch"                   => 28773,
                         "veteran"                 => 2735,
                         "veterans"                => 2827,
                         "veterinarians"           => 20894,
                         "veterinary"              => 5947,
                         "vetoed"                  => 11872,
                         "vettel"                  => 12762,
                         "vetting"                 => 28195,
                         "vexillum"                => 21714,
                         "vfl/afl"                 => 24469,
                         "via"                     => 576,
                         "viability"               => 9908,
                         "viable"                  => 5428,
                         "viacom"                  => 12488,
                         "viaduct"                 => 6937,
                         "viaducts"                => 20214,
                         "viareggio"               => 21815,
                         "viasat"                  => 29212,
                         "vibrant"                 => 7515,
                         "vibraphone"              => 24994,
                         "vibration"               => 7900,
                         "vibrational"             => 18200,
                         "vibrato"                 => 18465,
                         "vicar"                   => 4716,
                         "vicarage"                => 13336,
                         "vicariate"               => 12471,
                         "vice"                    => 888,
                         "vicenza"                 => 12975,
                         "viceroy"                 => 6520,
                         "viceroyalty"             => 13932,
                         "viceroys"                => 28794,
                         "vichy"                   => 9231,
                         "vicinity"                => 3670,
                         "vicomte"                 => 26386,
                         "victimization"           => 22333,
                         "victims"                 => 2023,
                         "victorian"               => 2211,
                         "victorians"              => 25871,
                         "victorias"               => 28978,
                         "victories"               => 2958,
                         "victorious"              => 5055,
                         "victors"                 => 14728,
                         "vidarbha"                => 24804,
                         "video"                   => 341,
                         "videogame"               => 16938,
                         "videography"             => 25383,
                         "videos"                  => 2167,
                         "vidhan"                  => 7382,
                         "vidin"                   => 24541,
                         "vidya"                   => 12607,
                         "vidyalaya"               => 12829,
                         "vidyasagar"              => 24864,
                         "vieja"                   => 27131,
                         "viejo"                   => 14097,
                         "vienna"                  => 2003,
                         "vienne"                  => 14056,
                         "viennese"                => 11122,
                         "vientiane"               => 16556,
                         "vieques"                 => 25874,
                         "vietcong"                => 28749,
                         "vietnam"                 => 1504,
                         "vietnamese"              => 3078,
                         "vieux"                   => 16982,
                         "view"                    => 772,
                         "viewable"                => 19886,
                         "viewed"                  => 2306,
                         "viewer"                  => 5033,
                         "viewers"                 => 2335,
                         "viewership"              => 10368,
                         "viewfinder"              => 21190,
                         "viewing"                 => 3971,
                         "viewpoint"               => 7491,
                         "viewpoints"              => 11305,
                         "views"                   => 1544,
                         "viggo"                   => 25699,
                         "vignette"                => 23254,
                         "vignettes"               => 15148,
                         "vigor"                   => 14982,
                         "vigorous"                => 7708,
                         "vigorously"              => 9839,
                         "vigour"                  => 18955,
                         "vihar"                   => 18593,
                         "vihara"                  => 22931,
                         "viii"                    => 3721,
                         "vijay"                   => 7157,
                         "vijaya"                  => 12954,
                         "vijayan"                 => 26274,
                         "vijayanagar"             => 23222,
                         "vijayanagara"            => 18396,
                         "vijayawada"              => 16755,
                         "vikas"                   => 20129,
                         "vikram"                  => 11199,
                         "vikramaditya"            => 25102,
                         "vilaine"                 => 24609,
                         "vilas"                   => 21083,
                         "vilayet"                 => 16509,
                         "vilhelm"                 => 21836,
                         "viljandi"                => 29974,
                         "village"                 => 168,
                         "villager"                => 19030,
                         "villagers"               => 4563,
                         "villages"                => 1219,
                         "villain"                 => 5013,
                         "villainous"              => 12340,
                         "villains"                => 5942,
                         "villars"                 => 23430,
                         "villas"                  => 8957,
                         "ville"                   => 8028,
                         "villers"                 => 18049,
                         "villiers"                => 9888,
                         "vilna"                   => 17851,
                         "vilnius"                 => 7425,
                         "vinay"                   => 23966,
                         "vinaya"                  => 25915,
                         "vineland"                => 27382,
                         "vineyards"               => 6861,
                         "vinifera"                => 29088,
                         "vinnytsia"               => 29515,
                         "vinod"                   => 15203,
                         "vinyl"                   => 3473,
                         "violas"                  => 27491,
                         "violations"              => 4804,
                         "violators"               => 24072,
                         "violence"                => 1588,
                         "violently"               => 8665,
                         "violinist"               => 6210,
                         "violinists"              => 20983,
                         "violins"                 => 10967,
                         "violist"                 => 21285,
                         "viral"                   => 5182,
                         "virginian"               => 15717,
                         "virginians"              => 25292,
                         "viridis"                 => 24695,
                         "virology"                => 21650,
                         "virtual"                 => 2562,
                         "virtualization"          => 14099,
                         "virtually"               => 3116,
                         "virtues"                 => 7874,
                         "virtuosic"               => 27405,
                         "virtuosity"              => 17938,
                         "virtuoso"                => 10695,
                         "virtus"                  => 21398,
                         "virulence"               => 19898,
                         "viruses"                 => 6446,
                         "visakhapatnam"           => 15797,
                         "visalia"                 => 22388,
                         "visas"                   => 10586,
                         "visayan"                 => 22012,
                         "visayas"                 => 14708,
                         "visby"                   => 27452,
                         "viscosity"               => 11026,
                         "viscount"                => 4594,
                         "viscountcy"              => 28702,
                         "viscountess"             => 24761,
                         "viscounts"               => 23211,
                         "viscous"                 => 14051,
                         "visegrad"                => 24311,
                         "viseu"                   => 27475,
                         "vishnu"                  => 6186,
                         "visibility"              => 6173,
                         "visible"                 => 2079,
                         "visibly"                 => 11225,
                         "visigothic"              => 17870,
                         "visigoths"               => 18478,
                         "visionaries"             => 27728,
                         "visionary"               => 9533,
                         "visitations"             => 27512,
                         "visited"                 => 1410,
                         "visiting"                => 2040,
                         "visitors"                => 1853,
                         "visits"                  => 2826,
                         "vista"                   => 4800,
                         "vistas"                  => 18801,
                         "vistula"                 => 12532,
                         "visual"                  => 1601,
                         "visualization"           => 9993,
                         "visualized"              => 18560,
                         "visually"                => 6522,
                         "visuals"                 => 10139,
                         "viswanathan"             => 19098,
                         "vital"                   => 3369,
                         "vitality"                => 11935,
                         "vitaphone"               => 27988,
                         "vitebsk"                 => 18640,
                         "viterbo"                 => 19821,
                         "viticultural"            => 22714,
                         "viticulture"             => 15404,
                         "vitis"                   => 18814,
                         "vitor"                   => 22699,
                         "vitoria"                 => 10316,
                         "vitreous"                => 21270,
                         "vitro"                   => 8604,
                         "vitruvius"               => 24651,
                         "vitus"                   => 22062,
                         "vivek"                   => 18511,
                         "vivekananda"             => 11723,
                         "vivendi"                 => 21480,
                         "viviparous"              => 25435,
                         "vizcaya"                 => 22995,
                         "vizianagaram"            => 28344,
                         "vizier"                  => 10137,
                         "vlaanderen"              => 29931,
                         "vlachs"                  => 20909,
                         "vladikavkaz"             => 26223,
                         "vladimirovich"           => 16300,
                         "vladivostok"             => 13895,
                         "vliet"                   => 27004,
                         "vlore"                   => 23042,
                         "vmware"                  => 20950,
                         "vocabularies"            => 29561,
                         "vocal"                   => 2069,
                         "vocalist"                => 2803,
                         "vocalists"               => 8842,
                         "vocalization"            => 24563,
                         "vocalizations"           => 21064,
                         "vocally"                 => 17615,
                         "vocals"                  => 1654,
                         "vocational"              => 4671,
                         "vocations"               => 21868,
                         "vodacom"                 => 14841,
                         "vodou"                   => 25403,
                         "vogue"                   => 6599,
                         "voiced"                  => 3154,
                         "voiceless"               => 12403,
                         "voiceover"               => 15736,
                         "voicing"                 => 11153,
                         "voided"                  => 20604,
                         "voids"                   => 20210,
                         "voivode"                 => 15664,
                         "voivodeship"             => 1520,
                         "vojislav"                => 28432,
                         "vojvodina"               => 9731,
                         "vol.1"                   => 28081,
                         "volador"                 => 23252,
                         "volatility"              => 13037,
                         "volcanic"                => 3946,
                         "volcanics"               => 27310,
                         "volcanism"               => 16297,
                         "volcano"                 => 4915,
                         "volcanoes"               => 8051,
                         "voles"                   => 22355,
                         "volga"                   => 8664,
                         "volhynia"                => 17167,
                         "volkoff"                 => 27827,
                         "volleyball"              => 2871,
                         "volleys"                 => 26264,
                         "volodymyr"               => 15934,
                         "volos"                   => 28168,
                         "vols."                   => 17687,
                         "volta"                   => 10469,
                         "voltage"                 => 3451,
                         "voltages"                => 12448,
                         "volterra"                => 27209,
                         "volume"                  => 1129,
                         "volumes"                 => 2291,
                         "volumetric"              => 19151,
                         "voluminous"              => 17468,
                         "voluntary"               => 3883,
                         "volunteer"               => 2312,
                         "volunteerism"            => 26379,
                         "volunteers"              => 2378,
                         "volusia"                 => 27563,
                         "volyn"                   => 29644,
                         "voracious"               => 24177,
                         "vorarlberg"              => 23971,
                         "voronezh"                => 15988,
                         "vorpommern"              => 12974,
                         "vortices"                => 22406,
                         "vosges"                  => 14289,
                         "vosta"                   => 23232,
                         "vote"                    => 925,
                         "voted"                   => 1662,
                         "voter"                   => 5063,
                         "voters"                  => 2397,
                         "votes"                   => 1261,
                         "voting"                  => 2255,
                         "votive"                  => 17148,
                         "vowel"                   => 4847,
                         "vowels"                  => 5487,
                         "voyage"                  => 3318,
                         "voyages"                 => 7689,
                         "voyageurs"               => 22993,
                         "vries"                   => 15235,
                         "vriesea"                 => 23134,
                         "vrije"                   => 28813,
                         "vuelta"                  => 11747,
                         "vuitton"                 => 18381,
                         "vukovar"                 => 20367,
                         "vulcans"                 => 27639,
                         "vulgaris"                => 16677,
                         "vulgarity"               => 29600,
                         "vulgate"                 => 16579,
                         "vulnerabilities"         => 14931,
                         "vyacheslav"              => 15627,
                         "vyasa"                   => 28026,
                         "vyborg"                  => 24158,
                         "vysocina"                => 26101,
                         "vytautas"                => 17515,
                         "w.a.k.o"                 => 28803,
                         "waals"                   => 22181,
                         "wabash"                  => 10608,
                         "waclaw"                  => 29492,
                         "waders"                  => 19166,
                         "wadham"                  => 18244,
                         "wadia"                   => 24937,
                         "wafers"                  => 20996,
                         "waffen"                  => 11346,
                         "waged"                   => 10896,
                         "wagga"                   => 13170,
                         "wagnerian"               => 29957,
                         "wagons"                  => 5823,
                         "wahab"                   => 25073,
                         "waheed"                  => 26074,
                         "wahhabi"                 => 29131,
                         "wahid"                   => 19682,
                         "waikato"                 => 10337,
                         "wailers"                 => 23195,
                         "wairarapa"               => 17674,
                         "waistcoat"               => 28559,
                         "waitakere"               => 26143,
                         "waitangi"                => 19728,
                         "waived"                  => 6684,
                         "waiver"                  => 12622,
                         "waivers"                 => 10090,
                         "wakayama"                => 19721,
                         "waldegrave"              => 24883,
                         "wales"                   => 768,
                         "walesa"                  => 25844,
                         "walgreens"               => 28550,
                         "walid"                   => 13699,
                         "walkers"                 => 9168,
                         "walkout"                 => 29956,
                         "walkover"                => 26816,
                         "walkway"                 => 9835,
                         "walkways"                => 13810,
                         "wallabies"               => 14580,
                         "wallachia"               => 12896,
                         "wallachian"              => 22352,
                         "walled"                  => 6819,
                         "wallenberg"              => 21206,
                         "wallonia"                => 14285,
                         "walloon"                 => 12748,
                         "wallsend"                => 24648,
                         "walsall"                 => 9005,
                         "walsingham"              => 16162,
                         "walt"                    => 3954,
                         "waltham"                 => 11021,
                         "walthamstow"             => 19447,
                         "wampanoag"               => 25103,
                         "wanderers"               => 4988,
                         "wanderings"              => 26995,
                         "wandsworth"              => 15733,
                         "waned"                   => 11957,
                         "wanganui"                => 16606,
                         "wantage"                 => 29679,
                         "wapping"                 => 28946,
                         "war"                     => 84,
                         "warangal"                => 20363,
                         "waratah"                 => 25727,
                         "waratahs"                => 22911,
                         "warbler"                 => 10242,
                         "warblers"                => 13960,
                         "warburg"                 => 15109,
                         "wardens"                 => 17191,
                         "wards"                   => 4427,
                         "warehouses"              => 8452,
                         "warehousing"             => 17381,
                         "wares"                   => 12712,
                         "warfare"                 => 2866,
                         "wargame"                 => 23570,
                         "wargaming"               => 27007,
                         "warlike"                 => 17871,
                         "warlords"                => 12560,
                         "warmian"                 => 8524,
                         "warminster"              => 26689,
                         "warmly"                  => 13464,
                         "warners"                 => 23886,
                         "warnings"                => 6455,
                         "warns"                   => 7266,
                         "warping"                 => 20521,
                         "warplanes"               => 29785,
                         "warrenton"               => 24373,
                         "warring"                 => 10704,
                         "warringah"               => 17206,
                         "warrnambool"             => 23515,
                         "wars"                    => 1634,
                         "warsaw"                  => 2760,
                         "warship"                 => 7595,
                         "warships"                => 5792,
                         "warta"                   => 26623,
                         "wartime"                 => 4225,
                         "warwickshire"            => 6151,
                         "was"                     => 5,
                         "wasatch"                 => 20148,
                         "waseda"                  => 20630,
                         "washers"                 => 26537,
                         "washoe"                  => 22319,
                         "wasps"                   => 8490,
                         "wastes"                  => 11715,
                         "wastewater"              => 9194,
                         "wataru"                  => 28768,
                         "watauga"                 => 25264,
                         "watchmaker"              => 20240,
                         "watchtower"              => 15850,
                         "water"                   => 228,
                         "waterbirds"              => 25663,
                         "watercolor"              => 12093,
                         "watercolors"             => 15091,
                         "watercolour"             => 13836,
                         "watercolours"            => 16692,
                         "watercourse"             => 19983,
                         "watercourses"            => 20261,
                         "watercraft"              => 19650,
                         "waterfall"               => 6234,
                         "waterfalls"              => 8370,
                         "waterford"               => 6400,
                         "waterfowl"               => 11699,
                         "waterfront"              => 6085,
                         "waterline"               => 12381,
                         "waterlogged"             => 24342,
                         "watermark"               => 23225,
                         "watermill"               => 18733,
                         "watermills"              => 29577,
                         "waterpark"               => 24561,
                         "watershed"               => 4135,
                         "watersheds"              => 15952,
                         "waterside"               => 18673,
                         "watertight"              => 18032,
                         "watertown"               => 12327,
                         "waterville"              => 19672,
                         "waterway"                => 7824,
                         "waterways"               => 7273,
                         "waterwheel"              => 23481,
                         "watling"                 => 19547,
                         "wattle"                  => 15549,
                         "waukegan"                => 29374,
                         "waukesha"                => 21141,
                         "wausau"                  => 22378,
                         "wave"                    => 1676,
                         "waveform"                => 15264,
                         "waveforms"               => 22828,
                         "wavefunction"            => 24345,
                         "waveguide"               => 19264,
                         "wavelength"              => 6837,
                         "wavelengths"             => 9222,
                         "wavelet"                 => 21554,
                         "wavell"                  => 27265,
                         "waverley"                => 11428,
                         "waves"                   => 2946,
                         "wawel"                   => 28729,
                         "wawrinka"                => 28541,
                         "wayanad"                 => 29247,
                         "wayang"                  => 29228,
                         "wayans"                  => 25686,
                         "waynesboro"              => 24417,
                         "wazir"                   => 21347,
                         "waziristan"              => 20481,
                         "weakened"                => 4593,
                         "weakening"               => 8165,
                         "weakens"                 => 23954,
                         "weakly"                  => 11158,
                         "weald"                   => 16066,
                         "wealth"                  => 2615,
                         "wealthier"               => 14080,
                         "wealthiest"              => 9226,
                         "wealthy"                 => 2586,
                         "weaned"                  => 26096,
                         "weaponry"                => 8363,
                         "weapons"                 => 1420,
                         "wearable"                => 20852,
                         "wearer"                  => 11622,
                         "weather"                 => 1496,
                         "weatherboard"            => 23125,
                         "weatherfield"            => 27615,
                         "weathering"              => 13017,
                         "weavers"                 => 10736,
                         "weaves"                  => 19730,
                         "weaving"                 => 6799,
                         "web.com"                 => 25568,
                         "webbed"                  => 16178,
                         "webcast"                 => 19711,
                         "webcomic"                => 17948,
                         "webern"                  => 29548,
                         "webisodes"               => 27570,
                         "weblog"                  => 26408,
                         "webpage"                 => 14878,
                         "website"                 => 988,
                         "websites"                => 3895,
                         "wedgwood"                => 15623,
                         "wednesbury"              => 27166,
                         "weekday"                 => 5989,
                         "weekdays"                => 7063,
                         "weeklies"                => 24070,
                         "weekly"                  => 1386,
                         "weeknight"               => 18110,
                         "weeknights"              => 18080,
                         "weevils"                 => 28309,
                         "wehrmacht"               => 7177,
                         "weibo"                   => 21204,
                         "weierstrass"             => 27307,
                         "weighed"                 => 5780,
                         "weight"                  => 1391,
                         "weighted"                => 7510,
                         "weighting"               => 15886,
                         "weightlifter"            => 15744,
                         "weightlifting"           => 8354,
                         "weights"                 => 6334,
                         "weilburg"                => 29147,
                         "weill"                   => 14031,
                         "weimar"                  => 7221,
                         "weirs"                   => 21995,
                         "weizmann"                => 19035,
                         "wejherowo"               => 27358,
                         "welbeck"                 => 29205,
                         "welby"                   => 23520,
                         "welcomed"                => 4674,
                         "welcomes"                => 12167,
                         "welded"                  => 9809,
                         "welding"                 => 8202,
                         "welfare"                 => 2791,
                         "welland"                 => 15437,
                         "wellbeing"               => 16125,
                         "wellesley"               => 9050,
                         "wellingborough"          => 26397,
                         "wellington"              => 3012,
                         "wellness"                => 8514,
                         "welshpool"               => 29328,
                         "welterweight"            => 7507,
                         "welwyn"                  => 22351,
                         "wembley"                 => 6013,
                         "wemyss"                  => 19613,
                         "wenatchee"               => 20922,
                         "wenceslas"               => 29751,
                         "wenceslaus"              => 15919,
                         "wenders"                 => 29316,
                         "wendover"                => 22571,
                         "wenlock"                 => 22967,
                         "wenzhou"                 => 27290,
                         "wenzong"                 => 22391,
                         "were"                    => 17,
                         "werft"                   => 25219,
                         "werke"                   => 19189,
                         "werribee"                => 23433,
                         "weser"                   => 14186,
                         "wesleyan"                => 6902,
                         "wessex"                  => 9024,
                         "westbound"               => 8393,
                         "westbourne"              => 26323,
                         "westchester"             => 8560,
                         "westerly"                => 10213,
                         "western"                 => 262,
                         "westerner"               => 28811,
                         "westerners"              => 13661,
                         "westernmost"             => 10396,
                         "westerns"                => 11767,
                         "westfalen"               => 26327,
                         "westinghouse"            => 10031,
                         "westland"                => 11866,
                         "westmeath"               => 14030,
                         "westminster"             => 3263,
                         "westmorland"             => 13534,
                         "westmount"               => 26180,
                         "westpac"                 => 17276,
                         "westphalia"              => 7467,
                         "westphalian"             => 21653,
                         "wests"                   => 15973,
                         "westville"               => 28618,
                         "westward"                => 5310,
                         "westwards"               => 11037,
                         "wethersfield"            => 28966,
                         "wetland"                 => 7492,
                         "wetlands"                => 5701,
                         "wettest"                 => 14991,
                         "wettin"                  => 26989,
                         "wexford"                 => 7780,
                         "weybridge"               => 28066,
                         "weyden"                  => 29642,
                         "wftda"                   => 26621,
                         "whalers"                 => 10668,
                         "whaling"                 => 7974,
                         "whampoa"                 => 25108,
                         "whangarei"               => 24297,
                         "wharf"                   => 6331,
                         "whatcom"                 => 29767,
                         "wheatbelt"               => 26411,
                         "wheatland"               => 24219,
                         "whedon"                  => 14279,
                         "wheelbase"               => 9426,
                         "wheeled"                 => 8743,
                         "wheelers"                => 20194,
                         "wheldon"                 => 26536,
                         "whelks"                  => 25035,
                         "when"                    => 39,
                         "where"                   => 56,
                         "whereas"                 => 1940,
                         "whereby"                 => 4688,
                         "wherein"                 => 6148,
                         "whereupon"               => 8691,
                         "which"                   => 19,
                         "whidbey"                 => 24211,
                         "whigs"                   => 11988,
                         "while"                   => 71,
                         "whilst"                  => 1796,
                         "whisperer"               => 24962,
                         "whistleblower"           => 15958,
                         "whistleblowers"          => 26298,
                         "whitecaps"               => 13624,
                         "whitechapel"             => 13468,
                         "whitefish"               => 16315,
                         "whitehall"               => 9786,
                         "whitehaven"              => 18446,
                         "whitehorse"              => 17653,
                         "whites"                  => 4948,
                         "whitestone"              => 29184,
                         "whitewashed"             => 21584,
                         "whitewater"              => 11296,
                         "whitish"                 => 6720,
                         "whitlam"                 => 15162,
                         "who"                     => 32,
                         "wholesale"               => 6115,
                         "wholesalers"             => 19402,
                         "wholly"                  => 4819,
                         "whom"                    => 638,
                         "whorl"                   => 11623,
                         "whorls"                  => 9469,
                         "whose"                   => 560,
                         "wichita"                 => 6607,
                         "wicket"                  => 4137,
                         "wicketkeeper"            => 19213,
                         "wickets"                 => 3271,
                         "wicklow"                 => 12094,
                         "wide"                    => 625,
                         "widely"                  => 1000,
                         "widened"                 => 7913,
                         "widening"                => 8548,
                         "widens"                  => 16425,
                         "wider"                   => 2790,
                         "wideroe"                 => 23418,
                         "widescreen"              => 12066,
                         "widespread"              => 2190,
                         "widest"                  => 10248,
                         "widgets"                 => 19615,
                         "widnes"                  => 12598,
                         "widow"                   => 2933,
                         "widowed"                 => 8325,
                         "widowers"                => 15280,
                         "widows"                  => 8655,
                         "width"                   => 3589,
                         "widths"                  => 19230,
                         "wielded"                 => 14548,
                         "wields"                  => 17162,
                         "wielka"                  => 20064,
                         "wielki"                  => 22079,
                         "wielkie"                 => 15635,
                         "wielkopolska"            => 25912,
                         "wielkopolski"            => 14753,
                         "wielun"                  => 27357,
                         "wiesbaden"               => 11660,
                         "wiesenthal"              => 24124,
                         "wigan"                   => 5153,
                         "wigmore"                 => 18077,
                         "wigner"                  => 22661,
                         "wigram"                  => 29215,
                         "wikileaks"               => 13363,
                         "wikimedia"               => 18907,
                         "wikipedia"               => 5311,
                         "wikis"                   => 27775,
                         "wilberforce"             => 15214,
                         "wilbraham"               => 24036,
                         "wildcards"               => 11883,
                         "wilderness"              => 3688,
                         "wilders"                 => 27493,
                         "wildfires"               => 16287,
                         "wildflower"              => 19960,
                         "wildland"                => 28970,
                         "wildlife"                => 2151,
                         "wildstorm"               => 22255,
                         "wilfrid"                 => 10483,
                         "wilfried"                => 20220,
                         "wilhelmine"              => 22782,
                         "wilhelmshaven"           => 18896,
                         "will.i.am"               => 18126,
                         "willamette"              => 9451,
                         "willesden"               => 21585,
                         "williamsburg"            => 8626,
                         "williamsport"            => 14879,
                         "williamstown"            => 12978,
                         "willingness"             => 7652,
                         "wilmington"              => 6185,
                         "wilno"                   => 22182,
                         "wilsons"                 => 27517,
                         "wilts"                   => 27205,
                         "wiltshire"               => 5973,
                         "wimax"                   => 24266,
                         "wimbledon"               => 4572,
                         "wimborne"                => 26632,
                         "win"                     => 386,
                         "windhoek"                => 18100,
                         "winding"                 => 6467,
                         "windings"                => 21605,
                         "winds"                   => 2629,
                         "windscreen"              => 16842,
                         "windshaft"               => 29648,
                         "winegrowing"             => 29373,
                         "winehouse"               => 18339,
                         "winemaker"               => 21412,
                         "winemakers"              => 21669,
                         "winemaking"              => 15239,
                         "wineries"                => 12967,
                         "winery"                  => 8108,
                         "wing"                    => 763,
                         "winged"                  => 6136,
                         "wingers"                 => 22191,
                         "wingless"                => 28880,
                         "wings"                   => 1789,
                         "wingspan"                => 3930,
                         "wingtip"                 => 28832,
                         "wingtips"                => 29210,
                         "winless"                 => 15584,
                         "winners"                 => 1561,
                         "winning"                 => 513,
                         "winningest"              => 18599,
                         "winnipeg"                => 3851,
                         "wins"                    => 1447,
                         "winslet"                 => 26596,
                         "winterbottom"            => 23131,
                         "wintered"                => 25741,
                         "wintering"               => 13663,
                         "winterthur"              => 16693,
                         "winwood"                 => 22631,
                         "wireless"                => 3491,
                         "wirral"                  => 13796,
                         "wisbech"                 => 25078,
                         "wisconsin"               => 1430,
                         "wisden"                  => 11504,
                         "wisla"                   => 18491,
                         "with"                    => 10,
                         "withdraw"                => 3964,
                         "withdrawal"              => 3713,
                         "withdrawing"             => 8361,
                         "withdrawn"               => 3498,
                         "withdrew"                => 2701,
                         "within"                  => 178,
                         "withstand"               => 7659,
                         "withstood"               => 16927,
                         "witnessed"               => 4098,
                         "witney"                  => 24547,
                         "witold"                  => 22597,
                         "wittelsbach"             => 20990,
                         "wittgenstein"            => 12245,
                         "witton"                  => 23758,
                         "witwatersrand"           => 17755,
                         "wladyslaw"               => 8931,
                         "wloclawek"               => 20282,
                         "woburn"                  => 19306,
                         "wodehouse"               => 16108,
                         "woden"                   => 29334,
                         "wodonga"                 => 29597,
                         "wojciech"                => 16292,
                         "woking"                  => 13283,
                         "wokingham"               => 27730,
                         "wolds"                   => 25433,
                         "wolfenbuttel"            => 19328,
                         "wolfpacks"               => 24956,
                         "wolfsburg"               => 14838,
                         "wolka"                   => 18872,
                         "wollaston"               => 17972,
                         "wollongong"              => 12443,
                         "wollstonecraft"          => 21499,
                         "wolof"                   => 27732,
                         "wolseley"                => 15950,
                         "wolverhampton"           => 6750,
                         "wolverines"              => 7918,
                         "women"                   => 213,
                         "won"                     => 128,
                         "wonsan"                  => 27347,
                         "woodbine"                => 17262,
                         "woodblock"               => 21977,
                         "woodbridge"              => 11658,
                         "woodcut"                 => 19316,
                         "woodcuts"                => 18341,
                         "wooded"                  => 6447,
                         "wooden"                  => 1965,
                         "woodlands"               => 6609,
                         "woodpeckers"             => 15911,
                         "woodville"               => 13830,
                         "woodwinds"               => 23236,
                         "woodworking"             => 16285,
                         "wool"                    => 5231,
                         "woolen"                  => 15003,
                         "woollen"                 => 15718,
                         "woolly"                  => 12966,
                         "woolwich"                => 9994,
                         "woolworths"              => 17629,
                         "worcester"               => 4432,
                         "worcestershire"          => 6639,
                         "wording"                 => 10450,
                         "wordless"                => 25169,
                         "wordplay"                => 19985,
                         "woreda"                  => 9953,
                         "woredas"                 => 23044,
                         "work"                    => 107,
                         "workbench"               => 26179,
                         "worked"                  => 310,
                         "workers"                 => 851,
                         "workflow"                => 14411,
                         "workforce"               => 5191,
                         "workhouse"               => 14057,
                         "workings"                => 9021,
                         "workington"              => 15582,
                         "workmen"                 => 12479,
                         "workouts"                => 22636,
                         "workpiece"               => 19661,
                         "workplace"               => 6097,
                         "workplaces"              => 15813,
                         "works"                   => 280,
                         "workshop"                => 3201,
                         "workshops"               => 3331,
                         "worksop"                 => 20784,
                         "workspace"               => 22131,
                         "workstation"             => 14731,
                         "workstations"            => 15025,
                         "world"                   => 53,
                         "worldview"               => 13214,
                         "worldwide"               => 1271,
                         "worn"                    => 2763,
                         "worsen"                  => 16995,
                         "worsened"                => 9393,
                         "worsening"               => 12629,
                         "worsens"                 => 26165,
                         "worship"                 => 2526,
                         "worshiped"               => 12546,
                         "worshipers"              => 18450,
                         "worshipful"              => 15544,
                         "worshippers"             => 13097,
                         "worthing"                => 13597,
                         "would"                   => 52,
                         "wounded"                 => 1817,
                         "wounding"                => 9358,
                         "woven"                   => 7577,
                         "wozniacki"               => 22475,
                         "wrangel"                 => 24095,
                         "wrangell"                => 29971,
                         "wranglers"               => 18030,
                         "wrangling"               => 27556,
                         "wraparound"              => 22250,
                         "wrasse"                  => 23784,
                         "wreath"                  => 10432,
                         "wreckage"                => 9402,
                         "wreckers"                => 26288,
                         "wrens"                   => 23008,
                         "wrest"                   => 23283,
                         "wrested"                 => 27972,
                         "wrestled"                => 7990,
                         "wrestlemania"            => 9112,
                         "wrestler"                => 3859,
                         "wrestlers"               => 5116,
                         "wrestling"               => 1419,
                         "wrexham"                 => 8451,
                         "wrights"                 => 27089,
                         "writer"                  => 685,
                         "writer/director"         => 22500,
                         "writers"                 => 1365,
                         "writes"                  => 2244,
                         "writing"                 => 545,
                         "writings"                => 2495,
                         "writs"                   => 17812,
                         "written"                 => 285,
                         "wroclaw"                 => 7797,
                         "wrongly"                 => 9828,
                         "wrote"                   => 329,
                         "wrought"                 => 8369,
                         "wuchang"                 => 29752,
                         "wuhan"                   => 11730,
                         "wuppertal"               => 18274,
                         "wurlitzer"               => 21055,
                         "wurttemberg"             => 5738,
                         "wurzburg"                => 10252,
                         "wushu"                   => 20113,
                         "wuxia"                   => 27075,
                         "wyandot"                 => 27283,
                         "wyandotte"               => 21760,
                         "wyclef"                  => 26202,
                         "wycliffe"                => 17724,
                         "wycombe"                 => 10032,
                         "wyeth"                   => 17399,
                         "wylde"                   => 21260,
                         "wynton"                  => 25976,
                         "wynyard"                 => 25039,
                         "wyoming"                 => 3710,
                         "wysokie"                 => 25656,
                         "xalapa"                  => 29852,
                         "xanthi"                  => 26020,
                         "xaver"                   => 24182,
                         "xbox"                    => 4617,
                         "xenophobia"              => 22188,
                         "xenophobic"              => 24970,
                         "xfinity"                 => 22306,
                         "xhosa"                   => 16909,
                         "xhtml"                   => 27100,
                         "xi'an"                   => 14419,
                         "xiahou"                  => 25526,
                         "xiamen"                  => 18034,
                         "xianbei"                 => 23533,
                         "xianzong"                => 21875,
                         "xiaoping"                => 19405,
                         "xinhua"                  => 19921,
                         "xinjiang"                => 8400,
                         "xiongnu"                 => 14609,
                         "xizong"                  => 23322,
                         "xperia"                  => 24075,
                         "xuanwu"                  => 24445,
                         "xuanzang"                => 25174,
                         "xuanzong"                => 13470,
                         "xuzhou"                  => 26505,
                         "xviii"                   => 11354,
                         "xxiii"                   => 12004,
                         "xxvii"                   => 27547,
                         "xxviii"                  => 29700,
                         "xylophone"               => 24858,
                         "yaakov"                  => 16401,
                         "yachting"                => 15021,
                         "yachts"                  => 10263,
                         "yadav"                   => 11316,
                         "yadkin"                  => 27228,
                         "yahoo"                   => 6870,
                         "yahya"                   => 11779,
                         "yakima"                  => 14068,
                         "yakov"                   => 19012,
                         "yakovlev"                => 17689,
                         "yakutsk"                 => 28884,
                         "yale"                    => 2839,
                         "yamagata"                => 15360,
                         "yamanashi"               => 23318,
                         "yamhill"                 => 28369,
                         "yamuna"                  => 15357,
                         "yan'an"                  => 27136,
                         "yangon"                  => 12184,
                         "yangtze"                 => 9889,
                         "yangzhou"                => 21394,
                         "yankovic"                => 13586,
                         "yankton"                 => 28055,
                         "yanow"                   => 16358,
                         "yanukovych"              => 16493,
                         "yaounde"                 => 20401,
                         "yaqub"                   => 25836,
                         "yaqui"                   => 23425,
                         "yard"                    => 1138,
                         "yardage"                 => 16356,
                         "yardbirds"               => 22622,
                         "yarder"                  => 24441,
                         "yards"                   => 1229,
                         "yarmouth"                => 9303,
                         "yarns"                   => 18874,
                         "yaroslavl"               => 15054,
                         "yarra"                   => 11770,
                         "yarrow"                  => 16461,
                         "yasser"                  => 18365,
                         "yassin"                  => 26149,
                         "yatra"                   => 18106,
                         "yavapai"                 => 24544,
                         "yayoi"                   => 29576,
                         "yazid"                   => 19228,
                         "yazoo"                   => 18224,
                         "year"                    => 50,
                         "yearly"                  => 4114,
                         "years"                   => 47,
                         "yeast"                   => 7621,
                         "yeasts"                  => 26097,
                         "yehuda"                  => 12892,
                         "yehudi"                  => 24592,
                         "yekaterinburg"           => 20632,
                         "yellowhead"              => 26898,
                         "yellowish"               => 6771,
                         "yellowknife"             => 20561,
                         "yellowstone"             => 9122,
                         "yeltsin"                 => 14438,
                         "yemen"                   => 5051,
                         "yemeni"                  => 10992,
                         "yemenite"                => 22155,
                         "yeomanry"                => 9224,
                         "yeomen"                  => 22616,
                         "yeong"                   => 23800,
                         "yeovil"                  => 10328,
                         "yerba"                   => 20545,
                         "yerevan"                 => 9202,
                         "yeshiva"                 => 7075,
                         "yeshivas"                => 22393,
                         "yevgeni"                 => 20589,
                         "yiddish"                 => 7164,
                         "yield"                   => 3940,
                         "yielded"                 => 6437,
                         "yielding"                => 7523,
                         "yields"                  => 5592,
                         "yildirim"                => 25417,
                         "yilmaz"                  => 24841,
                         "yishuv"                  => 27262,
                         "yisrael"                 => 14103,
                         "yitzchak"                => 27376,
                         "yitzhak"                 => 14046,
                         "yogic"                   => 28953,
                         "yogyakarta"              => 13987,
                         "yohannan"                => 28897,
                         "yokai"                   => 26140,
                         "yokohama"                => 7525,
                         "yokosuka"                => 10258,
                         "yokozuna"                => 15713,
                         "yomiuri"                 => 19882,
                         "yonge"                   => 13063,
                         "yonne"                   => 21484,
                         "york"                    => 157,
                         "yorker"                  => 7194,
                         "yorkist"                 => 28944,
                         "yorkshire"               => 2228,
                         "yorkville"               => 25467,
                         "yoruba"                  => 11571,
                         "yosef"                   => 12408,
                         "yoshihiro"               => 26593,
                         "yossi"                   => 25658,
                         "younger"                 => 1176,
                         "youngest"                => 2298,
                         "youngster"               => 11727,
                         "youngstown"              => 10628,
                         "yousuf"                  => 24381,
                         "youth"                   => 682,
                         "youths"                  => 7057,
                         "youtube"                 => 3185,
                         "ypres"                   => 11501,
                         "ypsilanti"               => 20736,
                         "ysgol"                   => 21611,
                         "yuan"                    => 3390,
                         "yucatan"                 => 9076,
                         "yucca"                   => 16635,
                         "yudhoyono"               => 27895,
                         "yugoslav"                => 4365,
                         "yugoslavia"              => 3076,
                         "yugoslavian"             => 14459,
                         "yuichi"                  => 29440,
                         "yukio"                   => 21302,
                         "yukon"                   => 6980,
                         "yulia"                   => 17548,
                         "yunnan"                  => 7980,
                         "yunus"                   => 17711,
                         "yup'ik"                  => 24247,
                         "yuriy"                   => 18632,
                         "yusef"                   => 20629,
                         "yushchenko"              => 20747,
                         "yusuf"                   => 8283,
                         "yutaka"                  => 25573,
                         "yuvan"                   => 25063,
                         "yuvraj"                  => 29425,
                         "yuwen"                   => 15845,
                         "yvelines"                => 24324,
                         "zacatecas"               => 17697,
                         "zadar"                   => 14870,
                         "zafar"                   => 17514,
                         "zagora"                  => 23456,
                         "zagreb"                  => 4898,
                         "zagros"                  => 25198,
                         "zahedan"                 => 28756,
                         "zahir"                   => 16119,
                         "zahra"                   => 16862,
                         "zaidi"                   => 19478,
                         "zainab"                  => 22745,
                         "zaire"                   => 12947,
                         "zakat"                   => 26250,
                         "zakir"                   => 24971,
                         "zalgiris"                => 23659,
                         "zalman"                  => 22988,
                         "zamalek"                 => 21103,
                         "zambales"                => 27230,
                         "zambezi"                 => 17669,
                         "zambia"                  => 5865,
                         "zambian"                 => 14920,
                         "zamboanga"               => 12584,
                         "zamindar"                => 20693,
                         "zamorin"                 => 23595,
                         "zamosc"                  => 18334,
                         "zamoyski"                => 26817,
                         "zanesville"              => 25677,
                         "zanjan"                  => 14506,
                         "zapatista"               => 27567,
                         "zaporizhia"              => 27053,
                         "zapotec"                 => 19990,
                         "zardari"                 => 25480,
                         "zarqawi"                 => 29169,
                         "zarzuela"                => 26566,
                         "zawahiri"                => 26482,
                         "zayed"                   => 17798,
                         "zbigniew"                => 15974,
                         "zdroj"                   => 20108,
                         "ze'ev"                   => 29473,
                         "zealand"                 => 661,
                         "zealander"               => 17114,
                         "zealanders"              => 12883,
                         "zealous"                 => 16088,
                         "zechariah"               => 24433,
                         "zedong"                  => 12617,
                         "zeebrugge"               => 29000,
                         "zeeland"                 => 16298,
                         "zeiss"                   => 16328,
                         "zeitschrift"             => 21385,
                         "zeitung"                 => 11923,
                         "zeljeznicar"             => 29381,
                         "zeljko"                  => 20271,
                         "zemlya"                  => 28858,
                         "zemun"                   => 22240,
                         "zenit"                   => 13798,
                         "zetas"                   => 21304,
                         "zetian"                  => 18115,
                         "zgierz"                  => 26854,
                         "zhaozong"                => 19141,
                         "zhejiang"                => 9098,
                         "zhengzhou"               => 24320,
                         "zhongshan"               => 19666,
                         "zhongshu"                => 19310,
                         "zhongzong"               => 22090,
                         "zhuge"                   => 14947,
                         "zhuhai"                  => 22036,
                         "zhytomyr"                => 29716,
                         "ziarat"                  => 29237,
                         "ziegfeld"                => 18177,
                         "zielona"                 => 16716,
                         "ziggler"                 => 21647,
                         "zilina"                  => 20067,
                         "zimbabwe"                => 4053,
                         "zimbabwean"              => 11312,
                         "zinc"                    => 5544,
                         "zindagi"                 => 25486,
                         "zinoviev"                => 29631,
                         "zionism"                 => 10659,
                         "zionist"                 => 7024,
                         "zionists"                => 17231,
                         "zirconium"               => 19803,
                         "zither"                  => 28905,
                         "zlatko"                  => 29386,
                         "znojmo"                  => 29221,
                         "zohar"                   => 18477,
                         "zomba"                   => 26501,
                         "zonal"                   => 13879,
                         "zone"                    => 1137,
                         "zoned"                   => 11441,
                         "zones"                   => 3481,
                         "zoological"              => 8698,
                         "zoologist"               => 11630,
                         "zoology"                 => 8259,
                         "zooplankton"             => 20416,
                         "zoran"                   => 13516,
                         "zoroaster"               => 28124,
                         "zoroastrian"             => 14597,
                         "zoroastrianism"          => 19652,
                         "zoroastrians"            => 26186,
                         "zsolt"                   => 29651,
                         "zubin"                   => 29231,
                         "zuckerberg"              => 26827,
                         "zulfikar"                => 26529,
                         "zulfiqar"                => 26964,
                         "zulia"                   => 28061,
                         "zulus"                   => 28824,
                         "zurich"                  => 3927,
                         "zvonareva"               => 27840,
                         "zweibrucken"             => 15361,
                         "zwickau"                 => 23688,
                         "zwingli"                 => 24295,
                         "zwolle"                  => 19959,
                         "zygmunt"                 => 18951,
                         "zynga"                   => 28331,
                       },
  female_names      => {
                         abbey       => 1433,
                         abbie       => 973,
                         abby        => 657,
                         abigail     => 493,
                         ada         => 304,
                         adah        => 2872,
                         adaline     => 2677,
                         addie       => 487,
                         adela       => 684,
                         adelaida    => 1330,
                         adelaide    => 954,
                         adele       => 497,
                         adelia      => 1718,
                         adelina     => 1066,
                         adeline     => 601,
                         adell       => 1292,
                         adella      => 1563,
                         adelle      => 1896,
                         adena       => 3191,
                         adina       => 1799,
                         adria       => 1683,
                         adriana     => 491,
                         adriane     => 1469,
                         adrianna    => 1371,
                         adrianne    => 997,
                         adrien      => 3124,
                         adriene     => 2676,
                         adrienne    => 382,
                         afton       => 1886,
                         agatha      => 1049,
                         agnes       => 215,
                         agnus       => 3555,
                         agripina    => 2966,
                         agueda      => 3554,
                         agustina    => 1655,
                         aida        => 530,
                         aide        => 2829,
                         aiko        => 3190,
                         aileen      => 648,
                         ailene      => 2828,
                         aimee       => 477,
                         aisha       => 864,
                         akiko       => 2207,
                         akilah      => 3123,
                         alaina      => 1236,
                         alaine      => 3630,
                         alana       => 752,
                         alane       => 3268,
                         alanna      => 1432,
                         alayna      => 3476,
                         alba        => 918,
                         alberta     => 325,
                         albertha    => 1584,
                         albertina   => 2089,
                         albertine   => 1895,
                         albina      => 1455,
                         alda        => 1323,
                         alease      => 2711,
                         alecia      => 1065,
                         aleen       => 2871,
                         aleida      => 2377,
                         aleisha     => 3332,
                         alejandra   => 754,
                         alejandrina => 1952,
                         alena       => 1775,
                         alene       => 1075,
                         alesha      => 1468,
                         aleshia     => 2754,
                         alesia      => 1421,
                         alessandra  => 3122,
                         aleta       => 1370,
                         aletha      => 1154,
                         alethea     => 1822,
                         alethia     => 2155,
                         alexa       => 1134,
                         alexandra   => 384,
                         alexandria  => 708,
                         alexia      => 1643,
                         alfreda     => 859,
                         alfredia    => 3331,
                         alia        => 2032,
                         alica       => 2031,
                         alice       => 51,
                         alicia      => 152,
                         alida       => 1636,
                         alina       => 1170,
                         aline       => 796,
                         alisa       => 570,
                         alise       => 2349,
                         alisha      => 476,
                         alishia     => 2637,
                         alisia      => 2607,
                         alison      => 338,
                         alissa      => 816,
                         alita       => 2790,
                         alix        => 2465,
                         aliza       => 2675,
                         alla        => 2426,
                         alleen      => 2827,
                         allegra     => 2293,
                         allena      => 3404,
                         allene      => 981,
                         allie       => 725,
                         alline      => 2498,
                         allison     => 225,
                         allyn       => 3712,
                         allyson     => 736,
                         alma        => 194,
                         almeda      => 1609,
                         almeta      => 2538,
                         alona       => 3711,
                         alta        => 586,
                         altagracia  => 1369,
                         altha       => 2184,
                         althea      => 749,
                         alvera      => 2376,
                         alverta     => 3065,
                         alvina      => 1082,
                         alyce       => 825,
                         alycia      => 1540,
                         alysa       => 3121,
                         alyse       => 2322,
                         alysha      => 2154,
                         alysia      => 1674,
                         alyson      => 920,
                         alyssa      => 430,
                         amada       => 1717,
                         amal        => 3475,
                         amalia      => 851,
                         amanda      => 40,
                         amber       => 139,
                         amberly     => 2710,
                         amee        => 3403,
                         amelia      => 324,
                         amie        => 748,
                         amiee       => 3402,
                         amina       => 1992,
                         amira       => 3553,
                         ammie       => 2402,
                         amparo      => 861,
                         amy         => 32,
                         ana         => 179,
                         anabel      => 1420,
                         analisa     => 3267,
                         anamaria    => 3009,
                         anastacia   => 1852,
                         anastasia   => 853,
                         andera      => 3189,
                         andra       => 1312,
                         andrea      => 81,
                         andree      => 2183,
                         andria      => 1185,
                         anette      => 2088,
                         angela      => 29,
                         angele      => 2569,
                         angelena    => 2674,
                         angelia     => 624,
                         angelic     => 2321,
                         angelica    => 380,
                         angelika    => 2182,
                         angelina    => 400,
                         angeline    => 617,
                         angelique   => 905,
                         angelita    => 885,
                         angella     => 1758,
                         angelyn     => 3266,
                         angie       => 320,
                         angila      => 3710,
                         angla       => 3265,
                         angle       => 2320,
                         anglea      => 1732,
                         anika       => 1874,
                         anisa       => 2914,
                         anisha      => 2870,
                         anissa      => 1284,
                         anita       => 136,
                         anitra      => 1635,
                         anja        => 3330,
                         anjanette   => 2133,
                         anjelica    => 3329,
                         ann         => 48,
                         anna        => 33,
                         annabel     => 1654,
                         annabell    => 2254,
                         annabelle   => 764,
                         annalee     => 2497,
                         annalisa    => 2606,
                         annamae     => 2375,
                         annamaria   => 2826,
                         annamarie   => 1291,
                         anne        => 85,
                         anneliese   => 1821,
                         annelle     => 3709,
                         annemarie   => 1143,
                         annett      => 2636,
                         annetta     => 1110,
                         annette     => 175,
                         annice      => 2464,
                         annie       => 97,
                         annika      => 3401,
                         annis       => 2253,
                         annita      => 2965,
                         annmarie    => 888,
                         antionette  => 952,
                         antoinette  => 352,
                         antonetta   => 3264,
                         antonette   => 1212,
                         antonia     => 411,
                         antonietta  => 2348,
                         antonina    => 1873,
                         anya        => 1965,
                         apolonia    => 2709,
                         april       => 142,
                         apryl       => 2635,
                         araceli     => 829,
                         aracelis    => 2634,
                         aracely     => 1523,
                         arcelia     => 1838,
                         ardath      => 3328,
                         ardelia     => 3708,
                         ardell      => 2605,
                         ardella     => 2017,
                         ardelle     => 3400,
                         ardis       => 1467,
                         ardith      => 1466,
                         aretha      => 1163,
                         argelia     => 2789,
                         ariana      => 1265,
                         ariane      => 2673,
                         arianna     => 2206,
                         arianne     => 2753,
                         arica       => 3120,
                         arie        => 2672,
                         arielle     => 1706,
                         arla        => 2319,
                         arlean      => 3327,
                         arleen      => 1001,
                         arlena      => 2401,
                         arlene      => 222,
                         arletha     => 2788,
                         arletta     => 2231,
                         arlette     => 1894,
                         arlinda     => 3008,
                         arline      => 840,
                         arlyne      => 3474,
                         armanda     => 2671,
                         armandina   => 2913,
                         armida      => 1477,
                         arminda     => 2633,
                         arnetta     => 2064,
                         arnette     => 3399,
                         arnita      => 2318,
                         artie       => 1476,
                         arvilla     => 2374,
                         asha        => 1757,
                         ashanti     => 2869,
                         ashely      => 1653,
                         ashlea      => 3552,
                         ashlee      => 737,
                         ashleigh    => 977,
                         ashley      => 63,
                         ashli       => 2016,
                         ashlie      => 1583,
                         ashly       => 1595,
                         ashlyn      => 2496,
                         ashton      => 1522,
                         asley       => 3551,
                         assunta     => 2604,
                         astrid      => 1347,
                         asuncion    => 2205,
                         athena      => 1054,
                         audie       => 2347,
                         audra       => 667,
                         audrea      => 2252,
                         audrey      => 173,
                         audria      => 3707,
                         audrie      => 3706,
                         audry       => 1548,
                         augusta     => 848,
                         augustina   => 2251,
                         aundrea     => 2568,
                         aura        => 1203,
                         aurea       => 1731,
                         aurelia     => 846,
                         aurora      => 505,
                         aurore      => 2825,
                         autumn      => 626,
                         ava         => 703,
                         avelina     => 2204,
                         avis        => 724,
                         avril       => 3629,
                         awilda      => 1608,
                         ayako       => 3119,
                         ayana       => 2030,
                         ayanna      => 2087,
                         ayesha      => 1820,
                         azalee      => 3326,
                         azucena     => 2567,
                         azzie       => 3188,
                         babara      => 2108,
                         babette     => 2086,
                         bambi       => 1405,
                         barabara    => 3628,
                         barb        => 1098,
                         barbar      => 2603,
                         barbara     => 4,
                         barbera     => 2537,
                         barbra      => 677,
                         bari        => 3705,
                         barrie      => 2824,
                         basilia     => 3473,
                         beata       => 2964,
                         beatrice    => 170,
                         beatris     => 3325,
                         beatriz     => 612,
                         beaulah     => 2963,
                         bebe        => 3472,
                         becki       => 2787,
                         beckie      => 1991,
                         becky       => 281,
                         belen       => 1254,
                         belia       => 2107,
                         belinda     => 299,
                         belkis      => 3187,
                         bella       => 1109,
                         belle       => 993,
                         belva       => 1173,
                         benita      => 735,
                         berenice    => 1819,
                         berna       => 3007,
                         bernadette  => 388,
                         bernadine   => 686,
                         bernarda    => 3006,
                         bernardina  => 3471,
                         bernardine  => 2786,
                         berneice    => 2463,
                         bernetta    => 2250,
                         bernice     => 172,
                         berniece    => 1142,
                         bernita     => 1368,
                         berta       => 834,
                         bertha      => 156,
                         bertie      => 917,
                         beryl       => 890,
                         bess        => 1032,
                         bessie      => 218,
                         beth        => 197,
                         bethanie    => 3118,
                         bethann     => 2495,
                         bethany     => 386,
                         bethel      => 1964,
                         betsey      => 2632,
                         betsy       => 413,
                         bette       => 574,
                         bettie      => 528,
                         bettina     => 1155,
                         betty       => 14,
                         bettyann    => 3550,
                         bettye      => 673,
                         beula       => 3704,
                         beulah      => 351,
                         beverlee    => 2132,
                         beverley    => 933,
                         beverly     => 73,
                         bianca      => 671,
                         bibi        => 2962,
                         billi       => 3263,
                         billie      => 272,
                         billye      => 1936,
                         birgit      => 2203,
                         blanca      => 374,
                         blanch      => 1380,
                         blanche     => 314,
                         blondell    => 2961,
                         blossom     => 2785,
                         blythe      => 2494,
                         bobbi       => 642,
                         bobbie      => 282,
                         bobbye      => 1907,
                         bobette     => 3470,
                         bong        => 3186,
                         bonita      => 483,
                         bonnie      => 88,
                         bonny       => 1393,
                         branda      => 2493,
                         brande      => 3262,
                         brandee     => 1634,
                         brandi      => 313,
                         brandie     => 927,
                         breana      => 3469,
                         breann      => 2784,
                         breanna     => 1124,
                         breanne     => 1730,
                         bree        => 1885,
                         brenda      => 31,
                         brenna      => 1181,
                         briana      => 828,
                         brianna     => 699,
                         brianne     => 1028,
                         bridget     => 359,
                         bridgett    => 884,
                         bridgette   => 681,
                         brigette    => 1386,
                         brigid      => 2015,
                         brigida     => 2292,
                         brigitte    => 919,
                         brinda      => 2631,
                         britany     => 2046,
                         britni      => 1990,
                         britta      => 2708,
                         brittaney   => 3261,
                         brittani    => 1532,
                         brittanie   => 2960,
                         brittany    => 185,
                         britteny    => 3703,
                         brittney    => 518,
                         brittni     => 2202,
                         brittny     => 2868,
                         bronwyn     => 2425,
                         brook       => 1322,
                         brooke      => 385,
                         bruna       => 3260,
                         brunilda    => 2014,
                         bryanna     => 3702,
                         brynn       => 2566,
                         buena       => 3627,
                         bula        => 3626,
                         bulah       => 2959,
                         burma       => 3625,
                         caitlin     => 531,
                         caitlyn     => 1491,
                         calandra    => 2912,
                         calista     => 3701,
                         callie      => 641,
                         camelia     => 1963,
                         camellia    => 3468,
                         cami        => 1716,
                         camie       => 2867,
                         camila      => 3624,
                         camilla     => 972,
                         camille     => 464,
                         cammie      => 2201,
                         cammy       => 3398,
                         candace     => 334,
                         candance    => 1633,
                         candelaria  => 1398,
                         candi       => 1223,
                         candice     => 353,
                         candida     => 1081,
                         candie      => 1989,
                         candis      => 1632,
                         candra      => 3700,
                         candy       => 544,
                         candyce     => 2400,
                         caprice     => 2153,
                         cara        => 496,
                         caren       => 1042,
                         cari        => 1007,
                         caridad     => 1161,
                         carie       => 1924,
                         carin       => 1617,
                         carina      => 1447,
                         carisa      => 2536,
                         carissa     => 894,
                         carita      => 3117,
                         carla       => 200,
                         carlee      => 3259,
                         carleen     => 1440,
                         carlena     => 3699,
                         carlene     => 768,
                         carletta    => 2045,
                         carley      => 2399,
                         carli       => 2866,
                         carlie      => 2346,
                         carline     => 2131,
                         carlita     => 3623,
                         carlota     => 1705,
                         carlotta    => 1339,
                         carlyn      => 1818,
                         carma       => 1700,
                         carman      => 1367,
                         carmel      => 1126,
                         carmela     => 607,
                         carmelia    => 3467,
                         carmelina   => 2373,
                         carmelita   => 1141,
                         carmella    => 760,
                         carmen      => 111,
                         carmina     => 3116,
                         carmon      => 2565,
                         carol       => 18,
                         carola      => 2783,
                         carolann    => 1774,
                         carole      => 270,
                         carolee     => 1508,
                         carolin     => 2958,
                         caroline    => 245,
                         caroll      => 3698,
                         carolyn     => 42,
                         carolyne    => 2249,
                         carolynn    => 1817,
                         caroyln     => 3115,
                         carri       => 1756,
                         carrie      => 129,
                         caryl       => 1494,
                         carylon     => 3549,
                         caryn       => 985,
                         casandra    => 883,
                         casie       => 2106,
                         casimira    => 3466,
                         cassandra   => 264,
                         cassaundra  => 3005,
                         cassey      => 3697,
                         cassi       => 3258,
                         cassondra   => 3004,
                         cassy       => 3257,
                         catalina    => 702,
                         catarina    => 2535,
                         caterina    => 2398,
                         catharine   => 1172,
                         catherina   => 3696,
                         catherine   => 46,
                         cathern     => 3003,
                         catheryn    => 3465,
                         cathey      => 2317,
                         cathi       => 1787,
                         cathie      => 1346,
                         cathleen    => 623,
                         cathrine    => 1097,
                         cathryn     => 881,
                         cathy       => 163,
                         catina      => 1321,
                         catrice     => 3695,
                         catrina     => 1020,
                         cayla       => 3622,
                         cecelia     => 427,
                         cecila      => 2152,
                         cecile      => 577,
                         cecilia     => 311,
                         cecille     => 3324,
                         cecily      => 1652,
                         celena      => 2291,
                         celesta     => 3064,
                         celeste     => 494,
                         celestina   => 1988,
                         celestine   => 1041,
                         celia       => 361,
                         celina      => 937,
                         celinda     => 3464,
                         celsa       => 3256,
                         ceola       => 2752,
                         chae        => 3463,
                         chana       => 1573,
                         chanda      => 1357,
                         chandra     => 717,
                         chanel      => 1303,
                         chanell     => 3002,
                         chanelle    => 2823,
                         chantal     => 1294,
                         chantay     => 3323,
                         chante      => 2372,
                         chantel     => 1045,
                         chantell    => 2316,
                         chantelle   => 1594,
                         chara       => 3397,
                         charis      => 3114,
                         charise     => 2397,
                         charissa    => 1622,
                         charisse    => 1379,
                         charita     => 3255,
                         charity     => 610,
                         charla      => 1118,
                         charleen    => 1283,
                         charlena    => 3548,
                         charlene    => 217,
                         charlesetta => 3254,
                         charlette   => 1741,
                         charline    => 1302,
                         charlotte   => 130,
                         charlsie    => 3547,
                         charlyn     => 3185,
                         charmain    => 3396,
                         charmaine   => 784,
                         charolette  => 1755,
                         chasidy     => 3694,
                         chasity     => 822,
                         chassidy    => 3693,
                         chastity    => 1196,
                         chau        => 2630,
                         chaya       => 1962,
                         chelsey     => 951,
                         chelsie     => 1392,
                         cher        => 2751,
                         chere       => 3113,
                         cheree      => 2822,
                         cherelle    => 3395,
                         cheri       => 492,
                         cherie      => 549,
                         cherilyn    => 2911,
                         cherise     => 1572,
                         cherish     => 2275,
                         cherly      => 1493,
                         cherlyn     => 3394,
                         cherri      => 1651,
                         cherrie     => 1607,
                         cherryl     => 2424,
                         chery       => 2782,
                         cheryl      => 59,
                         cheryle     => 1465,
                         cheryll     => 2315,
                         chia        => 3253,
                         chieko      => 3393,
                         ching       => 2781,
                         chiquita    => 1219,
                         christa     => 535,
                         christal    => 1116,
                         christeen   => 2396,
                         christel    => 1547,
                         christen    => 1053,
                         christena   => 2395,
                         christene   => 1906,
                         christi     => 631,
                         christiana  => 1642,
                         christiane  => 1754,
                         christie    => 414,
                         christina   => 70,
                         christine   => 43,
                         christinia  => 3184,
                         christy     => 255,
                         chrystal    => 791,
                         chun        => 1837,
                         ciara       => 1593,
                         cicely      => 2492,
                         ciera       => 2181,
                         cierra      => 1582,
                         cinda       => 1606,
                         cinderella  => 3252,
                         cindi       => 1031,
                         cindie      => 3692,
                         cindy       => 113,
                         cinthia     => 1454,
                         cira        => 3462,
                         claire      => 294,
                         clara       => 144,
                         clare       => 753,
                         claretha    => 3183,
                         claretta    => 3546,
                         claribel    => 1851,
                         clarice     => 614,
                         clarinda    => 3461,
                         clarine     => 2423,
                         claris      => 3392,
                         clarisa     => 3251,
                         clarissa    => 705,
                         clarita     => 2564,
                         classie     => 3112,
                         claudette   => 622,
                         claudia     => 231,
                         claudie     => 2707,
                         claudine    => 814,
                         clelia      => 3391,
                         clemencia   => 2957,
                         clementina  => 1951,
                         clementine  => 1258,
                         clemmie     => 2314,
                         cleo        => 563,
                         cleopatra   => 2345,
                         cleora      => 2534,
                         cleotilde   => 3322,
                         cleta       => 1616,
                         clora       => 2910,
                         clorinda    => 2780,
                         clotilde    => 2248,
                         codi        => 3691,
                         coleen      => 862,
                         colene      => 3321,
                         coletta     => 2563,
                         colette     => 801,
                         colleen     => 224,
                         collen      => 2274,
                         collene     => 3690,
                         collette    => 1282,
                         concepcion  => 709,
                         conception  => 2909,
                         concetta    => 916,
                         concha      => 3545,
                         conchita    => 2085,
                         connie      => 106,
                         constance   => 229,
                         consuela    => 2084,
                         consuelo    => 545,
                         contessa    => 3320,
                         cora        => 302,
                         coral       => 1439,
                         coralee     => 2750,
                         coralie     => 3063,
                         corazon     => 1872,
                         cordelia    => 1217,
                         cordia      => 3319,
                         cordie      => 2562,
                         coreen      => 2083,
                         corene      => 1673,
                         coretta     => 2063,
                         cori        => 1147,
                         corie       => 2273,
                         corina      => 858,
                         corine      => 789,
                         corinna     => 1431,
                         corinne     => 525,
                         corliss     => 2247,
                         cornelia    => 670,
                         corrie      => 1278,
                         corrin      => 3621,
                         corrina     => 1773,
                         corrine     => 707,
                         corrinne    => 3318,
                         cortney     => 944,
                         courtney    => 242,
                         creola      => 2865,
                         criselda    => 2670,
                         crissy      => 2371,
                         crista      => 2029,
                         cristal     => 1306,
                         cristen     => 2561,
                         cristi      => 1786,
                         cristie     => 2533,
                         cristin     => 1850,
                         cristina    => 419,
                         cristine    => 1521,
                         cristy      => 1140,
                         crysta      => 3390,
                         crystal     => 102,
                         crystle     => 3544,
                         cyndi       => 1615,
                         cyndy       => 3062,
                         cynthia     => 28,
                         cyrstal     => 3620,
                         cythia      => 1849,
                         dacia       => 2749,
                         dagmar      => 2272,
                         dagny       => 3689,
                         dahlia      => 2082,
                         daina       => 2864,
                         daine       => 3619,
                         daisey      => 2105,
                         daisy       => 289,
                         dalene      => 3111,
                         dalia       => 1108,
                         dalila      => 2104,
                         damaris     => 1171,
                         dana        => 177,
                         danae       => 2462,
                         danelle     => 1301,
                         danette     => 1026,
                         dani        => 1816,
                         dania       => 1923,
                         danica      => 1729,
                         daniela     => 1064,
                         daniele     => 1815,
                         daniell     => 2706,
                         daniella    => 1430,
                         danielle    => 150,
                         danika      => 2560,
                         danille     => 2748,
                         danita      => 1180,
                         dann        => 3389,
                         danna       => 1030,
                         dannette    => 2491,
                         dannielle   => 1836,
                         danuta      => 2559,
                         danyel      => 2821,
                         danyell     => 2747,
                         danyelle    => 1893,
                         daphine     => 2246,
                         daphne      => 585,
                         dara        => 1072,
                         darcel      => 3250,
                         darcey      => 3460,
                         darci       => 1475,
                         darcie      => 1605,
                         darcy       => 758,
                         daria       => 1429,
                         darla       => 448,
                         darleen     => 1250,
                         darlena     => 3001,
                         darlene     => 157,
                         darline     => 1604,
                         davida      => 1650,
                         davina      => 1581,
                         dawn        => 105,
                         dawna       => 1345,
                         dawne       => 2422,
                         dayle       => 2200,
                         dayna       => 984,
                         daysi       => 3543,
                         deadra      => 3000,
                         deana       => 647,
                         deandra     => 2271,
                         deandrea    => 3317,
                         deane       => 2421,
                         deann       => 926,
                         deanna      => 256,
                         deanne      => 793,
                         debbi       => 1987,
                         debbie      => 141,
                         debbra      => 1835,
                         debby       => 1016,
                         debera      => 3316,
                         debi        => 1311,
                         debora      => 548,
                         deborah     => 25,
                         debra       => 39,
                         debrah      => 1277,
                         debroah     => 2180,
                         dede        => 3388,
                         dedra       => 1592,
                         dee         => 659,
                         deeann      => 2062,
                         deeanna     => 3459,
                         deedee      => 2908,
                         deedra      => 2956,
                         deena       => 845,
                         deetta      => 3618,
                         deidra      => 947,
                         deidre      => 821,
                         deirdre     => 826,
                         deja        => 3387,
                         delaine     => 2705,
                         delana      => 2151,
                         delcie      => 3458,
                         delena      => 2532,
                         delfina     => 1243,
                         delia       => 440,
                         delicia     => 2490,
                         delila      => 3542,
                         delilah     => 1019,
                         delinda     => 2081,
                         delisa      => 2179,
                         dell        => 2230,
                         della       => 366,
                         delma       => 999,
                         delmy       => 3386,
                         delois      => 1092,
                         deloise     => 2907,
                         delora      => 1871,
                         deloras     => 3541,
                         delores     => 219,
                         deloris     => 489,
                         delorse     => 3182,
                         delpha      => 2602,
                         delphia     => 1753,
                         delphine    => 1027,
                         delsie      => 2955,
                         demetra     => 1591,
                         demetria    => 998,
                         demetrice   => 2531,
                         dena        => 540,
                         denae       => 3249,
                         deneen      => 1798,
                         denese      => 2530,
                         denice      => 941,
                         denise      => 74,
                         denisha     => 2420,
                         denisse     => 3540,
                         denita      => 1935,
                         denna       => 1785,
                         dennise     => 1922,
                         denyse      => 3617,
                         deonna      => 2999,
                         desirae     => 1870,
                         desiree     => 410,
                         despina     => 2954,
                         dessie      => 957,
                         detra       => 2313,
                         devona      => 2150,
                         devora      => 2669,
                         devorah     => 2629,
                         dian        => 1336,
                         diana       => 96,
                         diane       => 50,
                         diann       => 893,
                         dianna      => 404,
                         dianne      => 273,
                         diedra      => 2419,
                         diedre      => 2529,
                         dierdre     => 3248,
                         digna       => 2229,
                         dimple      => 2668,
                         dina        => 551,
                         dinah       => 1063,
                         dinorah     => 3181,
                         dione       => 2290,
                         dionna      => 2461,
                         dionne      => 887,
                         divina      => 3688,
                         dixie       => 457,
                         dodie       => 3539,
                         dollie      => 779,
                         dolly       => 655,
                         dolores     => 171,
                         doloris     => 2460,
                         domenica    => 1834,
                         dominga     => 1130,
                         dominica    => 2863,
                         dominique   => 636,
                         dominque    => 2149,
                         domitila    => 2862,
                         domonique   => 2489,
                         dona        => 713,
                         donella     => 3180,
                         donetta     => 2418,
                         donette     => 3457,
                         donita      => 1366,
                         donna       => 17,
                         donnetta    => 3247,
                         donnette    => 3246,
                         donya       => 2488,
                         dora        => 246,
                         dorathy     => 2289,
                         dorcas      => 1264,
                         doreatha    => 3616,
                         doreen      => 408,
                         dorene      => 1179,
                         doretha     => 946,
                         dorethea    => 3615,
                         doretta     => 2704,
                         dori        => 1474,
                         doria       => 3179,
                         dorie       => 2528,
                         dorinda     => 1365,
                         dorine      => 2013,
                         doris       => 55,
                         dorla       => 3385,
                         dorotha     => 1814,
                         dorothea    => 555,
                         dorothy     => 10,
                         dorris      => 1107,
                         dortha      => 1305,
                         dorthea     => 1715,
                         dorthey     => 3178,
                         dorthy      => 500,
                         dottie      => 992,
                         dotty       => 3061,
                         dovie       => 1189,
                         dreama      => 2370,
                         drema       => 2601,
                         drucilla    => 1986,
                         drusilla    => 2288,
                         dulce       => 1316,
                         dulcie      => 3110,
                         dung        => 2459,
                         dusti       => 3060,
                         dwana       => 3384,
                         dyan        => 2527,
                         earlean     => 2245,
                         earleen     => 2344,
                         earlene     => 766,
                         earlie      => 3109,
                         earline     => 701,
                         earnestine  => 759,
                         eartha      => 1699,
                         easter      => 1315,
                         eboni       => 1672,
                         ebonie      => 2779,
                         ebony       => 468,
                         echo        => 2628,
                         edda        => 2600,
                         edelmira    => 1884,
                         eden        => 1698,
                         edie        => 1404,
                         edith       => 117,
                         edna        => 109,
                         edra        => 3614,
                         edris       => 3245,
                         edwina      => 775,
                         edyth       => 2998,
                         edythe      => 976,
                         effie       => 501,
                         ehtel       => 3108,
                         eileen      => 203,
                         eilene      => 2906,
                         eladia      => 3538,
                         elaina      => 1490,
                         elaine      => 127,
                         elana       => 1714,
                         elane       => 3107,
                         elanor      => 2558,
                         elayne      => 2080,
                         elba        => 923,
                         elda        => 968,
                         eldora      => 1784,
                         eleanor     => 148,
                         eleanora    => 1848,
                         eleanore    => 1006,
                         elease      => 2044,
                         elena       => 398,
                         elene       => 3456,
                         eleni       => 2312,
                         elenor      => 1364,
                         elenora     => 1950,
                         elenore     => 2703,
                         eleonor     => 3315,
                         eleonora    => 3383,
                         eleonore    => 3177,
                         elfreda     => 3455,
                         elfrieda    => 2820,
                         elfriede    => 1697,
                         elia        => 1015,
                         eliana      => 2394,
                         elicia      => 2228,
                         elida       => 996,
                         elidia      => 3613,
                         elin        => 3244,
                         elina       => 2819,
                         elinor      => 755,
                         elinore     => 2953,
                         elisa       => 467,
                         elisabeth   => 529,
                         elise       => 576,
                         elisha      => 956,
                         elissa      => 1119,
                         eliz        => 3059,
                         eliza       => 679,
                         elizabeth   => 5,
                         elizbeth    => 1975,
                         elizebeth   => 1335,
                         elke        => 2287,
                         ella        => 208,
                         ellamae     => 3058,
                         ellan       => 3612,
                         ellen       => 126,
                         ellena      => 3687,
                         elli        => 3686,
                         ellie       => 1105,
                         elly        => 2458,
                         ellyn       => 2199,
                         elma        => 633,
                         elmira      => 1783,
                         elna        => 1580,
                         elnora      => 716,
                         elodia      => 2012,
                         elois       => 2627,
                         eloisa      => 1040,
                         eloise      => 424,
                         elouise     => 1169,
                         elsa        => 453,
                         elsie       => 196,
                         elsy        => 3537,
                         elva        => 524,
                         elvera      => 1752,
                         elvia       => 824,
                         elvie       => 2270,
                         elvina      => 2557,
                         elvira      => 439,
                         elwanda     => 3057,
                         elyse       => 1152,
                         elza        => 3176,
                         emelda      => 2311,
                         emelia      => 1847,
                         emelina     => 3243,
                         emeline     => 3106,
                         emely       => 2997,
                         emerita     => 2778,
                         emiko       => 2269,
                         emilee      => 1921,
                         emilia      => 734,
                         emilie      => 971,
                         emily       => 99,
                         emma        => 134,
                         emmaline    => 3454,
                         emmie       => 2103,
                         emmy        => 2061,
                         emogene     => 1696,
                         enda        => 3685,
                         enedina     => 1571,
                         eneida      => 2227,
                         enid        => 873,
                         enola       => 2148,
                         enriqueta   => 1428,
                         epifania    => 2526,
                         erica       => 169,
                         ericka      => 714,
                         erika       => 292,
                         erin        => 160,
                         erinn       => 2667,
                         erlene      => 2102,
                         erlinda     => 1096,
                         erline      => 2487,
                         erma        => 373,
                         ermelinda   => 2457,
                         erminia     => 2666,
                         erna        => 872,
                         ernestina   => 995,
                         ernestine   => 395,
                         eryn        => 2818,
                         esmeralda   => 739,
                         esperanza   => 558,
                         essie       => 450,
                         esta        => 1920,
                         estefana    => 3536,
                         estela      => 697,
                         estell      => 1974,
                         estella     => 512,
                         estelle     => 403,
                         ester       => 587,
                         esther      => 132,
                         estrella    => 1562,
                         etha        => 2861,
                         ethel       => 125,
                         ethelene    => 2486,
                         ethelyn     => 1570,
                         ethyl       => 2198,
                         etsuko      => 3611,
                         etta        => 507,
                         ettie       => 3610,
                         eufemia     => 2996,
                         eugena      => 3453,
                         eugenia     => 534,
                         eugenie     => 1869,
                         eula        => 420,
                         eulah       => 3535,
                         eulalia     => 1314,
                         euna        => 2860,
                         eunice      => 319,
                         eura        => 3534,
                         eusebia     => 3175,
                         eustolia    => 3242,
                         eva         => 140,
                         evalyn      => 1614,
                         evangelina  => 869,
                         evangeline  => 800,
                         eve         => 740,
                         evelia      => 1649,
                         evelin      => 2456,
                         evelina     => 1919,
                         eveline     => 1973,
                         evelyn      => 57,
                         evelyne     => 1949,
                         evelynn     => 3684,
                         evette      => 1168,
                         evia        => 3452,
                         evie        => 1410,
                         evita       => 3533,
                         evon        => 1569,
                         evonne      => 1453,
                         exie        => 2599,
                         fabiola     => 1290,
                         faith       => 460,
                         fallon      => 1905,
                         fannie      => 335,
                         fanny       => 913,
                         farah       => 2147,
                         farrah      => 1489,
                         fatima      => 1004,
                         fatimah     => 3174,
                         faustina    => 2226,
                         faviola     => 3683,
                         fawn        => 1351,
                         fay         => 553,
                         faye        => 303,
                         felecia     => 930,
                         felica      => 1695,
                         felice      => 1797,
                         felicia     => 277,
                         felicidad   => 2905,
                         felicita    => 1139,
                         felicitas   => 1492,
                         felipa      => 1391,
                         felisa      => 1846,
                         felisha     => 1473,
                         fermina     => 3609,
                         fern        => 523,
                         fernanda    => 2225,
                         fernande    => 3056,
                         ferne       => 1671,
                         fidela      => 3055,
                         fidelia     => 3532,
                         filomena    => 1158,
                         fiona       => 1740,
                         flavia      => 2130,
                         fleta       => 3173,
                         flor        => 1167,
                         flora       => 344,
                         florance    => 2129,
                         florence    => 107,
                         florencia   => 1934,
                         florene     => 1590,
                         florentina  => 2011,
                         floretta    => 2598,
                         floria      => 3382,
                         florinda    => 2010,
                         florine     => 909,
                         florrie     => 3381,
                         flossie     => 687,
                         floy        => 1263,
                         fonda       => 1561,
                         fran        => 815,
                         francene    => 2952,
                         frances     => 47,
                         francesca   => 906,
                         franchesca  => 3105,
                         francie     => 2597,
                         francina    => 2525,
                         francine    => 488,
                         francisca   => 513,
                         francoise   => 2665,
                         fransisca   => 3608,
                         freda       => 415,
                         fredda      => 3314,
                         frederica   => 2128,
                         fredericka  => 2286,
                         fredia      => 2178,
                         fredricka   => 3172,
                         freeda      => 2127,
                         freida      => 878,
                         frida       => 2995,
                         frieda      => 618,
                         fumiko      => 2455,
                         gabriela    => 595,
                         gabriele    => 1948,
                         gabriella   => 1229,
                         gabrielle   => 625,
                         gail        => 155,
                         gala        => 3313,
                         gale        => 653,
                         garnet      => 1409,
                         garnett     => 2126,
                         gaye        => 1193,
                         gayla       => 960,
                         gayle       => 365,
                         gaylene     => 2556,
                         gaynell     => 1682,
                         gaynelle    => 2746,
                         gearldine   => 2524,
                         gema        => 3682,
                         gemma       => 1546,
                         gena        => 827,
                         geneva      => 297,
                         genevie     => 3312,
                         genevieve   => 326,
                         genevive    => 3451,
                         genia       => 2454,
                         genie       => 2268,
                         genna       => 2994,
                         gennie      => 2596,
                         genny       => 2904,
                         genoveva    => 1257,
                         georgann    => 3054,
                         georgeann   => 2993,
                         georgeanna  => 3104,
                         georgene    => 1972,
                         georgetta   => 1868,
                         georgette   => 813,
                         georgia     => 228,
                         georgiana   => 1222,
                         georgiann   => 2903,
                         georgianna  => 1262,
                         georgianne  => 3531,
                         georgie     => 1320,
                         georgina    => 678,
                         georgine    => 2267,
                         geraldine   => 161,
                         geralyn     => 1560,
                         gerda       => 1403,
                         geri        => 980,
                         germaine    => 942,
                         gerri       => 1310,
                         gertha      => 2393,
                         gertie      => 1249,
                         gertrud     => 2125,
                         gertrude    => 205,
                         gertrudis   => 3607,
                         gertude     => 2777,
                         ghislaine   => 3606,
                         gianna      => 2745,
                         gidget      => 3171,
                         gigi        => 1933,
                         gilberte    => 3681,
                         gilda       => 899,
                         gillian     => 1157,
                         gilma       => 3605,
                         gina        => 211,
                         ginette     => 2817,
                         ginny       => 1276,
                         giovanna    => 1545,
                         gisela      => 1101,
                         gisele      => 1613,
                         giselle     => 1464,
                         gita        => 3241,
                         giuseppina  => 3053,
                         gladis      => 1648,
                         glady       => 2146,
                         gladys      => 103,
                         glayds      => 3311,
                         glenda      => 239,
                         glendora    => 2124,
                         glenna      => 594,
                         glennie     => 2523,
                         glennis     => 2224,
                         glinda      => 2223,
                         gloria      => 56,
                         glory       => 1694,
                         glynda      => 2555,
                         glynis      => 2744,
                         golda       => 1568,
                         goldie      => 536,
                         grace       => 114,
                         gracia      => 2145,
                         gracie      => 605,
                         graciela    => 589,
                         grayce      => 2776,
                         grazyna     => 3380,
                         gregoria    => 1211,
                         greta       => 689,
                         gretchen    => 426,
                         gretta      => 1867,
                         gricelda    => 2816,
                         grisel      => 3310,
                         griselda    => 994,
                         guadalupe   => 298,
                         gudrun      => 2369,
                         guillermina => 1039,
                         gussie      => 970,
                         gwen        => 432,
                         gwenda      => 2343,
                         gwendolyn   => 259,
                         gwenn       => 2485,
                         gwyn        => 2664,
                         gwyneth     => 3240,
                         hailey      => 1531,
                         haley       => 683,
                         halina      => 2177,
                         halley      => 3170,
                         hallie      => 871,
                         hana        => 2043,
                         hanh        => 2595,
                         hannelore   => 2123,
                         harriet     => 309,
                         harriett    => 730,
                         harriette   => 1160,
                         hassie      => 3052,
                         hattie      => 308,
                         haydee      => 1153,
                         hayley      => 1205,
                         hazel       => 138,
                         heather     => 53,
                         hedwig      => 1641,
                         hedy        => 2484,
                         heide       => 2009,
                         heidi       => 238,
                         heidy       => 3680,
                         heike       => 3051,
                         helaine     => 3239,
                         helen       => 15,
                         helena      => 562,
                         helene      => 522,
                         helga       => 898,
                         hellen      => 1289,
                         henrietta   => 429,
                         henriette   => 2079,
                         herlinda    => 1208,
                         herma       => 3238,
                         hermelinda  => 1507,
                         hermila     => 3450,
                         hermina     => 2285,
                         hermine     => 1985,
                         herminia    => 935,
                         herta       => 2702,
                         hertha      => 2951,
                         hettie      => 1559,
                         hiedi       => 3050,
                         hien        => 3379,
                         hilaria     => 2594,
                         hilary      => 696,
                         hilda       => 258,
                         hilde       => 2626,
                         hildegard   => 1225,
                         hildegarde  => 2453,
                         hildred     => 2452,
                         hillary     => 747,
                         hilma       => 1918,
                         hiroko      => 2078,
                         hisako      => 3237,
                         holli       => 1350,
                         hollie      => 902,
                         holly       => 184,
                         hortencia   => 1022,
                         hortense    => 1408,
                         hortensia   => 1681,
                         hsiu        => 3449,
                         hulda       => 1659,
                         huong       => 1845,
                         hyacinth    => 2483,
                         hyon        => 2392,
                         hyun        => 2077,
                         ida         => 181,
                         idalia      => 1631,
                         idell       => 1917,
                         idella      => 1235,
                         iesha       => 2008,
                         ignacia     => 2076,
                         ila         => 688,
                         ilana       => 2368,
                         ilda        => 2451,
                         ileana      => 1397,
                         ileen       => 2992,
                         ilene       => 786,
                         iliana      => 1693,
                         illa        => 3309,
                         ilona       => 1630,
                         ilse        => 1530,
                         iluminada   => 2593,
                         imelda      => 836,
                         imogene     => 590,
                         ina         => 527,
                         indira      => 2222,
                         inell       => 2367,
                         ines        => 915,
                         inez        => 321,
                         inga        => 1558,
                         inge        => 1488,
                         ingeborg    => 1544,
                         inger       => 2221,
                         ingrid      => 532,
                         inocencia   => 2663,
                         iola        => 991,
                         iona        => 1033,
                         ione        => 1100,
                         iraida      => 3103,
                         irena       => 1629,
                         irene       => 76,
                         iris        => 318,
                         irma        => 250,
                         irmgard     => 1916,
                         isabel      => 306,
                         isabell     => 1099,
                         isabella    => 934,
                         isabelle    => 578,
                         isadora     => 3530,
                         isaura      => 2342,
                         isela       => 1866,
                         isidra      => 2662,
                         isis        => 2482,
                         isobel      => 2902,
                         iva         => 533,
                         ivana       => 2366,
                         ivelisse    => 2743,
                         ivette      => 1052,
                         ivonne      => 1204,
                         ivy         => 658,
                         izetta      => 3049,
                         izola       => 2859,
                         jacalyn     => 1704,
                         jacelyn     => 2858,
                         jacinda     => 2701,
                         jacinta     => 1579,
                         jackeline   => 1844,
                         jackelyn    => 3378,
                         jacki       => 2060,
                         jackie      => 232,
                         jacklyn     => 877,
                         jackqueline => 3236,
                         jaclyn      => 604,
                         jacqualine  => 2341,
                         jacque      => 1234,
                         jacquelin   => 1192,
                         jacqueline  => 86,
                         jacquelyn   => 372,
                         jacquelyne  => 2592,
                         jacquelynn  => 2391,
                         jacquetta   => 3102,
                         jacqui      => 3377,
                         jacquie     => 2742,
                         jacquiline  => 2625,
                         jacquline   => 987,
                         jacqulyn    => 2075,
                         jada        => 1529,
                         jade        => 940,
                         jadwiga     => 2522,
                         jaimee      => 3235,
                         jaimie      => 1487,
                         jaleesa     => 2591,
                         jalisa      => 2857,
                         jama        => 3679,
                         jamee       => 3169,
                         jami        => 715,
                         jamie       => 146,
                         jamika      => 3448,
                         jamila      => 1515,
                         jammie      => 1680,
                         jan         => 332,
                         jana        => 431,
                         janae       => 1833,
                         janay       => 2624,
                         jane        => 77,
                         janean      => 3234,
                         janee       => 2700,
                         janeen      => 1349,
                         janel       => 1055,
                         janell      => 914,
                         janella     => 2950,
                         janelle     => 519,
                         janene      => 1813,
                         janessa     => 2042,
                         janet       => 45,
                         janeth      => 2176,
                         janett      => 2122,
                         janetta     => 1984,
                         janette     => 542,
                         janey       => 1782,
                         jani        => 3447,
                         janice      => 66,
                         janie       => 329,
                         janiece     => 3308,
                         janina      => 1374,
                         janine      => 567,
                         janis       => 412,
                         janise      => 2741,
                         janita      => 2266,
                         jann        => 2450,
                         janna       => 843,
                         jannet      => 2699,
                         jannette    => 1275,
                         jannie      => 886,
                         janyce      => 3529,
                         jaqueline   => 1000,
                         jaquelyn    => 3604,
                         jasmin      => 965,
                         jaunita     => 1713,
                         jaye        => 2775,
                         jayme       => 1125,
                         jaymie      => 2815,
                         jayna       => 2949,
                         jayne       => 603,
                         jazmin      => 1557,
                         jazmine     => 2121,
                         jean        => 58,
                         jeana       => 1300,
                         jeane       => 1486,
                         jeanelle    => 2856,
                         jeanene     => 2340,
                         jeanett     => 3048,
                         jeanetta    => 1415,
                         jeanette    => 189,
                         jeanice     => 2901,
                         jeanie      => 727,
                         jeanine     => 615,
                         jeanmarie   => 2774,
                         jeanna      => 1018,
                         jeanne      => 198,
                         jeannetta   => 3678,
                         jeannette   => 355,
                         jeannie     => 455,
                         jeannine    => 646,
                         jeffie      => 3528,
                         jena        => 1013,
                         jenae       => 3307,
                         jene        => 2698,
                         jenee       => 3047,
                         jenell      => 2007,
                         jenelle     => 1446,
                         jenette     => 1947,
                         jeneva      => 3603,
                         jeni        => 2144,
                         jenice      => 2623,
                         jenifer     => 538,
                         jeniffer    => 1363,
                         jenine      => 2284,
                         jenise      => 2101,
                         jenna       => 433,
                         jennefer    => 2175,
                         jennell     => 3376,
                         jennette    => 1514,
                         jenni       => 1463,
                         jennie      => 260,
                         jennifer    => 6,
                         jenniffer   => 1772,
                         jennine     => 3101,
                         jenny       => 276,
                         jeraldine   => 1712,
                         jeri        => 663,
                         jerica      => 2855,
                         jerilyn     => 1612,
                         jerlene     => 3446,
                         jerri       => 757,
                         jerrica     => 2697,
                         jerrie      => 1506,
                         jesenia     => 2028,
                         jesica      => 1270,
                         jessenia    => 2265,
                         jessi       => 2041,
                         jessia      => 3527,
                         jessica     => 26,
                         jessie      => 213,
                         jessika     => 2854,
                         jestine     => 3526,
                         jesusa      => 2590,
                         jesusita    => 3525,
                         jetta       => 2740,
                         jettie      => 1771,
                         jewel       => 495,
                         jewell      => 552,
                         jill        => 159,
                         jillian     => 554,
                         jina        => 2059,
                         jinny       => 3677,
                         joan        => 62,
                         joana       => 1865,
                         joane       => 2948,
                         joanie      => 1424,
                         joann       => 164,
                         joanna      => 317,
                         joanne      => 147,
                         joannie     => 2696,
                         joaquina    => 3445,
                         jocelyn     => 580,
                         jodee       => 2100,
                         jodi        => 328,
                         jodie       => 628,
                         jody        => 390,
                         joeann      => 2365,
                         joella      => 2310,
                         joelle      => 1216,
                         joellen     => 1438,
                         joetta      => 1711,
                         joette      => 3306,
                         johana      => 2589,
                         johanna     => 462,
                         johanne     => 3168,
                         johna       => 2773,
                         johnetta    => 1710,
                         johnette    => 3046,
                         johnna      => 1202,
                         johnsie     => 3233,
                         joie        => 3676,
                         jolanda     => 2588,
                         joleen      => 1520,
                         jolene      => 591,
                         jolie       => 2040,
                         joline      => 3100,
                         jolyn       => 2739,
                         jolynn      => 1670,
                         jona        => 2481,
                         jone        => 2947,
                         jonell      => 1961,
                         jonelle     => 2006,
                         jong        => 3602,
                         joni        => 582,
                         jonie       => 3045,
                         jonna       => 1628,
                         jonnie      => 1344,
                         josefa      => 847,
                         josefina    => 454,
                         josefine    => 3375,
                         joselyn     => 2005,
                         josephina   => 1452,
                         josephine   => 121,
                         josette     => 1218,
                         josie       => 514,
                         joslyn      => 2220,
                         josphine    => 2738,
                         jovan       => 3374,
                         jovita      => 1238,
                         joy         => 227,
                         joya        => 3305,
                         joyce       => 49,
                         joycelyn    => 1390,
                         joye        => 2074,
                         juana       => 354,
                         juanita     => 135,
                         judi        => 950,
                         judie       => 1781,
                         judith      => 64,
                         judy        => 69,
                         jule        => 3167,
                         julee       => 2417,
                         julene      => 3166,
                         juli        => 1269,
                         julia       => 89,
                         juliana     => 795,
                         juliane     => 2622,
                         juliann     => 1751,
                         julianna    => 1184,
                         julianne    => 773,
                         julie       => 52,
                         julieann    => 3232,
                         julienne    => 2339,
                         juliet      => 876,
                         julieta     => 1728,
                         julietta    => 3524,
                         juliette    => 844,
                         julissa     => 1770,
                         jung        => 1151,
                         junie       => 3231,
                         junita      => 2480,
                         junko       => 3444,
                         justa       => 3099,
                         justina     => 969,
                         justine     => 632,
                         jutta       => 2120,
                         kacey       => 1709,
                         kaci        => 1892,
                         kacie       => 1843,
                         kacy        => 2390,
                         kaila       => 2695,
                         kaitlin     => 907,
                         kaitlyn     => 975,
                         kala        => 1528,
                         kaleigh     => 3230,
                         kaley       => 2521,
                         kali        => 1946,
                         kallie      => 3523,
                         kalyn       => 3304,
                         kamala      => 3098,
                         kami        => 1319,
                         kamilah     => 3097,
                         kandace     => 1832,
                         kandi       => 1539,
                         kandice     => 1538,
                         kandis      => 2772,
                         kandra      => 3443,
                         kandy       => 1669,
                         kanesha     => 3601,
                         kanisha     => 3165,
                         kara        => 371,
                         karan       => 1796,
                         kareen      => 3044,
                         karen       => 13,
                         karena      => 2853,
                         karey       => 2174,
                         kari        => 402,
                         karie       => 1578,
                         karima      => 3373,
                         karin       => 517,
                         karine      => 2587,
                         karisa      => 3229,
                         karissa     => 1427,
                         karla       => 360,
                         karleen     => 2479,
                         karlene     => 1769,
                         karly       => 2852,
                         karlyn      => 3372,
                         karma       => 2364,
                         karmen      => 2309,
                         karol       => 1228,
                         karole      => 3675,
                         karoline    => 3096,
                         karolyn     => 1472,
                         karon       => 1178,
                         karren      => 1983,
                         karri       => 1603,
                         karrie      => 1062,
                         karry       => 3600,
                         kary        => 2737,
                         karyl       => 2586,
                         karyn       => 866,
                         kasandra    => 1831,
                         kasey       => 798,
                         kasha       => 3371,
                         kasi        => 3522,
                         kasie       => 2520,
                         kassandra   => 1389,
                         kassie      => 2244,
                         kate        => 441,
                         katelin     => 3043,
                         katelyn     => 830,
                         katelynn    => 2946,
                         katerine    => 3521,
                         kathaleen   => 2039,
                         katharina   => 2004,
                         katharine   => 627,
                         katharyn    => 3228,
                         kathe       => 2449,
                         katheleen   => 3227,
                         katherin    => 2143,
                         katherina   => 3599,
                         katherine   => 61,
                         kathern     => 2173,
                         katheryn    => 892,
                         kathey      => 2448,
                         kathi       => 959,
                         kathie      => 807,
                         kathleen    => 36,
                         kathlene    => 1627,
                         kathline    => 3370,
                         kathlyn     => 1739,
                         kathrin     => 2814,
                         kathrine    => 782,
                         kathryn     => 82,
                         kathryne    => 1768,
                         kathy       => 71,
                         kathyrn     => 1830,
                         kati        => 2027,
                         katia       => 2554,
                         katie       => 191,
                         katina      => 889,
                         katlyn      => 2308,
                         katrice     => 2519,
                         katrina     => 293,
                         kattie      => 1971,
                         katy        => 772,
                         kay         => 267,
                         kayce       => 3095,
                         kaycee      => 3303,
                         kaye        => 790,
                         kayla       => 330,
                         kaylee      => 1626,
                         kayleen     => 2307,
                         kayleigh    => 2197,
                         kaylene     => 2099,
                         kazuko      => 2243,
                         kecia       => 1767,
                         keeley      => 3442,
                         keely       => 1462,
                         keena       => 2553,
                         keesha      => 1970,
                         keiko       => 1864,
                         keila       => 2945,
                         keira       => 3674,
                         keisha      => 592,
                         keitha      => 2813,
                         keli        => 1891,
                         kelle       => 2661,
                         kellee      => 2219,
                         kelli       => 357,
                         kellie      => 444,
                         kelly       => 67,
                         kellye      => 2218,
                         kelsey      => 526,
                         kelsi       => 2900,
                         kelsie      => 1883,
                         kemberly    => 3164,
                         kena        => 2552,
                         kenda       => 2812,
                         kendal      => 3163,
                         kendra      => 391,
                         kenia       => 2899,
                         kenisha     => 2242,
                         kenna       => 1738,
                         kenya       => 778,
                         kenyatta    => 1780,
                         kenyetta    => 1982,
                         kera        => 3162,
                         keren       => 2991,
                         keri        => 596,
                         kerri       => 509,
                         kerrie      => 1137,
                         kerstin     => 2811,
                         kesha       => 1299,
                         keshia      => 1313,
                         keturah     => 3042,
                         keva        => 3673,
                         khadijah    => 3520,
                         khalilah    => 3441,
                         kiana       => 2306,
                         kiara       => 1703,
                         kiera       => 2098,
                         kiersten    => 2736,
                         kiesha      => 2097,
                         kiley       => 2073,
                         kim         => 118,
                         kimber      => 2172,
                         kimberely   => 1692,
                         kimberlee   => 964,
                         kimberley   => 560,
                         kimberli    => 1915,
                         kimberlie   => 2416,
                         kimberly    => 24,
                         kimbery     => 2585,
                         kimbra      => 3598,
                         kimi        => 2944,
                         kimiko      => 2621,
                         kina        => 3226,
                         kindra      => 2119,
                         kira        => 1080,
                         kirsten     => 599,
                         kirstie     => 3369,
                         kirstin     => 1708,
                         kisha       => 1104,
                         kittie      => 3161,
                         kiyoko      => 3041,
                         kizzie      => 3160,
                         kizzy       => 1904,
                         klara       => 2771,
                         kori        => 1513,
                         kortney     => 3159,
                         kourtney    => 2026,
                         krissy      => 2851,
                         krista      => 378,
                         kristal     => 1150,
                         kristan     => 1602,
                         kristeen    => 3440,
                         kristel     => 2447,
                         kristen     => 192,
                         kristi      => 312,
                         kristian    => 1829,
                         kristie     => 475,
                         kristin     => 212,
                         kristina    => 284,
                         kristine    => 333,
                         kristle     => 3672,
                         kristy      => 346,
                         kristyn     => 1727,
                         krysta      => 2338,
                         krystal     => 399,
                         krysten     => 2898,
                         krystin     => 3158,
                         krystina    => 2897,
                         krystle     => 990,
                         krystyna    => 1601,
                         kyla        => 1242,
                         kylee       => 1668,
                         kylie       => 1115,
                         kymberly    => 2305,
                         kyoko       => 2896,
                         kyong       => 1396,
                         kyra        => 1378,
                         kyung       => 1414,
                         lacey       => 593,
                         lachelle    => 2770,
                         laci        => 1812,
                         lacie       => 1527,
                         lacresha    => 3671,
                         lacy        => 875,
                         ladawn      => 3225,
                         ladonna     => 650,
                         lael        => 3368,
                         lahoma      => 3224,
                         laila       => 1945,
                         laine       => 3519,
                         lajuana     => 2850,
                         lakeesha    => 3302,
                         lakeisha    => 818,
                         lakendra    => 3157,
                         lakenya     => 3367,
                         lakesha     => 979,
                         lakeshia    => 1402,
                         lakia       => 2895,
                         lakiesha    => 2735,
                         lakisha     => 774,
                         lakita      => 3040,
                         lala        => 2769,
                         lamonica    => 3597,
                         lana        => 447,
                         lanell      => 2415,
                         lanelle     => 2849,
                         lanette     => 1611,
                         lani        => 1667,
                         lanie       => 2990,
                         lanita      => 1882,
                         lannie      => 3094,
                         lanora      => 3039,
                         laquanda    => 2768,
                         laquita     => 1221,
                         larae       => 2171,
                         laraine     => 2584,
                         laree       => 3670,
                         larhonda    => 2058,
                         larissa     => 1089,
                         larita      => 2989,
                         laronda     => 2518,
                         larraine    => 3669,
                         larue       => 1589,
                         lasandra    => 2660,
                         lashanda    => 1426,
                         lashandra   => 3596,
                         lashaun     => 3366,
                         lashaunda   => 3301,
                         lashawn     => 1071,
                         lashawna    => 3518,
                         lashawnda   => 2894,
                         lashay      => 3668,
                         lashell     => 3595,
                         lashon      => 2943,
                         lashonda    => 949,
                         lashunda    => 2072,
                         lasonya     => 2810,
                         latanya     => 961,
                         latarsha    => 2848,
                         latasha     => 482,
                         latashia    => 2659,
                         latesha     => 2517,
                         latia       => 2337,
                         laticia     => 2057,
                         latina      => 2767,
                         latisha     => 676,
                         latonia     => 1288,
                         latonya     => 543,
                         latoria     => 2170,
                         latosha     => 1338,
                         latoya      => 362,
                         latoyia     => 2809,
                         latrice     => 1012,
                         latricia    => 1281,
                         latrina     => 2056,
                         latrisha    => 2734,
                         launa       => 2551,
                         laura       => 22,
                         lauralee    => 3038,
                         lauran      => 3517,
                         laure       => 2389,
                         laureen     => 1348,
                         laurel      => 521,
                         lauren      => 162,
                         laurena     => 3667,
                         laurene     => 1811,
                         lauretta    => 1114,
                         laurette    => 1505,
                         lauri       => 897,
                         laurice     => 2516,
                         laurie      => 190,
                         laurinda    => 2942,
                         laurine     => 2264,
                         lauryn      => 2733,
                         lavada      => 1750,
                         lavelle     => 3300,
                         lavenia     => 2941,
                         lavera      => 2446,
                         laverna     => 1969,
                         laverne     => 435,
                         laveta      => 2988,
                         lavette     => 2732,
                         lavina      => 1413,
                         lavinia     => 1842,
                         lavon       => 1407,
                         lavona      => 2893,
                         lavonda     => 1625,
                         lavone      => 3594,
                         lavonia     => 2445,
                         lavonna     => 2766,
                         lavonne     => 785,
                         lawana      => 2118,
                         lawanda     => 803,
                         lawanna     => 2550,
                         layla       => 2304,
                         lea         => 630,
                         leah        => 265,
                         lean        => 3156,
                         leana       => 2071,
                         leandra     => 1666,
                         leann       => 680,
                         leanna      => 860,
                         leanne      => 645,
                         leanora     => 3439,
                         leatha      => 1600,
                         leatrice    => 1401,
                         lecia       => 3516,
                         leda        => 1761,
                         leeann      => 955,
                         leeanna     => 2444,
                         leeanne     => 2263,
                         leena       => 2987,
                         leesa       => 1737,
                         leia        => 3037,
                         leida       => 3515,
                         leigh       => 421,
                         leigha      => 3438,
                         leighann    => 2515,
                         leila       => 669,
                         leilani     => 1309,
                         leisa       => 1343,
                         leisha      => 2694,
                         lekisha     => 3155,
                         lela        => 461,
                         lelah       => 3437,
                         lelia       => 882,
                         lena        => 254,
                         lenita      => 3593,
                         lenna       => 2142,
                         lennie      => 1702,
                         lenora      => 506,
                         lenore      => 718,
                         leola       => 584,
                         leoma       => 3036,
                         leona       => 275,
                         leonarda    => 2196,
                         leone       => 1308,
                         leonia      => 2892,
                         leonida     => 3592,
                         leonie      => 2443,
                         leonila     => 2442,
                         leonor      => 839,
                         leonora     => 1188,
                         leonore     => 2514,
                         leontine    => 3035,
                         leora       => 1048,
                         leota       => 1123,
                         lera        => 2169,
                         lesa        => 932,
                         lesha       => 3591,
                         lesia       => 2055,
                         leslee      => 1691,
                         lesley      => 579,
                         lesli       => 1795,
                         leslie      => 143,
                         lessie      => 850,
                         leta        => 929,
                         letha       => 695,
                         leticia     => 376,
                         letisha     => 2847,
                         letitia     => 925,
                         lettie      => 1085,
                         letty       => 2003,
                         lezlie      => 2658,
                         liana       => 1690,
                         liane       => 1779,
                         lianne      => 2940,
                         libbie      => 3223,
                         libby       => 958,
                         librada     => 2657,
                         lida        => 1437,
                         lidia       => 706,
                         lien        => 1932,
                         lieselotte  => 3299,
                         ligia       => 2168,
                         lila        => 446,
                         lili        => 2441,
                         lilia       => 751,
                         lilian      => 794,
                         liliana     => 849,
                         lilla       => 1968,
                         lilli       => 3365,
                         lillia      => 3298,
                         lilliam     => 3436,
                         lillian     => 98,
                         lilliana    => 3435,
                         lillie      => 230,
                         lilly       => 693,
                         lily        => 619,
                         lina        => 792,
                         linda       => 3,
                         lindsay     => 296,
                         lindsey     => 295,
                         lindsy      => 3434,
                         lindy       => 1298,
                         linette     => 1640,
                         ling        => 2303,
                         linh        => 1890,
                         linnea      => 1471,
                         linnie      => 1318,
                         linsey      => 1863,
                         lisa        => 11,
                         lisabeth    => 3433,
                         lisandra    => 3154,
                         lisbeth     => 2478,
                         lise        => 1461,
                         lisette     => 1362,
                         lisha       => 2336,
                         lissa       => 1766,
                         lissette    => 1329,
                         lita        => 1647,
                         livia       => 2414,
                         liz         => 896,
                         liza        => 763,
                         lizabeth    => 1460,
                         lizbeth     => 1504,
                         lizeth      => 3222,
                         lizette     => 1297,
                         lizzette    => 2693,
                         lizzie      => 598,
                         loida       => 2477,
                         lois        => 91,
                         loise       => 3432,
                         lola        => 349,
                         lolita      => 908,
                         loma        => 2413,
                         lona        => 1044,
                         londa       => 3034,
                         loni        => 1931,
                         lonna       => 2070,
                         lora        => 406,
                         loraine     => 731,
                         loralee     => 2939,
                         lore        => 2283,
                         lorean      => 3590,
                         loree       => 1930,
                         loreen      => 1903,
                         lorelei     => 1736,
                         lorena      => 443,
                         lorene      => 452,
                         lorenza     => 1395,
                         loreta      => 2891,
                         loretta     => 187,
                         lorette     => 2938,
                         lori        => 78,
                         loria       => 2937,
                         loriann     => 2513,
                         lorie       => 649,
                         lorilee     => 3666,
                         lorina      => 2846,
                         lorinda     => 1588,
                         lorine      => 1177,
                         loris       => 2692,
                         lorita      => 2808,
                         lorna       => 541,
                         lorraine    => 165,
                         lorretta    => 1679,
                         lorri       => 1095,
                         lorriane    => 2890,
                         lorrie      => 756,
                         lorrine     => 3665,
                         lory        => 2512,
                         lottie      => 508,
                         lou         => 571,
                         louann      => 1183,
                         louanne     => 2335,
                         louella     => 928,
                         louetta     => 3514,
                         louisa      => 765,
                         louise      => 83,
                         loura       => 3589,
                         lourdes     => 520,
                         lourie      => 3664,
                         louvenia    => 2054,
                         lovella     => 2388,
                         lovetta     => 3663,
                         lovie       => 1485,
                         loyce       => 2002,
                         luana       => 1881,
                         luann       => 797,
                         luanna      => 3431,
                         luanne      => 1176,
                         luba        => 3513,
                         luci        => 2889,
                         lucia       => 458,
                         luciana     => 1794,
                         lucie       => 1400,
                         lucienne    => 1749,
                         lucila      => 1187,
                         lucile      => 644,
                         lucilla     => 2986,
                         lucille     => 145,
                         lucina      => 1944,
                         lucinda     => 499,
                         lucrecia    => 2025,
                         lucretia    => 1061,
                         lucy        => 206,
                         ludie       => 2412,
                         ludivina    => 2936,
                         luella      => 634,
                         luetta      => 2845,
                         luisa       => 662,
                         luise       => 2476,
                         lula        => 348,
                         lulu        => 1361,
                         lupe        => 569,
                         lupita      => 1646,
                         lura        => 1133,
                         lurlene     => 3297,
                         lurline     => 2141,
                         luvenia     => 1929,
                         luz         => 341,
                         lyda        => 1599,
                         lydia       => 240,
                         lyla        => 1810,
                         lynda       => 322,
                         lyndia      => 2888,
                         lyndsay     => 1678,
                         lyndsey     => 1373,
                         lynell      => 2475,
                         lynelle     => 2363,
                         lynetta     => 2731,
                         lynette     => 417,
                         lynn        => 166,
                         lynna       => 3364,
                         lynne       => 368,
                         lynnette    => 857,
                         lynsey      => 2549,
                         mabel       => 251,
                         mabelle     => 2844,
                         mable       => 394,
                         machelle    => 1765,
                         macie       => 2217,
                         mackenzie   => 1501,
                         macy        => 2262,
                         madalene    => 3588,
                         madaline    => 2117,
                         madalyn     => 1943,
                         madelaine   => 3033,
                         madeleine   => 879,
                         madelene    => 2935,
                         madeline    => 323,
                         madelyn     => 842,
                         madge       => 806,
                         madie       => 1981,
                         madlyn      => 2511,
                         mae         => 287,
                         maegan      => 1880,
                         mafalda     => 3093,
                         magali      => 3092,
                         magaly      => 1980,
                         magan       => 2362,
                         magaret     => 2440,
                         magda       => 1227,
                         magdalen    => 2656,
                         magdalena   => 664,
                         magdalene   => 1328,
                         magen       => 2411,
                         magnolia    => 1436,
                         mahalia     => 3587,
                         mai         => 868,
                         maia        => 2548,
                         maida       => 2195,
                         maile       => 2730,
                         maira       => 1902,
                         maire       => 2887,
                         maisha      => 3153,
                         maisie      => 3363,
                         majorie     => 1207,
                         makeda      => 3662,
                         malena      => 3661,
                         malia       => 1735,
                         malika      => 2194,
                         malinda     => 743,
                         malisa      => 2167,
                         malissa     => 1043,
                         malka       => 3152,
                         mallie      => 2765,
                         mallory     => 767,
                         malorie     => 2934,
                         malvina     => 3512,
                         mamie       => 347,
                         mammie      => 2241,
                         mana        => 2655,
                         manda       => 2216,
                         mandi       => 1129,
                         mandie      => 2886,
                         mandy       => 451,
                         manie       => 3296,
                         manuela     => 652,
                         maple       => 2439,
                         mara        => 880,
                         maragaret   => 3295,
                         maragret    => 2843,
                         maranda     => 1385,
                         marcela     => 1166,
                         marcelene   => 3511,
                         marcelina   => 1356,
                         marceline   => 2654,
                         marcell     => 3660,
                         marcella    => 397,
                         marcelle    => 1248,
                         marcene     => 3091,
                         marchelle   => 3221,
                         marci       => 838,
                         marcia      => 233,
                         marcie      => 762,
                         marcy       => 661,
                         mardell     => 3430,
                         maren       => 2166,
                         marg        => 3362,
                         margaret    => 9,
                         margareta   => 2547,
                         margarete   => 1624,
                         margarett   => 1914,
                         margaretta  => 2282,
                         margarette  => 1451,
                         margarita   => 300,
                         margarite   => 1942,
                         margart     => 2302,
                         marge       => 1156,
                         margene     => 3032,
                         margeret    => 2116,
                         margert     => 2691,
                         margery     => 777,
                         marget      => 2653,
                         margherita  => 2885,
                         margie      => 262,
                         margit      => 2096,
                         margo       => 639,
                         margorie    => 2281,
                         margot      => 953,
                         margret     => 635,
                         margrett    => 3294,
                         marguerita  => 2510,
                         marguerite  => 307,
                         margurite   => 2024,
                         margy       => 3586,
                         marhta      => 3220,
                         mari        => 812,
                         maria       => 7,
                         mariah      => 1215,
                         mariam      => 1268,
                         marian      => 243,
                         mariana     => 874,
                         marianela   => 3429,
                         mariann     => 1342,
                         marianna    => 1037,
                         marianne    => 370,
                         maribel     => 572,
                         maribeth    => 1567,
                         marica      => 2807,
                         maricela    => 776,
                         maricruz    => 3510,
                         marie       => 44,
                         mariel      => 2165,
                         mariela     => 1793,
                         mariella    => 3428,
                         marielle    => 3427,
                         marietta    => 837,
                         mariette    => 2933,
                         mariko      => 2690,
                         marilee     => 1384,
                         marilou     => 1809,
                         marilu      => 2620,
                         marilyn     => 80,
                         marilynn    => 1060,
                         marinda     => 2689,
                         marion      => 176,
                         marisa      => 608,
                         marisela    => 1047,
                         marisha     => 2932,
                         marisol     => 613,
                         marissa     => 516,
                         marita      => 1388,
                         maritza     => 643,
                         marivel     => 2729,
                         marjorie    => 128,
                         marjory     => 1165,
                         marketta    => 3509,
                         markita     => 2261,
                         marla       => 480,
                         marlana     => 2509,
                         marleen     => 2140,
                         marlen      => 2652,
                         marlena     => 1175,
                         marlene     => 237,
                         marline     => 2806,
                         marlo       => 1537,
                         marlyn      => 1241,
                         marlys      => 1201,
                         marna       => 2115,
                         marni       => 2164,
                         marnie      => 1360,
                         marquerite  => 1450,
                         marquetta   => 2301,
                         marquita    => 901,
                         marquitta   => 3219,
                         marsha      => 252,
                         marta       => 459,
                         marth       => 3031,
                         martha      => 38,
                         marti       => 1526,
                         martina     => 638,
                         martine     => 1748,
                         marva       => 835,
                         marvel      => 1503,
                         marvella    => 3218,
                         marvis      => 2985,
                         mary        => 1,
                         marya       => 2410,
                         maryalice   => 2583,
                         maryam      => 2409,
                         maryann     => 336,
                         maryanna    => 2842,
                         maryanne    => 799,
                         marybelle   => 3293,
                         marybeth    => 989,
                         maryellen   => 895,
                         maryetta    => 3659,
                         maryjo      => 1639,
                         marylee     => 1778,
                         marylin     => 1406,
                         maryln      => 3658,
                         marylou     => 720,
                         marylouise  => 3030,
                         marylyn     => 1828,
                         marylynn    => 2931,
                         maryrose    => 3090,
                         masako      => 1928,
                         matha       => 3508,
                         mathilda    => 1862,
                         mathilde    => 2546,
                         matilda     => 668,
                         matilde     => 1088,
                         mattie      => 248,
                         maud        => 1296,
                         maude       => 537,
                         maudie      => 1017,
                         maura       => 867,
                         maureen     => 223,
                         maurine     => 1011,
                         maurita     => 3657,
                         mavis       => 640,
                         maxie       => 1484,
                         maximina    => 3361,
                         maxine      => 249,
                         maya        => 1079,
                         maybell     => 2508,
                         maybelle    => 1445,
                         maye        => 2438,
                         mayme       => 1103,
                         mayola      => 3029,
                         mayra       => 602,
                         mazie       => 1556,
                         meagan      => 666,
                         meaghan     => 1327,
                         mechelle    => 1665,
                         meda        => 3507,
                         megan       => 151,
                         meggan      => 2651,
                         meghan      => 422,
                         meghann     => 2215,
                         melaine     => 2650,
                         melani      => 2930,
                         melania     => 3360,
                         melanie     => 186,
                         melany      => 2387,
                         melba       => 469,
                         melda       => 2764,
                         melia       => 3151,
                         melida      => 2929,
                         melina      => 1449,
                         melinda     => 220,
                         melisa      => 721,
                         melissa     => 30,
                         melissia    => 2582,
                         melita      => 2928,
                         mellie      => 2437,
                         mellisa     => 963,
                         mellissa    => 1106,
                         melodee     => 2984,
                         melodi      => 3506,
                         melodie     => 1132,
                         melody      => 340,
                         melonie     => 1555,
                         melony      => 1512,
                         melva       => 802,
                         melvina     => 1274,
                         melynda     => 2386,
                         mendy       => 2728,
                         mercedez    => 3089,
                         mercy       => 1543,
                         meredith    => 416,
                         meri        => 2507,
                         merideth    => 3217,
                         meridith    => 2436,
                         merilyn     => 2139,
                         merissa     => 3656,
                         merlene     => 2095,
                         merlyn      => 3028,
                         merna       => 2280,
                         merri       => 2094,
                         merrie      => 2688,
                         merrilee    => 2983,
                         merry       => 1070,
                         mertie      => 3585,
                         meryl       => 1726,
                         meta        => 1511,
                         mia         => 704,
                         mica        => 2727,
                         micaela     => 1199,
                         micha       => 3655,
                         michaela    => 983,
                         michaele    => 3150,
                         michele     => 154,
                         michelina   => 3088,
                         micheline   => 2279,
                         michell     => 943,
                         michelle    => 21,
                         michiko     => 2038,
                         micki       => 2069,
                         mickie      => 1879,
                         miesha      => 3216,
                         migdalia    => 1051,
                         mignon      => 2726,
                         miguelina   => 2506,
                         mika        => 2649,
                         mikaela     => 3359,
                         miki        => 2805,
                         mikki       => 2068,
                         mila        => 1967,
                         milagro     => 2474,
                         milagros    => 733,
                         milda       => 2841,
                         mildred     => 60,
                         milissa     => 1566,
                         millicent   => 891,
                         millie      => 621,
                         milly       => 3292,
                         mimi        => 1191,
                         mina        => 962,
                         minda       => 2725,
                         mindi       => 1587,
                         mindy       => 449,
                         minerva     => 692,
                         ming        => 2982,
                         minna       => 2361,
                         minnie      => 236,
                         minta       => 3584,
                         mira        => 1747,
                         miranda     => 456,
                         mireille    => 2581,
                         mirella     => 2840,
                         mireya      => 1394,
                         miriam      => 279,
                         mirian      => 1510,
                         mirna       => 1136,
                         mirta       => 1577,
                         mirtha      => 2619,
                         misha       => 2804,
                         missy       => 1146,
                         misti       => 1195,
                         mistie      => 3654,
                         misty       => 286,
                         mitsue      => 3583,
                         mitsuko     => 2839,
                         mittie      => 1419,
                         mitzi       => 811,
                         mitzie      => 2724,
                         miyoko      => 3215,
                         modesta     => 1645,
                         moira       => 1677,
                         mollie      => 568,
                         molly       => 310,
                         mona        => 407,
                         monet       => 3149,
                         monica      => 131,
                         monika      => 948,
                         monique     => 327,
                         monnie      => 3148,
                         monserrate  => 2385,
                         moriah      => 2927,
                         mozell      => 1827,
                         mozella     => 2334,
                         mozelle     => 1214,
                         muoi        => 3087,
                         muriel      => 396,
                         myesha      => 3582,
                         myong       => 1746,
                         myra        => 375,
                         myriam      => 1459,
                         myrl        => 3214,
                         myrle       => 2333,
                         myrna       => 479,
                         myrta       => 3581,
                         myrtice     => 1777,
                         myrtie      => 2193,
                         myrtis      => 1280,
                         myrtle      => 253,
                         myung       => 2332,
                         nada        => 1676,
                         nadene      => 3086,
                         nadia       => 805,
                         nadine      => 401,
                         naida       => 3580,
                         nakesha     => 3291,
                         nakia       => 1174,
                         nakisha     => 1901,
                         nakita      => 2240,
                         nana        => 2360,
                         nancee      => 3505,
                         nancey      => 3213,
                         nanci       => 1383,
                         nancie      => 2384,
                         nancy       => 12,
                         nanette     => 783,
                         nannette    => 1483,
                         nannie      => 729,
                         naoma       => 2114,
                         naomi       => 269,
                         narcisa     => 2505,
                         natacha     => 3212,
                         natalia     => 855,
                         natalie     => 214,
                         natalya     => 3504,
                         natashia    => 2687,
                         nathalie    => 1247,
                         natisha     => 2981,
                         natividad   => 1317,
                         natosha     => 2239,
                         necole      => 3579,
                         neda        => 2838,
                         nedra       => 1287,
                         neida       => 3653,
                         nelda       => 691,
                         nelia       => 2053,
                         nelida      => 1808,
                         nell        => 556,
                         nella       => 1689,
                         nelle       => 1586,
                         nellie      => 235,
                         nelly       => 945,
                         nena        => 1482,
                         nenita      => 2980,
                         neoma       => 1941,
                         neomi       => 3358,
                         nereida     => 1240,
                         nerissa     => 2435,
                         nery        => 2926,
                         neta        => 2067,
                         nettie      => 471,
                         neva        => 719,
                         ngan        => 3290,
                         ngoc        => 2052,
                         nguyet      => 3357,
                         nichelle    => 1878,
                         nichol      => 1900,
                         nichole     => 392,
                         nicholle    => 3578,
                         nicki       => 1206,
                         nickie      => 1960,
                         nickole     => 2331,
                         nicol       => 2383,
                         nicolasa    => 1899,
                         nicole      => 68,
                         nicolette   => 1638,
                         nicolle     => 2001,
                         nida        => 3027,
                         nidia       => 1536,
                         niesha      => 3026,
                         niki        => 1295,
                         nikia       => 2113,
                         nikki       => 511,
                         nikole      => 1940,
                         nila        => 1444,
                         nilda       => 1029,
                         nilsa       => 1725,
                         nina        => 263,
                         ninfa       => 1760,
                         nisha       => 3025,
                         nita        => 769,
                         nobuko      => 3356,
                         noelia      => 1598,
                         noella      => 1959,
                         noelle      => 924,
                         noemi       => 761,
                         nohemi      => 2925,
                         nola        => 685,
                         noma        => 2580,
                         nona        => 810,
                         nora        => 261,
                         norah       => 2579,
                         noreen      => 744,
                         norene      => 1542,
                         noriko      => 2686,
                         norine      => 1688,
                         norma       => 94,
                         nova        => 1448,
                         novella     => 1443,
                         nubia       => 3426,
                         nydia       => 1500,
                         nyla        => 2408,
                         obdulia     => 2648,
                         ocie        => 1701,
                         octavia     => 939,
                         odelia      => 2723,
                         odessa      => 728,
                         odette      => 1734,
                         odilia      => 2359,
                         ofelia      => 665,
                         ola         => 566,
                         olene       => 2884,
                         oleta       => 1233,
                         olevia      => 3577,
                         olga        => 271,
                         olimpia     => 2722,
                         olinda      => 3085,
                         oliva       => 1826,
                         olive       => 436,
                         olivia      => 343,
                         ollie       => 473,
                         olympia     => 2037,
                         oneida      => 2138,
                         onie        => 3425,
                         onita       => 3024,
                         opal        => 337,
                         ophelia     => 808,
                         ora         => 470,
                         oralee      => 3289,
                         oralia      => 1087,
                         oretha      => 3288,
                         orpha       => 1502,
                         ossie       => 2000,
                         otelia      => 3576,
                         otilia      => 1707,
                         ouida       => 1724,
                         ozell       => 3652,
                         ozella      => 2618,
                         ozie        => 3287,
                         paige       => 581,
                         palma       => 1764,
                         palmira     => 3023,
                         pam         => 356,
                         pamala      => 982,
                         pamela      => 37,
                         pamelia     => 2093,
                         pamella     => 2163,
                         pamila      => 3651,
                         pamula      => 3147,
                         pansy       => 922,
                         paola       => 1759,
                         parthenia   => 3146,
                         particia    => 1927,
                         pasty       => 3424,
                         pat         => 377,
                         patience    => 1958,
                         patria      => 2721,
                         patrica     => 559,
                         patrice     => 484,
                         patricia    => 2,
                         patrina     => 1999,
                         patsy       => 257,
                         patti       => 442,
                         pattie      => 1057,
                         patty       => 363,
                         paula       => 95,
                         paulene     => 2803,
                         pauletta    => 2238,
                         paulette    => 405,
                         paulina     => 1122,
                         pauline     => 133,
                         paulita     => 3355,
                         pearl       => 221,
                         pearle      => 1998,
                         pearlene    => 2278,
                         pearlie     => 741,
                         pearline    => 1164,
                         pearly      => 3022,
                         peggie      => 1442,
                         peggy       => 101,
                         penelope    => 732,
                         penney      => 2407,
                         penni       => 2578,
                         pennie      => 1499,
                         penny       => 266,
                         perla       => 1210,
                         petra       => 588,
                         petrina     => 2330,
                         petronila   => 3211,
                         phebe       => 3354,
                         phillis     => 1094,
                         philomena   => 1186,
                         phung       => 3210,
                         phuong      => 1377,
                         phylicia    => 2720,
                         phylis      => 1376,
                         phyliss     => 1418,
                         phyllis     => 93,
                         piedad      => 2617,
                         pilar       => 1117,
                         pinkie      => 1807,
                         polly       => 550,
                         porsha      => 2277,
                         portia      => 1069,
                         pricilla    => 1149,
                         priscila    => 3084,
                         priscilla   => 268,
                         providencia => 2802,
                         prudence    => 1498,
                         pura        => 2979,
                         qiana       => 2260,
                         queenie     => 1913,
                         quiana      => 2092,
                         quyen       => 3021,
                         rachael     => 393,
                         rachal      => 3145,
                         racheal     => 1038,
                         rachel      => 79,
                         rachele     => 2162,
                         rachell     => 2036,
                         rachelle    => 583,
                         racquel     => 1745,
                         rae         => 712,
                         raeann      => 2358,
                         raelene     => 3209,
                         rafaela     => 1078,
                         raguel      => 2719,
                         raina       => 2051,
                         raisa       => 2837,
                         ramona      => 290,
                         ramonita    => 2023,
                         rana        => 1939,
                         ranae       => 2473,
                         randa       => 1806,
                         randee      => 2472,
                         randi       => 674,
                         ranee       => 3020,
                         raquel      => 428,
                         rasheeda    => 2647,
                         rashida     => 1723,
                         raye        => 2300,
                         raylene     => 2577,
                         raymonde    => 3650,
                         rayna       => 2022,
                         reanna      => 3208,
                         reatha      => 2299,
                         reba        => 503,
                         rebbeca     => 2237,
                         rebbecca    => 2192,
                         rebeca      => 988,
                         rebecca     => 34,
                         rebecka     => 2801,
                         rebekah     => 498,
                         reda        => 2576,
                         reena       => 3286,
                         refugia     => 2883,
                         regena      => 2050,
                         regenia     => 2259,
                         regina      => 168,
                         regine      => 3575,
                         reginia     => 3144,
                         reiko       => 2646,
                         reina       => 1113,
                         reita       => 3353,
                         rema        => 3285,
                         remedios    => 2329,
                         remona      => 3207,
                         rena        => 478,
                         renae       => 966,
                         renata      => 1261,
                         renate      => 1260,
                         renay       => 3284,
                         renda       => 3352,
                         renea       => 1722,
                         renee       => 180,
                         renetta     => 2645,
                         renita      => 1091,
                         renna       => 3503,
                         ressie      => 2882,
                         reta        => 1112,
                         retha       => 1003,
                         retta       => 1957,
                         reva        => 820,
                         reyna       => 911,
                         reynalda    => 2718,
                         rhea        => 900,
                         rheba       => 3502,
                         rhiannon    => 1519,
                         rhoda       => 682,
                         rhona       => 2685,
                         rhonda      => 137,
                         ricarda     => 3423,
                         richelle    => 1232,
                         ricki       => 2763,
                         rikki       => 1926,
                         rima        => 3501,
                         rina        => 1565,
                         risa        => 1925,
                         rita        => 104,
                         riva        => 3143,
                         rivka       => 2978,
                         robbi       => 3019,
                         robbin      => 1025,
                         robbyn      => 3351,
                         robena      => 3649,
                         roberta     => 183,
                         robin       => 100,
                         robyn       => 381,
                         rochel      => 2977,
                         rochell     => 2545,
                         rochelle    => 425,
                         rocio       => 974,
                         rolanda     => 1610,
                         rolande     => 3574,
                         roma        => 1231,
                         romaine     => 2276,
                         romana      => 1861,
                         romelia     => 2035,
                         romona      => 1190,
                         rona        => 1382,
                         ronda       => 485,
                         roni        => 1912,
                         ronna       => 1541,
                         ronni       => 2191,
                         rosa        => 112,
                         rosalba     => 1259,
                         rosalee     => 1010,
                         rosalia     => 986,
                         rosalie     => 383,
                         rosalina    => 1256,
                         rosalind    => 609,
                         rosalinda   => 750,
                         rosaline    => 1792,
                         rosalva     => 1597,
                         rosalyn     => 700,
                         rosamaria   => 3083,
                         rosamond    => 2049,
                         rosana      => 2258,
                         rosann      => 2298,
                         rosanna     => 870,
                         rosanne     => 831,
                         rosaria     => 1776,
                         rosario     => 565,
                         rosaura     => 1658,
                         rose        => 65,
                         roseann     => 817,
                         roseanna    => 1435,
                         roseanne    => 1145,
                         roselee     => 3206,
                         roselia     => 3283,
                         roseline    => 2762,
                         rosella     => 856,
                         roselle     => 2717,
                         roselyn     => 1273,
                         rosemarie   => 409,
                         rosemary    => 202,
                         rosena      => 3500,
                         rosenda     => 3648,
                         rosetta     => 547,
                         rosette     => 3573,
                         rosia       => 2357,
                         rosie       => 316,
                         rosina      => 1341,
                         rosio       => 3282,
                         rosita      => 1036,
                         roslyn      => 781,
                         rossana     => 2924,
                         rossie      => 3499,
                         rosy        => 3018,
                         rowena      => 910,
                         roxana      => 1148,
                         roxane      => 1434,
                         roxann      => 1198,
                         roxanna     => 1102,
                         roxanne     => 379,
                         roxie       => 780,
                         rozanne     => 3205,
                         rozella     => 2471,
                         rubi        => 3142,
                         rubie       => 1911,
                         ruby        => 90,
                         rubye       => 1355,
                         rufina      => 1825,
                         ruth        => 19,
                         rutha       => 2684,
                         ruthann     => 1326,
                         ruthanne    => 2976,
                         ruthe       => 3017,
                         ruthie      => 690,
                         ryann       => 3141,
                         sabina      => 1246,
                         sabra       => 1744,
                         sabrina     => 305,
                         sacha       => 2800,
                         sachiko     => 2161,
                         sade        => 1576,
                         sadie       => 387,
                         sadye       => 2975,
                         salena      => 2190,
                         salina      => 1518,
                         sallie      => 504,
                         sally       => 167,
                         salome      => 2048,
                         samara      => 2160,
                         samatha     => 1086,
                         samella     => 3350,
                         samira      => 2575,
                         sana        => 3572,
                         sanda       => 3016,
                         sandee      => 3082,
                         sandi       => 1077,
                         sandie      => 2716,
                         sandra      => 16,
                         sandy       => 315,
                         sanjuana    => 1387,
                         sanjuanita  => 1381,
                         sanora      => 2544,
                         santa       => 1131,
                         santina     => 2356,
                         sara        => 84,
                         sarah       => 23,
                         sarai       => 3571,
                         saran       => 3570,
                         sari        => 2236,
                         sarina      => 2137,
                         sarita      => 1564,
                         sasha       => 841,
                         saturnina   => 3422,
                         saundra     => 746,
                         savanna     => 2355,
                         savannah    => 852,
                         scarlett    => 1359,
                         sebrina     => 2574,
                         seema       => 3647,
                         selena      => 770,
                         selene      => 2257,
                         selina      => 978,
                         selma       => 654,
                         sena        => 3140,
                         senaida     => 3349,
                         serafina    => 3081,
                         serena      => 723,
                         serina      => 2021,
                         serita      => 2881,
                         setsuko     => 3080,
                         shae        => 3079,
                         shaina      => 1470,
                         shakia      => 2974,
                         shakira     => 2159,
                         shakita     => 3139,
                         shala       => 2923,
                         shalanda    => 2880,
                         shalon      => 3281,
                         shalonda    => 1525,
                         shameka     => 1334,
                         shamika     => 1481,
                         shan        => 3348,
                         shana       => 600,
                         shanae      => 2836,
                         shanda      => 1093,
                         shandi      => 3569,
                         shandra     => 1805,
                         shaneka     => 2091,
                         shanel      => 3280,
                         shanell     => 1763,
                         shanelle    => 2434,
                         shani       => 1804,
                         shanice     => 2066,
                         shanika     => 1554,
                         shaniqua    => 3078,
                         shanita     => 1803,
                         shanna      => 561,
                         shannan     => 1664,
                         shannon     => 123,
                         shanon      => 1224,
                         shanta      => 1337,
                         shantae     => 3568,
                         shantay     => 3204,
                         shante      => 1354,
                         shantel     => 1253,
                         shantell    => 1743,
                         shantelle   => 2799,
                         shanti      => 3347,
                         shaquana    => 3203,
                         shaquita    => 2922,
                         shara       => 1417,
                         sharan      => 3077,
                         sharda      => 3138,
                         sharee      => 1841,
                         sharell     => 3646,
                         sharen      => 1840,
                         shari       => 463,
                         sharice     => 3279,
                         sharie      => 2835,
                         sharika     => 3498,
                         sharilyn    => 3202,
                         sharita     => 1938,
                         sharla      => 1325,
                         sharleen    => 2433,
                         sharlene    => 931,
                         sharmaine   => 3567,
                         sharolyn    => 3201,
                         sharon      => 20,
                         sharonda    => 1252,
                         sharri      => 2715,
                         sharron     => 711,
                         sharyl      => 2328,
                         sharyn      => 1293,
                         shauna      => 620,
                         shaunda     => 2761,
                         shaunna     => 2470,
                         shaunta     => 3076,
                         shaunte     => 3137,
                         shavon      => 2020,
                         shavonda    => 3136,
                         shavonne    => 2543,
                         shawana     => 2469,
                         shawanda    => 1860,
                         shawanna    => 3200,
                         shawna      => 466,
                         shawnda     => 2112,
                         shawnee     => 2090,
                         shawnna     => 2468,
                         shawnta     => 3421,
                         shay        => 1859,
                         shayla      => 1084,
                         shayna      => 1412,
                         sheba       => 3278,
                         sheena      => 616,
                         sheila      => 124,
                         sheilah     => 2542,
                         shela       => 2432,
                         shelba      => 2111,
                         shelia      => 364,
                         shella      => 2798,
                         shelley     => 345,
                         shelli      => 1213,
                         shellie     => 1046,
                         shelly      => 288,
                         shemeka     => 2760,
                         shemika     => 2354,
                         shena       => 1889,
                         shenika     => 3199,
                         shenita     => 2616,
                         shenna      => 3566,
                         shera       => 2921,
                         sheree      => 823,
                         sherell     => 3135,
                         sheri       => 369,
                         sherice     => 3497,
                         sherie      => 1399,
                         sherika     => 2759,
                         sherill     => 3015,
                         sherilyn    => 1858,
                         sherise     => 3014,
                         sherita     => 1458,
                         sherlene    => 3496,
                         sherley     => 2327,
                         sherly      => 2326,
                         sherlyn     => 2504,
                         sheron      => 1802,
                         sherrell    => 2235,
                         sherri      => 291,
                         sherrie     => 486,
                         sherril     => 3346,
                         sherrill    => 1416,
                         sherron     => 1733,
                         sherry      => 119,
                         sherryl     => 1535,
                         shery       => 2644,
                         sheryl      => 301,
                         sheryll     => 2834,
                         shiela      => 1068,
                         shila       => 3075,
                         shira       => 2382,
                         shirely     => 2797,
                         shirl       => 2796,
                         shirlee     => 1553,
                         shirleen    => 2615,
                         shirlene    => 1333,
                         shirley     => 27,
                         shirly      => 1657,
                         shizue      => 3198,
                         shizuko     => 3495,
                         shona       => 2047,
                         shonda      => 1021,
                         shondra     => 3494,
                         shonna      => 2136,
                         shonta      => 2920,
                         shoshana    => 2431,
                         shyla       => 2919,
                         sibyl       => 1663,
                         signe       => 2189,
                         sigrid      => 1637,
                         silvana     => 2573,
                         silvia      => 438,
                         sima        => 2918,
                         simona      => 1898,
                         simone      => 672,
                         simonne     => 2879,
                         sina        => 3493,
                         sindy       => 2214,
                         siobhan     => 1721,
                         sirena      => 3345,
                         sixta       => 3645,
                         slyvia      => 2297,
                         socorro     => 637,
                         sofia       => 726,
                         soila       => 3565,
                         solange     => 2541,
                         soledad     => 1050,
                         somer       => 3277,
                         sona        => 3492,
                         sondra      => 606,
                         sonia       => 278,
                         sonja       => 445,
                         sonya       => 331,
                         sook        => 2296,
                         sophia      => 423,
                         soraya      => 2430,
                         stacee      => 3420,
                         stacey      => 209,
                         staci       => 629,
                         stacia      => 1197,
                         stacie      => 490,
                         stacy       => 178,
                         starla      => 1375,
                         stasia      => 3013,
                         stefani     => 1762,
                         stefania    => 2381,
                         stefanie    => 564,
                         stefany     => 3197,
                         steffanie   => 2213,
                         stella      => 244,
                         stepanie    => 3074,
                         stephaine   => 1552,
                         stephane    => 1979,
                         stephania   => 2917,
                         stephanie   => 41,
                         stephany    => 1226,
                         stephenie   => 1245,
                         stephine    => 1687,
                         stephnie    => 3491,
                         suanne      => 3644,
                         sudie       => 2188,
                         sue         => 195,
                         sueann      => 2429,
                         suellen     => 2034,
                         sulema      => 3276,
                         sumiko      => 3275,
                         sunni       => 3643,
                         sunny       => 1307,
                         susan       => 8,
                         susana      => 575,
                         susann      => 1857,
                         susanna     => 819,
                         susannah    => 1517,
                         susanne     => 573,
                         susie       => 342,
                         susy        => 2683,
                         suzan       => 1083,
                         suzann      => 1966,
                         suzanna     => 1237,
                         suzanne     => 153,
                         suzette     => 788,
                         suzi        => 3134,
                         suzie       => 1742,
                         suzy        => 1596,
                         sybil       => 656,
                         syble       => 1534,
                         sylvia      => 120,
                         sylvie      => 2795,
                         synthia     => 2295,
                         syreeta     => 2406,
                         tabatha     => 722,
                         tabetha     => 2234,
                         tabitha     => 472,
                         taina       => 3490,
                         taisha      => 2682,
                         tajuana     => 3489,
                         takako      => 3642,
                         takisha     => 2212,
                         talia       => 1623,
                         talisha     => 2353,
                         talitha     => 2643,
                         tama        => 3073,
                         tamala      => 2135,
                         tamar       => 1720,
                         tamara      => 226,
                         tamatha     => 1877,
                         tambra      => 3072,
                         tameika     => 2614,
                         tameka      => 745,
                         tamekia     => 2294,
                         tamela      => 1135,
                         tamera      => 904,
                         tamesha     => 2572,
                         tami        => 465,
                         tamica      => 2256,
                         tamie       => 1888,
                         tamika      => 546,
                         tamiko      => 1824,
                         tamisha     => 2681,
                         tammara     => 2233,
                         tammera     => 2973,
                         tammi       => 787,
                         tammie      => 481,
                         tammy       => 75,
                         tamra       => 863,
                         tana        => 1121,
                         tandra      => 3641,
                         tandy       => 3071,
                         taneka      => 2878,
                         tanesha     => 1585,
                         tangela     => 1686,
                         tania       => 738,
                         tanika      => 1621,
                         tanisha     => 771,
                         tanja       => 1910,
                         tanna       => 2187,
                         tanya       => 234,
                         tara        => 201,
                         tarah       => 2019,
                         taren       => 3419,
                         tari        => 2972,
                         tarra       => 2971,
                         tarsha      => 1801,
                         taryn       => 1014,
                         tasha       => 437,
                         tashia      => 2642,
                         tashina     => 3070,
                         tasia       => 2794,
                         tatiana     => 1182,
                         taunya      => 3640,
                         tawana      => 1073,
                         tawanda     => 1423,
                         tawanna     => 1575,
                         tawna       => 3488,
                         tawny       => 2158,
                         tawnya      => 1457,
                         tayna       => 3639,
                         teena       => 1497,
                         tegan       => 3564,
                         teisha      => 3418,
                         telma       => 3417,
                         temeka      => 2613,
                         temika      => 3416,
                         tempie      => 3274,
                         tena        => 1244,
                         tenesha     => 3487,
                         tenisha     => 1856,
                         tennie      => 2325,
                         tennille    => 2255,
                         teodora     => 1887,
                         teofila     => 3638,
                         tera        => 1059,
                         tereasa     => 2540,
                         teresa      => 54,
                         terese      => 1358,
                         teresia     => 3133,
                         teresita    => 1024,
                         teressa     => 1353,
                         teri        => 418,
                         terica      => 3486,
                         terina      => 3132,
                         terisa      => 2877,
                         terra       => 936,
                         terresa     => 2186,
                         terri       => 204,
                         terrie      => 694,
                         terrilyn    => 3485,
                         tesha       => 2503,
                         tessa       => 833,
                         tessie      => 1058,
                         thalia      => 2065,
                         thao        => 2352,
                         thea        => 1251,
                         theda       => 1267,
                         thelma      => 122,
                         theodora    => 1023,
                         theola      => 2641,
                         theresa     => 72,
                         therese     => 539,
                         theresia    => 2157,
                         theressa    => 2916,
                         thersa      => 1823,
                         thomasena   => 3563,
                         thomasina   => 1662,
                         thomasine   => 2324,
                         thora       => 2758,
                         thresa      => 1956,
                         thuy        => 1422,
                         tia         => 710,
                         tiana       => 1230,
                         tianna      => 2380,
                         tiara       => 1144,
                         tien        => 3344,
                         tiera       => 2915,
                         tierra      => 1509,
                         tiesha      => 2211,
                         tifany      => 3196,
                         tiffaney    => 2833,
                         tiffani     => 1120,
                         tiffanie    => 1425,
                         tiffany     => 110,
                         tiffiny     => 1897,
                         tijuana     => 3131,
                         tilda       => 3343,
                         tillie      => 1005,
                         timika      => 3415,
                         tina        => 92,
                         tinisha     => 2876,
                         tisa        => 3637,
                         tish        => 3562,
                         tisha       => 903,
                         tobi        => 2793,
                         tobie       => 3273,
                         toccara     => 3561,
                         tomasa      => 1128,
                         tomeka      => 1524,
                         tomi        => 2714,
                         tomika      => 1937,
                         tomiko      => 2680,
                         tommye      => 2970,
                         tomoko      => 2351,
                         tona        => 2875,
                         tonda       => 2428,
                         tonette     => 3414,
                         toni        => 285,
                         tonia       => 611,
                         tonie       => 2210,
                         tonisha     => 3342,
                         tonita      => 3636,
                         tonja       => 1194,
                         tonya       => 207,
                         tora        => 3484,
                         tori        => 938,
                         torie       => 3341,
                         torri       => 3012,
                         torrie      => 3069,
                         tosha       => 1239,
                         toshia      => 3195,
                         toshiko     => 2640,
                         tova        => 3340,
                         towanda     => 2502,
                         toya        => 1456,
                         tracee      => 1876,
                         tracey      => 274,
                         traci       => 389,
                         tracie      => 515,
                         tracy       => 108,
                         trang       => 2501,
                         treasa      => 2832,
                         treena      => 3560,
                         trena       => 1332,
                         tresa       => 1441,
                         tressa      => 1411,
                         tressie     => 1644,
                         treva       => 1008,
                         tricia      => 434,
                         trina       => 502,
                         trinh       => 2757,
                         trish       => 1551,
                         trisha      => 510,
                         trista      => 1220,
                         trudi       => 1997,
                         trudie      => 1978,
                         trudy       => 557,
                         trula       => 2539,
                         tula        => 3413,
                         tuyet       => 2405,
                         twana       => 2018,
                         twanda      => 2969,
                         twanna      => 2679,
                         twila       => 912,
                         twyla       => 1286,
                         tyesha      => 2209,
                         tyisha      => 3339,
                         tynisha     => 3559,
                         tyra        => 1266,
                         ulrike      => 3194,
                         ursula      => 597,
                         usha        => 2639,
                         vada        => 1162,
                         valarie     => 698,
                         valda       => 2134,
                         valene      => 2968,
                         valeri      => 3011,
                         valeria     => 809,
                         valerie     => 149,
                         valery      => 2427,
                         vallie      => 1977,
                         valorie     => 1304,
                         valrie      => 2874,
                         vanda       => 2379,
                         vanesa      => 2110,
                         vanessa     => 193,
                         vanetta     => 3068,
                         vania       => 3193,
                         vanita      => 2404,
                         vanna       => 3338,
                         vannesa     => 3272,
                         vannessa    => 1955,
                         vashti      => 2831,
                         vasiliki    => 3635,
                         veda        => 1056,
                         velda       => 1200,
                         velia       => 1620,
                         vella       => 2500,
                         velma       => 280,
                         velva       => 1574,
                         vena        => 2156,
                         venessa     => 1255,
                         venetta     => 3412,
                         venice      => 2208,
                         venita      => 1331,
                         vennie      => 3337,
                         venus       => 1138,
                         veola       => 2638,
                         vera        => 216,
                         verda       => 1074,
                         verdell     => 2350,
                         verdie      => 2467,
                         verena      => 2466,
                         vergie      => 1480,
                         verla       => 1272,
                         verlene     => 2571,
                         verlie      => 2570,
                         verline     => 3634,
                         verna       => 350,
                         vernell     => 1127,
                         vernetta    => 1996,
                         vernia      => 3483,
                         vernice     => 1067,
                         vernie      => 1791,
                         vernita     => 1719,
                         verona      => 1661,
                         veronica    => 158,
                         veronique   => 3271,
                         versie      => 2109,
                         vertie      => 3010,
                         vesta       => 1090,
                         veta        => 2612,
                         vicenta     => 1685,
                         vickey      => 1352,
                         vicki       => 199,
                         vickie      => 247,
                         vicky       => 367,
                         victoria    => 116,
                         victorina   => 3558,
                         vida        => 1035,
                         vikki       => 1271,
                         vilma       => 854,
                         vina        => 1684,
                         vincenza    => 1909,
                         vinita      => 3557,
                         vinnie      => 2033,
                         viola       => 241,
                         violet      => 283,
                         violeta     => 1279,
                         violette    => 1954,
                         virgen      => 2967,
                         virgie      => 675,
                         virgina     => 1002,
                         virginia    => 35,
                         vita        => 1550,
                         viva        => 1790,
                         vivan       => 2185,
                         vivian      => 182,
                         viviana     => 1285,
                         vivien      => 1995,
                         vivienne    => 1976,
                         voncile     => 3411,
                         vonda       => 921,
                         vonnie      => 1789,
                         waltraud    => 2611,
                         wanda       => 87,
                         waneta      => 2713,
                         wanetta     => 3633,
                         wanita      => 1656,
                         wava        => 3067,
                         wendi       => 832,
                         wendie      => 3270,
                         wendolyn    => 3130,
                         wendy       => 115,
                         wenona      => 3269,
                         whitney     => 358,
                         wilda       => 865,
                         wilhelmina  => 1009,
                         wilhemina   => 3632,
                         willa       => 651,
                         willena     => 3482,
                         willene     => 1875,
                         willetta    => 3410,
                         willette    => 2403,
                         willia      => 2232,
                         williemae   => 2756,
                         willodean   => 3336,
                         wilma       => 210,
                         windy       => 1340,
                         winifred    => 474,
                         winnie      => 660,
                         winnifred   => 1324,
                         winona      => 1034,
                         wonda       => 2610,
                         wynell      => 3481,
                         wynona      => 1800,
                         xenia       => 3066,
                         xiao        => 3335,
                         xiomara     => 1479,
                         xochitl     => 2678,
                         xuan        => 3129,
                         yadira      => 1209,
                         yaeko       => 3480,
                         yael        => 3409,
                         yahaira     => 3128,
                         yajaira     => 3192,
                         yanira      => 2378,
                         yasmin      => 1496,
                         yasmine     => 2830,
                         yasuko      => 2873,
                         yelena      => 3127,
                         yesenia     => 804,
                         yessenia    => 2792,
                         yetta       => 1660,
                         yevette     => 3408,
                         ying        => 1908,
                         yoko        => 1855,
                         yolanda     => 188,
                         yolande     => 1994,
                         yolando     => 2609,
                         yolonda     => 1495,
                         yoshie      => 3407,
                         yoshiko     => 1516,
                         youlanda    => 3126,
                         yuette      => 3556,
                         yuki        => 3406,
                         yukiko      => 2608,
                         yuko        => 2499,
                         yulanda     => 2791,
                         yung        => 2755,
                         yuonne      => 3334,
                         yuri        => 2712,
                         yuriko      => 3479,
                         yvette      => 339,
                         yvone       => 3405,
                         yvonne      => 174,
                         zada        => 3333,
                         zaida       => 1788,
                         zana        => 3631,
                         zandra      => 1854,
                         zelda       => 967,
                         zella       => 1076,
                         zelma       => 742,
                         zena        => 1619,
                         zenaida     => 1159,
                         zenia       => 3478,
                         zenobia     => 1839,
                         zetta       => 3125,
                         zina        => 1618,
                         zita        => 1993,
                         zofia       => 2323,
                         zoila       => 1111,
                         zola        => 1478,
                         zona        => 1533,
                         zonia       => 3477,
                         zora        => 1549,
                         zoraida     => 1372,
                         zula        => 1675,
                         zulema      => 1953,
                         zulma       => 1853,
                       },
  male_names        => {
                         aaron       => 77,
                         abdul       => 678,
                         abe         => 694,
                         abel        => 420,
                         abraham     => 308,
                         abram       => 861,
                         adalberto   => 854,
                         adam        => 69,
                         adan        => 624,
                         adolfo      => 484,
                         adolph      => 544,
                         adrian      => 211,
                         agustin     => 481,
                         ahmad       => 721,
                         ahmed       => 816,
                         alan        => 89,
                         albert      => 54,
                         alberto     => 247,
                         alden       => 725,
                         aldo        => 690,
                         alec        => 761,
                         alejandro   => 274,
                         alex        => 151,
                         alfonso     => 295,
                         alfonzo     => 745,
                         alfred      => 121,
                         alfredo     => 246,
                         ali         => 521,
                         allan       => 231,
                         alonso      => 983,
                         alonzo      => 389,
                         alphonse    => 673,
                         alphonso    => 552,
                         alton       => 320,
                         alva        => 651,
                         alvaro      => 525,
                         alvin       => 163,
                         amado       => 788,
                         ambrose     => 896,
                         amos        => 406,
                         andre       => 204,
                         andreas     => 907,
                         andres      => 311,
                         andrew      => 35,
                         andy        => 259,
                         angelo      => 291,
                         anibal      => 784,
                         anthony     => 22,
                         antione     => 939,
                         antoine     => 458,
                         anton       => 501,
                         antone      => 808,
                         antonio     => 98,
                         antony      => 649,
                         antwan      => 724,
                         archie      => 321,
                         arden       => 882,
                         ariel       => 677,
                         arlen       => 923,
                         arlie       => 963,
                         armand      => 524,
                         armando     => 237,
                         arnoldo     => 955,
                         arnulfo     => 685,
                         aron        => 703,
                         arron       => 648,
                         arthur      => 48,
                         arturo      => 273,
                         aubrey      => 426,
                         augustine   => 661,
                         augustus    => 774,
                         aurelio     => 610,
                         avery       => 541,
                         barry       => 136,
                         bart        => 487,
                         basil       => 561,
                         beau        => 594,
                         ben         => 201,
                         benedict    => 917,
                         benito      => 474,
                         benjamin    => 66,
                         bennie      => 329,
                         benny       => 337,
                         bernard     => 137,
                         bernardo    => 557,
                         bernie      => 628,
                         bert        => 391,
                         bertram     => 842,
                         bill        => 154,
                         billy       => 73,
                         blaine      => 477,
                         blake       => 304,
                         bob         => 243,
                         bobby       => 82,
                         boris       => 699,
                         brad        => 206,
                         bradford    => 403,
                         bradley     => 124,
                         bradly      => 811,
                         brain       => 510,
                         branden     => 623,
                         brandon     => 68,
                         brant       => 748,
                         brendan     => 417,
                         brendon     => 823,
                         brent       => 187,
                         brenton     => 753,
                         bret        => 437,
                         brett       => 195,
                         brian       => 20,
                         brice       => 793,
                         broderick   => 982,
                         bruce       => 67,
                         bruno       => 583,
                         bryan       => 100,
                         bryce       => 457,
                         bryon       => 523,
                         bud         => 777,
                         buford      => 627,
                         burl        => 813,
                         burt        => 717,
                         byron       => 252,
                         caleb       => 381,
                         calvin      => 150,
                         carey       => 506,
                         carl        => 47,
                         carlo       => 607,
                         carlos      => 80,
                         carlton     => 298,
                         carmelo     => 588,
                         carmine     => 660,
                         carrol      => 886,
                         cary        => 424,
                         casey       => 245,
                         cecil       => 202,
                         cedric      => 343,
                         cedrick     => 962,
                         cesar       => 312,
                         chad        => 118,
                         chadwick    => 663,
                         charles     => 8,
                         charley     => 605,
                         chas        => 878,
                         chauncey    => 769,
                         chet        => 841,
                         chi         => 807,
                         chong       => 865,
                         chris       => 94,
                         christian   => 218,
                         christoper  => 744,
                         christopher => 11,
                         chuck       => 467,
                         chung       => 853,
                         clair       => 626,
                         clarence    => 91,
                         claud       => 891,
                         claude      => 214,
                         claudio     => 757,
                         clay        => 401,
                         clayton     => 232,
                         clement     => 579,
                         clemente    => 881,
                         cletus      => 833,
                         cleveland   => 465,
                         cliff       => 519,
                         clifford    => 144,
                         clifton     => 255,
                         clint       => 369,
                         clinton     => 221,
                         clyde       => 179,
                         cody        => 228,
                         colby       => 587,
                         colin       => 334,
                         collin      => 613,
                         colton      => 943,
                         columbus    => 840,
                         conrad      => 394,
                         cordell     => 911,
                         corey       => 174,
                         cornelius   => 398,
                         cornell     => 646,
                         cory        => 213,
                         coy         => 580,
                         craig       => 88,
                         cristobal   => 895,
                         cristopher  => 938,
                         curt        => 479,
                         curtis      => 110,
                         cyril       => 655,
                         cyrus       => 654,
                         dale        => 107,
                         damian      => 468,
                         damien      => 491,
                         damion      => 806,
                         damon       => 316,
                         dan         => 172,
                         dane        => 527,
                         danial      => 620,
                         daniel      => 12,
                         danilo      => 890,
                         dannie      => 781,
                         danny       => 99,
                         dante       => 578,
                         darell      => 981,
                         daren       => 639,
                         darin       => 405,
                         dario       => 796,
                         darius      => 514,
                         darnell     => 412,
                         daron       => 864,
                         darrel      => 386,
                         darrell     => 159,
                         darren      => 225,
                         darrick     => 827,
                         darrin      => 416,
                         darron      => 872,
                         darryl      => 216,
                         darwin      => 496,
                         daryl       => 257,
                         dave        => 248,
                         david       => 6,
                         dean        => 166,
                         deandre     => 731,
                         deangelo    => 931,
                         delbert     => 333,
                         delmar      => 599,
                         delmer      => 795,
                         demarcus    => 832,
                         demetrius   => 451,
                         denis       => 490,
                         dennis      => 40,
                         denny       => 572,
                         denver      => 614,
                         deon        => 743,
                         derek       => 158,
                         derick      => 548,
                         derrick     => 171,
                         deshawn     => 885,
                         desmond     => 494,
                         devin       => 347,
                         devon       => 483,
                         dewayne     => 433,
                         dewey       => 376,
                         dewitt      => 752,
                         diego       => 543,
                         dino        => 728,
                         dion        => 577,
                         dirk        => 622,
                         domenic     => 871,
                         domingo     => 425,
                         dominic     => 331,
                         dominick    => 421,
                         don         => 131,
                         donald      => 15,
                         dong        => 870,
                         donn        => 763,
                         donnell     => 571,
                         donnie      => 282,
                         donny       => 592,
                         donovan     => 560,
                         donte       => 847,
                         dorian      => 708,
                         doug        => 288,
                         douglas     => 45,
                         douglass    => 910,
                         drew        => 374,
                         duane       => 203,
                         dudley      => 585,
                         dustin      => 169,
                         dusty       => 679,
                         dwain       => 846,
                         dwayne      => 235,
                         dwight      => 236,
                         dylan       => 466,
                         earl        => 96,
                         earle       => 693,
                         earnest     => 336,
                         eddie       => 132,
                         eddy        => 566,
                         edgar       => 198,
                         edgardo     => 760,
                         edison      => 884,
                         edmond      => 431,
                         edmund      => 341,
                         edmundo     => 971,
                         eduardo     => 267,
                         edward      => 19,
                         edwardo     => 635,
                         edwin       => 130,
                         efrain      => 448,
                         efren       => 723,
                         elbert      => 392,
                         elden       => 980,
                         eldon       => 453,
                         eli         => 456,
                         elias       => 390,
                         elijah      => 423,
                         eliseo      => 720,
                         elliot      => 495,
                         ellsworth   => 913,
                         elmer       => 205,
                         elmo        => 702,
                         eloy        => 707,
                         elroy       => 880,
                         elton       => 464,
                         elvin       => 504,
                         elvis       => 556,
                         elwood      => 512,
                         emanuel     => 429,
                         emerson     => 630,
                         emery       => 574,
                         emil        => 432,
                         emile       => 701,
                         emilio      => 422,
                         emmanuel    => 441,
                         emmett      => 427,
                         emmitt      => 863,
                         emory       => 616,
                         enoch       => 822,
                         enrique     => 269,
                         erasmo      => 901,
                         eric        => 33,
                         erich       => 662,
                         erick       => 384,
                         erik        => 215,
                         ernest      => 84,
                         ernesto     => 299,
                         ernie       => 478,
                         errol       => 633,
                         ervin       => 375,
                         erwin       => 473,
                         esteban     => 500,
                         ethan       => 452,
                         eugene      => 79,
                         eugenio     => 683,
                         eusebio     => 869,
                         evan        => 280,
                         everett     => 240,
                         everette    => 705,
                         ezekiel     => 877,
                         ezequiel    => 900,
                         ezra        => 689,
                         fabian      => 536,
                         faustino    => 756,
                         fausto      => 922,
                         federico    => 568,
                         felipe      => 328,
                         felix       => 238,
                         felton      => 899,
                         ferdinand   => 687,
                         fermin      => 852,
                         fernando    => 220,
                         fidel       => 517,
                         filiberto   => 930,
                         florencio   => 826,
                         florentino  => 879,
                         floyd       => 161,
                         forrest     => 352,
                         francesco   => 926,
                         francis     => 123,
                         francisco   => 140,
                         frank       => 31,
                         frankie     => 385,
                         franklyn    => 970,
                         fred        => 71,
                         freddie     => 270,
                         frederic    => 602,
                         frederick   => 127,
                         fredric     => 810,
                         fredrick    => 272,
                         fritz       => 739,
                         gabriel     => 207,
                         galen       => 596,
                         garland     => 446,
                         garret      => 921,
                         garry       => 325,
                         garth       => 653,
                         gary        => 26,
                         gaston      => 929,
                         gavin       => 573,
                         gaylord     => 928,
                         genaro      => 644,
                         gene        => 191,
                         geoffrey    => 326,
                         george      => 16,
                         gerald      => 58,
                         geraldo     => 839,
                         gerard      => 287,
                         gerardo     => 330,
                         gerry       => 550,
                         gil         => 719,
                         gilbert     => 190,
                         gilberto    => 368,
                         gino        => 759,
                         giovanni    => 652,
                         giuseppe    => 831,
                         glen        => 180,
                         glenn       => 114,
                         gonzalo     => 547,
                         grady       => 396,
                         graig       => 969,
                         granville   => 933,
                         greg        => 167,
                         gregg       => 345,
                         gregorio    => 497,
                         gregory     => 37,
                         grover      => 463,
                         guillermo   => 335,
                         gus         => 540,
                         gustavo     => 364,
                         hal         => 509,
                         hank        => 801,
                         hans        => 475,
                         harlan      => 493,
                         harland     => 954,
                         harold      => 44,
                         harry       => 70,
                         hassan      => 830,
                         haywood     => 876,
                         heath       => 449,
                         hector      => 181,
                         henry       => 46,
                         herb        => 906,
                         herbert     => 126,
                         heriberto   => 570,
                         herman      => 175,
                         herschel    => 650,
                         hershel     => 714,
                         hilario     => 776,
                         hilton      => 845,
                         hipolito    => 851,
                         hiram       => 559,
                         hobert      => 961,
                         hollis      => 590,
                         homer       => 286,
                         hong        => 919,
                         horace      => 305,
                         horacio     => 792,
                         hosea       => 945,
                         hoyt        => 875,
                         hubert      => 290,
                         huey        => 844,
                         hugh        => 233,
                         hugo        => 379,
                         humberto    => 440,
                         hung        => 647,
                         hyman       => 898,
                         ian         => 241,
                         ignacio     => 380,
                         ira         => 310,
                         irvin       => 409,
                         irving      => 356,
                         irwin       => 603,
                         isaac       => 254,
                         isaiah      => 539,
                         isaias      => 850,
                         isiah       => 700,
                         isidro      => 597,
                         ismael      => 372,
                         israel      => 350,
                         isreal      => 920,
                         issac       => 584,
                         ivan        => 249,
                         ivory       => 734,
                         jacinto     => 968,
                         jack        => 53,
                         jacob       => 119,
                         jacques     => 632,
                         jaime       => 244,
                         jake        => 365,
                         jamaal      => 751,
                         jamal       => 482,
                         jamar       => 698,
                         jame        => 643,
                         jamel       => 671,
                         james       => 1,
                         jamey       => 855,
                         jamison     => 825,
                         jared       => 210,
                         jarod       => 905,
                         jarred      => 762,
                         jarrett     => 676,
                         jarrod      => 488,
                         jarvis      => 582,
                         jason       => 24,
                         javier      => 219,
                         jay         => 147,
                         jayson      => 576,
                         jed         => 786,
                         jeff        => 117,
                         jefferey    => 815,
                         jeffery     => 115,
                         jeffrey     => 30,
                         jeffry      => 526,
                         jerald      => 430,
                         jeramy      => 973,
                         jere        => 979,
                         jeremiah    => 279,
                         jeremy      => 76,
                         jermaine    => 351,
                         jerold      => 738,
                         jerome      => 160,
                         jeromy      => 960,
                         jerrell     => 959,
                         jerrod      => 712,
                         jerrold     => 799,
                         jerry       => 39,
                         jess        => 438,
                         jesse       => 87,
                         jesus       => 125,
                         jim         => 148,
                         jimmie      => 239,
                         jimmy       => 97,
                         joaquin     => 492,
                         joe         => 51,
                         joel        => 129,
                         joesph      => 528,
                         joey        => 275,
                         john        => 2,
                         johnathan   => 313,
                         johnathon   => 600,
                         johnie      => 675,
                         johnnie     => 250,
                         johnny      => 95,
                         jon         => 152,
                         jonah       => 798,
                         jonas       => 667,
                         jonathan    => 55,
                         jonathon    => 327,
                         jordon      => 889,
                         jorge       => 168,
                         jose        => 28,
                         josef       => 706,
                         joseph      => 9,
                         josh        => 378,
                         joshua      => 38,
                         josiah      => 747,
                         jospeh      => 942,
                         josue       => 634,
                         juan        => 52,
                         jude        => 909,
                         judson      => 758,
                         jules       => 718,
                         julian      => 253,
                         julio       => 229,
                         julius      => 281,
                         justin      => 56,
                         kareem      => 697,
                         karl        => 212,
                         keenan      => 836,
                         keith       => 59,
                         kelvin      => 317,
                         ken         => 242,
                         kendall     => 460,
                         kendrick    => 513,
                         keneth      => 967,
                         kenneth     => 17,
                         kennith     => 659,
                         kenny       => 289,
                         kent        => 264,
                         kenton      => 805,
                         kermit      => 498,
                         kerry       => 307,
                         keven       => 775,
                         kevin       => 23,
                         kieth       => 733,
                         kip         => 812,
                         kirk        => 261,
                         korey       => 941,
                         kory        => 773,
                         kraig       => 958,
                         kris        => 538,
                         kristofer   => 953,
                         kristopher  => 361,
                         kurt        => 230,
                         kurtis      => 609,
                         kyle        => 122,
                         lamar       => 399,
                         lamont      => 445,
                         lance       => 227,
                         landon      => 621,
                         lanny       => 696,
                         larry       => 29,
                         laurence    => 371,
                         lavern      => 716,
                         lawerence   => 860,
                         lawrence    => 63,
                         lazaro      => 672,
                         leandro     => 957,
                         leif        => 972,
                         leland      => 354,
                         lemuel      => 715,
                         lenard      => 768,
                         lenny       => 789,
                         leo         => 162,
                         leon        => 157,
                         leonard     => 105,
                         leonardo    => 471,
                         leonel      => 615,
                         leopoldo    => 704,
                         leroy       => 139,
                         les         => 730,
                         lester      => 186,
                         levi        => 362,
                         lincoln     => 642,
                         lino        => 904,
                         linwood     => 593,
                         lionel      => 366,
                         lloyd       => 155,
                         lon         => 658,
                         lonnie      => 226,
                         lonny       => 902,
                         loren       => 332,
                         lorenzo     => 301,
                         louie       => 443,
                         louis       => 75,
                         lowell      => 344,
                         loyd        => 542,
                         luciano     => 680,
                         lucien      => 686,
                         lucio       => 711,
                         lucius      => 952,
                         luigi       => 966,
                         luis        => 102,
                         luke        => 285,
                         luther      => 277,
                         lyle        => 293,
                         lyman       => 746,
                         lyndon      => 835,
                         lynwood     => 978,
                         mac         => 797,
                         malcolm     => 314,
                         malcom      => 940,
                         malik       => 934,
                         manual      => 927,
                         manuel      => 108,
                         marc        => 192,
                         marcel      => 520,
                         marcelino   => 606,
                         marcellus   => 951,
                         marcelo     => 772,
                         marco       => 322,
                         marcos      => 363,
                         marcus      => 141,
                         margarito   => 726,
                         mariano     => 619,
                         mario       => 138,
                         mark        => 14,
                         markus      => 843,
                         marlin      => 516,
                         marlon      => 428,
                         marquis     => 695,
                         marty       => 367,
                         marvin      => 112,
                         mathew      => 223,
                         matt        => 294,
                         matthew     => 25,
                         maurice     => 176,
                         mauricio    => 558,
                         mauro       => 780,
                         max         => 234,
                         maximo      => 858,
                         mckinley    => 857,
                         mel         => 771,
                         melvin      => 120,
                         merle       => 404,
                         merrill     => 604,
                         mervin      => 669,
                         micah       => 447,
                         michael     => 4,
                         michal      => 977,
                         michale     => 932,
                         micheal     => 142,
                         michel      => 533,
                         miguel      => 145,
                         mike        => 103,
                         mikel       => 821,
                         milan       => 903,
                         milford     => 741,
                         millard     => 545,
                         milo        => 785,
                         milton      => 199,
                         minh        => 829,
                         miquel      => 868,
                         mitch       => 692,
                         mitchel     => 668,
                         modesto     => 925,
                         mohamed     => 794,
                         mohammad    => 618,
                         mohammed    => 684,
                         moises      => 515,
                         monte       => 476,
                         monty       => 534,
                         mose        => 918,
                         moses       => 408,
                         moshe       => 820,
                         myles       => 666,
                         myron       => 340,
                         napoleon    => 737,
                         nathan      => 106,
                         nathanael   => 916,
                         nathanial   => 888,
                         nathaniel   => 196,
                         ned         => 530,
                         neil        => 217,
                         nestor      => 589,
                         neville     => 883,
                         nicholas    => 64,
                         nick        => 276,
                         nickolas    => 562,
                         nicky       => 937,
                         nicolas     => 370,
                         nigel       => 722,
                         noah        => 395,
                         noe         => 554,
                         noel        => 338,
                         nolan       => 505,
                         norbert     => 503,
                         norberto    => 736,
                         norman      => 111,
                         normand     => 732,
                         numbers     => 625,
                         octavio     => 645,
                         odell       => 581,
                         odis        => 767,
                         olen        => 783,
                         olin        => 755,
                         omar        => 302,
                         omer        => 849,
                         oren        => 819,
                         orlando     => 296,
                         orval       => 779,
                         orville     => 373,
                         oscar       => 146,
                         osvaldo     => 729,
                         oswaldo     => 912,
                         otha        => 867,
                         otis        => 283,
                         otto        => 434,
                         owen        => 357,
                         pablo       => 300,
                         pasquale    => 617,
                         patrick     => 42,
                         paul        => 13,
                         pedro       => 170,
                         percy       => 402,
                         pete        => 323,
                         peter       => 43,
                         phil        => 397,
                         philip      => 93,
                         phillip     => 85,
                         pierre      => 455,
                         porfirio    => 766,
                         preston     => 319,
                         quentin     => 480,
                         quincy      => 565,
                         quintin     => 824,
                         quinton     => 508,
                         rafael      => 197,
                         raleigh     => 859,
                         ralph       => 62,
                         ramiro      => 393,
                         ramon       => 188,
                         randal      => 413,
                         randall     => 135,
                         randell     => 674,
                         randolph    => 324,
                         randy       => 78,
                         raphael     => 522,
                         rashad      => 862,
                         raul        => 200,
                         ray         => 128,
                         rayford     => 894,
                         raymon      => 893,
                         raymond     => 36,
                         raymundo    => 638,
                         refugio     => 727,
                         reggie      => 537,
                         reginald    => 193,
                         reinaldo    => 710,
                         renaldo     => 950,
                         renato      => 874,
                         rene        => 266,
                         reuben      => 469,
                         rex         => 297,
                         reynaldo    => 436,
                         rhett       => 908,
                         ricardo     => 183,
                         richard     => 7,
                         richie      => 791,
                         rick        => 185,
                         rickey      => 309,
                         rickie      => 553,
                         ricky       => 133,
                         rico        => 750,
                         rigoberto   => 551,
                         rob         => 511,
                         robbie      => 459,
                         robby       => 641,
                         robert      => 3,
                         roberto     => 178,
                         robt        => 800,
                         rocco       => 546,
                         rocky       => 454,
                         rod         => 507,
                         roderick    => 306,
                         rodger      => 450,
                         rodney      => 109,
                         rodolfo     => 339,
                         rodrick     => 709,
                         rodrigo     => 549,
                         rogelio     => 387,
                         roger       => 50,
                         roland      => 209,
                         rolando     => 400,
                         rolf        => 949,
                         rolland     => 804,
                         roman       => 411,
                         romeo       => 575,
                         ron         => 208,
                         ronald      => 21,
                         ronnie      => 153,
                         ronny       => 656,
                         roosevelt   => 349,
                         rory        => 535,
                         roscoe      => 499,
                         rosendo     => 740,
                         roy         => 65,
                         royce       => 461,
                         ruben       => 194,
                         rubin       => 691,
                         rudolf      => 948,
                         rudolph     => 315,
                         rudy        => 318,
                         rueben      => 956,
                         rufus       => 358,
                         rupert      => 803,
                         russ        => 665,
                         russel      => 472,
                         russell     => 81,
                         rusty       => 532,
                         ryan        => 49,
                         sal         => 778,
                         salvador    => 260,
                         salvatore   => 342,
                         sam         => 184,
                         sammie      => 531,
                         sammy       => 360,
                         samual      => 866,
                         samuel      => 60,
                         sanford     => 586,
                         sang        => 742,
                         santo       => 947,
                         saul        => 410,
                         scot        => 563,
                         scott       => 32,
                         scottie     => 682,
                         sean        => 92,
                         sebastian   => 567,
                         sergio      => 262,
                         seth        => 263,
                         seymour     => 681,
                         shad        => 946,
                         shane       => 182,
                         shaun       => 292,
                         shawn       => 90,
                         shayne      => 887,
                         sheldon     => 383,
                         sherman     => 346,
                         sherwood    => 892,
                         shon        => 976,
                         sidney      => 251,
                         silas       => 601,
                         simon       => 355,
                         solomon     => 502,
                         stan        => 470,
                         stanford    => 818,
                         stanley     => 104,
                         stefan      => 591,
                         stephan     => 442,
                         stephen     => 34,
                         sterling    => 462,
                         steve       => 74,
                         steven      => 18,
                         stevie      => 657,
                         stuart      => 271,
                         sung        => 802,
                         sylvester   => 348,
                         tad         => 765,
                         ted         => 222,
                         teddy       => 435,
                         teodoro     => 856,
                         terence     => 388,
                         terrance    => 265,
                         terrell     => 407,
                         terrence    => 268,
                         terry       => 57,
                         thad        => 688,
                         thaddeus    => 518,
                         thanh       => 787,
                         theo        => 838,
                         theodore    => 143,
                         theron      => 637,
                         thomas      => 10,
                         thurman     => 529,
                         tim         => 164,
                         timmy       => 415,
                         timothy     => 27,
                         titus       => 897,
                         tobias      => 828,
                         toby        => 418,
                         tod         => 770,
                         todd        => 86,
                         tom         => 149,
                         tomas       => 382,
                         tommie      => 414,
                         tommy       => 156,
                         toney       => 915,
                         tony        => 101,
                         tory        => 790,
                         travis      => 116,
                         trent       => 439,
                         trenton     => 608,
                         trevor      => 284,
                         trey        => 735,
                         trinidad    => 764,
                         tristan     => 640,
                         troy        => 134,
                         truman      => 598,
                         tuan        => 936,
                         tyler       => 189,
                         tyree       => 814,
                         tyrell      => 834,
                         tyron       => 848,
                         tyrone      => 224,
                         tyson       => 485,
                         ulysses     => 569,
                         van         => 419,
                         vance       => 489,
                         vern        => 555,
                         vernon      => 177,
                         vicente     => 444,
                         victor      => 83,
                         vince       => 564,
                         vincent     => 113,
                         vincenzo    => 975,
                         virgil      => 258,
                         virgilio    => 914,
                         vito        => 612,
                         waldo       => 809,
                         wally       => 965,
                         walter      => 41,
                         waylon      => 944,
                         wayne       => 72,
                         weldon      => 595,
                         wendell     => 278,
                         werner      => 837,
                         wesley      => 165,
                         weston      => 713,
                         wilber      => 873,
                         wilbert     => 353,
                         wilbur      => 303,
                         wilburn     => 664,
                         wilford     => 636,
                         wilfred     => 377,
                         wilfredo    => 486,
                         willard     => 256,
                         william     => 5,
                         willian     => 974,
                         willie      => 61,
                         willy       => 817,
                         wilmer      => 629,
                         wilton      => 749,
                         winford     => 964,
                         winfred     => 611,
                         woodrow     => 359,
                         yong        => 754,
                         zachariah   => 782,
                         zachary     => 173,
                         zachery     => 631,
                         zack        => 924,
                         zackary     => 935,
                         zane        => 670,
                       },
  passwords         => {
                         "!qaz2wsx"             => 8441,
                         "!qazxsw2"             => 22176,
                         "%%passwo"             => 9943,
                         "%e2%82%ac"            => 27913,
                         "(null"                => 23423,
                         "****er"               => 27458,
                         "****me"               => 18825,
                         "****you"              => 20149,
                         ".adgjm"               => 12899,
                         ".adgjmptw"            => 17229,
                         ".ktxrf"               => 13506,
                         ".ktymrf"              => 14332,
                         ".kzirf"               => 28816,
                         "0.0.0.000"            => 2248,
                         "0.0.000"              => 1500,
                         "000000"               => 34,
                         "0000000000d"          => 21531,
                         "0000000000o"          => 8065,
                         "00000001"             => 20349,
                         "00000007"             => 21959,
                         "0000001"              => 13484,
                         "0000007"              => 4571,
                         "000000a"              => 8745,
                         "000000z"              => 23881,
                         "000001"               => 2399,
                         "000002"               => 23241,
                         "000005"               => 19935,
                         "000006"               => 10971,
                         "000007"               => 1957,
                         "000008"               => 26239,
                         "000009"               => 17612,
                         "00000a"               => 22643,
                         "00000ty"              => 28760,
                         "00001"                => 15451,
                         "00007"                => 13668,
                         "00009999"             => 20774,
                         "0001"                 => 6222,
                         "000111"               => 3222,
                         "0007"                 => 1506,
                         "000777fffa"           => 20161,
                         "00096462"             => 13799,
                         "001100"               => 10186,
                         "00133"                => 13069,
                         "00197400"             => 16316,
                         "002200"               => 28690,
                         "005500"               => 18227,
                         "006900"               => 19392,
                         "00700"                => 24522,
                         "007000"               => 26297,
                         "007007"               => 391,
                         "007008"               => 19868,
                         "0072563"              => 20203,
                         "007700"               => 7971,
                         "007bond"              => 5664,
                         "007james"             => 11169,
                         "007jr"                => 16547,
                         "008800"               => 28426,
                         "009900"               => 11372,
                         "00998877"             => 21870,
                         "01011"                => 753,
                         "01011900"             => 3979,
                         "01011910"             => 2794,
                         "01011950"             => 6356,
                         "01011960"             => 4235,
                         "01011961"             => 6750,
                         "01011970"             => 2040,
                         "01011971"             => 5303,
                         "01011972"             => 5772,
                         "01011973"             => 5462,
                         "01011974"             => 4672,
                         "01011975"             => 2970,
                         "01011976"             => 4952,
                         "01011977"             => 3097,
                         "01011978"             => 4212,
                         "01011979"             => 3581,
                         "0101198"              => 25226,
                         "01011980"             => 742,
                         "01011981"             => 2088,
                         "01011982"             => 3281,
                         "01011983"             => 3240,
                         "01011984"             => 2662,
                         "01011985"             => 2011,
                         "01011986"             => 2103,
                         "01011987"             => 2668,
                         "01011988"             => 2572,
                         "01011989"             => 2497,
                         "01011990"             => 992,
                         "01011991"             => 1887,
                         "01011992"             => 2888,
                         "01011993"             => 2979,
                         "01011994"             => 4563,
                         "01011995"             => 4441,
                         "01011999"             => 3352,
                         "01012000"             => 760,
                         "01012001"             => 1693,
                         "01012010"             => 1258,
                         "01012011"             => 339,
                         "010180"               => 3610,
                         "0101dd"               => 23986,
                         "010203"               => 483,
                         "01020304"             => 3330,
                         "0102030405"           => 8928,
                         "010203040506"         => 11571,
                         "01021990"             => 4769,
                         "01031985"             => 4736,
                         "01031988"             => 4139,
                         "01031989"             => 4654,
                         "01041985"             => 4379,
                         "01041988"             => 4551,
                         "01061986"             => 4547,
                         "01061990"             => 4232,
                         "01071986"             => 4319,
                         "01081988m"            => 19748,
                         "01081989"             => 3854,
                         "01091987"             => 4408,
                         "01091989"             => 2899,
                         "01121986"             => 4303,
                         "01121988"             => 4462,
                         "0112358"              => 24340,
                         "012345678910"         => 20004,
                         "0123654789"           => 26414,
                         "0128um"               => 20869,
                         "013579"               => 10118,
                         "0137485"              => 14157,
                         "013cpfza"             => 11409,
                         "014702580369"         => 27485,
                         "0147258369"           => 19969,
                         "0147852"              => 25722,
                         "01478520"             => 8851,
                         "0147852369"           => 21644,
                         "014789"               => 10098,
                         "01478963"             => 22841,
                         "0147896325"           => 11320,
                         "019283"               => 11578,
                         "0192837465"           => 5469,
                         "01telemike01"         => 20758,
                         "02011971"             => 5874,
                         "02011975"             => 5280,
                         "02011980"             => 3575,
                         "02011981"             => 4300,
                         "02011982"             => 4693,
                         "02011983"             => 4608,
                         "02011984"             => 3774,
                         "02011985"             => 3075,
                         "02011986"             => 3353,
                         "02011987"             => 3197,
                         "02011988"             => 3524,
                         "02011989"             => 4219,
                         "02020"                => 20891,
                         "02021971"             => 5268,
                         "02021973"             => 4326,
                         "02021976"             => 4245,
                         "02021979"             => 4107,
                         "02021981"             => 4162,
                         "02021982"             => 3659,
                         "02021983"             => 3430,
                         "02021984"             => 3290,
                         "02021985"             => 3315,
                         "02021986"             => 3215,
                         "02021987"             => 3070,
                         "02021988"             => 3150,
                         "02021989"             => 3466,
                         "02021990"             => 4415,
                         "02031970"             => 6115,
                         "02031973"             => 5249,
                         "02031974"             => 5765,
                         "02031975"             => 5042,
                         "02031977"             => 4634,
                         "02031978"             => 4887,
                         "02031979"             => 4259,
                         "02031980"             => 4487,
                         "02031981"             => 4054,
                         "02031982"             => 3785,
                         "02031984"             => 3294,
                         "02031985"             => 3696,
                         "02031986"             => 3148,
                         "02031987"             => 3507,
                         "02031988"             => 4643,
                         "02031989"             => 4527,
                         "02041972"             => 5784,
                         "02041973"             => 5650,
                         "02041974"             => 4658,
                         "02041975"             => 4727,
                         "02041976"             => 5199,
                         "02041977"             => 5104,
                         "02041978"             => 4876,
                         "02041979"             => 4010,
                         "02041980"             => 4537,
                         "02041981"             => 3967,
                         "02041982"             => 3554,
                         "02041983"             => 3467,
                         "02041984"             => 3379,
                         "02041985"             => 3896,
                         "02041986"             => 3094,
                         "02041987"             => 3558,
                         "02041988"             => 3557,
                         "02041989"             => 4200,
                         "02051970"             => 5758,
                         "02051972"             => 4850,
                         "02051973"             => 4755,
                         "02051975"             => 5306,
                         "02051976"             => 4709,
                         "02051977"             => 4905,
                         "02051978"             => 4683,
                         "02051980"             => 4568,
                         "02051981"             => 4767,
                         "02051982"             => 3763,
                         "02051983"             => 3482,
                         "02051984"             => 4081,
                         "02051985"             => 4700,
                         "02051986"             => 3104,
                         "02051987"             => 3998,
                         "02051988"             => 4035,
                         "02051989"             => 4084,
                         "02061971"             => 5797,
                         "02061972"             => 5610,
                         "02061974"             => 5605,
                         "02061976"             => 5167,
                         "02061977"             => 5039,
                         "02061980"             => 3800,
                         "02061982"             => 4116,
                         "02061983"             => 3968,
                         "02061984"             => 4050,
                         "02061985"             => 3170,
                         "02061986"             => 3270,
                         "02061987"             => 3842,
                         "02061988"             => 3691,
                         "02061989"             => 3367,
                         "02071971"             => 5486,
                         "02071975"             => 5001,
                         "02071976"             => 5137,
                         "02071978"             => 4639,
                         "02071979"             => 4673,
                         "02071980"             => 3921,
                         "02071981"             => 4234,
                         "02071982"             => 2925,
                         "02071983"             => 4324,
                         "02071984"             => 3636,
                         "02071986"             => 2715,
                         "02071987"             => 3928,
                         "02071988"             => 4007,
                         "02071989"             => 4346,
                         "02081970"             => 5931,
                         "02081973"             => 5752,
                         "02081974"             => 5483,
                         "02081976"             => 4945,
                         "02081977"             => 4037,
                         "02081980"             => 4396,
                         "02081982"             => 3748,
                         "02081983"             => 4280,
                         "02081984"             => 3263,
                         "02081985"             => 3619,
                         "02081986"             => 3525,
                         "02081987"             => 3269,
                         "02081988"             => 3084,
                         "02081989"             => 3341,
                         "02091971"             => 5519,
                         "02091973"             => 5465,
                         "02091975"             => 5319,
                         "02091976"             => 5289,
                         "02091977"             => 5359,
                         "02091980"             => 3976,
                         "02091981"             => 3957,
                         "02091983"             => 3856,
                         "02091984"             => 3977,
                         "02091985"             => 4117,
                         "02091986"             => 3208,
                         "02091987"             => 3115,
                         "02091989"             => 4344,
                         "02101973"             => 5627,
                         "02101976"             => 5173,
                         "02101977"             => 5316,
                         "02101979"             => 4695,
                         "02101981"             => 4522,
                         "02101983"             => 4508,
                         "02101984"             => 3591,
                         "02101985"             => 3127,
                         "02101986"             => 4215,
                         "02101987"             => 3877,
                         "02101988"             => 4404,
                         "02101989"             => 3907,
                         "024680"               => 17265,
                         "02551670"             => 24801,
                         "02588520"             => 29754,
                         "028526"               => 26852,
                         "03031986"             => 4670,
                         "03038"                => 28003,
                         "03041986"             => 4458,
                         "03041991"             => 4255,
                         "03082006"             => 2732,
                         "033028pw"             => 18740,
                         "04041988"             => 4569,
                         "04041991"             => 4492,
                         "0420"                 => 2544,
                         "04325956"             => 18345,
                         "043aaa"               => 12820,
                         "048ro"                => 23488,
                         "04975756"             => 14820,
                         "05051985"             => 4016,
                         "05051987"             => 3895,
                         "05051989"             => 4591,
                         "06060"                => 16347,
                         "06061986"             => 4159,
                         "06068"                => 29822,
                         "06225930"             => 15503,
                         "063dyjuy"             => 8955,
                         "07070"                => 17137,
                         "07071977"             => 4941,
                         "07071987"             => 4349,
                         "07078"                => 27009,
                         "07091990"             => 4761,
                         "074401"               => 18955,
                         "0773417k"             => 22757,
                         "07831505"             => 11368,
                         "07931505"             => 21427,
                         "08031985"             => 4684,
                         "08031986"             => 4062,
                         "08051990"             => 4583,
                         "08080"                => 26342,
                         "08081988"             => 4635,
                         "08121986"             => 4464,
                         "08154711"             => 10002,
                         "08522580"             => 11401,
                         "085tzzqi"             => 8920,
                         "088011"               => 8778,
                         "09051945"             => 4501,
                         "09080706"             => 23647,
                         "090808qwe"            => 14724,
                         "09090"                => 17800,
                         "090909t"              => 13141,
                         "098123"               => 12944,
                         "0987654321a"          => 19314,
                         "0987654321q"          => 6582,
                         "09877890"             => 15884,
                         "098890"               => 14131,
                         "098poi"               => 29735,
                         "0cdh0v99ue"           => 23831,
                         "0o9i8u"               => 9029,
                         "0o9i8u7y"             => 6914,
                         "0o9i8u7y6t"           => 20863,
                         "0okm9ijn"             => 15791,
                         "0p9o8i"               => 18437,
                         "0p9o8i7u"             => 18946,
                         "0range"               => 14646,
                         "0raziel0"             => 14292,
                         "0sister0"             => 23083,
                         "0u812"                => 18780,
                         "0wnsyo0"              => 10241,
                         "1-oct"                => 27637,
                         "1000"                 => 2404,
                         "10000"                => 9471,
                         "100000"               => 2164,
                         "1000000"              => 3837,
                         "100001"               => 9864,
                         "1001"                 => 2180,
                         "1001001"              => 11761,
                         "10011986"             => 4128,
                         "10011990"             => 4499,
                         "1001sin"              => 24104,
                         "1002"                 => 4175,
                         "10020"                => 28504,
                         "100200300"            => 8963,
                         "1003"                 => 4621,
                         "10031988"             => 4374,
                         "1004"                 => 5288,
                         "10048"                => 24242,
                         "1005"                 => 3000,
                         "100500"               => 4598,
                         "10051987"             => 4435,
                         "1007"                 => 2862,
                         "10071987"             => 4422,
                         "10078"                => 26548,
                         "1008"                 => 5059,
                         "1009"                 => 6901,
                         "100years"             => 22153,
                         "10101"                => 2863,
                         "1010101"              => 14538,
                         "10101986"             => 4453,
                         "10101990"             => 4732,
                         "1010220"              => 21204,
                         "1010321"              => 25533,
                         "101091m"              => 6070,
                         "1011"                 => 3585,
                         "1011111"              => 23360,
                         "10111213"             => 15635,
                         "1012"                 => 2775,
                         "10121v"               => 29582,
                         "1012nw"               => 17220,
                         "1013"                 => 3915,
                         "1017"                 => 3185,
                         "1020"                 => 3184,
                         "10203"                => 2449,
                         "102030"               => 342,
                         "1020304"              => 13342,
                         "10203040"             => 2773,
                         "102030405"            => 23377,
                         "1020304050"           => 6280,
                         "102030405060"         => 11942,
                         "102030q"              => 25561,
                         "1020315"              => 20333,
                         "1022"                 => 3533,
                         "1023"                 => 3894,
                         "1024"                 => 2583,
                         "102938"               => 1576,
                         "10293847"             => 5493,
                         "102938475"            => 29305,
                         "1029384756"           => 752,
                         "1029384756q"          => 19316,
                         "10293847qp"           => 27169,
                         "1031"                 => 4342,
                         "104328q"              => 24326,
                         "1066"                 => 2112,
                         "106666"               => 17473,
                         "1066ad"               => 12325,
                         "108888"               => 28997,
                         "10inch"               => 15090,
                         "10inches"             => 11499,
                         "10sne1"               => 9085,
                         "11001001"             => 7126,
                         "1102"                 => 4312,
                         "110442"               => 7055,
                         "110491g"              => 21158,
                         "11051987"             => 4122,
                         "11051990"             => 4542,
                         "11061985"             => 4526,
                         "11081989"             => 4274,
                         "111000"               => 4127,
                         "111111"               => 8,
                         "11111111"             => 63,
                         "1111111111zz"         => 10321,
                         "11111111a"            => 16356,
                         "11111118"             => 24491,
                         "1111111a"             => 19507,
                         "1111111q"             => 17367,
                         "1111112"              => 28075,
                         "111111a"              => 3434,
                         "111111aa"             => 11701,
                         "111111q"              => 4034,
                         "111111w"              => 27195,
                         "111111z"              => 22434,
                         "1111122222"           => 11190,
                         "11111a"               => 5323,
                         "11111aaaaa"           => 22753,
                         "11111q"               => 4751,
                         "11111z"               => 13548,
                         "11112222"             => 1620,
                         "11119999"             => 25792,
                         "1111aaaa"             => 10576,
                         "1111qq"               => 20549,
                         "1111qqqq"             => 6075,
                         "1112"                 => 3862,
                         "11121314"             => 10833,
                         "1112131415"           => 13287,
                         "11121986"             => 4653,
                         "111222"               => 459,
                         "11122233"             => 8276,
                         "111222333"            => 1331,
                         "111222333000"         => 23954,
                         "111222333444555"      => 27717,
                         "111222333a"           => 14376,
                         "111222q"              => 20920,
                         "111333"               => 3206,
                         "111555"               => 5976,
                         "111777"               => 5176,
                         "111a111"              => 20502,
                         "111aaa"               => 6187,
                         "111lox"               => 28511,
                         "111luzer"             => 24096,
                         "111qqq"               => 3824,
                         "111zzzzz"             => 29382,
                         "1121"                 => 4036,
                         "1122"                 => 1555,
                         "112211"               => 2640,
                         "1122112211"           => 13992,
                         "11223"                => 2893,
                         "112233"               => 56,
                         "11223300"             => 24446,
                         "11223311"             => 24444,
                         "1122334"              => 7718,
                         "11223344"             => 346,
                         "112233445"            => 22026,
                         "1122334455"           => 1578,
                         "112233445566"         => 6293,
                         "11223344q"            => 11953,
                         "11223355"             => 22960,
                         "112233a"              => 9070,
                         "112233aa"             => 19612,
                         "112233q"              => 9025,
                         "1123"                 => 3452,
                         "1123456"              => 14541,
                         "11234567"             => 29998,
                         "112358"               => 1195,
                         "1123581"              => 18146,
                         "11235813"             => 1114,
                         "112358132"            => 28059,
                         "1123581321"           => 1206,
                         "1124"                 => 4762,
                         "1125"                 => 4306,
                         "11251422"             => 24439,
                         "113311"               => 19185,
                         "113322"               => 11618,
                         "113355"               => 12048,
                         "11335577"             => 20980,
                         "1133557799"           => 20769,
                         "114411"               => 12966,
                         "114477"               => 6324,
                         "115511"               => 26404,
                         "115599"               => 5682,
                         "1169900"              => 28092,
                         "117711"               => 28161,
                         "118801"               => 29246,
                         "118811"               => 29250,
                         "118a105b"             => 21883,
                         "11924704"             => 11559,
                         "119911"               => 16071,
                         "119955"               => 29251,
                         "119966"               => 26396,
                         "11aa11"               => 21065,
                         "11bravo"              => 15019,
                         "11c645df"             => 13966,
                         "11qq11"               => 16433,
                         "11qq22ww"             => 13918,
                         "12011987"             => 3125,
                         "12021988"             => 4231,
                         "12031985"             => 4626,
                         "12031987"             => 4627,
                         "1204"                 => 4666,
                         "12051988"             => 3902,
                         "120676"               => 3439,
                         "1210"                 => 4585,
                         "1211"                 => 3633,
                         "1211123a"             => 16927,
                         "12121"                => 1648,
                         "1212121"              => 9309,
                         "1212123"              => 11754,
                         "121212a"              => 13040,
                         "121212q"              => 8813,
                         "12121985"             => 4515,
                         "12121990"             => 4421,
                         "1212312121"           => 29333,
                         "12123434"             => 20912,
                         "1212qq"               => 15176,
                         "1213"                 => 3062,
                         "121314"               => 1298,
                         "12131415"             => 2438,
                         "1213141516"           => 7470,
                         "1215"                 => 4145,
                         "121ebay"              => 26069,
                         "1221"                 => 1709,
                         "12213443"             => 26964,
                         "1223"                 => 3547,
                         "122333"               => 2428,
                         "1223334444"           => 10547,
                         "122333444455555"      => 27912,
                         "12233445"             => 10221,
                         "1224"                 => 3622,
                         "1225"                 => 2037,
                         "123-123"              => 25290,
                         "123000"               => 3962,
                         "1230123"              => 8210,
                         "123098"               => 1427,
                         "12312"                => 705,
                         "123123"               => 11,
                         "1231230"              => 28096,
                         "1231231"              => 10070,
                         "12312312"             => 1568,
                         "123123123a"           => 12992,
                         "123123123q"           => 10651,
                         "123123321"            => 11860,
                         "1231234"              => 6045,
                         "12312345"             => 12448,
                         "123123456"            => 17086,
                         "123123789"            => 29307,
                         "123123a"              => 620,
                         "123123e"              => 9729,
                         "123123f"              => 21009,
                         "123123q"              => 2375,
                         "123123qq"             => 24000,
                         "123123qwe"            => 10598,
                         "123123qweqwe"         => 13213,
                         "123123s"              => 17406,
                         "123123z"              => 8197,
                         "123211"               => 19780,
                         "1232123"              => 16689,
                         "123213"               => 18960,
                         "1232323"              => 20356,
                         "1232323q"             => 489,
                         "123234"               => 11638,
                         "123258"               => 9026,
                         "1232580"              => 23349,
                         "12332"                => 1962,
                         "123321"               => 23,
                         "1233210"              => 10074,
                         "12332100"             => 18598,
                         "1233211"              => 9791,
                         "12332112"             => 10562,
                         "123321123"            => 1423,
                         "1233214"              => 13333,
                         "12332145"             => 16090,
                         "123321456"            => 9327,
                         "123321456654"         => 25745,
                         "1233215"              => 25542,
                         "123321a"              => 3090,
                         "123321aa"             => 24284,
                         "123321az"             => 23281,
                         "123321q"              => 1682,
                         "123321qaz"            => 21691,
                         "123321qq"             => 17398,
                         "123321qw"             => 25828,
                         "123321qwe"            => 9420,
                         "123321qweewq"         => 19310,
                         "123321s"              => 22693,
                         "123321w"              => 23251,
                         "123321z"              => 8807,
                         "123333"               => 10974,
                         "123342"               => 23418,
                         "123345"               => 12405,
                         "123369"               => 9819,
                         "1234"                 => 7,
                         "123400"               => 17749,
                         "12340987"             => 7717,
                         "123412"               => 7339,
                         "1234123"              => 4676,
                         "12341234q"            => 22475,
                         "12342000"             => 18079,
                         "123423"               => 17337,
                         "123432"               => 11976,
                         "1234321"              => 1185,
                         "12343412"             => 20907,
                         "1234432"              => 9795,
                         "12344321"             => 213,
                         "12344321a"            => 22016,
                         "12344321q"            => 10746,
                         "123444"               => 11977,
                         "123445"               => 20677,
                         "12345"                => 6,
                         "12345\$"              => 22110,
                         "123450"               => 5911,
                         "1234509876"           => 5787,
                         "123451"               => 2872,
                         "1234512"              => 18509,
                         "12345123"             => 7276,
                         "123451234"            => 23363,
                         "1234512i"             => 24049,
                         "123452"               => 23426,
                         "123452000"            => 16476,
                         "123452345"            => 18837,
                         "123454"               => 9358,
                         "12345432"             => 9152,
                         "123454321"            => 1165,
                         "123455"               => 3333,
                         "123455432"            => 16479,
                         "1234554321"           => 539,
                         "1234554321a"          => 28054,
                         "1234554321q"          => 17514,
                         "123456"               => 1,
                         "1234560"              => 3831,
                         "12345600"             => 14716,
                         "1234561"              => 5673,
                         "12345611"             => 22681,
                         "12345612"             => 7723,
                         "123456123"            => 4393,
                         "1234562000"           => 28010,
                         "123456321"            => 29310,
                         "1234565"              => 14543,
                         "12345654321"          => 8095,
                         "12345656"             => 29909,
                         "1234566"              => 5538,
                         "123456654"            => 20751,
                         "123456654321"         => 2975,
                         "12345666"             => 11552,
                         "1234567"              => 9,
                         "12345670"             => 20905,
                         "12345671"             => 11474,
                         "12345672000"          => 29684,
                         "12345677"             => 6300,
                         "12345678"             => 3,
                         "123456780"            => 16482,
                         "123456781"            => 14970,
                         "123456782000"         => 17152,
                         "123456788"            => 19559,
                         "1234567887654321"     => 27381,
                         "123456789"            => 5,
                         "123456789."           => 20557,
                         "1234567890"           => 24,
                         "12345678900"          => 7969,
                         "123456789000"         => 27778,
                         "12345678900987654321" => 11321,
                         "1234567890987654321"  => 25194,
                         "1234567890a"          => 3192,
                         "1234567890d"          => 28500,
                         "1234567890m"          => 22267,
                         "1234567890o"          => 26719,
                         "1234567890p"          => 26673,
                         "1234567890q"          => 1759,
                         "1234567890qaz"        => 22672,
                         "1234567890qw"         => 13341,
                         "1234567890qwe"        => 16279,
                         "1234567890qwerty"     => 25114,
                         "1234567890s"          => 12017,
                         "1234567890w"          => 17102,
                         "1234567890z"          => 6612,
                         "1234567890zzz"        => 18521,
                         "1234567891"           => 3465,
                         "12345678910"          => 1011,
                         "123456789101"         => 21642,
                         "12345678912"          => 13508,
                         "123456789123"         => 7744,
                         "1234567892000"        => 27396,
                         "12345678987654321"    => 15404,
                         "1234567899"           => 5737,
                         "123456789987654321"   => 6236,
                         "123456789a"           => 486,
                         "123456789aa"          => 16063,
                         "123456789abc"         => 9863,
                         "123456789as"          => 18393,
                         "123456789asd"         => 27138,
                         "123456789b"           => 13266,
                         "123456789c"           => 20634,
                         "123456789d"           => 5338,
                         "123456789e"           => 19885,
                         "123456789f"           => 14153,
                         "123456789g"           => 11998,
                         "123456789i"           => 18105,
                         "123456789j"           => 26343,
                         "123456789k"           => 8431,
                         "123456789l"           => 7595,
                         "123456789m"           => 5139,
                         "123456789n"           => 9886,
                         "123456789o"           => 6625,
                         "123456789p"           => 7476,
                         "123456789q"           => 690,
                         "123456789qaz"         => 10818,
                         "123456789qq"          => 15398,
                         "123456789qqq"         => 12862,
                         "123456789qw"          => 14780,
                         "123456789qwe"         => 5572,
                         "123456789qwer"        => 27640,
                         "123456789qwerty"      => 9990,
                         "123456789r"           => 6142,
                         "123456789s"           => 4058,
                         "123456789t"           => 13239,
                         "123456789v"           => 6492,
                         "123456789w"           => 10569,
                         "123456789x"           => 12452,
                         "123456789y"           => 21720,
                         "123456789z"           => 1989,
                         "123456789zx"          => 20933,
                         "123456789zxc"         => 14803,
                         "123456789zz"          => 27967,
                         "12345678a"            => 2928,
                         "12345678c"            => 12250,
                         "12345678d"            => 27317,
                         "12345678i"            => 25472,
                         "12345678m"            => 20381,
                         "12345678q"            => 2738,
                         "12345678qwe"          => 17544,
                         "12345678s"            => 18922,
                         "12345678w"            => 24969,
                         "12345678z"            => 13135,
                         "12345679"             => 2829,
                         "123456798"            => 19558,
                         "1234567a"             => 1312,
                         "1234567aa"            => 6155,
                         "1234567b"             => 17448,
                         "1234567d"             => 13643,
                         "1234567j"             => 29575,
                         "1234567k"             => 18229,
                         "1234567l"             => 19620,
                         "1234567m"             => 20519,
                         "1234567q"             => 1628,
                         "1234567qw"            => 20587,
                         "1234567qwertyu"       => 23797,
                         "1234567r"             => 16444,
                         "1234567s"             => 18915,
                         "1234567t"             => 14507,
                         "1234567u"             => 9708,
                         "1234567v"             => 19236,
                         "1234567w"             => 15363,
                         "1234567z"             => 10374,
                         "1234568"              => 5675,
                         "12345687"             => 7064,
                         "12345689"             => 13773,
                         "1234569"              => 8459,
                         "12345698"             => 18604,
                         "123456987"            => 6570,
                         "12345699"             => 24216,
                         "123456\@"             => 17437,
                         "123456a"              => 226,
                         "123456aa"             => 1742,
                         "123456aaa"            => 17476,
                         "123456ab"             => 7611,
                         "123456abc"            => 8887,
                         "123456as"             => 5781,
                         "123456asd"            => 8375,
                         "123456b"              => 7812,
                         "123456c"              => 6839,
                         "123456d"              => 5838,
                         "123456e"              => 13216,
                         "123456f"              => 6630,
                         "123456g"              => 6071,
                         "123456h"              => 9749,
                         "123456i"              => 12461,
                         "123456j"              => 10223,
                         "123456k"              => 1985,
                         "123456l"              => 3995,
                         "123456m"              => 4049,
                         "123456n"              => 5796,
                         "123456o"              => 10435,
                         "123456p"              => 10141,
                         "123456q"              => 295,
                         "123456qaz"            => 10930,
                         "123456qq"             => 7725,
                         "123456qqq"            => 5782,
                         "123456qw"             => 3152,
                         "123456qwe"            => 3627,
                         "123456qwer"           => 20765,
                         "123456qwert"          => 22934,
                         "123456qwerty"         => 1711,
                         "123456r"              => 2469,
                         "123456rrr"            => 27097,
                         "123456ru"             => 4664,
                         "123456s"              => 2689,
                         "123456ss"             => 16985,
                         "123456t"              => 5159,
                         "123456v"              => 6380,
                         "123456w"              => 5662,
                         "123456x"              => 13624,
                         "123456y"              => 7156,
                         "123456z"              => 1347,
                         "123456zx"             => 14527,
                         "123456zxc"            => 10080,
                         "123456zz"             => 16874,
                         "123457"               => 1879,
                         "1234576"              => 14544,
                         "1234578"              => 18507,
                         "12345789"             => 22676,
                         "123458"               => 8896,
                         "123459"               => 5284,
                         "123459876"            => 13390,
                         "1234599"              => 20373,
                         "12345a"               => 296,
                         "12345aa"              => 16953,
                         "12345ab"              => 17532,
                         "12345abc"             => 5327,
                         "12345abcd"            => 26057,
                         "12345abcde"           => 18161,
                         "12345as"              => 13156,
                         "12345asd"             => 7512,
                         "12345asdfg"           => 20357,
                         "12345b"               => 15212,
                         "12345c"               => 8846,
                         "12345d"               => 6679,
                         "12345e"               => 11024,
                         "12345f"               => 11219,
                         "12345g"               => 11298,
                         "12345i"               => 10984,
                         "12345j"               => 22671,
                         "12345k"               => 7663,
                         "12345l"               => 14920,
                         "12345m"               => 4940,
                         "12345n"               => 14900,
                         "12345q"               => 450,
                         "12345qaz"             => 5411,
                         "12345qq"              => 14513,
                         "12345qqq"             => 23816,
                         "12345qw"              => 4697,
                         "12345qwe"             => 2876,
                         "12345qwer"            => 5000,
                         "12345qwert"           => 504,
                         "12345qwerty"          => 5069,
                         "12345r"               => 5849,
                         "12345rewq"            => 21538,
                         "12345s"               => 4798,
                         "12345t"               => 3118,
                         "12345ta"              => 13438,
                         "12345trewq"           => 11280,
                         "12345v"               => 7412,
                         "12345w"               => 7223,
                         "12345x"               => 15256,
                         "12345z"               => 2639,
                         "12345zx"              => 17666,
                         "12345zxc"             => 14783,
                         "12345zxcvb"           => 11614,
                         "123465"               => 3663,
                         "12346789"             => 14252,
                         "12347890"             => 11473,
                         "12348765"             => 5498,
                         "12349876"             => 7062,
                         "1234a"                => 16608,
                         "1234aa"               => 28704,
                         "1234ab"               => 12313,
                         "1234abc"              => 7112,
                         "1234abcd"             => 954,
                         "1234as"               => 17215,
                         "1234asd"              => 15967,
                         "1234asdf"             => 3512,
                         "1234kekc"             => 7517,
                         "1234qaz"              => 6322,
                         "1234qq"               => 18667,
                         "1234qw"               => 4097,
                         "1234qwe"              => 2016,
                         "1234qwer"             => 86,
                         "1234qwerasdf"         => 13517,
                         "1234qwerasdfzxcv"     => 23869,
                         "1234qwert"            => 13926,
                         "1234qwerty"           => 10839,
                         "1234rewq"             => 5701,
                         "1234rmvb"             => 11359,
                         "1234zxcv"             => 4922,
                         "123555"               => 11388,
                         "123567"               => 5049,
                         "12356789"             => 24215,
                         "123569"               => 29525,
                         "1235789"              => 5235,
                         "123578951"            => 23350,
                         "123579"               => 23043,
                         "123580"               => 14359,
                         "1235813"              => 8017,
                         "123581321"            => 6831,
                         "123589"               => 23429,
                         "123592"               => 26199,
                         "123645"               => 16151,
                         "12365"                => 3613,
                         "123654"               => 150,
                         "1236547"              => 18158,
                         "12365478"             => 3678,
                         "123654789"            => 652,
                         "1236547890"           => 17913,
                         "123654789a"           => 26581,
                         "123654987"            => 17889,
                         "123654a"              => 15104,
                         "123654q"              => 16597,
                         "123654z"              => 21776,
                         "123666"               => 10952,
                         "123678"               => 20679,
                         "123698"               => 8640,
                         "1236987"              => 3216,
                         "12369874"             => 1525,
                         "123698741"            => 7846,
                         "123698745"            => 1491,
                         "1236987z"             => 15115,
                         "123699"               => 26198,
                         "1237654"              => 28108,
                         "123777"               => 16154,
                         "123789"               => 533,
                         "123789456"            => 2425,
                         "1237895"              => 6056,
                         "123852"               => 23049,
                         "123888"               => 27699,
                         "123890"               => 5999,
                         "123963"               => 14603,
                         "123978"               => 26196,
                         "123987"               => 1583,
                         "123987456"            => 28050,
                         "123a123"              => 13100,
                         "123a321"              => 14872,
                         "123a456"              => 24167,
                         "123aaa"               => 2797,
                         "123ab"                => 7754,
                         "123abc"               => 223,
                         "123abc123"            => 21840,
                         "123abcd"              => 18154,
                         "123as123"             => 15036,
                         "123asd"               => 1102,
                         "123asd123"            => 11896,
                         "123bbb"               => 8598,
                         "123boots1"            => 26034,
                         "123dan"               => 12747,
                         "123ert"               => 21073,
                         "123ewq"               => 4230,
                         "123ewqasd"            => 29392,
                         "123four"              => 20878,
                         "123fuck"              => 13665,
                         "123hfjdk147"          => 8692,
                         "123jlb"               => 23340,
                         "123joker"             => 29502,
                         "123kat"               => 12196,
                         "123kid"               => 16698,
                         "123llll"              => 27087,
                         "123lol123"            => 23946,
                         "123masha"             => 8665,
                         "123max"               => 27609,
                         "123mudar"             => 7739,
                         "123q123"              => 6000,
                         "123q321"              => 15935,
                         "123qaz"               => 1541,
                         "123qaz123"            => 10924,
                         "123qazwsx"            => 19311,
                         "123qq123"             => 3271,
                         "123qqq"               => 24042,
                         "123qw"                => 3887,
                         "123qw123"             => 26061,
                         "123qwaszx"            => 27774,
                         "123qwe"               => 33,
                         "123qwe1"              => 25493,
                         "123qwe12"             => 21828,
                         "123qwe123"            => 1086,
                         "123qwe321"            => 12069,
                         "123qwe456"            => 8642,
                         "123qwe456rty"         => 13543,
                         "123qweas"             => 7748,
                         "123qweasd"            => 610,
                         "123qweasdzx"          => 23216,
                         "123qweasdzxc"         => 850,
                         "123qweqwe"            => 16674,
                         "123qwer"              => 4268,
                         "123qwert"             => 5349,
                         "123qwerty"            => 2606,
                         "123qwerty123"         => 28668,
                         "123red"               => 14137,
                         "123rrr"               => 9281,
                         "123sas"               => 10238,
                         "123sex"               => 19719,
                         "123test"              => 26035,
                         "123vika"              => 26559,
                         "123wer"               => 17153,
                         "123www"               => 13711,
                         "123xxx"               => 14815,
                         "123xyi2"              => 29469,
                         "123xyz"               => 10054,
                         "123zxc"               => 1574,
                         "123zxc123"            => 14569,
                         "123zzz"               => 12238,
                         "124038"               => 6824,
                         "124356"               => 9504,
                         "12435687"             => 16088,
                         "124365"               => 26194,
                         "124536"               => 27694,
                         "124578"               => 756,
                         "12457896"             => 25877,
                         "124578963"            => 12151,
                         "124816"               => 9842,
                         "12481632"             => 14248,
                         "124c41"               => 28089,
                         "125000"               => 27693,
                         "125267"               => 27692,
                         "125412"               => 23080,
                         "125478"               => 18949,
                         "125521"               => 23104,
                         "125678"               => 16609,
                         "125689"               => 23129,
                         "125690"               => 26189,
                         "125wm"                => 25209,
                         "12758698"             => 26987,
                         "128500"               => 2068,
                         "128mo"                => 18202,
                         "129834"               => 29537,
                         "12e3e456"             => 12352,
                         "12inches"             => 25796,
                         "12locked"             => 7597,
                         "12monkey"             => 12768,
                         "12monkeys"            => 26425,
                         "12pack"               => 15744,
                         "12play"               => 25935,
                         "12qw12"               => 3232,
                         "12qw12qw"             => 4328,
                         "12qw34"               => 13159,
                         "12qw34er"             => 2837,
                         "12qw34er56ty"         => 16816,
                         "12qwas"               => 2779,
                         "12qwasz"              => 10820,
                         "12qwaszx"             => 349,
                         "12qwer"               => 28387,
                         "12qwerty"             => 8528,
                         "12s3t4p55"            => 8340,
                         "12step"               => 25298,
                         "12string"             => 29814,
                         "13021990"             => 4748,
                         "13031987"             => 4389,
                         "13041987"             => 4243,
                         "13041988"             => 4155,
                         "13061986"             => 4432,
                         "13121985"             => 4690,
                         "13131"                => 6254,
                         "131313"               => 64,
                         "1313131"              => 23329,
                         "1313666"              => 16715,
                         "131415"               => 9531,
                         "1314520"              => 16716,
                         "131517"               => 22066,
                         "132333"               => 23760,
                         "132435"               => 1901,
                         "13243546"             => 2229,
                         "132456"               => 4863,
                         "13245678"             => 19361,
                         "13245768"             => 7733,
                         "132465"               => 5297,
                         "132465798"            => 11038,
                         "132546"               => 29682,
                         "132613"               => 29683,
                         "132forever"           => 27709,
                         "133113"               => 11807,
                         "133159"               => 16596,
                         "13324124"             => 16722,
                         "133andre"             => 27231,
                         "134679"               => 665,
                         "134679258"            => 12757,
                         "1346795"              => 25549,
                         "13467982"             => 29812,
                         "13467985"             => 27151,
                         "134679852"            => 3941,
                         "1346798520"           => 28002,
                         "134679a"              => 26504,
                         "134679q"              => 25552,
                         "134kzbip"             => 17246,
                         "135135ab"             => 20714,
                         "135246"               => 2410,
                         "135531"               => 10143,
                         "135642"               => 27382,
                         "1357"                 => 2665,
                         "135711"               => 17236,
                         "13571113"             => 29809,
                         "1357246"              => 18162,
                         "13572468"             => 9218,
                         "1357642"              => 21187,
                         "13576479"             => 9475,
                         "13579"                => 1072,
                         "13579-"               => 10180,
                         "135790"               => 780,
                         "1357900"              => 15452,
                         "1357908642"           => 6424,
                         "135791"               => 4196,
                         "1357911"              => 5760,
                         "1357911q"             => 10735,
                         "1357913"              => 23328,
                         "13579135"             => 19381,
                         "135792"               => 11814,
                         "1357924"              => 28126,
                         "13579246"             => 10615,
                         "135792468"            => 2957,
                         "1357924680"           => 3212,
                         "135795"               => 19549,
                         "135797531"            => 11202,
                         "135798"               => 29686,
                         "135798642"            => 5005,
                         "135799"               => 9535,
                         "1357997531"           => 13988,
                         "13579a"               => 14377,
                         "1362840"              => 22003,
                         "1366613"              => 1903,
                         "136666"               => 29687,
                         "1369"                 => 3154,
                         "136900"               => 27368,
                         "136913"               => 29689,
                         "137946"               => 20768,
                         "137955"               => 26062,
                         "14021985"             => 4475,
                         "14021986"             => 4717,
                         "14028"                => 26578,
                         "14038"                => 28989,
                         "14058"                => 28986,
                         "14061991"             => 4264,
                         "14071789"             => 20804,
                         "14111986"             => 4366,
                         "14142135"             => 23842,
                         "141516"               => 7860,
                         "141592"               => 27134,
                         "14159265"             => 23840,
                         "141627"               => 1032,
                         "142500"               => 27126,
                         "142536"               => 787,
                         "142536789"            => 20752,
                         "142857"               => 4756,
                         "143000"               => 25945,
                         "14314314"             => 29726,
                         "143333"               => 29819,
                         "144000"               => 16277,
                         "144444"               => 25940,
                         "145236"               => 4872,
                         "1453145"              => 18495,
                         "145632"               => 9574,
                         "145678"               => 27111,
                         "146969"               => 22464,
                         "147123"               => 14397,
                         "147258"               => 468,
                         "1472583"              => 22001,
                         "14725836"             => 2905,
                         "147258369"            => 426,
                         "1472583690"           => 22118,
                         "147258369a"           => 25868,
                         "147369"               => 3087,
                         "147369258"            => 28047,
                         "1475369"              => 6844,
                         "1475963"              => 10107,
                         "147741"               => 3726,
                         "147789"               => 20854,
                         "147852"               => 492,
                         "1478520"              => 9597,
                         "14785236"             => 6239,
                         "147852369"            => 703,
                         "147852963"            => 28045,
                         "147896"               => 5033,
                         "1478963"              => 1062,
                         "14789632"             => 1186,
                         "147896321"            => 8415,
                         "147896325"            => 1411,
                         "147963"               => 3448,
                         "14881488"             => 5471,
                         "148888"               => 18014,
                         "1492"                 => 3160,
                         "14938685"             => 16036,
                         "149521"               => 24055,
                         "14ss88"               => 27586,
                         "14u2nv"               => 29750,
                         "14vbqk9p"             => 14263,
                         "15011987"             => 4631,
                         "15021985"             => 4735,
                         "15051981"             => 4085,
                         "15051990"             => 4667,
                         "15058"                => 28621,
                         "150781"               => 2194,
                         "15101986"             => 4711,
                         "1512198"              => 25554,
                         "151500"               => 22858,
                         "151617"               => 15520,
                         "151nxjmt"             => 9434,
                         "152535"               => 12423,
                         "15253545"             => 27489,
                         "153246"               => 29956,
                         "153351"               => 22870,
                         "153426"               => 13480,
                         "153624"               => 4026,
                         "153759"               => 7229,
                         "154263"               => 22872,
                         "15426378"             => 1888,
                         "154ugeiu"             => 11812,
                         "155555"               => 20963,
                         "157953"               => 20071,
                         "158272"               => 18497,
                         "158uefas"             => 23480,
                         "159000"               => 26857,
                         "159123"               => 16329,
                         "159263"               => 6133,
                         "159357"               => 248,
                         "1593570"              => 21997,
                         "159357123"            => 26345,
                         "159357258"            => 15772,
                         "159357456"            => 18835,
                         "15935746"             => 29628,
                         "159357852"            => 29318,
                         "159357a"              => 5030,
                         "159456"               => 24397,
                         "159487"               => 13490,
                         "159632"               => 3489,
                         "1596321"              => 8134,
                         "1596357"              => 16732,
                         "15975"                => 3563,
                         "159753"               => 68,
                         "1597530"              => 20423,
                         "15975300"             => 19619,
                         "15975312"             => 27501,
                         "159753123"            => 9439,
                         "1597532"              => 23319,
                         "15975321"             => 15332,
                         "1597532486"           => 22119,
                         "159753258"            => 14012,
                         "159753456"            => 6961,
                         "159753456852"         => 17076,
                         "15975346"             => 16001,
                         "1597535"              => 28156,
                         "159753852"            => 10091,
                         "15975391"             => 26117,
                         "159753a"              => 7665,
                         "159753q"              => 15798,
                         "159753z"              => 18121,
                         "159789"               => 20967,
                         "159852"               => 7998,
                         "159874"               => 12795,
                         "1598741"              => 14549,
                         "1598753"              => 5436,
                         "15987532"             => 13721,
                         "159875321"            => 10608,
                         "159951"               => 645,
                         "159951159"            => 26344,
                         "159963"               => 13495,
                         "15s9pu03"             => 17818,
                         "16051987"             => 4580,
                         "16051989"             => 4578,
                         "16121987"             => 4726,
                         "161718"               => 14203,
                         "162534"               => 2380,
                         "164379"               => 21808,
                         "16473a"               => 21060,
                         "165432"               => 28749,
                         "1654321"              => 18490,
                         "166666"               => 21810,
                         "167943"               => 21813,
                         "1701"                 => 1431,
                         "17011987"             => 4729,
                         "1701ab"               => 29838,
                         "1701d"                => 12413,
                         "17051988"             => 4434,
                         "17061988"             => 4614,
                         "17071994a"            => 22307,
                         "17098"                => 26589,
                         "171204j"              => 21835,
                         "17171717aa"           => 8485,
                         "171819"               => 12904,
                         "1725782"              => 9043,
                         "1726354"              => 21182,
                         "172839"               => 4304,
                         "172839456"            => 22060,
                         "17711771s"            => 23400,
                         "1776"                 => 4486,
                         "178500"               => 12256,
                         "179355"               => 18466,
                         "18011987"             => 4314,
                         "18061990"             => 4625,
                         "18068"                => 28970,
                         "18091985"             => 4641,
                         "1812"                 => 4359,
                         "18121812"             => 5881,
                         "18254288"             => 24790,
                         "18273645"             => 8085,
                         "182838"               => 23479,
                         "183461"               => 17178,
                         "18436572"             => 2289,
                         "1861brr"              => 27660,
                         "187211"               => 13546,
                         "18821221"             => 12561,
                         "18n28n24a"            => 29196,
                         "19061987"             => 4418,
                         "19101987"             => 4384,
                         "1911a1"               => 7966,
                         "192168"               => 12298,
                         "19216801"             => 19159,
                         "19216811"             => 28111,
                         "192837"               => 2644,
                         "19283746"             => 4825,
                         "192837465"            => 1472,
                         "1928374655"           => 29337,
                         "19371ayj"             => 19266,
                         "19372846"             => 26382,
                         "19380018"             => 26383,
                         "19391945"             => 12850,
                         "19411945"             => 2897,
                         "195000"               => 17960,
                         "1958proman"           => 19105,
                         "196100"               => 27243,
                         "196400"               => 22273,
                         "196800"               => 23679,
                         "196820"               => 23680,
                         "196969"               => 4552,
                         "197000"               => 13152,
                         "197010"               => 27212,
                         "197100"               => 21326,
                         "197101"               => 27210,
                         "19719870"             => 21772,
                         "197200"               => 25331,
                         "1972chev"             => 13116,
                         "197300"               => 22282,
                         "19733791"             => 20565,
                         "197430"               => 23704,
                         "197500"               => 13678,
                         "19755791"             => 24527,
                         "197600"               => 22293,
                         "19761977"             => 29268,
                         "197700"               => 27142,
                         "197800"               => 18777,
                         "198000"               => 13685,
                         "19801982"             => 28133,
                         "19801984"             => 29266,
                         "198020"               => 25304,
                         "198200"               => 12702,
                         "198206"               => 23733,
                         "198207"               => 23734,
                         "19821983"             => 28140,
                         "19822891"             => 26391,
                         "198300"               => 18787,
                         "19831985"             => 28141,
                         "19833891"             => 28142,
                         "198400"               => 16700,
                         "19841989"             => 29263,
                         "19844891"             => 11012,
                         "198500"               => 15015,
                         "198505"               => 27072,
                         "19851985p"            => 25599,
                         "198520"               => 27061,
                         "19855891"             => 26393,
                         "198600"               => 21351,
                         "19866891"             => 20140,
                         "1986irachka"          => 21150,
                         "1986mets"             => 29588,
                         "198700"               => 19522,
                         "198701"               => 23765,
                         "19877891"             => 11789,
                         "198800"               => 25283,
                         "198900"               => 17911,
                         "198910"               => 22352,
                         "19891959"             => 29256,
                         "198920"               => 22358,
                         "19899891"             => 19177,
                         "1989cc"               => 25382,
                         "199000"               => 15716,
                         "199020"               => 26956,
                         "199103"               => 23795,
                         "19911992"             => 23105,
                         "199200"               => 18828,
                         "19921993"             => 28153,
                         "19922991"             => 13953,
                         "19932916"             => 28165,
                         "19933991"             => 11265,
                         "199410"               => 25256,
                         "199430"               => 23823,
                         "19944991"             => 24490,
                         "19952009sa"           => 20271,
                         "19955991"             => 23026,
                         "19966991"             => 15658,
                         "1996gta"              => 25929,
                         "19977991"             => 19182,
                         "19992000"             => 15659,
                         "1999ar"               => 16152,
                         "19delta"              => 29925,
                         "19mtpgam19"           => 15721,
                         "1a2a3a"               => 9396,
                         "1a2a3a4a"             => 7762,
                         "1a2a3a4a5a"           => 9606,
                         "1a2b3c"               => 1021,
                         "1a2b3c4"              => 16574,
                         "1a2b3c4d"             => 1377,
                         "1a2b3c4d5e"           => 7704,
                         "1a2s3d"               => 4975,
                         "1a2s3d4f"             => 3546,
                         "1a2s3d4f5g"           => 7367,
                         "1a2s3d4f5g6h"         => 22871,
                         "1aaaaa"               => 10512,
                         "1aaaaaa"              => 18150,
                         "1aaaaaaa"             => 15095,
                         "1abc2"                => 18275,
                         "1abcdef"              => 27342,
                         "1abcdefg"             => 23451,
                         "1access"              => 14886,
                         "1accord"              => 29548,
                         "1adam12"              => 17285,
                         "1albert"              => 27890,
                         "1alex"                => 25838,
                         "1amanda"              => 19155,
                         "1amber"               => 21424,
                         "1andonly"             => 27306,
                         "1andrea"              => 17247,
                         "1andrew"              => 13634,
                         "1angel"               => 15497,
                         "1angela"              => 28470,
                         "1apple"               => 18379,
                         "1arsenal"             => 25871,
                         "1arthur"              => 17814,
                         "1asdfgh"              => 27277,
                         "1asdfghj"             => 26046,
                         "1ashley"              => 17797,
                         "1asshole"             => 9243,
                         "1assword"             => 25824,
                         "1august"              => 26811,
                         "1austin"              => 14223,
                         "1autopas"             => 29625,
                         "1baby"                => 24483,
                         "1badger"              => 25775,
                         "1bailey"              => 16502,
                         "1balls"               => 19000,
                         "1banana"              => 20055,
                         "1barney"              => 27115,
                         "1basebal"             => 8686,
                         "1bastard"             => 24845,
                         "1batman"              => 9413,
                         "1bbbbb"               => 20286,
                         "1bbbbbb"              => 26115,
                         "1bbbbbbb"             => 22037,
                         "1bear"                => 16659,
                         "1beavis"              => 18075,
                         "1beer"                => 23728,
                         "1bigdadd"             => 25845,
                         "1bigdick"             => 13359,
                         "1bigdog"              => 9648,
                         "1bigfish"             => 29934,
                         "1bigmac"              => 24349,
                         "1bill"                => 24035,
                         "1birdie"              => 29744,
                         "1bitch"               => 6739,
                         "1biteme"              => 19723,
                         "1black"               => 17438,
                         "1blood"               => 22827,
                         "1blue"                => 17374,
                         "1booger"              => 23638,
                         "1boomer"              => 15377,
                         "1brandon"             => 23640,
                         "1braves"              => 20177,
                         "1brian"               => 27664,
                         "1bubba"               => 10240,
                         "1buddy"               => 18380,
                         "1bulldog"             => 17191,
                         "1bullshi"             => 24702,
                         "1buster"              => 9603,
                         "1butthea"             => 20351,
                         "1camaro"              => 22300,
                         "1carlos"              => 24778,
                         "1carolin"             => 28309,
                         "1cassie"              => 28791,
                         "1ccccc"               => 16747,
                         "1ccccccc"             => 20201,
                         "1celtic"              => 28193,
                         "1chance"              => 16278,
                         "1charles"             => 20837,
                         "1charlie"             => 12520,
                         "1chelsea"             => 16685,
                         "1cherry"              => 26099,
                         "1chester"             => 26498,
                         "1chevy"               => 17946,
                         "1chicken"             => 14608,
                         "1chris"               => 10250,
                         "1christi"             => 26643,
                         "1clutch"              => 18261,
                         "1coffee"              => 28887,
                         "1compute"             => 15129,
                         "1cookie"              => 22740,
                         "1cooper"              => 28262,
                         "1corvett"             => 18326,
                         "1cowboy"              => 11193,
                         "1cowboys"             => 19486,
                         "1crazy"               => 19273,
                         "1creativ"             => 25694,
                         "1cricket"             => 24910,
                         "1crystal"             => 26407,
                         "1daddy"               => 11044,
                         "1dakota"              => 28736,
                         "1dallas"              => 8237,
                         "1daniel"              => 12531,
                         "1dave"                => 29753,
                         "1david"               => 14940,
                         "1dawg"                => 12775,
                         "1ddddd"               => 18123,
                         "1derful"              => 22446,
                         "1diablo"              => 21337,
                         "1diamond"             => 10246,
                         "1dick"                => 12796,
                         "1digital"             => 26323,
                         "1doctor"              => 22404,
                         "1dolphin"             => 19424,
                         "1dragon"              => 4677,
                         "1drummer"             => 25421,
                         "1eagle"               => 14650,
                         "1eagles"              => 21134,
                         "1edward"              => 22859,
                         "1eeeee"               => 18562,
                         "1eeeeeee"             => 26110,
                         "1elvis"               => 22623,
                         "1escobar2"            => 28202,
                         "1explore"             => 25218,
                         "1falcon"              => 25566,
                         "1fender"              => 21135,
                         "1ferrari"             => 16775,
                         "1fffff"               => 18122,
                         "1ffffff"              => 27493,
                         "1fire"                => 17167,
                         "1fish"                => 26920,
                         "1fishing"             => 21925,
                         "1flowers"             => 25987,
                         "1footbal"             => 9558,
                         "1forever"             => 20748,
                         "1frank"               => 25059,
                         "1fred"                => 17393,
                         "1freedom"             => 19055,
                         "1friday"              => 27952,
                         "1friend"              => 29279,
                         "1fuck"                => 7707,
                         "1fucker"              => 15961,
                         "1fuckme"              => 9645,
                         "1fuckyou"             => 12495,
                         "1gandalf"             => 26252,
                         "1gateway"             => 25309,
                         "1george"              => 10242,
                         "1ggggg"               => 18561,
                         "1gggggg"              => 23827,
                         "1ggggggg"             => 29632,
                         "1giants"              => 24967,
                         "1ginger"              => 12856,
                         "1girls"               => 14814,
                         "1golf"                => 25990,
                         "1golfer"              => 10248,
                         "1grand"               => 14384,
                         "1green"               => 20628,
                         "1grizzly"             => 18406,
                         "1guitar"              => 15786,
                         "1hammer"              => 14054,
                         "1happy"               => 22072,
                         "1hardon"              => 26174,
                         "1harley"              => 9657,
                         "1harry"               => 28776,
                         "1hawaii"              => 29944,
                         "1heather"             => 17717,
                         "1hello"               => 11833,
                         "1herbier"             => 21793,
                         "1hhhhh"               => 22756,
                         "1hockey"              => 15926,
                         "1honda"               => 25697,
                         "1horny"               => 16513,
                         "1horse"               => 26367,
                         "1hotdog"              => 27287,
                         "1house"               => 18971,
                         "1hunter"              => 11839,
                         "1hxboqg2"             => 8646,
                         "1hxboqg2s"            => 16570,
                         "1iceman"              => 23674,
                         "1iiiii"               => 15801,
                         "1iiiiiii"             => 27480,
                         "1inside"              => 27478,
                         "1irish"               => 26772,
                         "1j9e7f6f"             => 18599,
                         "1jack"                => 21550,
                         "1jackson"             => 24281,
                         "1james"               => 11142,
                         "1jeffrey"             => 21147,
                         "1jennife"             => 9899,
                         "1jerry"               => 29850,
                         "1jessica"             => 15333,
                         "1jesus"               => 15440,
                         "1jjjjj"               => 20922,
                         "1jjjjjj"              => 27487,
                         "1jjjjjjj"             => 23812,
                         "1john"                => 15927,
                         "1johnny"              => 15551,
                         "1johnson"             => 21429,
                         "1jones"               => 18211,
                         "1jordan"              => 10662,
                         "1joshua"              => 15987,
                         "1junior"              => 29006,
                         "1justin"              => 24596,
                         "1kevin"               => 29978,
                         "1killer"              => 9628,
                         "1king"                => 25050,
                         "1kitty"               => 18413,
                         "1kkkkk"               => 24937,
                         "1knight"              => 23063,
                         "1ladybug"             => 23701,
                         "1legend"              => 26566,
                         "1letmein"             => 7984,
                         "1light"               => 24011,
                         "1linda"               => 27871,
                         "1little"              => 28205,
                         "1lllll"               => 24938,
                         "1london"              => 29449,
                         "1love"                => 6349,
                         "1lover"               => 9762,
                         "1lovers"              => 14347,
                         "1loveyou"             => 24535,
                         "1lucky"               => 26289,
                         "1maggie"              => 20031,
                         "1manager"             => 21799,
                         "1marine"              => 24038,
                         "1martin"              => 11941,
                         "1master"              => 4966,
                         "1matrix"              => 22634,
                         "1matt"                => 24851,
                         "1matthew"             => 16173,
                         "1melissa"             => 15646,
                         "1member"              => 22288,
                         "1mercede"             => 26813,
                         "1merlin"              => 19206,
                         "1michael"             => 5515,
                         "1michell"             => 20633,
                         "1mickey"              => 19907,
                         "1mike"                => 18535,
                         "1miller"              => 20780,
                         "1million"             => 5743,
                         "1mmmmm"               => 27092,
                         "1money"               => 7820,
                         "1monkey"              => 7363,
                         "1monster"             => 22758,
                         "1montana"             => 26897,
                         "1month"               => 25858,
                         "1moose"               => 23935,
                         "1morgan"              => 17824,
                         "1mouse"               => 20227,
                         "1muffin"              => 25834,
                         "1murphy"              => 22537,
                         "1mustang"             => 6967,
                         "1nascar"              => 25672,
                         "1newlife"             => 27946,
                         "1nicole"              => 10654,
                         "1nissan"              => 29941,
                         "1nnnnn"               => 24330,
                         "1oliver"              => 28532,
                         "1ooooo"               => 23669,
                         "1orange"              => 12834,
                         "1p2o3i"               => 18217,
                         "1packers"             => 25788,
                         "1panther"             => 16210,
                         "1panties"             => 27459,
                         "1pass"                => 20939,
                         "1pass1page"           => 13496,
                         "1passwor"             => 1434,
                         "1password"            => 7119,
                         "1patrick"             => 11634,
                         "1peaches"             => 29947,
                         "1peanut"              => 21831,
                         "1penguin"             => 24245,
                         "1pepper"              => 12655,
                         "1phoenix"             => 16434,
                         "1pillow"              => 11572,
                         "1pionee"              => 14208,
                         "1pizza"               => 19435,
                         "1player"              => 17982,
                         "1please"              => 18804,
                         "1pookie"              => 21269,
                         "1porsche"             => 21718,
                         "1power"               => 18576,
                         "1prince"              => 23074,
                         "1pumpkin"             => 29076,
                         "1pussy"               => 3071,
                         "1q1q1q1"              => 26025,
                         "1q2345"               => 26100,
                         "1q2a3z"               => 12896,
                         "1q2q3q"               => 5399,
                         "1q2q3q4q"             => 6178,
                         "1q2q3q4q5q"           => 10346,
                         "1q2s3c"               => 21649,
                         "1q2w3"                => 8233,
                         "1q2w3e"               => 686,
                         "1q2w3e4r"             => 192,
                         "1q2w3e4r5"            => 2808,
                         "1q2w3e4r5t"           => 290,
                         "1q2w3e4r5t6y"         => 1353,
                         "1q3e5t7u"             => 21140,
                         "1qa2ws"               => 3666,
                         "1qa2ws3e"             => 13452,
                         "1qa2ws3ed"            => 2228,
                         "1qa2ws3ed4rf"         => 14734,
                         "1qa2ws3ed4rf5tg"      => 26702,
                         "1qasw2"               => 16027,
                         "1qasw23ed"            => 19951,
                         "1qay2wsx"             => 10206,
                         "1qayxsw2"             => 25085,
                         "1qaz!qaz"             => 9024,
                         "1qaz0okm"             => 27006,
                         "1qaz2w"               => 15010,
                         "1qaz2ws"              => 3229,
                         "1qaz2wsx"             => 28,
                         "1qaz2wsx3edc"         => 1000,
                         "1qaz2wsx3edc4rfv"     => 6766,
                         "1qaz3edc"             => 17459,
                         "1qaz\@wsx"            => 17521,
                         "1qazse4"              => 8349,
                         "1qazwsx"              => 13377,
                         "1qazwsxedc"           => 25224,
                         "1qazxc"               => 8034,
                         "1qazxcvb"             => 17150,
                         "1qazxdr5"             => 23564,
                         "1qazxs"               => 29072,
                         "1qazxsw"              => 6024,
                         "1qazxsw2"             => 311,
                         "1qazxsw23edc"         => 5591,
                         "1qazxsw23edcvfr4"     => 16868,
                         "1qazzaq1"             => 5672,
                         "1qqqqq"               => 17484,
                         "1qw23e"               => 10373,
                         "1qw23er4"             => 6043,
                         "1qwe2"                => 28362,
                         "1qwert"               => 7530,
                         "1qwerty"              => 2591,
                         "1qwerty1"             => 14504,
                         "1qwertyu"             => 13707,
                         "1qwertyuiop"          => 19826,
                         "1rabbit"              => 26516,
                         "1rachel"              => 26868,
                         "1rainbow"             => 26108,
                         "1ranger"              => 8391,
                         "1rangers"             => 24486,
                         "1richard"             => 18410,
                         "1robert"              => 11043,
                         "1rock"                => 25846,
                         "1rocket"              => 26440,
                         "1rocks"               => 16705,
                         "1rocky"               => 19441,
                         "1rosebud"             => 18538,
                         "1rusty"               => 29108,
                         "1s1h1e1f1"            => 25169,
                         "1sailor"              => 29254,
                         "1samanth"             => 15488,
                         "1sarah"               => 25823,
                         "1scooter"             => 13885,
                         "1scott"               => 15938,
                         "1secret"              => 28197,
                         "1sexsex"              => 27594,
                         "1sexy"                => 9013,
                         "1sexyred"             => 13905,
                         "1shadow"              => 8934,
                         "1shelly"              => 29607,
                         "1shot2"               => 17435,
                         "1sierra"              => 29963,
                         "1silver"              => 14073,
                         "1simpson"             => 23962,
                         "1slayer"              => 16205,
                         "1smith"               => 18266,
                         "1snoopy"              => 26615,
                         "1soccer"              => 12560,
                         "1spanky"              => 27286,
                         "1sparky"              => 22923,
                         "1speedy"              => 27518,
                         "1spider"              => 13424,
                         "1star"                => 17462,
                         "1starwar"             => 15912,
                         "1steeler"             => 19465,
                         "1steve"               => 18141,
                         "1stunner"             => 29936,
                         "1sucks"               => 26905,
                         "1sugar"               => 29971,
                         "1summer"              => 12311,
                         "1sunshin"             => 19678,
                         "1super"               => 23482,
                         "1superma"             => 13408,
                         "1surfer"              => 22260,
                         "1taylor"              => 15437,
                         "1test"                => 14368,
                         "1theman"              => 24357,
                         "1therock"             => 28453,
                         "1thomas"              => 13162,
                         "1thunder"             => 12624,
                         "1tiffany"             => 21593,
                         "1tiger"               => 15237,
                         "1tigers"              => 26847,
                         "1tigger"              => 11541,
                         "1time"                => 27649,
                         "1tits"                => 20532,
                         "1tommy"               => 21448,
                         "1trouble"             => 29402,
                         "1truck"               => 21130,
                         "1um83z"               => 14491,
                         "1vader"               => 26884,
                         "1vampire"             => 27042,
                         "1vette"               => 29960,
                         "1video"               => 25354,
                         "1w2q3r4e"             => 21819,
                         "1w2w3w"               => 21993,
                         "1w2w3w4w"             => 20107,
                         "1warrior"             => 23548,
                         "1wildcat"             => 15117,
                         "1william"             => 11152,
                         "1winner"              => 11225,
                         "1winston"             => 29988,
                         "1winter"              => 20469,
                         "1wizard"              => 18700,
                         "1world"               => 21936,
                         "1wwwww"               => 21940,
                         "1x2zkg8w"             => 2681,
                         "1xrg4kcq"             => 20590,
                         "1xxxxx"               => 15454,
                         "1xxxxxx"              => 16769,
                         "1xxxxxxx"             => 26101,
                         "1yamaha"              => 27570,
                         "1yellow"              => 16729,
                         "1yyyyy"               => 18120,
                         "1z2x3c"               => 3758,
                         "1z2x3c4v"             => 3880,
                         "1z2x3c4v5b"           => 6556,
                         "1z2z3z"               => 13219,
                         "1zxcvbn"              => 23190,
                         "1zxcvbnm"             => 15955,
                         "1zzzzz"               => 15126,
                         "1zzzzzz"              => 27486,
                         "1zzzzzzz"             => 18552,
                         "20000"                => 17643,
                         "200000"               => 2452,
                         "200001"               => 22388,
                         "20001"                => 11817,
                         "2000jeep"             => 26954,
                         "200190ru"             => 29145,
                         "2002tii"              => 12870,
                         "20031987"             => 4567,
                         "20038"                => 28966,
                         "2004-10-"             => 18582,
                         "2004rj"               => 16497,
                         "20051988"             => 4651,
                         "20061988"             => 4279,
                         "20068"                => 28965,
                         "20091988"             => 4663,
                         "20091989q"            => 27356,
                         "20091991"             => 4584,
                         "20111986"             => 4436,
                         "201980"               => 28218,
                         "201jedlz"             => 14034,
                         "2022958"              => 25569,
                         "203040"               => 12766,
                         "204060"               => 25144,
                         "20spanks"             => 6571,
                         "21011989"             => 4269,
                         "21031987"             => 4151,
                         "21031988"             => 3342,
                         "21031990"             => 4558,
                         "21051988"             => 4783,
                         "21051991"             => 4637,
                         "21101986"             => 4712,
                         "2110se"               => 17332,
                         "2112"                 => 312,
                         "21125150"             => 10867,
                         "2112rush"             => 10793,
                         "2112yyz"              => 15735,
                         "212009164"            => 29321,
                         "2121212"              => 25573,
                         "212121qaz"            => 19595,
                         "212223"               => 10336,
                         "2128506"              => 2568,
                         "213141"               => 19897,
                         "213546879"            => 28035,
                         "213qwe879"            => 16866,
                         "214365"               => 6654,
                         "21436587"             => 17471,
                         "215487"               => 16524,
                         "2183rm"               => 20783,
                         "2196dc"               => 20312,
                         "21crack"              => 16039,
                         "22011988"             => 4516,
                         "22021986"             => 4605,
                         "22021989"             => 4284,
                         "22031984"             => 4734,
                         "22041987"             => 4042,
                         "22041988"             => 4786,
                         "22061941"             => 5247,
                         "22071986"             => 4694,
                         "221195ws"             => 18244,
                         "22221111"             => 19312,
                         "222222a"              => 29360,
                         "22223333"             => 20412,
                         "222333"               => 2264,
                         "222444"               => 8394,
                         "222555"               => 7779,
                         "222666"               => 21631,
                         "222777"               => 5500,
                         "222888"               => 11506,
                         "222999"               => 19207,
                         "223311"               => 21634,
                         "223322"               => 5228,
                         "223344"               => 1745,
                         "22334455"             => 7721,
                         "223355"               => 27931,
                         "223366"               => 24513,
                         "2234562"              => 10136,
                         "224422"               => 11509,
                         "224455"               => 24942,
                         "224466"               => 4629,
                         "22446688"             => 6149,
                         "224488"               => 8544,
                         "225522"               => 13046,
                         "225588"               => 3818,
                         "226622"               => 24515,
                         "227722"               => 17156,
                         "2278124q"             => 27639,
                         "228822"               => 24935,
                         "22q04w90e"            => 23087,
                         "22tango"              => 28743,
                         "2300mj"               => 7058,
                         "23021986"             => 4764,
                         "23041987"             => 4297,
                         "23049307"             => 12641,
                         "2305822q"             => 23317,
                         "230857z"              => 15258,
                         "23176djivanfros"      => 9980,
                         "232425"               => 7122,
                         "232629"               => 12930,
                         "233223"               => 9778,
                         "233391"               => 16657,
                         "234432"               => 19300,
                         "234523"               => 16427,
                         "235689"               => 2906,
                         "235711"               => 10464,
                         "237081a"              => 14001,
                         "23dp4x"               => 13994,
                         "23jordan"             => 17272,
                         "23skidoo"             => 4993,
                         "23wesdxc"             => 16783,
                         "24011985"             => 4392,
                         "2401pedro"            => 27905,
                         "24061986"             => 4263,
                         "24111989"             => 4780,
                         "241455"               => 23065,
                         "242526"               => 11160,
                         "243122"               => 24721,
                         "243462536"            => 10972,
                         "245lufpq"             => 22393,
                         "2468"                 => 1418,
                         "24680"                => 4546,
                         "246800"               => 16397,
                         "2468013579"           => 26328,
                         "246810"               => 852,
                         "24681012"             => 6859,
                         "24681357"             => 15267,
                         "246813579"            => 9773,
                         "246824"               => 21703,
                         "24688642"             => 28841,
                         "246890"               => 21702,
                         "2469"                 => 3578,
                         "247365"               => 14776,
                         "2481632"              => 18186,
                         "24861793"             => 28843,
                         "248ujnfk"             => 20824,
                         "24gordon"             => 25234,
                         "24lover"              => 22727,
                         "24pnz6kc"             => 15507,
                         "25000"                => 8616,
                         "2500aa"               => 29630,
                         "2500hd"               => 26260,
                         "2502557i"             => 19613,
                         "25031987"             => 4557,
                         "25041988"             => 4757,
                         "25081988"             => 4405,
                         "25091987"             => 4725,
                         "2509mmh"              => 17445,
                         "25121987"             => 4579,
                         "2521659"              => 21974,
                         "25251325"             => 11560,
                         "25252"                => 6771,
                         "2525252"              => 25582,
                         "252627"               => 13066,
                         "253634"               => 9060,
                         "254xtpss"             => 17871,
                         "255225"               => 22916,
                         "255555"               => 24524,
                         "25563o"               => 24823,
                         "255ooo"               => 23846,
                         "2580"                 => 3349,
                         "258000"               => 6892,
                         "25800852"             => 4444,
                         "258025"               => 13640,
                         "2580258"              => 28246,
                         "25802580"             => 1476,
                         "2580456"              => 12087,
                         "258046"               => 27863,
                         "258147"               => 22909,
                         "2583458"              => 11740,
                         "258369"               => 4796,
                         "258456"               => 1528,
                         "258741"               => 10666,
                         "258789"               => 17566,
                         "258852"               => 3727,
                         "258963"               => 4913,
                         "2597174"              => 23284,
                         "26028"                => 28954,
                         "26031988"             => 4738,
                         "26058"                => 28688,
                         "26061987"             => 4091,
                         "260zntpc"             => 15368,
                         "261397"               => 22776,
                         "26429vadim"           => 19520,
                         "267605"               => 19676,
                         "267ksyjf"             => 21244,
                         "26exkp"               => 9336,
                         "27061988"             => 4538,
                         "270873_"              => 11588,
                         "271828"               => 9908,
                         "272829"               => 16317,
                         "2741001"              => 14557,
                         "276115"               => 20331,
                         "27731828"             => 7348,
                         "2797349"              => 25586,
                         "28011987"             => 4576,
                         "28021990"             => 4597,
                         "28021992"             => 4451,
                         "28041987"             => 4399,
                         "282860"               => 12360,
                         "2835493"              => 18465,
                         "284655"               => 21445,
                         "287hf71h"             => 24177,
                         "28infern"             => 23064,
                         "29011985"             => 4594,
                         "29024"                => 28945,
                         "29051989"             => 4565,
                         "29071983"             => 4553,
                         "299792458"            => 17134,
                         "29palms"              => 24933,
                         "2b4dnvsx"             => 17981,
                         "2b8riedt"             => 14251,
                         "2bad4u"               => 13652,
                         "2balls"               => 25833,
                         "2big4u"               => 26362,
                         "2bigtits"             => 14338,
                         "2boobs"               => 28413,
                         "2bornot2"             => 17812,
                         "2bornot2b"            => 17761,
                         "2children"            => 27520,
                         "2cool4u"              => 10187,
                         "2dumb2live"           => 28306,
                         "2enter"               => 21742,
                         "2fast4u"              => 4991,
                         "2fchbg"               => 11402,
                         "2gether"              => 21053,
                         "2girls"               => 11718,
                         "2good4u"              => 13187,
                         "2h0t4me"              => 25548,
                         "2hot4u"               => 6366,
                         "2hot4you"             => 28581,
                         "2i5fdruv"             => 23326,
                         "2kash6zq"             => 16568,
                         "2kgwai"               => 13891,
                         "2legit"               => 27260,
                         "2letmein"             => 25717,
                         "2much4u"              => 23626,
                         "2n6wvq"               => 13304,
                         "2sexy2ho"             => 11964,
                         "2sweet"               => 6723,
                         "2twins"               => 22646,
                         "2vrd6"                => 27794,
                         "2w3e4r"               => 9056,
                         "2w3e4r5t"             => 11517,
                         "2wj2k9oj"             => 17277,
                         "2wsx1qaz"             => 13200,
                         "2wsx3edc"             => 6459,
                         "2wsx4rfv"             => 26789,
                         "2wsxcde3"             => 10190,
                         "2wsxzaq1"             => 9405,
                         "2ykn5ccf"             => 26938,
                         "3000"                 => 6629,
                         "300000"               => 13123,
                         "3000gt"               => 4237,
                         "30031988"             => 4657,
                         "30041986"             => 4541,
                         "30051985"             => 4251,
                         "3006"                 => 5233,
                         "300zx"                => 10415,
                         "300zxtt"              => 28137,
                         "302731"               => 17923,
                         "305pwzlr"             => 18616,
                         "30624700"             => 23724,
                         "308win"               => 23700,
                         "31011987"             => 4646,
                         "31021364"             => 28226,
                         "311420"               => 27320,
                         "311music"             => 20137,
                         "31217221027711"       => 15599,
                         "312mas"               => 28127,
                         "313233"               => 14482,
                         "31359092"             => 28176,
                         "314159"               => 935,
                         "3141592"              => 7162,
                         "31415926"             => 925,
                         "314159265"            => 11989,
                         "3141592654"           => 13288,
                         "31415927"             => 23581,
                         "3151020"              => 8190,
                         "315475"               => 352,
                         "315920"               => 9489,
                         "316271"               => 25361,
                         "316497"               => 21309,
                         "316769"               => 19725,
                         "321123"               => 2157,
                         "321456"               => 2303,
                         "321456987"            => 11978,
                         "321654"               => 1029,
                         "32165498"             => 9185,
                         "321654987"            => 2085,
                         "32167"                => 5620,
                         "3216732167"           => 9090,
                         "321678"               => 5723,
                         "321cba"               => 20953,
                         "321ewq"               => 12616,
                         "321ret32"             => 23373,
                         "322223"               => 9497,
                         "3234412"              => 9832,
                         "3247562"              => 19370,
                         "326159487"            => 10603,
                         "32615948worms"        => 19344,
                         "3263827"              => 9835,
                         "326598"               => 13004,
                         "331234"               => 14488,
                         "332211"               => 2326,
                         "332233"               => 18728,
                         "333000"               => 22235,
                         "333221"               => 9352,
                         "333222"               => 9838,
                         "333222111"            => 16499,
                         "33334444"             => 20719,
                         "333444"               => 4989,
                         "3334444"              => 18460,
                         "333555"               => 6128,
                         "333666"               => 2679,
                         "333666999"            => 9444,
                         "333777"               => 4040,
                         "333888"               => 11838,
                         "333999"               => 7193,
                         "333z333"              => 15389,
                         "334433"               => 22232,
                         "334455"               => 5957,
                         "335533"               => 10759,
                         "335533aa"             => 13279,
                         "335577"               => 8129,
                         "3364068"              => 15485,
                         "336633"               => 22230,
                         "336699"               => 2752,
                         "337733"               => 22229,
                         "339311"               => 18725,
                         "33ds5x"               => 16788,
                         "33rjhjds"             => 9252,
                         "33st33"               => 21985,
                         "342500"               => 27363,
                         "343104ky"             => 15689,
                         "3440172"              => 23271,
                         "34523452"             => 8984,
                         "34524815"             => 15662,
                         "345543"               => 18718,
                         "3465xxx"              => 9169,
                         "34778"                => 20580,
                         "34erdfcv"             => 27288,
                         "357159"               => 4868,
                         "357753"               => 8124,
                         "3578951"              => 21171,
                         "357951"               => 5122,
                         "357mag"               => 8731,
                         "358hkyp"              => 24833,
                         "3611jcmg"             => 23713,
                         "36169544"             => 29244,
                         "362436"               => 1994,
                         "362514"               => 8295,
                         "3630000"              => 21170,
                         "36363"                => 21944,
                         "36460341"             => 16981,
                         "365214"               => 25379,
                         "3657549"              => 21169,
                         "368ejhih"             => 13335,
                         "369147"               => 17168,
                         "369258"               => 3819,
                         "36925814"             => 23549,
                         "369258147"            => 5560,
                         "36936"                => 19128,
                         "369741"               => 23615,
                         "369852"               => 3857,
                         "36985214"             => 28159,
                         "369852147"            => 8416,
                         "3698741"              => 7678,
                         "36987412"             => 17840,
                         "369874125"            => 22076,
                         "369963"               => 3235,
                         "375125"               => 17991,
                         "37583867"             => 23544,
                         "37kazoo"              => 27136,
                         "380zliki"             => 10943,
                         "3816778"              => 25604,
                         "382436"               => 23614,
                         "382563"               => 25385,
                         "383pdjvl"             => 11780,
                         "3891576"              => 18459,
                         "38972091"             => 16448,
                         "38gjgeuftd"           => 20334,
                         "392781"               => 18705,
                         "3984240"              => 7674,
                         "3a5irt"               => 17360,
                         "3bears"               => 28279,
                         "3cudjz"               => 12090,
                         "3e2w1q"               => 9666,
                         "3e4r5t"               => 22270,
                         "3edc4rfv"             => 7326,
                         "3edcvfr4"             => 10371,
                         "3f3fpht7op"           => 21978,
                         "3girls"               => 11111,
                         "3ip76k2"              => 5802,
                         "3ki42x"               => 13035,
                         "3mpz4r"               => 13136,
                         "3mta3"                => 14152,
                         "3qvqod"               => 13785,
                         "3rjs1la7qe"           => 6794,
                         "3some"                => 10873,
                         "3stooges"             => 11412,
                         "3syqo15hil"           => 13681,
                         "3techsrl"             => 20896,
                         "3tmnej"               => 17870,
                         "3x7pxr"               => 4562,
                         "3xbobobo"             => 17377,
                         "40028922"             => 16450,
                         "4034407"              => 21167,
                         "405060"               => 19809,
                         "4071505"              => 14402,
                         "4077mash"             => 25094,
                         "4121"                 => 2735,
                         "4128"                 => 1259,
                         "413276191q"           => 24846,
                         "414243"               => 25387,
                         "415263"               => 4601,
                         "41d8cd98f00b"         => 20111,
                         "4200"                 => 4707,
                         "420000"               => 4337,
                         "420247"               => 2350,
                         "420420"               => 496,
                         "42042042"             => 13560,
                         "420666"               => 27442,
                         "4206969"              => 23265,
                         "420smoke"             => 28067,
                         "424365"               => 23596,
                         "426hemi"              => 3642,
                         "427900"               => 8997,
                         "427cobra"             => 15666,
                         "428054"               => 22200,
                         "4294967296"           => 21938,
                         "42qwerty42"           => 18603,
                         "43046721"             => 7948,
                         "430799"               => 14462,
                         "4311111q"             => 19541,
                         "43211234"             => 11843,
                         "4321rewq"             => 16681,
                         "441232"               => 25397,
                         "4417"                 => 3734,
                         "442200"               => 22196,
                         "442244"               => 18685,
                         "443322"               => 21280,
                         "44332211"             => 5766,
                         "444000"               => 22192,
                         "444111"               => 27514,
                         "444222"               => 14457,
                         "444333"               => 18683,
                         "44445555"             => 11223,
                         "44448888"             => 19610,
                         "444555"               => 6411,
                         "444555666"            => 17895,
                         "444666"               => 18678,
                         "444777"               => 9903,
                         "444888"               => 25407,
                         "44556"                => 21930,
                         "445566"               => 1603,
                         "44556677"             => 23521,
                         "446655"               => 18677,
                         "44e3ebda"             => 27750,
                         "44mag"                => 25336,
                         "44magnum"             => 8936,
                         "4500455"              => 16187,
                         "4506802a"             => 14379,
                         "451236"               => 10519,
                         "452073t"              => 19393,
                         "45454"                => 15613,
                         "454dfmcq"             => 19130,
                         "455445"               => 21274,
                         "456123"               => 808,
                         "456123789"            => 13282,
                         "456123a"              => 21225,
                         "456258"               => 9291,
                         "456321"               => 2385,
                         "45645"                => 12133,
                         "45645645"             => 23518,
                         "456654"               => 1655,
                         "45678912"             => 29261,
                         "456789123"            => 13283,
                         "456838"               => 19892,
                         "456852"               => 1394,
                         "456987"               => 6103,
                         "456asd"               => 25471,
                         "456rty"               => 24534,
                         "45auto"               => 20104,
                         "45colt"               => 22919,
                         "45m2do5bs"            => 4267,
                         "4637324"              => 10962,
                         "46466452"             => 26392,
                         "464811"               => 19904,
                         "46775575"             => 20730,
                         "46and2"               => 27543,
                         "46doris"              => 22252,
                         "474jdvff"             => 18088,
                         "475869"               => 11241,
                         "477041"               => 22180,
                         "478jfszk"             => 25954,
                         "479373"               => 10525,
                         "47ds8x"               => 23484,
                         "4809594q"             => 18422,
                         "481516"               => 17214,
                         "48151623"             => 9384,
                         "481516234"            => 17147,
                         "4815162342"           => 322,
                         "4815162342a"          => 16246,
                         "4815162342lost"       => 13061,
                         "4815162342q"          => 25315,
                         "483422"               => 25418,
                         "48n25rcc"             => 27715,
                         "4904s677075"          => 11126,
                         "492529"               => 15354,
                         "493949"               => 23558,
                         "49527843"             => 13475,
                         "495rus19"             => 14860,
                         "49ers"                => 6030,
                         "49ers1"               => 21128,
                         "4_life"               => 15039,
                         "4cancel"              => 23421,
                         "4cranker"             => 17858,
                         "4dwvjj"               => 15667,
                         "4ebouux8"             => 24493,
                         "4ever"                => 4753,
                         "4fa82hyx"             => 22131,
                         "4free"                => 10969,
                         "4freedom"             => 18964,
                         "4g3izhox"             => 20059,
                         "4gxrzemq"             => 20083,
                         "4iter"                => 21782,
                         "4jjcho"               => 22496,
                         "4life"                => 11470,
                         "4me2know"             => 22587,
                         "4me2no"               => 19257,
                         "4meonly"              => 13038,
                         "4mnveh"               => 18981,
                         "4money"               => 13207,
                         "4ng62t"               => 18414,
                         "4nick8"               => 28739,
                         "4play"                => 18436,
                         "4pussy"               => 17017,
                         "4r3e2w1q"             => 10266,
                         "4r5t6y"               => 11936,
                         "4real"                => 23738,
                         "4rfv3edc"             => 8652,
                         "4rfv5tgb"             => 11003,
                         "4rkpkt"               => 13317,
                         "4runner"              => 2050,
                         "4rzp8ab7"             => 25342,
                         "4seasons"             => 26982,
                         "4snz9g"               => 10538,
                         "4speed"               => 27745,
                         "4tlved"               => 15615,
                         "4wcqjn"               => 14278,
                         "4wheel"               => 11672,
                         "4wwvte"               => 12861,
                         "4x7wjr"               => 19786,
                         "4you"                 => 6164,
                         "4z34l0ts"             => 13188,
                         "4z3al0ts"             => 14392,
                         "4zqauf"               => 13036,
                         "5000"                 => 5990,
                         "50000"                => 26626,
                         "500000"               => 9641,
                         "500600"               => 27593,
                         "50cent"               => 2247,
                         "50spanks"             => 3427,
                         "51051051051"          => 11902,
                         "51094didi"            => 21168,
                         "511647"               => 27597,
                         "5150"                 => 308,
                         "515000"               => 5480,
                         "51501984"             => 29269,
                         "51502112"             => 26389,
                         "515051"               => 6740,
                         "515069"               => 23546,
                         "5150vh"               => 29670,
                         "515253"               => 9146,
                         "51525354"             => 23497,
                         "51842543"             => 16455,
                         "5201314"              => 5260,
                         "524645"               => 10283,
                         "52545856"             => 23492,
                         "526282"               => 21265,
                         "526452"               => 17242,
                         "52678677"             => 14912,
                         "527952"               => 23540,
                         "531879fiz"            => 21730,
                         "5329"                 => 5215,
                         "5411pimo"             => 23616,
                         "541233432442"         => 11066,
                         "54132442"             => 13270,
                         "543211"               => 27647,
                         "5432112345"           => 20113,
                         "543216"               => 14499,
                         "54321a"               => 15546,
                         "54343"                => 26628,
                         "54354"                => 26629,
                         "545645"               => 25437,
                         "545ettvy"             => 17208,
                         "54gv768"              => 29985,
                         "551scasi"             => 13975,
                         "552255"               => 27679,
                         "552861"               => 27682,
                         "55378008"             => 28110,
                         "554433"               => 17256,
                         "55443322"             => 29278,
                         "5544332211"           => 21616,
                         "554455"               => 10555,
                         "55495746"             => 26379,
                         "554uzpad"             => 13705,
                         "555000"               => 9533,
                         "5550123"              => 12881,
                         "5550666"              => 10319,
                         "555111"               => 11804,
                         "5551212"              => 2916,
                         "555123"               => 21261,
                         "5551298"              => 21951,
                         "555222"               => 7635,
                         "5552555"              => 16185,
                         "555333"               => 8078,
                         "555444"               => 10289,
                         "555551"               => 16225,
                         "555555a"              => 10830,
                         "555555d"              => 24108,
                         "555556"               => 9537,
                         "55555a"               => 10931,
                         "55555d"               => 22609,
                         "55555n"               => 16764,
                         "55555q"               => 14492,
                         "55555r"               => 27757,
                         "55556666"             => 12752,
                         "5556633"              => 25609,
                         "555666"               => 1218,
                         "555666777"            => 13547,
                         "555777"               => 2602,
                         "555888"               => 10586,
                         "555999"               => 14447,
                         "555aaa"               => 29473,
                         "556644"               => 23522,
                         "556655"               => 18034,
                         "556677"               => 5223,
                         "55667788"             => 14925,
                         "556699"               => 18655,
                         "557711"               => 14446,
                         "557744"               => 11798,
                         "557799"               => 18653,
                         "55832811"             => 12110,
                         "55bgates"             => 6220,
                         "55chevy"              => 8952,
                         "5641110"              => 10173,
                         "56565"                => 20571,
                         "565hlgqo"             => 14951,
                         "567765"               => 10942,
                         "5678ytr"              => 25924,
                         "567rntvm"             => 19977,
                         "5681392"              => 19402,
                         "56836803"             => 28103,
                         "56qhxs"               => 12817,
                         "57392632"             => 20739,
                         "57699434"             => 26374,
                         "5782790"              => 18208,
                         "5792076"              => 23255,
                         "579300"               => 21258,
                         "57chevy"              => 4773,
                         "57np39"               => 13339,
                         "58565254"             => 23460,
                         "59382113kevinp"       => 26429,
                         "5alive"               => 25806,
                         "5c92v5h6"             => 24479,
                         "5element"             => 27165,
                         "5gtgiaxm"             => 28245,
                         "5hsu75kpot"           => 8782,
                         "5lyedn"               => 16843,
                         "5nizza"               => 26363,
                         "5qnzjx"               => 17845,
                         "5rxypn"               => 12762,
                         "5speed"               => 25154,
                         "5string"              => 23202,
                         "5t4r3e2w1q"           => 15940,
                         "5t6y7u"               => 20364,
                         "5t6y7u8i"             => 15555,
                         "5tgb6yhn"             => 8628,
                         "5tgbnhy6"             => 21436,
                         "5thgbqi"              => 23461,
                         "5w76rnqp"             => 22102,
                         "5wr2i7h8"             => 5444,
                         "600000"               => 18649,
                         "6031769"              => 18445,
                         "6043dkf"              => 27982,
                         "6060842"              => 21947,
                         "615243"               => 7465,
                         "616879"               => 18647,
                         "616913"               => 14444,
                         "61808861"             => 26373,
                         "622521"               => 8552,
                         "625vrobg"             => 18063,
                         "62717315"             => 13804,
                         "6339cndh"             => 19827,
                         "6345789"              => 19412,
                         "635241"               => 4354,
                         "640xwfkv"             => 15279,
                         "645202"               => 27730,
                         "6458zn7a"             => 17985,
                         "64chevy"              => 25364,
                         "651550"               => 7049,
                         "654123"               => 3173,
                         "654321"               => 27,
                         "654321a"              => 8618,
                         "654321q"              => 9196,
                         "654321z"              => 26118,
                         "654456"               => 12367,
                         "654987"               => 13164,
                         "655321"               => 3661,
                         "65mustan"             => 24694,
                         "65pjv22"              => 22244,
                         "66005918"             => 23447,
                         "665259"               => 23489,
                         "665544"               => 7805,
                         "665566"               => 25462,
                         "666000"               => 16216,
                         "666111"               => 14437,
                         "6661313"              => 7083,
                         "66613666"             => 5774,
                         "666222"               => 23483,
                         "666333"               => 7052,
                         "666420"               => 21251,
                         "666425"               => 18052,
                         "666444"               => 25468,
                         "666555"               => 7440,
                         "666666"               => 21,
                         "6666667"              => 18443,
                         "666666a"              => 8221,
                         "666666q"              => 14289,
                         "66669999"             => 17866,
                         "666777"               => 1871,
                         "666888"               => 15390,
                         "66699"                => 20100,
                         "666999"               => 832,
                         "666999666"            => 18826,
                         "666satan"             => 21205,
                         "667766"               => 21249,
                         "667788"               => 13178,
                         "669966"               => 13412,
                         "669e53e1"             => 18271,
                         "66chevy"              => 22289,
                         "671fsa75yt"           => 28777,
                         "67390436"             => 23438,
                         "6751520"              => 1635,
                         "678910"               => 20021,
                         "67899876"             => 29287,
                         "67camaro"             => 8491,
                         "67mustan"             => 24470,
                         "67stang"              => 24500,
                         "67vette"              => 19046,
                         "6820055"              => 18442,
                         "682regkh"             => 20231,
                         "6846kg3r"             => 26122,
                         "686xqxfg"             => 14836,
                         "687887"               => 25473,
                         "68camaro"             => 9705,
                         "68stang"              => 24499,
                         "69213124"             => 8549,
                         "6942987"              => 28330,
                         "6969"                 => 75,
                         "69696"                => 3739,
                         "696969"               => 19,
                         "6969696"              => 23246,
                         "697769"               => 18629,
                         "699669"               => 8195,
                         "69a20a"               => 12349,
                         "69camaro"             => 5475,
                         "69dude"               => 15601,
                         "69pussy"              => 27851,
                         "6bjvpe"               => 14287,
                         "6chid8"               => 12895,
                         "6gcf636i"             => 25009,
                         "6jhwmqku"             => 19669,
                         "6string"              => 11959,
                         "6uldv8"               => 6788,
                         "6xe8j2z4"             => 19131,
                         "6yhn7ujm"             => 27223,
                         "700007"               => 18626,
                         "7007"                 => 3754,
                         "703751"               => 18625,
                         "705499fh"             => 21714,
                         "708090"               => 18624,
                         "708090a"              => 13964,
                         "7085506"              => 25610,
                         "709394"               => 22112,
                         "7224763"              => 19421,
                         "72chevy"              => 24019,
                         "72d5tn"               => 16421,
                         "73501505"             => 2025,
                         "7355608"              => 16819,
                         "74108520"             => 4229,
                         "741147"               => 20085,
                         "741236"               => 10631,
                         "7412369"              => 6235,
                         "74123698"             => 6969,
                         "741236985"            => 15586,
                         "741258"               => 6544,
                         "741258963"            => 6289,
                         "7415963"              => 9859,
                         "74185"                => 15604,
                         "741852"               => 804,
                         "74185296"             => 9162,
                         "741852963"            => 687,
                         "7418529630"           => 20915,
                         "741852kk"             => 17733,
                         "741963"               => 4874,
                         "74227422"             => 7883,
                         "742617000027"         => 19399,
                         "744744z"              => 19574,
                         "7452tr"               => 20848,
                         "747200"               => 25484,
                         "747400"               => 8572,
                         "747bbb"               => 17395,
                         "748159263"            => 10263,
                         "748596"               => 6977,
                         "7506751"              => 25613,
                         "753159"               => 1676,
                         "753357"               => 7614,
                         "75395"                => 13986,
                         "753951"               => 866,
                         "753951456"            => 23302,
                         "753951852"            => 19545,
                         "754321"               => 22092,
                         "754740g0"             => 22989,
                         "7550055"              => 12889,
                         "7555545"              => 10188,
                         "7558795"              => 16181,
                         "755dfx"               => 18165,
                         "7653ajl1"             => 19123,
                         "7654321a"             => 26821,
                         "76689295"             => 28082,
                         "766rglqy"             => 17118,
                         "770129ji"             => 27391,
                         "774411"               => 13234,
                         "7753191"              => 2440,
                         "775533"               => 13392,
                         "775577"               => 20118,
                         "777000"               => 8176,
                         "777111"               => 8061,
                         "777123"               => 27893,
                         "777222"               => 23437,
                         "777333"               => 5590,
                         "777444"               => 9949,
                         "777555"               => 6710,
                         "777555333"            => 26337,
                         "777666"               => 6021,
                         "777771"               => 20136,
                         "7777755102q"          => 15257,
                         "7777777"              => 29,
                         "77777778"             => 14930,
                         "7777777a"             => 5496,
                         "7777777s"             => 25707,
                         "7777777z"             => 25374,
                         "777777a"              => 18741,
                         "77778888"             => 17057,
                         "777888"               => 2675,
                         "777888999"            => 10113,
                         "7779311"              => 2995,
                         "777999"               => 5513,
                         "777angel"             => 14081,
                         "777vlad"              => 8449,
                         "777win"               => 18170,
                         "77879"                => 28746,
                         "778811"               => 18086,
                         "778899"               => 2578,
                         "779977"               => 21233,
                         "784512"               => 2887,
                         "785001"               => 23432,
                         "785612"               => 21232,
                         "786110"               => 22083,
                         "78621323"             => 23420,
                         "78678"                => 13989,
                         "78787"                => 19157,
                         "787898"               => 2913,
                         "78791"                => 28926,
                         "789056"               => 25497,
                         "789123"               => 2094,
                         "789123456"            => 10568,
                         "789321"               => 11090,
                         "78945"                => 4008,
                         "789456"               => 256,
                         "7894561"              => 18432,
                         "78945612"             => 2266,
                         "789456123"            => 382,
                         "7894561230"           => 4136,
                         "789456123a"           => 26371,
                         "7895123"              => 1235,
                         "789520"               => 13382,
                         "789551"               => 22082,
                         "7896321"              => 4953,
                         "78963214"             => 8539,
                         "789632145"            => 6476,
                         "789632147"            => 22090,
                         "789654"               => 1853,
                         "789654123"            => 5657,
                         "78978"                => 23147,
                         "78978978"             => 29292,
                         "789852"               => 9563,
                         "789963"               => 23422,
                         "789987"               => 2400,
                         "789qwe"               => 28154,
                         "78girl"               => 12091,
                         "78n3s5af"             => 13294,
                         "794613"               => 3162,
                         "794613258"            => 28022,
                         "794613852"            => 15575,
                         "7bgiqk"               => 12433,
                         "7elephants"           => 21240,
                         "7eleven"              => 22868,
                         "7ertu3ds"             => 19781,
                         "7f4df451"             => 18092,
                         "7f8srt"               => 20408,
                         "7gorwell"             => 19482,
                         "7grout"               => 6551,
                         "7hrdnw23"             => 9480,
                         "7imjfstw"             => 25959,
                         "7inches"              => 21497,
                         "7jokx7b9du"           => 21784,
                         "7kbe9d"               => 15123,
                         "7mary3"               => 26605,
                         "7ofnine"              => 21379,
                         "7ovtgimc"             => 17028,
                         "7pvn4t"               => 17999,
                         "7seven"               => 17155,
                         "7seven7"              => 24051,
                         "7u8i9o0p"             => 18862,
                         "7uftyx"               => 10903,
                         "7ugd5hip2j"           => 3274,
                         "7xm5rq"               => 16112,
                         "7xswzaq"              => 17505,
                         "800500"               => 22077,
                         "80070633pc"           => 14700,
                         "80637852730"          => 20902,
                         "808state"             => 13631,
                         "8096468644q"          => 27384,
                         "80988218126"          => 21860,
                         "811pahc"              => 13370,
                         "81726354"             => 17061,
                         "81fukkc"              => 4150,
                         "823762"               => 8156,
                         "824358553"            => 28021,
                         "824655"               => 20180,
                         "826248s"              => 29986,
                         "8318131"              => 16179,
                         "8363eddy"             => 22651,
                         "837519"               => 7758,
                         "83y6pv"               => 17851,
                         "8481068"              => 23240,
                         "85200258"             => 22019,
                         "8520456"              => 28340,
                         "852123"               => 13300,
                         "852147"               => 12375,
                         "852258"               => 6604,
                         "852456"               => 643,
                         "852654"               => 10672,
                         "852741"               => 12780,
                         "852963"               => 8597,
                         "8538622"              => 28350,
                         "8543852"              => 16838,
                         "8546404"              => 21934,
                         "85852008"             => 20747,
                         "85bears"              => 25922,
                         "863abgsg"             => 14304,
                         "867530"               => 20198,
                         "8675309"              => 215,
                         "86753099"             => 17066,
                         "86chevyx"             => 24954,
                         "86mets"               => 15493,
                         "87062134"             => 26356,
                         "870621345"            => 23290,
                         "875421"               => 5086,
                         "87654321q"            => 25500,
                         "878kckxy"             => 19808,
                         "87e5nclizry"          => 23266,
                         "87t5hdf"              => 13417,
                         "88002000600"          => 17678,
                         "8807031"              => 28354,
                         "880888"               => 25508,
                         "88351132"             => 17069,
                         "885522"               => 8424,
                         "887766"               => 25510,
                         "888111"               => 18556,
                         "888555"               => 21217,
                         "888777"               => 23396,
                         "88887777"             => 29300,
                         "888889"               => 27990,
                         "88889999"             => 17070,
                         "888999"               => 5639,
                         "889900"               => 18548,
                         "889988"               => 13366,
                         "88keys"               => 13336,
                         "88mike"               => 28554,
                         "890098890"            => 7692,
                         "89015173454"          => 10740,
                         "8902792"              => 19457,
                         "89032073168"          => 26952,
                         "89172735872"          => 17093,
                         "89211375759"          => 17994,
                         "89231243658s"         => 12748,
                         "8928190a"             => 20926,
                         "895623"               => 6701,
                         "89600506779"          => 9909,
                         "89876065093rax"       => 23553,
                         "8ball"                => 9557,
                         "8balls"               => 10114,
                         "8dihc6"               => 11521,
                         "8i9o0p"               => 22431,
                         "8inches"              => 6074,
                         "8j4ye3uz"             => 1732,
                         "8letters"             => 16535,
                         "8phrowz622"           => 8742,
                         "8phrowz624"           => 9153,
                         "8seconds"             => 27050,
                         "8uiazp"               => 16870,
                         "8vfhnf"               => 24731,
                         "8vjzus"               => 21409,
                         "8womys"               => 15072,
                         "8xuuobe4"             => 21306,
                         "900000"               => 13364,
                         "90210"                => 2784,
                         "902100"               => 6437,
                         "906090"               => 1806,
                         "908070"               => 20262,
                         "9085084232"           => 27772,
                         "9085603566"           => 27218,
                         "9111961"              => 6651,
                         "911911"               => 1194,
                         "911turbo"             => 6957,
                         "9124852"              => 25622,
                         "91328378"             => 29301,
                         "918273"               => 6204,
                         "918273645"            => 6599,
                         "926337"               => 21214,
                         "92702689"             => 19568,
                         "9293709b13"           => 3419,
                         "9379992"              => 639,
                         "9379992a"             => 17224,
                         "9379992q"             => 24666,
                         "93pn75"               => 20009,
                         "944turbo"             => 22809,
                         "94rwpe"               => 20114,
                         "951159"               => 10682,
                         "951357"               => 5735,
                         "95175"                => 13487,
                         "951753"               => 1113,
                         "951753852"            => 18822,
                         "9556035"              => 25626,
                         "9562876"              => 3484,
                         "963147"               => 22034,
                         "9632147"              => 16859,
                         "96321478"             => 15219,
                         "963214785"            => 18821,
                         "963258"               => 6054,
                         "963258741"            => 7182,
                         "96328i"               => 29745,
                         "963369"               => 9371,
                         "963741"               => 10814,
                         "963852"               => 1905,
                         "96385274"             => 10644,
                         "963852741"            => 2301,
                         "9638527410"           => 24158,
                         "9638v"                => 12883,
                         "968574"               => 10687,
                         "96ford"               => 29633,
                         "975310"               => 18537,
                         "976431"               => 10823,
                         "9788960"              => 12906,
                         "9811020"              => 23221,
                         "98256518"             => 29304,
                         "986532"               => 6635,
                         "987123"               => 4129,
                         "987321"               => 4474,
                         "9874123"              => 7087,
                         "98741236"             => 15204,
                         "987412365"            => 10261,
                         "987456"               => 1634,
                         "98745632"             => 12277,
                         "987456321"            => 3335,
                         "9875321"              => 28388,
                         "987654123"            => 28016,
                         "987654321a"           => 6700,
                         "987654321g"           => 29048,
                         "987654321q"           => 8269,
                         "987654321z"           => 18764,
                         "98766789"             => 26353,
                         "987789"               => 7419,
                         "98798798"             => 20749,
                         "989244342a"           => 13880,
                         "98xa29"               => 24919,
                         "9933162"              => 28394,
                         "995511"               => 20314,
                         "996633"               => 5219,
                         "996699"               => 14537,
                         "99762000"             => 6553,
                         "998877"               => 3682,
                         "99887766"             => 12239,
                         "9988776655"           => 26527,
                         "998899"               => 16655,
                         "9988aa"               => 14793,
                         "999000"               => 6532,
                         "999111"               => 8443,
                         "999111999q"           => 13126,
                         "999333"               => 12119,
                         "99941"                => 15903,
                         "999666"               => 4765,
                         "999666333"            => 26334,
                         "999777"               => 8804,
                         "999888"               => 6452,
                         "999888777"            => 18818,
                         "999998"               => 16661,
                         "99ford"               => 23383,
                         "99ranger"             => 29134,
                         "99strenght"           => 29922,
                         "9ball"                => 24185,
                         "9hmlpyjd"             => 25957,
                         "9hotpoin"             => 27414,
                         "9inches"              => 12201,
                         "9kyq6fge"             => 19355,
                         "9lives"               => 22360,
                         "9noize9"              => 22501,
                         "9skw5g"               => 14914,
                         "9z5ve9rrcz"           => 26267,
                         "[start]"              => 11815,
                         "a000000"              => 21243,
                         "a11111"               => 3224,
                         "a111111"              => 6904,
                         "a112233"              => 24829,
                         "a121212"              => 20176,
                         "a123123"              => 10846,
                         "a123321"              => 10039,
                         "a1234"                => 5084,
                         "a12345"               => 493,
                         "a123456"              => 485,
                         "a1234567"             => 1158,
                         "a12345678"            => 3338,
                         "a123456789"           => 2363,
                         "a1234567890"          => 18029,
                         "a123456a"             => 7535,
                         "a123456b"             => 24719,
                         "a123456z"             => 20463,
                         "a12345a"              => 11014,
                         "a1234a"               => 25759,
                         "a1234b"               => 19870,
                         "a123654"              => 25326,
                         "a131313"              => 18425,
                         "a13579"               => 29668,
                         "a159357"              => 24844,
                         "a159753"              => 23597,
                         "a19l1980"             => 17436,
                         "a1a2a3"               => 3706,
                         "a1a2a3a4"             => 6458,
                         "a1a2a3a4a5"           => 8710,
                         "a1b1c1"               => 24531,
                         "a1b2c"                => 15874,
                         "a1b2c3"               => 674,
                         "a1b2c3d"              => 24410,
                         "a1b2c3d4"             => 714,
                         "a1b2c3d4e5"           => 6685,
                         "a1l2e3x4"             => 16649,
                         "a1s2d3"               => 2741,
                         "a1s2d3f"              => 28313,
                         "a1s2d3f4"             => 1666,
                         "a1s2d3f4g5"           => 6784,
                         "a1s2d3f4g5h6"         => 28697,
                         "a22222"               => 27153,
                         "a23456"               => 23139,
                         "a32tv8ls"             => 20072,
                         "a333444"              => 25340,
                         "a3eilm2s2y"           => 21687,
                         "a3jtni"               => 21533,
                         "a4tech"               => 6909,
                         "a54321"               => 19639,
                         "a55555"               => 13091,
                         "a654321"              => 15241,
                         "a666666"              => 22147,
                         "a6pihd"               => 25680,
                         "a7777777"             => 11658,
                         "a7nz8546"             => 22197,
                         "a801016"              => 19040,
                         "a8kd47v5"             => 26317,
                         "a9387670a"            => 17353,
                         "a987654321"           => 13021,
                         "aa1111aa"             => 18841,
                         "aa123123"             => 21025,
                         "aa123321"             => 14709,
                         "aa1234"               => 10937,
                         "aa12345"              => 14738,
                         "aa123456"             => 3113,
                         "aa123456789"          => 27313,
                         "aaa111"               => 1748,
                         "aaa12"                => 21693,
                         "aaa123"               => 6386,
                         "aaa12345"             => 19298,
                         "aaa123456"            => 25716,
                         "aaa123a"              => 20150,
                         "aaa340"               => 11156,
                         "aaa555"               => 17865,
                         "aaa666"               => 28370,
                         "aaa777"               => 17677,
                         "aaaa1"                => 20219,
                         "aaaa1111"             => 6135,
                         "aaaa1122"             => 27666,
                         "aaaaa1"               => 4372,
                         "aaaaaa1"              => 6921,
                         "aaaaaaa1"             => 9429,
                         "aaaaaas"              => 15533,
                         "aaaabbbb"             => 19294,
                         "aaaassss"             => 27585,
                         "aaabbb"               => 6450,
                         "aaasss"               => 4997,
                         "aaazzz"               => 25325,
                         "aabbcc"               => 7330,
                         "aabbccdd"             => 15283,
                         "aalborg"              => 12525,
                         "aaliyah"              => 2614,
                         "aamaax"               => 21299,
                         "aardvark"             => 982,
                         "aaron1"               => 3319,
                         "aaron12"              => 24007,
                         "aaron123"             => 13902,
                         "aaronb"               => 19859,
                         "aassaa"               => 25723,
                         "aassdd"               => 7234,
                         "aassddff"             => 11606,
                         "ab1234"               => 7710,
                         "ab12345"              => 26908,
                         "ab123456"             => 14273,
                         "ab12cd34"             => 22207,
                         "ab55484"              => 24639,
                         "abacab"               => 5618,
                         "abacabb"              => 21176,
                         "abacus"               => 6268,
                         "abaddon"              => 17007,
                         "abagail"              => 26942,
                         "abarth"               => 16089,
                         "abbey1"               => 7585,
                         "abby12"               => 29867,
                         "abby123"              => 24296,
                         "abbydog"              => 23306,
                         "abc12"                => 1686,
                         "abc123"               => 13,
                         "abc1234"              => 2771,
                         "abc12345"             => 2201,
                         "abc123456"            => 6165,
                         "abc123456789"         => 19087,
                         "abc123a"              => 26645,
                         "abc123abc"            => 14847,
                         "abc125"               => 21156,
                         "abc321"               => 10205,
                         "abc456"               => 16392,
                         "abcd1"                => 26725,
                         "abcd12"               => 14755,
                         "abcd123"              => 2832,
                         "abcd1234"             => 221,
                         "abcd12345"            => 18501,
                         "abcde1"               => 18163,
                         "abcde123"             => 13345,
                         "abcde12345"           => 17455,
                         "abcdef1"              => 11235,
                         "abcdef12"             => 24064,
                         "abcdef123"            => 13619,
                         "abcdefg1"             => 5654,
                         "abcxyz"               => 8127,
                         "abdula"               => 19054,
                         "abdulla"              => 9298,
                         "abeille"              => 28669,
                         "abercrom"             => 15722,
                         "aberdeen"             => 1889,
                         "abfkrf"               => 13275,
                         "abgrtyu"              => 1224,
                         "abhishek"             => 19241,
                         "abigai"               => 17723,
                         "abigail1"             => 9490,
                         "abigale"              => 23913,
                         "abiodun"              => 27968,
                         "abkbgg"               => 25323,
                         "abkbvjy"              => 18303,
                         "abm1224"              => 22556,
                         "abnormal"             => 3602,
                         "abpbrf"               => 12264,
                         "abracada"             => 11940,
                         "abracadabra"          => 5870,
                         "abrakadabra"          => 3905,
                         "abramov"              => 18908,
                         "abramova"             => 17810,
                         "abraxas"              => 6517,
                         "abrupt"               => 8664,
                         "absinthe"             => 21208,
                         "absolut"              => 2467,
                         "abstr"                => 3828,
                         "abudfv"               => 8969,
                         "abulafia"             => 11026,
                         "ac2zxdty"             => 21253,
                         "acacia"               => 8704,
                         "acadia"               => 16395,
                         "acapulco"             => 5897,
                         "acces"                => 14571,
                         "access"               => 78,
                         "access01"             => 29568,
                         "access1"              => 6196,
                         "access12"             => 12281,
                         "access123"            => 18820,
                         "access14"             => 1118,
                         "access2"              => 9784,
                         "access20"             => 15370,
                         "access22"             => 21554,
                         "access88"             => 25503,
                         "access99"             => 6861,
                         "accessno"             => 12226,
                         "accobra"              => 25373,
                         "accord"               => 593,
                         "accord1"              => 17126,
                         "account1"             => 8115,
                         "accountbloc"          => 24556,
                         "acdeehan"             => 21137,
                         "ace1062"              => 23566,
                         "ace111"               => 27013,
                         "ace1210"              => 17927,
                         "ace123"               => 8458,
                         "acehigh"              => 25486,
                         "aceman"               => 7416,
                         "acer12"               => 25253,
                         "acer123"              => 17381,
                         "acerview"             => 12958,
                         "aceshigh"             => 12109,
                         "acess"                => 29617,
                         "acetate"              => 8362,
                         "acheron"              => 26211,
                         "achille"              => 17046,
                         "achilles"             => 1805,
                         "achim"                => 26075,
                         "achmed"               => 19572,
                         "achtung"              => 4177,
                         "acidburn"             => 5383,
                         "acidrain"             => 12774,
                         "ackbar"               => 27025,
                         "acls2h"               => 13915,
                         "acme34"               => 23504,
                         "acmilan"              => 4632,
                         "acmilan1"             => 19871,
                         "acorns"               => 20825,
                         "acrobat"              => 11967,
                         "action"               => 456,
                         "action1"              => 18648,
                         "actros"               => 20969,
                         "acuari"               => 16467,
                         "acuario"              => 22507,
                         "acun3t1x"             => 12567,
                         "acura"                => 4792,
                         "acura1"               => 8406,
                         "acuracl"              => 26970,
                         "acuransx"             => 17461,
                         "acurarsx"             => 20636,
                         "adagio"               => 11027,
                         "adam01"               => 26677,
                         "adam1"                => 9333,
                         "adam12"               => 3052,
                         "adam123"              => 13488,
                         "adam1234"             => 18547,
                         "adam25"               => 9197,
                         "adamas"               => 25721,
                         "adams1"               => 10708,
                         "adaptec"              => 25451,
                         "adapters"             => 24854,
                         "adastra"              => 17621,
                         "addams"               => 13713,
                         "addpass"              => 27362,
                         "adebayo"              => 26791,
                         "adelante"             => 26799,
                         "adelheid"             => 25310,
                         "adelphia"             => 11080,
                         "adelya"               => 29991,
                         "adgjmp"               => 4574,
                         "adgjmpt"              => 13209,
                         "adgjmptw"             => 1047,
                         "adida"                => 11045,
                         "adidas"               => 185,
                         "adidas1"              => 6483,
                         "adidas11"             => 23949,
                         "adidas12"             => 22193,
                         "adidas69"             => 28073,
                         "adilbek"              => 23746,
                         "adilet"               => 19062,
                         "aditya"               => 12341,
                         "admin"                => 715,
                         "admin1"               => 5150,
                         "admin12"              => 29913,
                         "admin123"             => 7243,
                         "admin18533362"        => 9888,
                         "admin2"               => 15917,
                         "admira"               => 29878,
                         "admiral1"             => 14442,
                         "adnama"               => 20103,
                         "adonai"               => 9566,
                         "adonis"               => 2565,
                         "adonis1"              => 27976,
                         "adpass"               => 23938,
                         "adrenali"             => 11082,
                         "adrenalin"            => 5435,
                         "adrian1"              => 7747,
                         "adriana1"             => 14673,
                         "adrianna1"            => 26160,
                         "adriano"              => 5491,
                         "adrock"               => 7573,
                         "adroit"               => 28548,
                         "adult1"               => 12060,
                         "adv12775"             => 19492,
                         "advance1"             => 29762,
                         "advantag"             => 15899,
                         "advent"               => 4728,
                         "adventur"             => 7865,
                         "advokat"              => 18430,
                         "adxel187"             => 18434,
                         "aeiou"                => 13691,
                         "aeiouy"               => 19115,
                         "aekara"               => 23871,
                         "aekdb"                => 26494,
                         "aenima"               => 11065,
                         "aerdna"               => 25424,
                         "aerith"               => 23197,
                         "aerosmit"             => 6940,
                         "aerosmith"            => 7885,
                         "aerostar"             => 19225,
                         "aessedai"             => 25617,
                         "aeynbr"               => 9045,
                         "aezakmi"              => 1645,
                         "aezakmi1"             => 18253,
                         "afdjhbn"              => 16477,
                         "afhfjy"               => 19872,
                         "afhvfwtdn"            => 29654,
                         "afric"                => 17376,
                         "africa1"              => 11947,
                         "afrika"               => 5157,
                         "afrika2002"           => 27516,
                         "afrodita"             => 9272,
                         "afrodite"             => 26129,
                         "afroman"              => 27521,
                         "aftermat"             => 22839,
                         "ag764ks"              => 20342,
                         "agamemno"             => 17977,
                         "agape"                => 18998,
                         "agapov58"             => 24615,
                         "agassi"               => 6490,
                         "agate"                => 27426,
                         "agathe"               => 27619,
                         "agatka"               => 27569,
                         "agbdlcid"             => 16175,
                         "agent007"             => 1843,
                         "agent1"               => 18044,
                         "agent86"              => 24181,
                         "agent99"              => 18297,
                         "agentx"               => 20865,
                         "aggarwal"             => 23100,
                         "aggie"                => 7566,
                         "aggie1"               => 13783,
                         "aggies"               => 1678,
                         "agile1"               => 24402,
                         "agnes1"               => 24336,
                         "agnieszka"            => 9599,
                         "agricola"             => 20171,
                         "agshar"               => 24338,
                         "aguil"                => 27827,
                         "aguilas"              => 22361,
                         "agusta"               => 29932,
                         "agusti"               => 29433,
                         "agyvorc"              => 9509,
                         "ahfywbz"              => 15491,
                         "ahjkjd"               => 19470,
                         "ahjkjdf"              => 27589,
                         "ahmed1"               => 23150,
                         "aidan1"               => 23303,
                         "aidana"               => 12500,
                         "aiden"                => 29236,
                         "aiden1"               => 25556,
                         "aigerim"              => 28064,
                         "aikido"               => 2013,
                         "aikman"               => 4819,
                         "aikman08"             => 29239,
                         "aikman8"              => 29017,
                         "aileron"              => 19603,
                         "aimee1"               => 24176,
                         "airbag"               => 16061,
                         "airborn"              => 9711,
                         "airborn1"             => 27652,
                         "airborne"             => 315,
                         "airbrush"             => 25149,
                         "airbus"               => 2041,
                         "aircav"               => 21123,
                         "airedale"             => 13812,
                         "airforce"             => 799,
                         "airforce1"            => 10817,
                         "airjordan"            => 17207,
                         "airmail"              => 23667,
                         "airman"               => 5663,
                         "airmax"               => 16208,
                         "airplane"             => 718,
                         "airsoft"              => 19016,
                         "airwalk"              => 11049,
                         "airwolf"              => 3963,
                         "aisan"                => 6037,
                         "aishiteru"            => 23761,
                         "aishwarya"            => 29562,
                         "ajax"                 => 6119,
                         "ajax01"               => 24873,
                         "ajcuivd289"           => 15523,
                         "ajhneyf"              => 16243,
                         "ajnjuhfa"             => 22968,
                         "ajnjuhfabz"           => 19571,
                         "ajtdmw"               => 15527,
                         "ak1234"               => 10121,
                         "ak470000"             => 22971,
                         "akademia"             => 28435,
                         "akasha"               => 8037,
                         "akatsuki"             => 8966,
                         "akimov"               => 29040,
                         "akinfeev"             => 26178,
                         "akira"                => 3233,
                         "akira1"               => 14165,
                         "akitas"               => 22530,
                         "akmaral"              => 28563,
                         "aksana"               => 29330,
                         "aksarben"             => 18773,
                         "akshay"               => 23308,
                         "akuma"                => 25159,
                         "al123456"             => 26086,
                         "al1716"               => 26092,
                         "al1916"               => 28561,
                         "al1916w"              => 28587,
                         "al9agd"               => 10890,
                         "alabala"              => 18306,
                         "alabam"               => 22101,
                         "alabama"              => 702,
                         "alabama1"             => 7245,
                         "alabama123"           => 21301,
                         "alabaste"             => 25113,
                         "aladdin"              => 6434,
                         "aladin"               => 4001,
                         "alain"                => 5933,
                         "alakazam"             => 15814,
                         "alan1"                => 21256,
                         "alan12"               => 14142,
                         "alan123"              => 28937,
                         "alanfahy"             => 21824,
                         "alaric"               => 23164,
                         "alaska"               => 455,
                         "alaska1"              => 13744,
                         "alastair"             => 11304,
                         "alatam"               => 7409,
                         "albacore"             => 15114,
                         "albany"               => 3997,
                         "albator"              => 21973,
                         "albatro"              => 27258,
                         "albatros"             => 2135,
                         "albcaz"               => 18651,
                         "albert1"              => 8251,
                         "albert12"             => 25420,
                         "albertjr"             => 25225,
                         "alberto1"             => 14735,
                         "albion"               => 2249,
                         "albundy"              => 13690,
                         "alcapone"             => 17309,
                         "alcat"                => 10785,
                         "alcatel"              => 6371,
                         "alcatraz"             => 5661,
                         "alchemy"              => 5016,
                         "alcoholi"             => 26675,
                         "aldebara"             => 21412,
                         "aldebaran"            => 26166,
                         "alderaan"             => 20691,
                         "aldric"               => 14430,
                         "aldrin"               => 18965,
                         "alegna"               => 26635,
                         "alejandr"             => 1112,
                         "aleks"                => 15069,
                         "aleksa"               => 9459,
                         "aleksand"             => 16847,
                         "aleksander"           => 8584,
                         "aleksandr"            => 1091,
                         "aleksandra"           => 2713,
                         "alekseev"             => 20378,
                         "alekseeva"            => 20483,
                         "aleksei"              => 6277,
                         "aleksey"              => 2666,
                         "alemania"             => 15567,
                         "alemap"               => 21024,
                         "alena1"               => 26560,
                         "alena123"             => 29028,
                         "alena2010"            => 20450,
                         "alenka"               => 3109,
                         "alenushka"            => 17389,
                         "aleshka"              => 22946,
                         "alesis"               => 14928,
                         "alessand"             => 6543,
                         "alessandr"            => 15981,
                         "alessandro"           => 3936,
                         "alessia"              => 9125,
                         "alessio"              => 7414,
                         "alesya"               => 19325,
                         "alevtina"             => 15840,
                         "alex00"               => 16964,
                         "alex007"              => 20292,
                         "alex01"               => 7056,
                         "alex02"               => 19373,
                         "alex06"               => 29107,
                         "alex1"                => 6333,
                         "alex10"               => 20520,
                         "alex11"               => 9084,
                         "alex111"              => 27907,
                         "alex12"               => 5315,
                         "alex123"              => 3314,
                         "alex1234"             => 6217,
                         "alex12345"            => 20032,
                         "alex13"               => 11894,
                         "alex15"               => 26819,
                         "alex1959"             => 20028,
                         "alex1971"             => 26512,
                         "alex1973"             => 20393,
                         "alex1974"             => 26060,
                         "alex1975"             => 26646,
                         "alex1976"             => 27857,
                         "alex1981"             => 26612,
                         "alex1982"             => 27651,
                         "alex1983"             => 27641,
                         "alex1985"             => 24057,
                         "alex1987"             => 24130,
                         "alex1989"             => 28833,
                         "alex1990"             => 14994,
                         "alex1991"             => 20395,
                         "alex1995"             => 23576,
                         "alex1996"             => 14842,
                         "alex1998"             => 28640,
                         "alex2"                => 23496,
                         "alex2000"             => 13695,
                         "alex2009"             => 29123,
                         "alex2010"             => 20618,
                         "alex21"               => 17464,
                         "alex2112"             => 17177,
                         "alex22"               => 10450,
                         "alex23"               => 19010,
                         "alex24"               => 28411,
                         "alex32"               => 13179,
                         "alex69"               => 16857,
                         "alex74"               => 27896,
                         "alex77"               => 15773,
                         "alex777"              => 13246,
                         "alex86"               => 29599,
                         "alex88"               => 28474,
                         "alex95"               => 20385,
                         "alex97"               => 26481,
                         "alex99"               => 11716,
                         "alexa1"               => 17581,
                         "alexan"               => 10847,
                         "alexand"              => 17198,
                         "alexand1"             => 28398,
                         "alexande"             => 399,
                         "alexander1"           => 5503,
                         "alexandr"             => 571,
                         "alexandra1"           => 24218,
                         "alexandre"            => 4633,
                         "alexandru"            => 8793,
                         "alexei"               => 8337,
                         "alexey"               => 3416,
                         "alexi"                => 5740,
                         "alexis"               => 280,
                         "alexis01"             => 22313,
                         "alexis1"              => 7291,
                         "alexsander"           => 29117,
                         "alexsandr"            => 14077,
                         "alexus"               => 6801,
                         "alexx"                => 24717,
                         "alexxx"               => 5988,
                         "alfa"                 => 2536,
                         "alfa147"              => 15606,
                         "alfa155"              => 22918,
                         "alfa156"              => 11515,
                         "alfabeta"             => 16666,
                         "alfalfa"              => 8516,
                         "alfarome"             => 7359,
                         "alfaromeo"            => 10313,
                         "alfie"                => 13708,
                         "alfie1"               => 15220,
                         "alfons"               => 9283,
                         "alfonse"              => 25790,
                         "alfred1"              => 14645,
                         "alfredo1"             => 20156,
                         "algerie"              => 29833,
                         "algernon"             => 8505,
                         "algore"               => 26824,
                         "alhambra"             => 11342,
                         "alhimik"              => 29265,
                         "ali123"               => 15221,
                         "alianz"               => 21816,
                         "alianza"              => 17305,
                         "alias1"               => 20566,
                         "alibaba"              => 2306,
                         "alibek"               => 20224,
                         "alicante"             => 13752,
                         "alicat"               => 18550,
                         "alice1"               => 4749,
                         "alice123"             => 23628,
                         "alices"               => 19194,
                         "alici"                => 11834,
                         "alicia1"              => 17338,
                         "alicja"               => 20254,
                         "alien1"               => 12859,
                         "aliens"               => 1494,
                         "aliev"                => 29793,
                         "alieva"               => 23567,
                         "aligator"             => 7217,
                         "alina1"               => 16925,
                         "alina12"              => 29372,
                         "alina123"             => 24674,
                         "alina1994"            => 28060,
                         "alina1995"            => 26347,
                         "alina1998"            => 28061,
                         "alina2002"            => 29306,
                         "alina2006"            => 28782,
                         "alina2010"            => 28187,
                         "alina2011"            => 28055,
                         "alinka"               => 5267,
                         "alino4ka"             => 20045,
                         "alinochka"            => 13781,
                         "aliona"               => 28988,
                         "alisa1"               => 15065,
                         "alisher"              => 7632,
                         "aliska"               => 11022,
                         "aliso"                => 20643,
                         "alison1"              => 17431,
                         "aliya"                => 20603,
                         "aliyah"               => 14739,
                         "alizee"               => 14496,
                         "alkaline"             => 7982,
                         "alkash"               => 29216,
                         "all4me"               => 9184,
                         "all4one"              => 5271,
                         "all4u"                => 16815,
                         "all4u2"               => 17854,
                         "all4u2c"              => 16321,
                         "all4u3"               => 18767,
                         "all4u8"               => 11086,
                         "all4u9"               => 29162,
                         "all4you"              => 13499,
                         "alla98"               => 27370,
                         "alladin"              => 16922,
                         "allah"                => 6373,
                         "allah1"               => 13611,
                         "allalone"             => 12786,
                         "allan1"               => 9012,
                         "allan123"             => 20592,
                         "allana"               => 28175,
                         "allanon"              => 14899,
                         "allay"                => 20204,
                         "allblack"             => 7822,
                         "allblacks"            => 18395,
                         "allday"               => 6123,
                         "allegro"              => 5207,
                         "allen1"               => 5684,
                         "allen123"             => 22274,
                         "alley1"               => 26270,
                         "alleycat"             => 5410,
                         "allianz"              => 18464,
                         "allie1"               => 29258,
                         "alligato"             => 12558,
                         "alligator"            => 8365,
                         "alliso"               => 19002,
                         "allison1"             => 5653,
                         "allister"             => 22355,
                         "allmine"              => 2673,
                         "allnight"             => 7026,
                         "allochka"             => 21726,
                         "allout"               => 19071,
                         "allover"              => 11974,
                         "allsop"               => 2360,
                         "allstar"              => 2839,
                         "allstar1"             => 15111,
                         "allstars"             => 9163,
                         "allstate"             => 6714,
                         "allston"              => 24390,
                         "allthat"              => 14575,
                         "alltheway"            => 26415,
                         "allure"               => 10165,
                         "almas"                => 21652,
                         "almat"                => 20658,
                         "almaz"                => 14862,
                         "almaz666"             => 21812,
                         "almera"               => 11897,
                         "almira"               => 17941,
                         "aloha"                => 3797,
                         "aloha1"               => 9306,
                         "alohomora"            => 14433,
                         "alomar"               => 29676,
                         "alondra"              => 26844,
                         "alone1"               => 21220,
                         "alons"                => 22798,
                         "aloysius"             => 13327,
                         "alpacino"             => 11871,
                         "alpha"                => 676,
                         "alpha01"              => 21615,
                         "alpha06"              => 12001,
                         "alpha1"               => 668,
                         "alpha12"              => 10479,
                         "alpha123"             => 5867,
                         "alpha2"               => 12723,
                         "alpha3"               => 11829,
                         "alpha5"               => 15304,
                         "alpha69"              => 27685,
                         "alpha7"               => 9079,
                         "alphabet"             => 2981,
                         "alphabeta"            => 17430,
                         "alphadog"             => 23126,
                         "alphaman"             => 8947,
                         "alphaome"             => 23524,
                         "alphaomega"           => 17683,
                         "alphaone"             => 12129,
                         "alphas"               => 16177,
                         "alphasig"             => 29098,
                         "alpina"               => 6631,
                         "alpine"               => 1064,
                         "alpine1"              => 14952,
                         "alskdj"               => 28552,
                         "alskdjfh"             => 23791,
                         "alskdjfhg"            => 13529,
                         "alsscan"              => 21777,
                         "altair"               => 6009,
                         "altavista"            => 19706,
                         "altec"                => 7548,
                         "altec1"               => 27610,
                         "alterego"             => 5972,
                         "alternat"             => 18808,
                         "alternativa"          => 29579,
                         "altezza"              => 27605,
                         "althor"               => 7790,
                         "altima"               => 4005,
                         "altoid"               => 13929,
                         "altoids"              => 5909,
                         "altosax"              => 20745,
                         "alucard"              => 2430,
                         "alucard1"             => 25989,
                         "alukard"              => 15976,
                         "alvar"                => 11226,
                         "alvin1"               => 20713,
                         "alway"                => 19667,
                         "always1"              => 16887,
                         "alydar"               => 28720,
                         "alyona"               => 20194,
                         "alyss"                => 12656,
                         "alyssa1"              => 11013,
                         "am4h39d8nh"           => 28216,
                         "amadeo"               => 14403,
                         "amadeus"              => 1320,
                         "amadeus1"             => 17380,
                         "amadeusptfcor"        => 27970,
                         "amalgam"              => 15600,
                         "amand"                => 4489,
                         "amanda01"             => 18885,
                         "amanda1"              => 2250,
                         "amanda10"             => 25148,
                         "amanda11"             => 15495,
                         "amanda12"             => 11694,
                         "amanda123"            => 26113,
                         "amanda18"             => 11232,
                         "amanda69"             => 12206,
                         "amandine"             => 14577,
                         "amaranth"             => 24458,
                         "amarill"              => 20949,
                         "amarillo"             => 8706,
                         "amarok"               => 29614,
                         "amaterasu"            => 17296,
                         "amateur"              => 845,
                         "amateurs"             => 3409,
                         "amatory"              => 5600,
                         "amatuers"             => 13758,
                         "amature"              => 6126,
                         "amazing1"             => 23725,
                         "amazon"               => 1627,
                         "amazon1"              => 28876,
                         "amazonas"             => 20853,
                         "amazonka"             => 22529,
                         "amber1"               => 1692,
                         "amber123"             => 13281,
                         "amber2"               => 22575,
                         "amber69"              => 23201,
                         "amberdog"             => 25819,
                         "amberlee"             => 22824,
                         "amberr"               => 23517,
                         "ambers"               => 5031,
                         "ambrosia"             => 5443,
                         "ambulanc"             => 13016,
                         "amega"                => 17902,
                         "amekpass"             => 16527,
                         "ameli"                => 11276,
                         "amelie"               => 6156,
                         "amenra"               => 29667,
                         "americ"               => 4345,
                         "america"              => 302,
                         "america1"             => 2223,
                         "america2"             => 25205,
                         "amerika"              => 3698,
                         "ameritec"             => 29513,
                         "amersham"             => 24766,
                         "ameteur"              => 7600,
                         "amethyst"             => 5596,
                         "ametuer"              => 8226,
                         "amidala"              => 8672,
                         "amiga"                => 6051,
                         "amiga1"               => 13322,
                         "amiga500"             => 24992,
                         "amigas"               => 26043,
                         "amigo"                => 3570,
                         "amigo1"               => 18461,
                         "amigos"               => 5029,
                         "aminka"               => 29717,
                         "aminor"               => 19388,
                         "amista"               => 16023,
                         "amistad"              => 20298,
                         "amitech"              => 28967,
                         "amizade"              => 27453,
                         "amoco"                => 29804,
                         "amoeba"               => 16528,
                         "amonra"               => 6354,
                         "amonte"               => 19575,
                         "amor"                 => 6390,
                         "amorcit"              => 4273,
                         "amorcito"             => 29759,
                         "amore"                => 4838,
                         "amoremio"             => 8507,
                         "amores"               => 8849,
                         "amormi"               => 9955,
                         "amour"                => 7358,
                         "ampere"               => 18353,
                         "amrita"               => 16906,
                         "amstel"               => 5729,
                         "amsterda"             => 2302,
                         "amsterdam"            => 1695,
                         "amsterdam1"           => 14871,
                         "amy123"               => 16079,
                         "amylee"               => 11557,
                         "amylynn"              => 16827,
                         "an83546921an13"       => 18365,
                         "anabe"                => 27177,
                         "anabelle"             => 24543,
                         "anabolic"             => 12577,
                         "anaconda"             => 2119,
                         "anadrol"              => 25979,
                         "anaell"               => 22390,
                         "anahit"               => 25966,
                         "anai"                 => 3965,
                         "anais"                => 25964,
                         "anakin"               => 1095,
                         "anakin1"              => 18985,
                         "anakonda"             => 7300,
                         "anal"                 => 1340,
                         "anal69"               => 29558,
                         "analfuck"             => 21802,
                         "anallove"             => 22990,
                         "analsex"              => 1591,
                         "analslut"             => 19510,
                         "anamari"              => 16058,
                         "anamika"              => 27846,
                         "ananas"               => 5579,
                         "ananda"               => 9158,
                         "anarchy"              => 1798,
                         "anarchy1"             => 23498,
                         "anasazi"              => 11425,
                         "anastaci"             => 28973,
                         "anastas"              => 22851,
                         "anastasi"             => 4088,
                         "anastasija"           => 18293,
                         "anastasiy"            => 17468,
                         "anastasiya"           => 3745,
                         "anastasya"            => 29844,
                         "anathema"             => 16592,
                         "anatol"               => 12243,
                         "anatole"              => 20851,
                         "anatoli"              => 25921,
                         "anatoliy"             => 9062,
                         "ancella2"             => 21753,
                         "anchorag"             => 17261,
                         "anchorat"             => 24882,
                         "and123"               => 21933,
                         "ander"                => 26523,
                         "anders1"              => 20867,
                         "anderso"              => 9581,
                         "andi03"               => 14464,
                         "andiamo"              => 26038,
                         "andone"               => 12456,
                         "andover"              => 9469,
                         "andranik"             => 29886,
                         "andre1"               => 8913,
                         "andre123"             => 12451,
                         "andrea1"              => 3675,
                         "andrea11"             => 20278,
                         "andrea12"             => 25116,
                         "andrea99"             => 25320,
                         "andreas1"             => 10457,
                         "andreea"              => 19813,
                         "andreev"              => 8590,
                         "andreeva"             => 13272,
                         "andrei"               => 1116,
                         "andrei1"              => 22631,
                         "andrei123"            => 21923,
                         "andreia"              => 22578,
                         "andreika"             => 24620,
                         "andrej"               => 8561,
                         "andretti"             => 15825,
                         "andrew01"             => 17420,
                         "andrew1"              => 1455,
                         "andrew10"             => 22731,
                         "andrew11"             => 23000,
                         "andrew12"             => 9035,
                         "andrew123"            => 16935,
                         "andrew13"             => 17933,
                         "andrew17"             => 27325,
                         "andrew2"              => 12538,
                         "andrew22"             => 20594,
                         "andrew23"             => 27823,
                         "andrew6"              => 23162,
                         "andrew88"             => 19817,
                         "andrew9"              => 27577,
                         "andrew99"             => 25861,
                         "andrewjackie"         => 16741,
                         "andrey"               => 389,
                         "andrey1"              => 25849,
                         "andrey12"             => 29544,
                         "andrey123"            => 14275,
                         "andrey1992"           => 26927,
                         "andreyka"             => 22596,
                         "andriy"               => 12647,
                         "andromed"             => 3425,
                         "andromeda"            => 2781,
                         "andron"               => 17428,
                         "andros"               => 9927,
                         "andrzej"              => 14064,
                         "anduril"              => 9001,
                         "andy01"               => 29923,
                         "andy1"                => 17897,
                         "andy11"               => 20173,
                         "andy12"               => 19190,
                         "andy123"              => 11378,
                         "andy2000"             => 26742,
                         "andy69"               => 20919,
                         "andy76"               => 26945,
                         "andyboy"              => 27217,
                         "andyman"              => 13077,
                         "andyod22"             => 4371,
                         "andzia"               => 24414,
                         "ane4ka"               => 19364,
                         "anechka"              => 7784,
                         "anelka"               => 13407,
                         "anemone"              => 21051,
                         "anetka"               => 24421,
                         "anfield"              => 2018,
                         "anfield1"             => 15797,
                         "anfisa"               => 6579,
                         "ang238"               => 28057,
                         "angel"                => 166,
                         "angel007"             => 25661,
                         "angel01"              => 13718,
                         "angel1"               => 727,
                         "angel11"              => 14316,
                         "angel12"              => 7819,
                         "angel123"             => 3999,
                         "angel13"              => 9825,
                         "angel17"              => 25777,
                         "angel2"               => 6219,
                         "angel20"              => 27222,
                         "angel21"              => 22652,
                         "angel22"              => 13023,
                         "angel3"               => 21317,
                         "angel5"               => 16430,
                         "angel6"               => 18189,
                         "angel666"             => 6980,
                         "angel69"              => 15471,
                         "angel7"               => 9038,
                         "angel77"              => 26641,
                         "angel777"             => 13313,
                         "angel9"               => 17622,
                         "angel99"              => 20019,
                         "angela1"              => 5528,
                         "angela12"             => 17402,
                         "angelbab"             => 19980,
                         "angeldog"             => 24928,
                         "angeleye"             => 9922,
                         "angeleyes"            => 25559,
                         "angeli"               => 16607,
                         "angelin"              => 12280,
                         "angeliqu"             => 14706,
                         "angelit"              => 7009,
                         "angelito"             => 8746,
                         "angelo1"              => 19657,
                         "angelo4ek"            => 14937,
                         "angelochek"           => 17474,
                         "angelofwar"           => 9630,
                         "angelok"              => 7853,
                         "angels"               => 198,
                         "angels1"              => 10355,
                         "angelus"              => 4261,
                         "angelz"               => 27038,
                         "angie1"               => 8787,
                         "angler"               => 12417,
                         "angrick"              => 22305,
                         "anguilla"             => 16343,
                         "angus"                => 2953,
                         "angus1"               => 4893,
                         "angus123"             => 26688,
                         "anguss"               => 13121,
                         "anhnhoem"             => 19936,
                         "anhyeuem"             => 2186,
                         "anima"                => 17403,
                         "animal"               => 343,
                         "animal1"              => 10421,
                         "animal2000"           => 25970,
                         "animals1"             => 21278,
                         "animalsex"            => 28709,
                         "animate"              => 20074,
                         "anime"                => 1609,
                         "anime1"               => 11087,
                         "anime123"             => 25744,
                         "animes"               => 28808,
                         "aninha"               => 19407,
                         "aniolek"              => 29441,
                         "aniram"               => 21750,
                         "anisimov"             => 23769,
                         "aniston"              => 16138,
                         "anita1"               => 9323,
                         "anitha"               => 26707,
                         "anjali"               => 9801,
                         "anjana"               => 17370,
                         "anjela"               => 19841,
                         "anjing"               => 13857,
                         "ankara"               => 6773,
                         "ankita"               => 18781,
                         "anklet"               => 10989,
                         "anna1"                => 18276,
                         "anna12"               => 12299,
                         "anna123"              => 8617,
                         "anna12345"            => 29976,
                         "anna13"               => 22844,
                         "anna1982"             => 24859,
                         "anna1984"             => 22792,
                         "anna1985"             => 24302,
                         "anna1986"             => 21769,
                         "anna1987"             => 13277,
                         "anna1988"             => 17659,
                         "anna1989"             => 18481,
                         "anna1990"             => 24419,
                         "anna1994"             => 24635,
                         "anna1997"             => 24422,
                         "anna2000"             => 16785,
                         "anna2002"             => 26567,
                         "anna2010"             => 16900,
                         "anna21"               => 18587,
                         "anna2614"             => 7813,
                         "annamari"             => 11704,
                         "annapoli"             => 24239,
                         "annarbor"             => 21063,
                         "anneke"               => 17417,
                         "anneli"               => 21756,
                         "annelies"             => 14355,
                         "annemari"             => 10423,
                         "annette1"             => 14877,
                         "annick"               => 17104,
                         "annie1"               => 3477,
                         "annie123"             => 20762,
                         "annie2"               => 14572,
                         "anniedog"             => 17658,
                         "annies"               => 15883,
                         "annushka"             => 14857,
                         "anomie"               => 28339,
                         "anonim"               => 12053,
                         "anonymer"             => 27010,
                         "anonymou"             => 13081,
                         "another1"             => 12669,
                         "anselm"               => 11441,
                         "ant123"               => 20686,
                         "antananarivu"         => 24594,
                         "antani"               => 19156,
                         "antanta"              => 27192,
                         "antares"              => 4544,
                         "anteater"             => 9105,
                         "antelope"             => 4410,
                         "antero"               => 19158,
                         "anthea"               => 15478,
                         "anthon"               => 4063,
                         "anthon1"              => 21315,
                         "anthony0"             => 20036,
                         "anthony1"             => 1166,
                         "anthony2"             => 7455,
                         "anthony3"             => 21965,
                         "anthony4"             => 28615,
                         "anthony5"             => 24986,
                         "anthony7"             => 6821,
                         "anthony8"             => 27054,
                         "anthony9"             => 24205,
                         "anthrax"              => 3697,
                         "anthro"               => 26413,
                         "antietam"             => 20268,
                         "antiflag"             => 28535,
                         "antigone"             => 8068,
                         "antigua"              => 11253,
                         "antihero"             => 24643,
                         "antivirus"            => 13808,
                         "antler"               => 17203,
                         "antman"               => 11092,
                         "antoha"               => 13010,
                         "antoin"               => 29355,
                         "anton1"               => 6454,
                         "anton123"             => 10758,
                         "antonell"             => 12810,
                         "antonella"            => 16167,
                         "antoni"               => 3156,
                         "antonia1"             => 25665,
                         "antonio1"             => 8104,
                         "antonio2"             => 24028,
                         "antonio3"             => 24788,
                         "antonioj"             => 25738,
                         "antonius"             => 10849,
                         "antonov"              => 6672,
                         "antonova"             => 22921,
                         "antosha"              => 14371,
                         "antoshka"             => 9354,
                         "antoxa"               => 20402,
                         "anubis"               => 1338,
                         "anupam"               => 25273,
                         "anuradha"             => 11596,
                         "anusha"               => 21849,
                         "anutka"               => 11879,
                         "anvils"               => 18784,
                         "anyuta"               => 20449,
                         "aoi856"               => 23719,
                         "aol123"               => 5948,
                         "aol999"               => 10935,
                         "aolcom"               => 22058,
                         "aolsucks"             => 5277,
                         "aotearoa"             => 29927,
                         "apa195"               => 22391,
                         "apacer"               => 29908,
                         "apache"               => 772,
                         "apache1"              => 11208,
                         "apache64"             => 25629,
                         "apathy"               => 10626,
                         "apelsin"              => 9416,
                         "apeman"               => 19216,
                         "apeshit"              => 26293,
                         "aphrodit"             => 22562,
                         "apocalyp"             => 23928,
                         "apogee"               => 17010,
                         "apokalipsis"          => 14449,
                         "apollo"               => 310,
                         "apollo1"              => 7643,
                         "apollo11"             => 5416,
                         "apollo12"             => 27309,
                         "apollo13"             => 1952,
                         "apollo8"              => 29681,
                         "apollon"              => 17358,
                         "apolon"               => 16621,
                         "apostol"              => 12123,
                         "appels"               => 17538,
                         "appelsin"             => 20816,
                         "apple"                => 318,
                         "apple1"               => 1179,
                         "apple11"              => 24240,
                         "apple12"              => 12459,
                         "apple123"             => 2594,
                         "apple13"              => 21012,
                         "apple2"               => 7852,
                         "apple22"              => 20405,
                         "apple3"               => 21312,
                         "apple5"               => 23153,
                         "applegat"             => 22245,
                         "applemac"             => 15494,
                         "applepie"             => 2200,
                         "apples"               => 218,
                         "apples1"              => 8927,
                         "apples12"             => 16605,
                         "apples123"            => 24165,
                         "apples2"              => 23729,
                         "applesauce"           => 15537,
                         "appleseed"            => 21262,
                         "appletre"             => 20626,
                         "appollo"              => 22891,
                         "apricot"              => 6258,
                         "april1"               => 4826,
                         "april10"              => 13394,
                         "april12"              => 13253,
                         "april13"              => 19976,
                         "april14"              => 27899,
                         "april15"              => 25983,
                         "april16"              => 28912,
                         "april17"              => 15914,
                         "april21"              => 25261,
                         "april22"              => 21610,
                         "april24"              => 28565,
                         "april26"              => 20622,
                         "april6"               => 18192,
                         "april7"               => 21503,
                         "april9"               => 28702,
                         "aprilia"              => 5561,
                         "aprils"               => 14559,
                         "apteka"               => 8028,
                         "aptiva"               => 3948,
                         "aq12ws"               => 20272,
                         "aq1sw2"               => 13482,
                         "aq1sw2de3"            => 12401,
                         "aqswde"               => 12652,
                         "aqswdefr"             => 11453,
                         "aquafina"             => 8842,
                         "aqualung"             => 9073,
                         "aquaman"              => 9239,
                         "aquamann"             => 22458,
                         "aquariu"              => 27051,
                         "aquarius"             => 1654,
                         "aquemini"             => 23441,
                         "aquila"               => 7783,
                         "aqwzsx"               => 7085,
                         "aqwzsxedc"            => 23887,
                         "ar3yuk3"              => 12321,
                         "ara123"               => 20444,
                         "arabella"             => 8767,
                         "aracel"               => 23569,
                         "arachne"              => 29896,
                         "arachnid"             => 12808,
                         "aragorn"              => 1020,
                         "aragorn1"             => 12025,
                         "arakis"               => 15671,
                         "aramis"               => 4409,
                         "ararat"               => 9697,
                         "arashi"               => 27903,
                         "arbeit"               => 19308,
                         "arbiter"              => 21107,
                         "arcadia"              => 3481,
                         "arcana"               => 19730,
                         "arcane"               => 8392,
                         "arcangel"             => 7402,
                         "arcanum"              => 21581,
                         "archana"              => 13925,
                         "archange"             => 5244,
                         "archangel"            => 7312,
                         "archer1"              => 18335,
                         "archery"              => 6918,
                         "archi"                => 17980,
                         "archibal"             => 22406,
                         "archie1"              => 16916,
                         "archimed"             => 29378,
                         "architec"             => 6764,
                         "archmage"             => 20709,
                         "archon"               => 8683,
                         "arclight"             => 17063,
                         "arcturus"             => 13981,
                         "ardmore"              => 23999,
                         "ardvark"              => 15576,
                         "area51"               => 1746,
                         "aregdone"             => 27672,
                         "arenrone"             => 23579,
                         "areyou"               => 22656,
                         "areyuke"              => 24208,
                         "areyukesc"            => 14205,
                         "argent"               => 8829,
                         "argentin"             => 4771,
                         "argento"              => 12837,
                         "argentum"             => 14337,
                         "argonaut"             => 9486,
                         "argyle"               => 6911,
                         "arhangel"             => 10684,
                         "ariadna"              => 12292,
                         "ariadne"              => 10395,
                         "arian"                => 12181,
                         "arianna1"             => 23259,
                         "ariel1"               => 14038,
                         "aries"                => 4927,
                         "aries1"               => 16633,
                         "arigato"              => 11033,
                         "arina"                => 10014,
                         "arioch"               => 9529,
                         "arisha"               => 10871,
                         "arisia"               => 24580,
                         "aristo"               => 18270,
                         "ariston"              => 19895,
                         "aristote"             => 19238,
                         "aristotl"             => 17120,
                         "arizona"              => 589,
                         "arizona1"             => 6215,
                         "arjay"                => 2202,
                         "arkady"               => 28531,
                         "arkangel"             => 22050,
                         "arkasha"              => 25517,
                         "arkham"               => 14592,
                         "arlingto"             => 22435,
                         "armada"               => 4340,
                         "armadill"             => 12978,
                         "armagedd"             => 16612,
                         "armageddon"           => 7186,
                         "armagedo"             => 17121,
                         "armagedon"            => 3103,
                         "arman"                => 8334,
                         "armani"               => 2100,
                         "armani1"              => 24978,
                         "armastus"             => 25555,
                         "armen"                => 21500,
                         "armine"               => 23836,
                         "arminia"              => 28129,
                         "armstron"             => 4241,
                         "armyman"              => 28574,
                         "armyof1"              => 23868,
                         "arnaud"               => 7431,
                         "arnhem"               => 15965,
                         "arnie1"               => 23178,
                         "arnol"                => 25753,
                         "arnold1"              => 15579,
                         "arnster55"            => 20413,
                         "arowana"              => 23833,
                         "arrakis"              => 7417,
                         "arriva"               => 16052,
                         "arrow"                => 3626,
                         "arrow1"               => 9390,
                         "arrowhea"             => 10610,
                         "arrows"               => 3882,
                         "arsch"                => 14466,
                         "arschloc"             => 16968,
                         "arschloch"            => 10702,
                         "arsehole"             => 10269,
                         "arsen"                => 12373,
                         "arsena"               => 6226,
                         "arsenal"              => 118,
                         "arsenal0"             => 26459,
                         "arsenal1"             => 1812,
                         "arsenal123"           => 29828,
                         "arsenal2"             => 15105,
                         "arsenal7"             => 29219,
                         "arsenal9"             => 29400,
                         "arsenalf"             => 12027,
                         "arsenalfc"            => 9181,
                         "arsenii"              => 25381,
                         "arseniy"              => 14425,
                         "arshavin"             => 18053,
                         "arslan"               => 9186,
                         "art123"               => 13011,
                         "art131313"            => 11924,
                         "artcast2"             => 27677,
                         "artefact"             => 27242,
                         "artem"                => 3327,
                         "artem1"               => 16134,
                         "artem123"             => 18234,
                         "artem1992"            => 26926,
                         "artem1995"            => 28631,
                         "artem2010"            => 17450,
                         "artem777"             => 22096,
                         "artema"               => 28497,
                         "artemi"               => 29954,
                         "artemis"              => 2280,
                         "artemis1"             => 23465,
                         "artemka"              => 3292,
                         "artemon"              => 16211,
                         "arthu"                => 13818,
                         "arthur1"              => 7524,
                         "artichok"             => 23177,
                         "artiller"             => 16314,
                         "artimus"              => 23232,
                         "artist1"              => 19784,
                         "artofwar"             => 9982,
                         "artur"                => 2719,
                         "artur1"               => 21735,
                         "arturik"              => 17317,
                         "artyom"               => 19988,
                         "aruba"                => 9264,
                         "arvind"               => 27924,
                         "arwpls4u"             => 16113,
                         "arxangel"             => 26355,
                         "arzen"                => 26067,
                         "as1234"               => 10587,
                         "as12345"              => 20306,
                         "as123456"             => 6231,
                         "asa123"               => 29885,
                         "asakura"              => 11283,
                         "asasa"                => 13436,
                         "asasin"               => 9308,
                         "ascona"               => 14593,
                         "asd12"                => 13863,
                         "asd123"               => 440,
                         "asd1234"              => 10194,
                         "asd12345"             => 7759,
                         "asd123456"            => 13292,
                         "asd123asd"            => 9554,
                         "asd123qwe"            => 22636,
                         "asd222"               => 5813,
                         "asd321"               => 19419,
                         "asd456"               => 7505,
                         "asdas"                => 7024,
                         "asdasd"               => 330,
                         "asdasd1"              => 16109,
                         "asdasd12"             => 21040,
                         "asdasd123"            => 6081,
                         "asdasd22"             => 28264,
                         "asdasdas"             => 10815,
                         "asdcxz"               => 24842,
                         "asddsa"               => 3725,
                         "asdewq"               => 10884,
                         "asdf"                 => 257,
                         "asdf1"                => 11281,
                         "asdf11"               => 19718,
                         "asdf12"               => 3822,
                         "asdf123"              => 1381,
                         "asdf1234"             => 388,
                         "asdf12345"            => 17073,
                         "asdf4321"             => 21674,
                         "asdf67nm"             => 21110,
                         "asdfas"               => 12709,
                         "asdfasd"              => 15815,
                         "asdfasdf"             => 206,
                         "asdfasdf1"            => 23538,
                         "asdffdsa"             => 5552,
                         "asdfg"                => 592,
                         "asdfg1"               => 9670,
                         "asdfg12"              => 14093,
                         "asdfg123"             => 5861,
                         "asdfg1234"            => 22091,
                         "asdfg12345"           => 8133,
                         "asdfgh"               => 40,
                         "asdfgh01"             => 4309,
                         "asdfgh1"              => 5930,
                         "asdfgh12"             => 12071,
                         "asdfgh123"            => 13380,
                         "asdfgh123456"         => 26900,
                         "asdfghj"              => 976,
                         "asdfghj1"             => 18491,
                         "asdfghjk"             => 307,
                         "asdfghjkl"            => 232,
                         "asdfghjkl1"           => 13507,
                         "asdfghjkl123"         => 13684,
                         "asdfjk"               => 10739,
                         "asdfjkl"              => 2057,
                         "asdfjkl1"             => 18262,
                         "asdfjkl;"             => 8577,
                         "asdflkj"              => 27937,
                         "asdflkjh"             => 17912,
                         "asdfqwer"             => 6162,
                         "asdfrewq"             => 20436,
                         "asdfzxcv"             => 3276,
                         "asdjkl"               => 15706,
                         "asdlkj"               => 14035,
                         "asdqwe"               => 4604,
                         "asdqwe123"            => 4348,
                         "asdzx"                => 29736,
                         "asdzxc"               => 1251,
                         "asdzxc123"            => 24380,
                         "asecret"              => 10517,
                         "asenna"               => 15366,
                         "asfnhg66"             => 13688,
                         "asgard"               => 4799,
                         "asguard"              => 28194,
                         "ash123"               => 25045,
                         "ashaman"              => 23600,
                         "ashes1"               => 27233,
                         "ashish"               => 10697,
                         "ashle"                => 4942,
                         "ashley01"             => 22670,
                         "ashley1"              => 2434,
                         "ashley11"             => 19746,
                         "ashley12"             => 10801,
                         "ashley123"            => 26111,
                         "ashley19"             => 26706,
                         "ashley2"              => 22080,
                         "ashley24"             => 28170,
                         "ashley69"             => 22603,
                         "ashlynn"              => 26091,
                         "ashton1"              => 19175,
                         "ashwin"               => 19366,
                         "asian1"               => 18652,
                         "asians"               => 4916,
                         "asilas"               => 24517,
                         "asimov"               => 4518,
                         "askar"                => 28582,
                         "aslan"                => 7750,
                         "asmara"               => 22219,
                         "asmodean"             => 22002,
                         "asmodeus"             => 7575,
                         "asmodey"              => 26505,
                         "asnaeb"               => 12007,
                         "aspen"                => 4715,
                         "aspen1"               => 13087,
                         "aspirant"             => 29966,
                         "aspire"               => 2197,
                         "aspirina"             => 29252,
                         "aspirine"             => 1604,
                         "asq321"               => 12821,
                         "asroma"               => 12654,
                         "ass123"               => 6345,
                         "assa123"              => 24050,
                         "assa1234"             => 12396,
                         "assasin"              => 4812,
                         "assasins"             => 25369,
                         "assass1"              => 26112,
                         "assassin"             => 851,
                         "assassins"            => 8893,
                         "assclown"             => 8957,
                         "asscock"              => 7925,
                         "asscrack"             => 15137,
                         "asseater"             => 19579,
                         "assembler"            => 21284,
                         "assface"              => 8833,
                         "assfuck"              => 1626,
                         "assfucke"             => 20842,
                         "asshat"               => 15083,
                         "asshead"              => 18696,
                         "asshol"               => 6515,
                         "asshole"              => 53,
                         "asshole1"             => 1518,
                         "asshole123"           => 27462,
                         "asshole2"             => 14671,
                         "asshole3"             => 20817,
                         "assholes"             => 2604,
                         "asslick"              => 10543,
                         "asslicke"             => 25514,
                         "asslicker"            => 14845,
                         "asslover"             => 7132,
                         "assman"               => 535,
                         "assman1"              => 16445,
                         "assmaste"             => 11345,
                         "assmaster"            => 24785,
                         "assmonke"             => 27418,
                         "assmunch"             => 7081,
                         "associat"             => 20779,
                         "asssex"               => 23073,
                         "assss"                => 23610,
                         "asssss"               => 9598,
                         "asswipe"              => 6212,
                         "assword"              => 3054,
                         "assword1"             => 15043,
                         "astalavista"          => 8171,
                         "astana"               => 11256,
                         "astaroth"             => 17647,
                         "aster"                => 16268,
                         "asterios"             => 9230,
                         "asterix"              => 1594,
                         "asterix1"             => 13325,
                         "asthma"               => 7040,
                         "astonmar"             => 22068,
                         "astonmartin"          => 20724,
                         "astonv"               => 25359,
                         "astonvil"             => 8112,
                         "astonvilla"           => 10634,
                         "astoria"              => 10431,
                         "astra"                => 3969,
                         "astra1"               => 10179,
                         "astra123"             => 19256,
                         "astral"               => 4398,
                         "astro"                => 3501,
                         "astro1"               => 6985,
                         "astroboy"             => 10181,
                         "astroman"             => 22210,
                         "astron"               => 23224,
                         "astros"               => 1660,
                         "astrovan"             => 16269,
                         "at4gftlw"             => 20007,
                         "at_asp"               => 19042,
                         "ataman"               => 23382,
                         "ataris"               => 24550,
                         "atdhfkm"              => 10574,
                         "atease"               => 28190,
                         "atep1"                => 26055,
                         "athena1"              => 20993,
                         "athene"               => 26180,
                         "athlon"               => 3387,
                         "athlon64"             => 24257,
                         "athome"               => 5907,
                         "atilla"               => 15549,
                         "atkbrc"               => 22532,
                         "atlant"               => 11367,
                         "atlanta"              => 798,
                         "atlanta1"             => 7005,
                         "atlanti"              => 27420,
                         "atlantida"            => 13138,
                         "atlantis"             => 853,
                         "atlas1"               => 9869,
                         "atlast"               => 14908,
                         "atljhjdf"             => 22513,
                         "atombomb"             => 20375,
                         "atomic"               => 1668,
                         "atrain"               => 12846,
                         "atreides"             => 6329,
                         "atreyu"               => 14428,
                         "attack1"              => 29953,
                         "attica"               => 11910,
                         "atticus"              => 5562,
                         "attila"               => 3672,
                         "atwork"               => 23808,
                         "atybrc"               => 11348,
                         "auburn"               => 1441,
                         "auburn1"              => 22620,
                         "auckland2010"         => 19122,
                         "audi"                 => 4506,
                         "audi100"              => 9467,
                         "audi80"               => 6524,
                         "audia3"               => 11547,
                         "audia4"               => 2659,
                         "audia6"               => 6379,
                         "audia8"               => 20644,
                         "audio1"               => 14644,
                         "audis4"               => 9977,
                         "auditt"               => 4659,
                         "audre"                => 21573,
                         "auggie"               => 4981,
                         "augus"                => 19090,
                         "august1"              => 10229,
                         "august10"             => 29103,
                         "august11"             => 18543,
                         "august12"             => 19390,
                         "august15"             => 23414,
                         "august16"             => 16687,
                         "august17"             => 22755,
                         "august2"              => 15993,
                         "august20"             => 28927,
                         "august22"             => 26082,
                         "august24"             => 24106,
                         "august25"             => 18733,
                         "august29"             => 28432,
                         "august31"             => 18671,
                         "august9"              => 23175,
                         "augustin"             => 6549,
                         "augusto"              => 8762,
                         "auntjudy"             => 25208,
                         "auralo"               => 10440,
                         "aureli"               => 18752,
                         "aurelie"              => 7644,
                         "aurelien"             => 24627,
                         "aurelius"             => 10494,
                         "aurinko"              => 20778,
                         "auror"                => 17030,
                         "aussie"               => 1599,
                         "aust1n"               => 24405,
                         "austi"                => 13514,
                         "austin"               => 77,
                         "austin01"             => 19295,
                         "austin1"              => 3055,
                         "austin11"             => 19335,
                         "austin12"             => 12285,
                         "austin123"            => 18756,
                         "austin2"              => 26054,
                         "austin31"             => 5293,
                         "austin316"            => 7869,
                         "austintx"             => 17786,
                         "australi"             => 2217,
                         "australia1"           => 21145,
                         "autechre"             => 15888,
                         "authcode"             => 24078,
                         "autobahn"             => 11909,
                         "autobot"              => 13361,
                         "autocad"              => 9785,
                         "autogod"              => 21908,
                         "automag"              => 21827,
                         "automati"             => 28928,
                         "autopas1"             => 29626,
                         "autopass"             => 13887,
                         "autumn1"              => 18859,
                         "av473dv"              => 24477,
                         "av626ss"              => 26647,
                         "avalanch"             => 2653,
                         "avalanche"            => 7699,
                         "avalon"               => 569,
                         "avalon1"              => 14903,
                         "avalon11"             => 27813,
                         "avangard"             => 8732,
                         "avanti"               => 7254,
                         "avata"                => 24295,
                         "avatar"               => 664,
                         "avatar1"              => 14257,
                         "avemaria"             => 16569,
                         "avenger"              => 1708,
                         "avenger1"             => 12388,
                         "avensis"              => 17328,
                         "aventura"             => 14353,
                         "avery1"               => 18241,
                         "avgust"               => 9817,
                         "aviator"              => 6190,
                         "avocado"              => 18451,
                         "avocat"               => 18801,
                         "avocet"               => 20421,
                         "avogadro"             => 27041,
                         "avondale"             => 15728,
                         "avr7000"              => 24151,
                         "avrillavigne"         => 19576,
                         "avrora"               => 7894,
                         "avtoritet"            => 25666,
                         "aw96b6"               => 18325,
                         "awacs"                => 16932,
                         "awatar"               => 16901,
                         "awdrgyjilp"           => 24221,
                         "awesom"               => 24633,
                         "awesome"              => 612,
                         "awesome1"             => 5087,
                         "awesome123"           => 29410,
                         "awesome2"             => 25269,
                         "awnyce"               => 5368,
                         "awo8rx3wa8t"          => 27444,
                         "awsedr"               => 20480,
                         "awsome"               => 12867,
                         "axelle"               => 23508,
                         "axeman"               => 8270,
                         "axio"                 => 6785,
                         "axlrose"              => 15616,
                         "axolotl"              => 15700,
                         "ayacdc"               => 21433,
                         "ayanami"              => 6588,
                         "ayi000"               => 24952,
                         "aynrand"              => 17302,
                         "ayrton"               => 8802,
                         "az12345"              => 23061,
                         "az123456"             => 15904,
                         "azalea"               => 14134,
                         "azalia"               => 16765,
                         "azamat"               => 1841,
                         "azathoth"             => 13352,
                         "azaz09"               => 17496,
                         "azazel"               => 4160,
                         "azbuka"               => 14640,
                         "azert"                => 5155,
                         "azerty"               => 286,
                         "azerty1"              => 16026,
                         "azerty12"             => 26116,
                         "azerty123"            => 10895,
                         "azertyu"              => 16551,
                         "azertyui"             => 5062,
                         "azertyuiop"           => 5566,
                         "azfpc310"             => 23967,
                         "azimut"               => 14358,
                         "azimuth"              => 24831,
                         "aziza"                => 18308,
                         "azizbek"              => 25842,
                         "azonic"               => 21341,
                         "azrael"               => 5847,
                         "azreal"               => 25032,
                         "azsxdc"               => 1955,
                         "azsxdcf"              => 17092,
                         "azsxdcfv"             => 2031,
                         "azsxdcfvgb"           => 10212,
                         "aztec"                => 9865,
                         "aztec1"               => 19801,
                         "azteca"               => 9555,
                         "aztecs"               => 9510,
                         "aztnm"                => 6167,
                         "azucar"               => 22942,
                         "azuywe"               => 18731,
                         "azwebitalia"          => 15013,
                         "azzer"                => 5372,
                         "azzurra"              => 21228,
                         "azzurro"              => 28521,
                         "b00bies"              => 21917,
                         "b00ger"               => 19391,
                         "b00mer"               => 16198,
                         "b0ll0cks"             => 15810,
                         "b12345"               => 6731,
                         "b123456"              => 8981,
                         "b1234567"             => 23140,
                         "b1afra"               => 15807,
                         "b26354"               => 28015,
                         "b7mguk"               => 19453,
                         "b929ezzh"             => 19449,
                         "ba25547"              => 27900,
                         "baba123"              => 25222,
                         "babaloo"              => 13528,
                         "babalu"               => 22366,
                         "babare"               => 28468,
                         "babcia"               => 19195,
                         "babe"                 => 1110,
                         "babe23"               => 14611,
                         "babe69"               => 18823,
                         "babel"                => 7799,
                         "babemagn"             => 7415,
                         "babemagnet"           => 6968,
                         "baberuth"             => 6160,
                         "babes"                => 970,
                         "babes1"               => 14231,
                         "babie"                => 21758,
                         "babilon"              => 20130,
                         "babochka"             => 27925,
                         "baboon"               => 6140,
                         "babushka"             => 8714,
                         "baby01"               => 21165,
                         "baby1"                => 10951,
                         "baby12"               => 22312,
                         "baby123"              => 6265,
                         "baby1234"             => 21345,
                         "baby2000"             => 16787,
                         "baby22"               => 27781,
                         "baby69"               => 21699,
                         "babybear"             => 5943,
                         "babyblu"              => 27369,
                         "babyblue"             => 2605,
                         "babybo"               => 28184,
                         "babyboo"              => 11197,
                         "babyboy"              => 1922,
                         "babyboy1"             => 23339,
                         "babycake"             => 5705,
                         "babycakes"            => 10333,
                         "babycat"              => 14999,
                         "babydoll"             => 875,
                         "babyfac"              => 27948,
                         "babyface"             => 2966,
                         "babygir"              => 8986,
                         "babygirl"             => 392,
                         "babygirl1"            => 11501,
                         "babygurl"             => 10912,
                         "babyhuey"             => 19495,
                         "babylon"              => 975,
                         "babylon5"             => 955,
                         "babylon6"             => 29563,
                         "babylove"             => 3360,
                         "babyphat"             => 25539,
                         "babyruth"             => 22106,
                         "babys"                => 29780,
                         "bacall"               => 29590,
                         "bacardi"              => 2855,
                         "bacardi1"             => 19699,
                         "bacchus"              => 3321,
                         "backbone"             => 6028,
                         "backd00r"             => 25048,
                         "backdoor"             => 2273,
                         "backdraf"             => 23845,
                         "backhoe"              => 14079,
                         "backlash"             => 11575,
                         "backspac"             => 9192,
                         "backspace"            => 17727,
                         "backwood"             => 25900,
                         "bacon1"               => 15655,
                         "bacons"               => 28294,
                         "bad11bad"             => 24617,
                         "bad123"               => 17042,
                         "badabing"             => 6426,
                         "badaboom"             => 22318,
                         "badass"               => 474,
                         "badass1"              => 19151,
                         "badbo"                => 17237,
                         "badbob"               => 19649,
                         "badboy"               => 167,
                         "badboy1"              => 6845,
                         "badboy69"             => 15273,
                         "badboys"              => 6597,
                         "badboyz"              => 28846,
                         "badcat"               => 13473,
                         "baddest"              => 6545,
                         "baddog"               => 2238,
                         "baddog1"              => 23873,
                         "badfish"              => 18230,
                         "badger"               => 454,
                         "badger1"              => 10781,
                         "badgers"              => 3954,
                         "badgirl"              => 2857,
                         "badgirls"             => 13256,
                         "badguy"               => 8611,
                         "badkarma"             => 8748,
                         "badkitty"             => 13446,
                         "badlands"             => 9811,
                         "badluck"              => 20513,
                         "badman"               => 3226,
                         "badminto"             => 22402,
                         "badmofo"              => 28560,
                         "badmojo"              => 19855,
                         "badnaamhere"          => 8914,
                         "badnews"              => 18404,
                         "badone"               => 11741,
                         "badseed"              => 22338,
                         "baerchen"             => 17281,
                         "baffle"               => 29524,
                         "bagdad"               => 22380,
                         "bagel1"               => 21077,
                         "bagels"               => 8300,
                         "bagger"               => 10571,
                         "baggie"               => 22949,
                         "baggies"              => 6950,
                         "baggins"              => 1368,
                         "baggins1"             => 14506,
                         "baggio"               => 3463,
                         "baggio10"             => 27133,
                         "bagheera"             => 15457,
                         "bagira"               => 2901,
                         "bagpipe"              => 16834,
                         "bagpipes"             => 10959,
                         "bagpuss"              => 5770,
                         "baguvix"              => 12305,
                         "bahama"               => 21393,
                         "bahamut"              => 4740,
                         "bahram"               => 21397,
                         "baikal"               => 11712,
                         "baile"                => 10243,
                         "bailee"               => 13504,
                         "bailey01"             => 17606,
                         "bailey1"              => 3475,
                         "bailey10"             => 19110,
                         "bailey11"             => 22706,
                         "bailey12"             => 16371,
                         "bailey2"              => 20258,
                         "baileys"              => 18881,
                         "bajingan"             => 6963,
                         "bajskorv"             => 22540,
                         "bakayaro"             => 15213,
                         "baker1"               => 6930,
                         "bakers"               => 10614,
                         "bakesale"             => 27326,
                         "baklan"               => 20781,
                         "baksik"               => 20500,
                         "bakugan"              => 15358,
                         "balalaika"            => 18352,
                         "balance1"             => 25175,
                         "balata"               => 24020,
                         "balaton"              => 28852,
                         "balbes"               => 17791,
                         "balboa"               => 7107,
                         "baldeagl"             => 26757,
                         "baldeagle"            => 27160,
                         "balder"               => 8256,
                         "baldhead"             => 24398,
                         "baldie"               => 21460,
                         "baldman"              => 23217,
                         "baldrick"             => 9636,
                         "baldur"               => 8897,
                         "baldy"                => 10674,
                         "balefire"             => 14198,
                         "balin"                => 24292,
                         "balinor"              => 29852,
                         "ball1"                => 28115,
                         "balla"                => 15949,
                         "balla007"             => 22716,
                         "ballbag"              => 12102,
                         "balle"                => 9844,
                         "ballen"               => 12549,
                         "baller"               => 838,
                         "baller1"              => 11239,
                         "baller23"             => 17735,
                         "ballers"              => 18289,
                         "ballgag"              => 9514,
                         "ballin"               => 4018,
                         "ballon"               => 12326,
                         "balloon"              => 2261,
                         "balloon1"             => 19749,
                         "balloons"             => 2914,
                         "balls"                => 910,
                         "balls1"               => 8592,
                         "balls123"             => 23859,
                         "balls2"               => 22606,
                         "ballsack"             => 6048,
                         "ballsdeep"            => 29096,
                         "ballsout"             => 29800,
                         "ballss"               => 12384,
                         "ballz"                => 11459,
                         "baloo"                => 19477,
                         "baloo1"               => 22617,
                         "balrog"               => 7488,
                         "balsam"               => 17850,
                         "baltika"              => 9607,
                         "baltimor"             => 5119,
                         "balzac"               => 14334,
                         "bama"                 => 5946,
                         "bama1"                => 24759,
                         "bama12"               => 23250,
                         "bamba"                => 14467,
                         "bambam"               => 650,
                         "bambam1"              => 19043,
                         "bambi1"               => 22874,
                         "bambina"              => 29298,
                         "bambino"              => 8040,
                         "bamboo"               => 3498,
                         "bambou"               => 22257,
                         "bambush"              => 17680,
                         "bammer"               => 22517,
                         "banaan"               => 7756,
                         "banaan123"            => 28135,
                         "banan"                => 5107,
                         "banana"               => 143,
                         "banana1"              => 6069,
                         "banana12"             => 17101,
                         "bananana"             => 27440,
                         "bananas"              => 1439,
                         "bananas1"             => 25066,
                         "banane"               => 2873,
                         "bananna"              => 20187,
                         "bananza"              => 24344,
                         "band1t"               => 24162,
                         "bandaid"              => 16326,
                         "bandana"              => 22708,
                         "bandera"              => 11188,
                         "banderas"             => 10272,
                         "banderos"             => 21118,
                         "bandi"                => 6865,
                         "bandicoot"            => 29281,
                         "bandido"              => 21543,
                         "bandit"               => 251,
                         "bandit01"             => 19731,
                         "bandit1"              => 5485,
                         "bandit11"             => 29397,
                         "bandit12"             => 15500,
                         "bandito"              => 16302,
                         "bandman"              => 25747,
                         "bandung"              => 17169,
                         "bang"                 => 1545,
                         "bangalor"             => 28341,
                         "bangbros"             => 27183,
                         "bangbus"              => 16842,
                         "banger"               => 3884,
                         "bangers"              => 12646,
                         "bangkok"              => 1680,
                         "bangkok1"             => 14288,
                         "banjo1"               => 15413,
                         "bankai"               => 20112,
                         "banker"               => 2477,
                         "bankone"              => 19958,
                         "bankshot"             => 24190,
                         "bannana"              => 14562,
                         "banner"               => 3088,
                         "banshee"              => 1273,
                         "banshee1"             => 19135,
                         "bantam"               => 9482,
                         "bantha"               => 25991,
                         "banyan"               => 19147,
                         "banzai"               => 3244,
                         "baobab"               => 17610,
                         "bapezm"               => 21398,
                         "baphomet"             => 9271,
                         "baraban"              => 9415,
                         "barabash"             => 26290,
                         "barabbas"             => 25435,
                         "baracuda"             => 5325,
                         "barada"               => 21598,
                         "baraka"               => 7804,
                         "barakuda"             => 9005,
                         "baranov"              => 12667,
                         "baranova"             => 17827,
                         "barbados"             => 3404,
                         "barbara1"             => 7411,
                         "barbaria"             => 12952,
                         "barbarian"            => 12034,
                         "barbaris"             => 21046,
                         "barbaros"             => 17151,
                         "barbel"               => 22138,
                         "barbell"              => 20133,
                         "barbi"                => 14283,
                         "barbie"               => 816,
                         "barbie1"              => 11513,
                         "barbos"               => 12474,
                         "barbwire"             => 17579,
                         "barca"                => 10691,
                         "barcelon"             => 1438,
                         "barcelona"            => 1049,
                         "barclays"             => 15401,
                         "bareback"             => 9249,
                         "barefeet"             => 6073,
                         "barefoot"             => 2737,
                         "barfly"               => 5301,
                         "baritone"             => 4615,
                         "barkley"              => 1733,
                         "barkley1"             => 13432,
                         "barks"                => 7831,
                         "barley"               => 5133,
                         "barmalei"             => 27179,
                         "barmaley"             => 20297,
                         "barman"               => 11230,
                         "barmen"               => 29002,
                         "barnaby"              => 8915,
                         "barnaul"              => 20692,
                         "barne"                => 14737,
                         "barney"               => 154,
                         "barney01"             => 23754,
                         "barney1"              => 4638,
                         "barney11"             => 22954,
                         "barney12"             => 20030,
                         "barnie"               => 7630,
                         "barolo"               => 15683,
                         "baron1"               => 7117,
                         "baronn"               => 6648,
                         "barrabas"             => 25453,
                         "barracud"             => 8125,
                         "barracuda"            => 8492,
                         "barrage"              => 6495,
                         "barrakuda"            => 18742,
                         "barret"               => 10320,
                         "barry1"               => 5212,
                         "barrynov"             => 21302,
                         "barrys"               => 16383,
                         "barselona"            => 4416,
                         "barsic"               => 26360,
                         "barsik"               => 2235,
                         "barsoom"              => 20016,
                         "barsuk"               => 11067,
                         "bart316"              => 28650,
                         "bartek"               => 9109,
                         "bartek1"              => 21626,
                         "bartend"              => 24547,
                         "bartende"             => 12244,
                         "bartjek"              => 14933,
                         "bartman"              => 3114,
                         "bartman1"             => 18945,
                         "bartok"               => 7588,
                         "barty"                => 15472,
                         "baseba11"             => 13831,
                         "basebal"              => 4059,
                         "basebal1"             => 8308,
                         "baseball"             => 12,
                         "baseball1"            => 3187,
                         "baseball11"           => 26149,
                         "baseball12"           => 23228,
                         "baseball2"            => 16861,
                         "baseball3"            => 17731,
                         "baseball7"            => 24839,
                         "baseball9"            => 23916,
                         "basenji"              => 19227,
                         "basher"               => 7179,
                         "bashful"              => 13660,
                         "basia"                => 27247,
                         "basia1"               => 20354,
                         "basil1"               => 23120,
                         "basilisk"             => 21525,
                         "basket"               => 1065,
                         "basket1"              => 25793,
                         "basketba"             => 919,
                         "basketbal"            => 7216,
                         "basketball1"          => 24533,
                         "bassale"              => 17024,
                         "bassboat"             => 14688,
                         "basser"               => 9089,
                         "basses"               => 13067,
                         "basset"               => 3867,
                         "bassey"               => 27953,
                         "bassfish"             => 11261,
                         "basshead"             => 22061,
                         "bassie"               => 16817,
                         "bassin"               => 8026,
                         "bassingw"             => 16000,
                         "bassline"             => 12585,
                         "bassman"              => 1092,
                         "bassman1"             => 14679,
                         "bassmast"             => 14812,
                         "bassoon"              => 6927,
                         "bassplay"             => 21729,
                         "basspro"              => 18534,
                         "bassss"               => 18390,
                         "bastard"              => 532,
                         "bastard1"             => 9290,
                         "bastardo"             => 17955,
                         "baster"               => 29044,
                         "bastet"               => 7647,
                         "bastogne"             => 24822,
                         "bastos"               => 9320,
                         "basura"               => 25632,
                         "batata"               => 15953,
                         "batboy"               => 14206,
                         "batcave"              => 19320,
                         "bateau"               => 12593,
                         "batgirl"              => 8876,
                         "bathory"              => 21709,
                         "batigol"              => 9477,
                         "batistuta"            => 21791,
                         "batma"                => 8038,
                         "batman"               => 42,
                         "batman01"             => 14118,
                         "batman1"              => 1914,
                         "batman11"             => 18539,
                         "batman12"             => 6838,
                         "batman123"            => 21613,
                         "batman13"             => 23059,
                         "batman2"              => 14128,
                         "batman21"             => 24718,
                         "batman23"             => 21275,
                         "batman69"             => 12140,
                         "batman7"              => 16650,
                         "batman99"             => 11334,
                         "batmonh"              => 24864,
                         "batterie"             => 22701,
                         "batterse"             => 12968,
                         "battery1"             => 24672,
                         "battle1"              => 21891,
                         "bauhaus"              => 6011,
                         "baura"                => 6109,
                         "baxter1"              => 13630,
                         "bayadera"             => 15992,
                         "bayamon"              => 28366,
                         "bayern"               => 2626,
                         "bayern1"              => 29919,
                         "baylee"               => 7640,
                         "bayliner"             => 9167,
                         "bayshore"             => 17839,
                         "bayside"              => 13131,
                         "baytown"              => 27070,
                         "bayview"              => 11100,
                         "baywatch"             => 8532,
                         "bazongaz"             => 28192,
                         "bazooka"              => 6862,
                         "bazuka"               => 20485,
                         "bazzzz"               => 18269,
                         "bb123456"             => 18608,
                         "bb334"                => 22349,
                         "bball"                => 5096,
                         "bball1"               => 9273,
                         "bball23"              => 21939,
                         "bballs"               => 24932,
                         "bbb747"               => 12740,
                         "bbbb1"                => 23038,
                         "bbbbb1"               => 10657,
                         "bbbbbb1"              => 7667,
                         "bbbbbb99"             => 22272,
                         "bbbbbbb1"             => 13404,
                         "bbking"               => 6228,
                         "bbonds"               => 23870,
                         "bcfields"             => 3159,
                         "bcgfybz"              => 19120,
                         "bckhere"              => 22704,
                         "bcnjhbz"              => 16813,
                         "bcrich"               => 22862,
                         "bdaddy"               => 23822,
                         "bdfyeirf"             => 22973,
                         "bdfyjd"               => 6574,
                         "bdfyjdf"              => 7847,
                         "bdfysx"               => 25897,
                         "bdr529"               => 28358,
                         "bdsm"                 => 4180,
                         "beach1"               => 4928,
                         "beach69"              => 20210,
                         "beachboy"             => 14736,
                         "beachbum"             => 7769,
                         "beaches"              => 2708,
                         "beaches1"             => 19644,
                         "beachs"               => 17192,
                         "beagle"               => 1139,
                         "beagle1"              => 26387,
                         "beagles"              => 22674,
                         "beaker"               => 4851,
                         "beaks"                => 8468,
                         "beamer"               => 3047,
                         "beanbag"              => 8188,
                         "beandip"              => 17006,
                         "beaner"               => 2130,
                         "beaner1"              => 22979,
                         "beanhead"             => 24605,
                         "beanie"               => 2429,
                         "beano002"             => 28336,
                         "beantown"             => 22568,
                         "bear"                 => 316,
                         "bear01"               => 18191,
                         "bear1"                => 6401,
                         "bear101"              => 21080,
                         "bear11"               => 17900,
                         "bear12"               => 10300,
                         "bear123"              => 12156,
                         "bear13"               => 25289,
                         "bear2327"             => 23013,
                         "bear69"               => 16936,
                         "bear99"               => 21507,
                         "bearcat"              => 3249,
                         "bearcat1"             => 18119,
                         "bearcats"             => 4210,
                         "bearclaw"             => 21335,
                         "bearcub"              => 24529,
                         "beardog"              => 3919,
                         "beardog1"             => 27828,
                         "beardown"             => 21956,
                         "bearman"              => 14279,
                         "bears1"               => 6644,
                         "bears34"              => 22619,
                         "bears85"              => 13790,
                         "bearshar"             => 15239,
                         "bearshare"            => 13779,
                         "bearss"               => 26977,
                         "beast"                => 1780,
                         "beast1"               => 3030,
                         "beast123"             => 29741,
                         "beast666"             => 20270,
                         "beastie"              => 2561,
                         "beastie1"             => 24124,
                         "beasty"               => 11926,
                         "beatbox"              => 25118,
                         "beater"               => 4995,
                         "beatit"               => 14082,
                         "beatle"               => 3237,
                         "beatles"              => 381,
                         "beatles1"             => 5008,
                         "beatles4"             => 20541,
                         "beatme"               => 25124,
                         "beatoff"              => 24107,
                         "beatri"               => 15536,
                         "beaudog"              => 18398,
                         "beaut"                => 10829,
                         "beautifu"             => 2998,
                         "beautiful1"           => 15896,
                         "beauty"               => 758,
                         "beauty1"              => 10987,
                         "beaver"               => 328,
                         "beaver1"              => 11272,
                         "beaver12"             => 21741,
                         "beaver69"             => 16379,
                         "beavis"               => 317,
                         "beavis1"              => 5028,
                         "beavis69"             => 18155,
                         "bebert"               => 24237,
                         "bebeto"               => 27725,
                         "bebit"                => 15193,
                         "bebop"                => 10607,
                         "bebop1"               => 20991,
                         "becca"                => 5966,
                         "becca1"               => 13427,
                         "becket"               => 10864,
                         "beckham"              => 1667,
                         "beckham23"            => 26510,
                         "beckham7"             => 6249,
                         "becks"                => 13395,
                         "becky1"               => 7435,
                         "beckys"               => 24966,
                         "becool"               => 8047,
                         "bedbug"               => 28046,
                         "bedlam"               => 6281,
                         "bedrock"              => 7587,
                         "beebop"               => 7626,
                         "beech"                => 5165,
                         "beefcake"             => 1782,
                         "beefer"               => 22493,
                         "beefy"                => 15939,
                         "beegee"               => 17718,
                         "beegees"              => 27399,
                         "beehive"              => 14950,
                         "beejay"               => 20232,
                         "beeker"               => 8328,
                         "beelch"               => 13284,
                         "beeline"              => 7074,
                         "beemer"               => 3048,
                         "beer"                 => 409,
                         "beer1"                => 15502,
                         "beer12"               => 20490,
                         "beer1234"             => 23934,
                         "beer30"               => 18892,
                         "beer4me"              => 21898,
                         "beer69"               => 23936,
                         "beerbong"             => 17655,
                         "beercan"              => 17344,
                         "beerman"              => 3937,
                         "beerme"               => 6841,
                         "beernuts"             => 19006,
                         "beerss"               => 26460,
                         "beertje"              => 15078,
                         "beethove"             => 5507,
                         "beetle"               => 1160,
                         "beetle1"              => 16619,
                         "beezer"               => 5080,
                         "befree"               => 17570,
                         "begemot"              => 5851,
                         "begemotik"            => 27963,
                         "begonia"              => 21411,
                         "begood"               => 10492,
                         "behappy"              => 5302,
                         "behemoth"             => 9407,
                         "beholder"             => 17781,
                         "belair"               => 6529,
                         "belgario"             => 16941,
                         "belgorod"             => 19240,
                         "belial"               => 14990,
                         "belinda1"             => 25259,
                         "belinea"              => 6513,
                         "belize"               => 7171,
                         "belkin"               => 6061,
                         "bell1"                => 26946,
                         "bella1"               => 3082,
                         "bella123"             => 11325,
                         "bellaboo"             => 22359,
                         "bellaco"              => 6382,
                         "belladog"             => 23263,
                         "belladon"             => 18970,
                         "bellagio"             => 6221,
                         "bellas"               => 17034,
                         "belle1"               => 7935,
                         "bellend"              => 28338,
                         "bellevue"             => 10857,
                         "bellsout"             => 16660,
                         "belluno"              => 26484,
                         "belly1"               => 23891,
                         "bellybut"             => 25477,
                         "belmar"               => 19654,
                         "belmont"              => 4361,
                         "belo4ka"              => 22780,
                         "belochka"             => 11377,
                         "beloit"               => 19163,
                         "belous"               => 21689,
                         "belova"               => 16361,
                         "beloved1"             => 25807,
                         "beluga"               => 9954,
                         "ben123"               => 8604,
                         "ben1234"              => 25308,
                         "bendis"               => 25482,
                         "bendix"               => 25333,
                         "bendog"               => 22735,
                         "bendover"             => 5941,
                         "benedikt"             => 14086,
                         "benelli"              => 21442,
                         "benessere"            => 5563,
                         "benetton"             => 18347,
                         "benfic"               => 16678,
                         "benfica"              => 2944,
                         "beng"                 => 3810,
                         "bengals"              => 2791,
                         "bengals1"             => 21584,
                         "benhogan"             => 22720,
                         "benhur"               => 15723,
                         "benidorm"             => 21234,
                         "benjami"              => 5938,
                         "benjamin1"            => 15566,
                         "benji"                => 6507,
                         "benji1"               => 11616,
                         "benjie"               => 13193,
                         "benladen"             => 15540,
                         "bennett1"             => 10724,
                         "bennevis"             => 22497,
                         "benno"                => 28579,
                         "benny1"               => 5846,
                         "bennyboy"             => 15765,
                         "bensam"               => 23586,
                         "benson1"              => 14741,
                         "bentley1"             => 12472,
                         "benwin"               => 25319,
                         "beograd"              => 17886,
                         "beowulf"              => 3008,
                         "ber02"                => 15469,
                         "berbatov"             => 17469,
                         "beretta"              => 2687,
                         "bereza"               => 9923,
                         "berezuckiy"           => 17828,
                         "bergen09"             => 29124,
                         "berger1"              => 27627,
                         "bergerac"             => 16470,
                         "bergkamp"             => 3953,
                         "berkut"               => 9284,
                         "berli"                => 19647,
                         "berlin"               => 659,
                         "berlin1"              => 17741,
                         "berliner"             => 11564,
                         "berlingo"             => 26895,
                         "berlit"               => 16803,
                         "bermuda1"             => 25040,
                         "bernadet"             => 17190,
                         "bernar"               => 19114,
                         "bernard1"             => 10808,
                         "bernhard"             => 7103,
                         "berni"                => 27732,
                         "bernie1"              => 20305,
                         "berry1"               => 24154,
                         "berserk"              => 7421,
                         "berserke"             => 13810,
                         "berserker"            => 13018,
                         "bertha1"              => 19703,
                         "bertie1"              => 27563,
                         "bertuzzi"             => 27962,
                         "berty75"              => 18928,
                         "besiktas"             => 9586,
                         "bespin"               => 26045,
                         "bestboy"              => 23148,
                         "bestbuy"              => 4543,
                         "bestfriend"           => 11357,
                         "bestia"               => 18785,
                         "beszoptad"            => 12743,
                         "beta1"                => 22823,
                         "bethan"               => 9589,
                         "bethany1"             => 12253,
                         "betmen"               => 25839,
                         "betsy1"               => 16871,
                         "better1"              => 28020,
                         "bettis36"             => 24413,
                         "betty1"               => 7839,
                         "bettyboo"             => 5603,
                         "bettyboop"            => 7091,
                         "bettylou"             => 20475,
                         "beverl"               => 22621,
                         "beverly1"             => 24156,
                         "beyblade"             => 28844,
                         "beyonce"              => 7306,
                         "bftest"               => 29095,
                         "bg6njokf"             => 28601,
                         "bh90210"              => 12888,
                         "bharat"               => 11389,
                         "bhavani"              => 21160,
                         "bhbcrf"               => 7765,
                         "bhbirf"               => 3035,
                         "bhbyf"                => 16736,
                         "bhbyjxrf"             => 19519,
                         "bhbyrf"               => 8164,
                         "bhecbr"               => 28100,
                         "bhjxrf"               => 8418,
                         "bian"                 => 3791,
                         "bianc"                => 17553,
                         "biao"                 => 3871,
                         "biarritz"             => 22223,
                         "biatch"               => 4442,
                         "bibble"               => 18958,
                         "bibigon"              => 27611,
                         "biceps"               => 9201,
                         "bicho"                => 23187,
                         "bichon"               => 18769,
                         "bicycle"              => 1976,
                         "bidule"               => 27658,
                         "biedronka"            => 24946,
                         "biene"                => 27100,
                         "biffer"               => 16835,
                         "big1"                 => 6816,
                         "big123"               => 10288,
                         "bigair"               => 16911,
                         "bigal"                => 6256,
                         "bigal1"               => 12955,
                         "bigal37"              => 22545,
                         "bigals"               => 24624,
                         "bigass"               => 2740,
                         "bigasses"             => 27460,
                         "bigbaby"              => 13218,
                         "bigbad"               => 8937,
                         "bigball"              => 21854,
                         "bigballa"             => 24093,
                         "bigballs"             => 1556,
                         "bigbang"              => 4714,
                         "bigbass"              => 12869,
                         "bigbear"              => 2481,
                         "bigben"               => 3913,
                         "bigberth"             => 27833,
                         "bigbill"              => 12161,
                         "bigbird"              => 2084,
                         "bigbird1"             => 23995,
                         "bigblack"             => 6172,
                         "bigblock"             => 4043,
                         "bigblue"              => 3471,
                         "bigblue1"             => 21578,
                         "bigbo"                => 21510,
                         "bigbob"               => 4179,
                         "bigboi"               => 10973,
                         "bigbone"              => 25330,
                         "bigboner"             => 23652,
                         "bigboob"              => 15321,
                         "bigboobs"             => 978,
                         "bigbooty"             => 4787,
                         "bigboss"              => 3861,
                         "bigboy"               => 341,
                         "bigboy1"              => 7854,
                         "bigboy11"             => 26877,
                         "bigboy12"             => 19192,
                         "bigboys"              => 24735,
                         "bigbri"               => 25657,
                         "bigbro"               => 21062,
                         "bigbroth"             => 23076,
                         "bigbubba"             => 25715,
                         "bigbuck"              => 11919,
                         "bigbucks"             => 6691,
                         "bigbull"              => 27718,
                         "bigbutt"              => 3130,
                         "bigbutts"             => 8199,
                         "bigcat"               => 3783,
                         "bigchief"             => 18286,
                         "bigcock"              => 671,
                         "bigcocks"             => 12463,
                         "bigd"                 => 6720,
                         "bigdad"               => 7250,
                         "bigdadd"              => 14808,
                         "bigdaddy"             => 164,
                         "bigdaddy1"            => 16364,
                         "bigdan"               => 14726,
                         "bigdave"              => 9203,
                         "bigdawg"              => 4642,
                         "bigdeal"              => 13672,
                         "bigdee"               => 10970,
                         "bigdic"               => 15216,
                         "bigdick"              => 174,
                         "bigdick1"             => 6576,
                         "bigdicks"             => 5170,
                         "bigdo"                => 19544,
                         "bigdog"               => 101,
                         "bigdog1"              => 5409,
                         "bigdog69"             => 15375,
                         "bigdogg"              => 9938,
                         "bigdogs"              => 14813,
                         "bigdon"               => 28612,
                         "bigdong"              => 23987,
                         "bigears"              => 20908,
                         "bigeasy"              => 21344,
                         "biged"                => 22549,
                         "bigfan"               => 18225,
                         "bigfeet"              => 21785,
                         "bigfella"             => 16075,
                         "bigfish"              => 3520,
                         "bigfoo"               => 26765,
                         "bigfoot"              => 969,
                         "bigfoot1"             => 10008,
                         "bigfun"               => 14921,
                         "biggame"              => 28220,
                         "biggdogg"             => 9889,
                         "biggi"                => 20983,
                         "biggie"               => 1266,
                         "biggin"               => 11108,
                         "biggio"               => 22214,
                         "biggirl"              => 7811,
                         "biggirls"             => 13996,
                         "biggles"              => 2716,
                         "biggreen"             => 17114,
                         "biggums"              => 25804,
                         "biggun"               => 5206,
                         "bigguns"              => 5366,
                         "biggus"               => 26769,
                         "bigguy"               => 1396,
                         "bigguy1"              => 29492,
                         "biggy"                => 11287,
                         "bighead"              => 4368,
                         "bighorn"              => 17793,
                         "bighouse"             => 18382,
                         "bighurt"              => 14678,
                         "bigjake"              => 25817,
                         "bigjay"               => 16726,
                         "bigjim"               => 6894,
                         "bigjoe"               => 7317,
                         "bigjohn"              => 5494,
                         "bigjohn1"             => 28909,
                         "bigjon"               => 18411,
                         "bigjuggs"             => 28124,
                         "bigkev"               => 26871,
                         "bigload"              => 14327,
                         "bigloser"             => 23494,
                         "biglou"               => 20964,
                         "biglove"              => 19230,
                         "bigmac"               => 763,
                         "bigmac1"              => 16812,
                         "bigmack"              => 21633,
                         "bigmama"              => 8178,
                         "bigman"               => 680,
                         "bigman1"              => 15282,
                         "bigman2"              => 16322,
                         "bigmax"               => 28733,
                         "bigmaxxx"             => 21850,
                         "bigmike"              => 2950,
                         "bigmoney"             => 2044,
                         "bigmouth"             => 24309,
                         "bignasty"             => 8690,
                         "bignose"              => 15295,
                         "bignuts"              => 7713,
                         "bigone"               => 962,
                         "bigones"              => 4613,
                         "bigpapa"              => 9833,
                         "bigpappa"             => 21013,
                         "bigpenis"             => 7448,
                         "bigpig"               => 15629,
                         "bigpimp"              => 4491,
                         "bigpimpi"             => 9867,
                         "bigpimpin"            => 13722,
                         "bigpoppa"             => 4460,
                         "bigpun"               => 8566,
                         "bigpussy"             => 8168,
                         "bigred"               => 549,
                         "bigred1"              => 6906,
                         "bigrick"              => 27957,
                         "bigrig"               => 26961,
                         "bigrob"               => 16306,
                         "bigsam"               => 26968,
                         "bigsexxy"             => 23335,
                         "bigsexy"              => 2213,
                         "bigsexy1"             => 22254,
                         "bigshot"              => 10592,
                         "bigshow"              => 7928,
                         "bigsky"               => 11314,
                         "bigsmall"             => 27945,
                         "bigstick"             => 9760,
                         "bigstud"              => 18517,
                         "bigstuff"             => 18071,
                         "bigsur"               => 21792,
                         "bigted"               => 23520,
                         "bigtee"               => 28583,
                         "bigten"               => 13741,
                         "bigtex"               => 24840,
                         "bigtim"               => 26063,
                         "bigtime"              => 2081,
                         "bigtime1"             => 18636,
                         "bigtit"               => 3280,
                         "bigtits"              => 202,
                         "bigtits1"             => 12480,
                         "bigtitts"             => 15162,
                         "bigtitty"             => 25150,
                         "bigtoe"               => 9362,
                         "bigtom"               => 21015,
                         "bigtop"               => 20959,
                         "bigtruck"             => 5810,
                         "bigtuna"              => 28406,
                         "bigtymer"             => 13498,
                         "bigun"                => 22476,
                         "biguns"               => 7076,
                         "bigwave"              => 19811,
                         "bigwaves"             => 27949,
                         "bigwig"               => 21439,
                         "bigwill"              => 18520,
                         "bigwilly"             => 11472,
                         "bigworm"              => 7166,
                         "biit"                 => 5700,
                         "bijoux"               => 25284,
                         "biker"                => 4500,
                         "biker1"               => 7696,
                         "bikerboy"             => 15424,
                         "bikers"               => 6505,
                         "bikini"               => 2061,
                         "bikman"               => 23233,
                         "bilbo"                => 3181,
                         "bilbo1"               => 8310,
                         "bilbob"               => 20861,
                         "bilbobag"             => 21980,
                         "bilbos"               => 23805,
                         "bilder"               => 16157,
                         "bill1"                => 10413,
                         "bill123"              => 15969,
                         "bill1234"             => 19972,
                         "bill2"                => 21918,
                         "bill99"               => 20411,
                         "billabon"             => 5246,
                         "billabong"            => 7233,
                         "billard"              => 17107,
                         "billbo"               => 18008,
                         "billbob"              => 22528,
                         "billee"               => 23588,
                         "billet"               => 22233,
                         "billgate"             => 16822,
                         "billgates"            => 18610,
                         "billiam"              => 20951,
                         "billiard"             => 9301,
                         "billly"               => 26183,
                         "billows"              => 7516,
                         "bills1"               => 19480,
                         "billy1"               => 2086,
                         "billy123"             => 11691,
                         "billy2"               => 18916,
                         "billy5"               => 25478,
                         "billyb"               => 9961,
                         "billybo"              => 16800,
                         "billybob"             => 721,
                         "billyboy"             => 1996,
                         "billyd"               => 15009,
                         "billyg"               => 23286,
                         "billygoa"             => 20821,
                         "billyjoe"             => 12274,
                         "billyk"               => 22347,
                         "billyray"             => 18807,
                         "billys"               => 10273,
                         "bimbo"                => 5017,
                         "bimbo1"               => 23710,
                         "bimbo38"              => 22837,
                         "bimini"               => 14497,
                         "bimmer"               => 2660,
                         "bimota"               => 18439,
                         "bing"                 => 2704,
                         "bingbong"             => 14865,
                         "binger"               => 11520,
                         "bingo"                => 1465,
                         "bingo1"               => 3248,
                         "bingo123"             => 14597,
                         "bingoo"               => 18447,
                         "bingos"               => 10069,
                         "binkie"               => 11783,
                         "binky"                => 7286,
                         "binky1"               => 14465,
                         "binladen"             => 3336,
                         "bintang"              => 16966,
                         "biochem"              => 14639,
                         "biohazar"             => 15905,
                         "biohazard"            => 6227,
                         "biolog"               => 29206,
                         "biomed"               => 16994,
                         "bionic"               => 7095,
                         "bionicle"             => 6941,
                         "bioshock"             => 19376,
                         "biotch"               => 12554,
                         "biotech"              => 11996,
                         "bird33"               => 3650,
                         "birdbath"             => 27333,
                         "birdcage"             => 23940,
                         "birddog"              => 4322,
                         "birder"               => 23407,
                         "birdhouse"            => 15285,
                         "birdie"               => 400,
                         "birdie1"              => 9861,
                         "birdies"              => 13834,
                         "birdland"             => 15511,
                         "birdman"              => 1596,
                         "birdman1"             => 19491,
                         "birdy"                => 10717,
                         "birillo"              => 17694,
                         "birmingh"             => 17089,
                         "birthday1"            => 9719,
                         "birthday10"           => 20870,
                         "birthday100"          => 22889,
                         "birthday2"            => 25876,
                         "birthday21"           => 11603,
                         "birthday26"           => 27299,
                         "birthday27"           => 29899,
                         "birthday28"           => 29413,
                         "birthday299"          => 15582,
                         "birthday3"            => 18030,
                         "birthday4"            => 8011,
                         "birthday5"            => 17349,
                         "birthday54"           => 14362,
                         "birthday6"            => 21267,
                         "biscayne"             => 16141,
                         "biscuit"              => 1238,
                         "biscuit1"             => 11460,
                         "bisexual"             => 6472,
                         "bishkek"              => 27515,
                         "bishop1"              => 12961,
                         "biskit"               => 16247,
                         "bismarck"             => 5495,
                         "bismark"              => 5817,
                         "bismilah"             => 28700,
                         "bismilla"             => 6564,
                         "bismillah"            => 4459,
                         "bisous"               => 28487,
                         "bisquit"              => 27316,
                         "bissjop"              => 21591,
                         "bitch"                => 204,
                         "bitch1"               => 1959,
                         "bitch123"             => 13020,
                         "bitch2"               => 29146,
                         "bitch69"              => 14095,
                         "bitchass"             => 3086,
                         "bitchboy"             => 19400,
                         "bitche"               => 21327,
                         "bitchedu"             => 17921,
                         "bitchedup"            => 17300,
                         "bitches"              => 451,
                         "bitches1"             => 16917,
                         "bitchs"               => 7654,
                         "bitchy"               => 4619,
                         "bitem"                => 18721,
                         "biteme"               => 72,
                         "biteme1"              => 4884,
                         "biteme12"             => 17011,
                         "biteme2"              => 14590,
                         "biteme69"             => 11289,
                         "bitter1"              => 29564,
                         "bitwise"              => 29694,
                         "bizkit"               => 2092,
                         "bizzare"              => 6440,
                         "bjarne"               => 21732,
                         "bjhgfi"               => 17222,
                         "bk.irf"               => 26764,
                         "bkmlfh"               => 21771,
                         "bkmyeh"               => 29652,
                         "blaat"                => 27456,
                         "blabl"                => 18258,
                         "blabla"               => 1039,
                         "blablabl"             => 11337,
                         "black1"               => 1279,
                         "black10"              => 28223,
                         "black12"              => 11906,
                         "black123"             => 8930,
                         "black13"              => 16206,
                         "black2"               => 10478,
                         "black22"              => 20736,
                         "black23"              => 24263,
                         "black3"               => 19383,
                         "black5"               => 28692,
                         "black666"             => 22885,
                         "black9"               => 24354,
                         "blackadd"             => 14683,
                         "blackass"             => 8442,
                         "blackb"               => 27710,
                         "blackbea"             => 13050,
                         "blackbel"             => 8574,
                         "blackbelt"            => 7919,
                         "blackber"             => 11206,
                         "blackberry"           => 6279,
                         "blackbir"             => 2949,
                         "blackbird"            => 5298,
                         "blackboo"             => 28316,
                         "blackbox"             => 12032,
                         "blackboy"             => 8465,
                         "blackbur"             => 14785,
                         "blackcat"             => 1253,
                         "blackcoc"             => 8461,
                         "blackcock"            => 8066,
                         "blackdic"             => 19609,
                         "blackdick"            => 20729,
                         "blackdog"             => 1371,
                         "blackdra"             => 28410,
                         "blackdragon"          => 29636,
                         "blackeye"             => 15657,
                         "blackfin"             => 23644,
                         "blackfly"             => 22811,
                         "blackhat"             => 25242,
                         "blackhaw"             => 2420,
                         "blackhawk"            => 6171,
                         "blackhea"             => 23806,
                         "blackheart"           => 23642,
                         "blackhol"             => 13567,
                         "blackhole"            => 22159,
                         "blackhorse"           => 26634,
                         "blackice"             => 6864,
                         "blackie"              => 1077,
                         "blackie1"             => 9131,
                         "blackjac"             => 1679,
                         "blackjack"            => 2965,
                         "blacklab"             => 5681,
                         "blackmag"             => 16290,
                         "blackmen"             => 15323,
                         "blackmetal"           => 22714,
                         "blackmor"             => 25286,
                         "blackone"             => 20229,
                         "blackops"             => 6765,
                         "blackout"             => 3145,
                         "blackpoo"             => 16884,
                         "blackpus"             => 29352,
                         "blackros"             => 24457,
                         "blackrose"            => 11141,
                         "blacks"               => 1799,
                         "blacksab"             => 22440,
                         "blacksex"             => 17848,
                         "blackshe"             => 11764,
                         "blacksta"             => 11502,
                         "blackstar"            => 21421,
                         "blacksun"             => 10050,
                         "blacktop"             => 11945,
                         "blackwhite"           => 24069,
                         "blackwid"             => 29598,
                         "blackwoo"             => 27004,
                         "blacky"               => 1675,
                         "blade"                => 1449,
                         "blade1"               => 6645,
                         "blade123"             => 18366,
                         "blade2"               => 9976,
                         "blade55"              => 27719,
                         "blademan"             => 26990,
                         "blader"               => 13904,
                         "bladerun"             => 12603,
                         "bladerunner"          => 9440,
                         "blades"               => 1294,
                         "bladez"               => 25291,
                         "blah123"              => 18646,
                         "blahblah"             => 951,
                         "blair1"               => 19672,
                         "blaise"               => 8766,
                         "blake1"               => 5517,
                         "blam"                 => 4178,
                         "blank1"               => 27991,
                         "blanka"               => 20611,
                         "blanked"              => 7545,
                         "blankman"             => 25327,
                         "blargh"               => 23277,
                         "blarney"              => 16893,
                         "blasen"               => 14317,
                         "blaster"              => 940,
                         "blaster1"             => 8205,
                         "blasters"             => 21477,
                         "blastoff"             => 10217,
                         "blaze"                => 3355,
                         "blaze1"               => 7016,
                         "blaze420"             => 29556,
                         "blazed"               => 13301,
                         "blazer"               => 354,
                         "blazer1"              => 12180,
                         "blazers"              => 6309,
                         "blazin"               => 10220,
                         "bleach"               => 5326,
                         "bleacher"             => 27281,
                         "blender"              => 7043,
                         "blenheim"             => 14911,
                         "blesse"               => 16793,
                         "blessed"              => 1150,
                         "blessed1"             => 7565,
                         "blessing"             => 2743,
                         "blessme"              => 18973,
                         "blessyou"             => 25255,
                         "blind1"               => 16611,
                         "blindax"              => 9020,
                         "blindman"             => 22955,
                         "blingbli"             => 17175,
                         "blingbling"           => 10239,
                         "blink1"               => 21347,
                         "blink18"              => 9573,
                         "blink182"             => 334,
                         "blinker"              => 17410,
                         "blinky"               => 6058,
                         "bliss1"               => 27695,
                         "bliss7"               => 23856,
                         "blister"              => 11138,
                         "blitz"                => 5839,
                         "blitz1"               => 16503,
                         "blitzen"              => 19638,
                         "blizzard"             => 689,
                         "blobby"               => 5757,
                         "blockbus"             => 26689,
                         "bloembol"             => 21876,
                         "blofeld"              => 25193,
                         "bloke"                => 7002,
                         "blome"                => 27400,
                         "blonde"               => 793,
                         "blonde1"              => 20047,
                         "blondes"              => 1601,
                         "blondi"               => 10484,
                         "blondie"              => 948,
                         "blondie1"             => 8600,
                         "blondinka"            => 7688,
                         "blonds"               => 6377,
                         "blondy"               => 8614,
                         "blood1"               => 12550,
                         "blood123"             => 16894,
                         "blood666"             => 24227,
                         "bloodlus"             => 23372,
                         "bloodlust"            => 29295,
                         "bloodred"             => 27331,
                         "bloods"               => 7849,
                         "bloody1"              => 26537,
                         "bloomin"              => 9887,
                         "bloopers"             => 8730,
                         "blotto"               => 17788,
                         "blower"               => 8712,
                         "blowfish"             => 4648,
                         "blowj"                => 27314,
                         "blowjo"               => 19852,
                         "blowjob"              => 214,
                         "blowjob1"             => 16654,
                         "blowjob69"            => 28884,
                         "blowjobs"             => 9895,
                         "blowme"               => 200,
                         "blowme1"              => 8806,
                         "blowme2"              => 26139,
                         "blowme69"             => 13826,
                         "bltynbabrfwbz"        => 25274,
                         "blubber"              => 5691,
                         "blucher"              => 17423,
                         "blue"                 => 260,
                         "blue00"               => 22241,
                         "blue01"               => 11849,
                         "blue02"               => 19144,
                         "blue1"                => 6626,
                         "blue10"               => 25210,
                         "blue11"               => 5831,
                         "blue12"               => 3648,
                         "blue123"              => 1345,
                         "blue1234"             => 5037,
                         "blue13"               => 11266,
                         "blue135"              => 26528,
                         "blue14"               => 22655,
                         "blue15"               => 21466,
                         "blue2"                => 15024,
                         "blue2000"             => 19853,
                         "blue21"               => 10804,
                         "blue22"               => 1137,
                         "blue23"               => 5786,
                         "blue24"               => 26256,
                         "blue25"               => 13767,
                         "blue28"               => 23568,
                         "blue30"               => 28304,
                         "blue32"               => 4842,
                         "blue33"               => 10792,
                         "blue42"               => 5553,
                         "blue44"               => 8579,
                         "blue45"               => 10056,
                         "blue52"               => 17600,
                         "blue55"               => 11351,
                         "blue56"               => 13639,
                         "blue66"               => 14598,
                         "blue69"               => 9631,
                         "blue72"               => 26827,
                         "blue77"               => 15588,
                         "blue88"               => 16495,
                         "blue92"               => 25982,
                         "blue99"               => 5018,
                         "bluearmy"             => 11496,
                         "blueball"             => 4737,
                         "blueballs"            => 16263,
                         "bluebear"             => 9550,
                         "bluebell"             => 4061,
                         "blueberr"             => 5996,
                         "bluebird"             => 806,
                         "blueboy"              => 2490,
                         "blueboys"             => 29421,
                         "bluecar"              => 17775,
                         "bluecat"              => 13566,
                         "bluedevi"             => 9138,
                         "bluedevil"            => 27645,
                         "bluedevils"           => 21270,
                         "bluedog"              => 2566,
                         "bluedog1"             => 27820,
                         "bluedragon"           => 23315,
                         "blueduck"             => 14534,
                         "blueeyes"             => 1560,
                         "bluefin"              => 12121,
                         "bluefire"             => 20063,
                         "bluefish"             => 3203,
                         "bluefox"              => 15557,
                         "bluegill"             => 10034,
                         "bluegras"             => 12083,
                         "blueice"              => 15829,
                         "bluejay"              => 6040,
                         "bluejay1"             => 29815,
                         "bluejays"             => 4947,
                         "bluejean"             => 17170,
                         "bluelight"            => 29446,
                         "blueline"             => 10122,
                         "blueman"              => 8685,
                         "bluemax"              => 11623,
                         "bluemoon"             => 1154,
                         "bluenose"             => 7757,
                         "bluenote"             => 10005,
                         "blueone"              => 23356,
                         "bluered"              => 14390,
                         "blueroom"             => 28830,
                         "bluerose"             => 11404,
                         "blues"                => 1346,
                         "blues1"               => 4294,
                         "blues2"               => 27852,
                         "bluesea"              => 21002,
                         "blueskie"             => 22378,
                         "bluesky"              => 1126,
                         "bluesky1"             => 22745,
                         "bluesman"             => 4307,
                         "bluess"               => 13582,
                         "bluestar"             => 6501,
                         "bluetick"             => 20645,
                         "bluewate"             => 29418,
                         "bluewave"             => 25808,
                         "blueyes"              => 12790,
                         "blumen"               => 17122,
                         "blumpkin"             => 27881,
                         "blunt1"               => 29622,
                         "blunt420"             => 16751,
                         "blunted"              => 8531,
                         "blunts"               => 5336,
                         "bmw123"               => 11312,
                         "bmw2002"              => 7108,
                         "bmw316"               => 19307,
                         "bmw318"               => 6984,
                         "bmw318i"              => 18712,
                         "bmw318is"             => 22097,
                         "bmw320"               => 8733,
                         "bmw320i"              => 20617,
                         "bmw323"               => 15908,
                         "bmw325"               => 4283,
                         "bmw325i"              => 11476,
                         "bmw325is"             => 15247,
                         "bmw328"               => 25725,
                         "bmw328i"              => 25422,
                         "bmw330"               => 14451,
                         "bmw330ci"             => 15837,
                         "bmw520"               => 14876,
                         "bmw525"               => 9168,
                         "bmw528"               => 25200,
                         "bmw530"               => 16697,
                         "bmw535"               => 18319,
                         "bmw540"               => 14361,
                         "bmw540i"              => 29167,
                         "bmw750"               => 25546,
                         "bmw750il"             => 23194,
                         "bmwm3"                => 11096,
                         "bnfkbz"               => 18754,
                         "bnm123"               => 23330,
                         "bo243ns"              => 20560,
                         "boarder"              => 8110,
                         "boater"               => 4920,
                         "boating"              => 4338,
                         "boating1"             => 28644,
                         "boats1"               => 19436,
                         "bob007"               => 22354,
                         "bob101"               => 16118,
                         "bob111"               => 26096,
                         "bob123"               => 2446,
                         "bob1234"              => 13910,
                         "bob12345"             => 16809,
                         "bob2000"              => 20639,
                         "bob666"               => 15925,
                         "bob69"                => 27698,
                         "bobafett"             => 761,
                         "bobbbb"               => 17133,
                         "bobber"               => 8573,
                         "bobbijo"              => 13561,
                         "bobbin"               => 17654,
                         "bobbins"              => 12124,
                         "bobble"               => 14944,
                         "bobbo"                => 11293,
                         "bobbob1"              => 22422,
                         "bobbobbo"             => 29358,
                         "bobby1"               => 2224,
                         "bobby12"              => 23789,
                         "bobby123"             => 11035,
                         "bobby18"              => 27782,
                         "bobby2"               => 16808,
                         "bobbyb"               => 16137,
                         "bobbybob"             => 27547,
                         "bobbyboy"             => 16101,
                         "bobbyd"               => 14091,
                         "bobbyg"               => 15177,
                         "bobbyj"               => 23345,
                         "bobbyjoe"             => 24660,
                         "bobbym"               => 18802,
                         "bobbyorr"             => 29097,
                         "bobbys"               => 8510,
                         "bobbyt"               => 25146,
                         "bobbyy"               => 11991,
                         "bobcat"               => 862,
                         "bobcat1"              => 26490,
                         "bobcat12"             => 25540,
                         "bobcats"              => 8398,
                         "bobdog"               => 11290,
                         "bobdole"              => 4448,
                         "bobdylan"             => 3368,
                         "bobert"               => 8071,
                         "bobjones"             => 28063,
                         "bobmarle"             => 8105,
                         "bobmarley"            => 6002,
                         "bobo1"                => 27799,
                         "bobo12"               => 29350,
                         "bobo123"              => 24951,
                         "bobo1234"             => 29356,
                         "bobob"                => 29357,
                         "bobolink"             => 24956,
                         "bobrik"               => 24599,
                         "bobrov"               => 26019,
                         "bobsmith"             => 29288,
                         "bobster"              => 18891,
                         "bocephus"             => 11224,
                         "bochum"               => 11809,
                         "bocman"               => 26861,
                         "bodean"               => 27760,
                         "bodger"               => 18506,
                         "bodiroga"             => 24850,
                         "bodybuil"             => 28217,
                         "bodyhamm"             => 18193,
                         "bodyshop"             => 13586,
                         "boeder"               => 13437,
                         "boeing"               => 1227,
                         "boeing1"              => 19887,
                         "boeing74"             => 13892,
                         "boeing77"             => 21629,
                         "bogart"               => 2149,
                         "bogdan"               => 1919,
                         "bogdan123"            => 20562,
                         "bogdana"              => 20429,
                         "bogdanova"            => 25078,
                         "bogey"                => 2700,
                         "bogey1"               => 10957,
                         "bogeys"               => 24441,
                         "boggie"               => 9674,
                         "boggle"               => 10779,
                         "bogie"                => 10203,
                         "bogies"               => 17976,
                         "bogomol"              => 24283,
                         "bogos"                => 21635,
                         "bogota"               => 6890,
                         "bogus1"               => 14523,
                         "bohica"               => 1818,
                         "boiler"               => 4305,
                         "boilerma"             => 28181,
                         "boing"                => 11149,
                         "boing747"             => 26266,
                         "boingo"               => 7430,
                         "bojangle"             => 16399,
                         "bokser"               => 26144,
                         "bolat"                => 29228,
                         "bolero"               => 8332,
                         "bolita"               => 22878,
                         "bolitas"              => 4587,
                         "boliva"               => 8852,
                         "bolivi"               => 7347,
                         "bollix"               => 22822,
                         "bollock"              => 12831,
                         "bollocks"             => 434,
                         "bollox"               => 1517,
                         "bologna"              => 4224,
                         "bologna1"             => 17785,
                         "boloto"               => 18431,
                         "boludo"               => 20812,
                         "bomba"                => 13583,
                         "bombadil"             => 22625,
                         "bombay"               => 3802,
                         "bomber"               => 1097,
                         "bomber1"              => 13531,
                         "bomberman"            => 27848,
                         "bombero"              => 23491,
                         "bombers"              => 3702,
                         "bombo"                => 19906,
                         "bombshel"             => 20695,
                         "bommel"               => 12080,
                         "bonaire"              => 27003,
                         "bonanza"              => 5151,
                         "bonapart"             => 24733,
                         "bond00"               => 23627,
                         "bond0007"             => 23353,
                         "bond007"              => 278,
                         "bond9007"             => 28855,
                         "bondage"              => 707,
                         "bondage1"             => 12506,
                         "bondar"               => 17095,
                         "bondarenko"           => 8988,
                         "bondra12"             => 26439,
                         "bonds25"              => 16449,
                         "bone1"                => 22227,
                         "bonefish"             => 10210,
                         "bonehead"             => 1189,
                         "boneman"              => 20994,
                         "boner"                => 1736,
                         "boner1"               => 10632,
                         "boner69"              => 22595,
                         "boners"               => 6491,
                         "bones"                => 1646,
                         "bones1"               => 9397,
                         "bones69"              => 10616,
                         "boness"               => 12169,
                         "bonethug"             => 8079,
                         "bonethugs"            => 22187,
                         "boneyard"             => 20702,
                         "bonghit"              => 7177,
                         "bonghits"             => 9257,
                         "bongo"                => 5128,
                         "bongo1"               => 15435,
                         "bongos"               => 12565,
                         "bongtoke"             => 29969,
                         "bongwater"            => 29448,
                         "bonit"                => 14711,
                         "bonita1"              => 29192,
                         "bonito"               => 10511,
                         "bonjou"               => 12211,
                         "bonjour"              => 1501,
                         "bonjour1"             => 20368,
                         "bonjovi"              => 3359,
                         "bonker"               => 28000,
                         "bonkers"              => 2567,
                         "bonkers1"             => 25890,
                         "bonni"                => 21125,
                         "bonnie1"              => 8081,
                         "bonobo"               => 14655,
                         "bonoedge"             => 20531,
                         "bonou2"               => 14744,
                         "bonovox"              => 6445,
                         "bonsai"               => 2258,
                         "bonscott"             => 21356,
                         "bonzai"               => 7261,
                         "bonzo"                => 8546,
                         "bonzo1"               => 19877,
                         "boob"                 => 2204,
                         "boobear"              => 5902,
                         "boobear1"             => 29114,
                         "boobed"               => 8803,
                         "boober"               => 9123,
                         "boobie"               => 2834,
                         "boobies"              => 449,
                         "boobies1"             => 14889,
                         "boobies2"             => 27228,
                         "boobis"               => 17283,
                         "boobless"             => 22438,
                         "boobman"              => 17180,
                         "boobo"                => 12680,
                         "booboo"               => 124,
                         "booboo1"              => 6846,
                         "booboo11"             => 25328,
                         "booboo12"             => 19688,
                         "booboo2"              => 26687,
                         "booboo69"             => 20581,
                         "boobs"                => 481,
                         "boobs1"               => 10232,
                         "boobs69"              => 26462,
                         "boobss"               => 20982,
                         "boobys"               => 21647,
                         "boochie"              => 26488,
                         "boodie"               => 28296,
                         "boodle"               => 22552,
                         "boodog"               => 13968,
                         "boofer"               => 28658,
                         "booga"                => 18493,
                         "boogaloo"             => 8666,
                         "booger"               => 244,
                         "booger1"              => 6603,
                         "boogers"              => 7315,
                         "boogie"               => 585,
                         "boogie1"              => 10902,
                         "boogiema"             => 23334,
                         "boogle"               => 26730,
                         "boognish"             => 24074,
                         "boogyman"             => 29180,
                         "boohoo"               => 7888,
                         "bookcase"             => 8481,
                         "bookert"              => 20515,
                         "bookie"               => 4746,
                         "bookmark"             => 11872,
                         "bookworm"             => 2961,
                         "booman"               => 21628,
                         "boomba"               => 29169,
                         "boomboom"             => 2581,
                         "boombox"              => 19607,
                         "boome"                => 13944,
                         "boomer"               => 119,
                         "boomer1"              => 4185,
                         "boomer12"             => 29416,
                         "boomer22"             => 29594,
                         "boomers"              => 24623,
                         "boomtown"             => 16946,
                         "boondock"             => 11592,
                         "booner"               => 11952,
                         "boonie"               => 17031,
                         "booom"                => 23054,
                         "boop4"                => 29696,
                         "booper"               => 8909,
                         "boopie"               => 17227,
                         "booster"              => 4045,
                         "booster1"             => 23003,
                         "bootay"               => 17022,
                         "bootcamp"             => 14674,
                         "booter"               => 7722,
                         "bootie"               => 2241,
                         "booties"              => 9894,
                         "bootleg"              => 8701,
                         "bootmort"             => 24228,
                         "bootneck"             => 11031,
                         "boots"                => 1960,
                         "boots1"               => 7429,
                         "bootsie"              => 5437,
                         "bootsman"             => 16680,
                         "bootsy"               => 5211,
                         "booty"                => 923,
                         "booty1"               => 9302,
                         "booty69"              => 26486,
                         "bootycal"             => 21007,
                         "bootycall"            => 21859,
                         "bootyman"             => 16846,
                         "bootys"               => 4774,
                         "booya"                => 18977,
                         "booyaa"               => 12572,
                         "booyah"               => 5789,
                         "booyaka"              => 25120,
                         "boozer"               => 3946,
                         "bopper"               => 7129,
                         "borabora"             => 4227,
                         "bordeaux"             => 5003,
                         "boredboi4u"           => 27175,
                         "boricua"              => 2776,
                         "boriqua"              => 19673,
                         "boris1"               => 6747,
                         "boris123"             => 8881,
                         "borisenko"            => 22432,
                         "boriska"              => 21569,
                         "borisov"              => 15999,
                         "borisova"             => 19802,
                         "bornfree"             => 17541,
                         "borntorun"            => 19913,
                         "boroda"               => 6017,
                         "borodin"              => 25835,
                         "borodina"             => 23603,
                         "boromir"              => 8248,
                         "borracho"             => 27762,
                         "borris"               => 12533,
                         "borussia"             => 3252,
                         "bosco"                => 1633,
                         "bosco1"               => 5638,
                         "bosco123"             => 20586,
                         "boscoe"               => 14029,
                         "boscoe01"             => 9730,
                         "boscos"               => 24006,
                         "bosox"                => 17686,
                         "boss1"                => 16973,
                         "boss302"              => 9549,
                         "boss429"              => 25903,
                         "bossdog"              => 21566,
                         "bosshog"              => 7863,
                         "bosshogg"             => 22586,
                         "bosslady"             => 28360,
                         "bossman"              => 1765,
                         "bossss"               => 26240,
                         "bosstone"             => 10027,
                         "bosto"                => 15164,
                         "boston"               => 145,
                         "boston1"              => 5078,
                         "boston11"             => 29089,
                         "boston12"             => 15846,
                         "bot2010"              => 26671,
                         "botafogo"             => 20432,
                         "botanik"              => 26336,
                         "bouboule"             => 26794,
                         "boulder"              => 5089,
                         "bounce"               => 2678,
                         "bouncer"              => 5576,
                         "bounder"              => 25607,
                         "bounty"               => 3634,
                         "boutit"               => 16344,
                         "bovine"               => 13554,
                         "bowhunt"              => 11965,
                         "bowhunte"             => 15648,
                         "bowhunter"            => 19687,
                         "bowie1"               => 24866,
                         "bowl300"              => 8982,
                         "bowl36"               => 29933,
                         "bowler"               => 1794,
                         "bowler1"              => 17602,
                         "bowling"              => 764,
                         "bowling1"             => 14204,
                         "bowling3"             => 29060,
                         "bowtie"               => 5823,
                         "bowwow"               => 4075,
                         "boxcar"               => 5307,
                         "boxer"                => 3771,
                         "boxer1"               => 11962,
                         "boxers"               => 3834,
                         "boxing"               => 2049,
                         "boxman"               => 25035,
                         "boxster"              => 3025,
                         "boxster1"             => 29050,
                         "boxter"               => 8007,
                         "boxxer"               => 24152,
                         "boy123"               => 18260,
                         "boy4u2ownnyc"         => 17928,
                         "boyscout"             => 14439,
                         "boytoy"               => 4525,
                         "boywonde"             => 22697,
                         "boyz"                 => 5431,
                         "bozo"                 => 4692,
                         "bozo123"              => 25399,
                         "bp2002"               => 6664,
                         "bpgjldsgjldthnf"      => 26535,
                         "bpvtyf"               => 24054,
                         "br00klyn"             => 13551,
                         "br0d3r"               => 2225,
                         "br1ttany"             => 26855,
                         "br549"                => 2904,
                         "br5499"               => 14985,
                         "brabus"               => 9752,
                         "bradle"               => 23273,
                         "bradley1"             => 5373,
                         "bradpitt"             => 14866,
                         "brady1"               => 23634,
                         "brady12"              => 14910,
                         "brahms"               => 12799,
                         "brain1"               => 18996,
                         "braindea"             => 16131,
                         "bramble"              => 6161,
                         "branca"               => 23604,
                         "brandan"              => 24592,
                         "branden1"             => 19803,
                         "brandi1"              => 19121,
                         "brandnew"             => 25563,
                         "brando"               => 1811,
                         "brando1"              => 15101,
                         "brandon0"             => 16962,
                         "brandon00"            => 27127,
                         "brandon1"             => 1771,
                         "brandon2"             => 13813,
                         "brandon3"             => 24824,
                         "brandon6"             => 23709,
                         "brandon7"             => 23399,
                         "brandon8"             => 28597,
                         "brandy"               => 155,
                         "brandy1"              => 4883,
                         "brandy12"             => 23772,
                         "branford"             => 28130,
                         "brasco"               => 25658,
                         "brasi"                => 18371,
                         "brasil"               => 1422,
                         "brasil1"              => 28982,
                         "brasilia"             => 9845,
                         "bratan"               => 12436,
                         "brattax"              => 22828,
                         "brause"               => 28667,
                         "bravada"              => 27140,
                         "brave1"               => 28614,
                         "bravehea"             => 7596,
                         "braveheart"           => 7396,
                         "braves"               => 332,
                         "braves1"              => 6065,
                         "braves10"             => 19153,
                         "braves95"             => 21962,
                         "bravo1"               => 7078,
                         "bravo7"               => 28636,
                         "bravos"               => 16129,
                         "brayden"              => 10764,
                         "brazil"               => 672,
                         "brazil1"              => 12045,
                         "brazzers"             => 10893,
                         "breadfan"             => 27021,
                         "breadman"             => 19025,
                         "breads"               => 23924,
                         "break1"               => 27488,
                         "breakdance"           => 28626,
                         "breaker"              => 5287,
                         "breaker1"             => 18091,
                         "breakers"             => 11891,
                         "breakfas"             => 14894,
                         "breast"               => 1981,
                         "breasts"              => 3007,
                         "breeze"               => 1779,
                         "breeze1"              => 28189,
                         "breezer"              => 16414,
                         "breezy"               => 7637,
                         "brehznev"             => 16031,
                         "breitlin"             => 18136,
                         "bremen"               => 4996,
                         "brend"                => 13597,
                         "brenda1"              => 7944,
                         "brenda69"             => 26940,
                         "brendan1"             => 11895,
                         "brenden"              => 9485,
                         "brennan1"             => 26097,
                         "brent1"               => 8547,
                         "brentfor"             => 10224,
                         "brentwoo"             => 28584,
                         "brest"                => 5842,
                         "bretagne"             => 10498,
                         "brethart"             => 13604,
                         "brett1"               => 13211,
                         "brett123"             => 26854,
                         "brewcrew"             => 22466,
                         "brewski"              => 17408,
                         "bri5kev6"             => 27531,
                         "brian1"               => 2332,
                         "brian123"             => 9692,
                         "brian2"               => 18131,
                         "brianb"               => 13696,
                         "brianc"               => 25183,
                         "briand"               => 13710,
                         "briane"               => 27779,
                         "brianjo"              => 11039,
                         "briank"               => 22081,
                         "brianm"               => 18602,
                         "briann"               => 14859,
                         "brianna1"             => 9632,
                         "brianp"               => 28538,
                         "brians"               => 8096,
                         "brianw"               => 25567,
                         "brick1"               => 20754,
                         "bricks"               => 4747,
                         "bricky"               => 25905,
                         "bridge1"              => 22767,
                         "bridget1"             => 13601,
                         "briefs"               => 8542,
                         "brielle"              => 21885,
                         "brigada"              => 8768,
                         "brighton"             => 2468,
                         "brigit"               => 19968,
                         "briley2"              => 17702,
                         "brille"               => 25060,
                         "brillian"             => 25344,
                         "brillig"              => 19091,
                         "brillo"               => 21722,
                         "brillo021"            => 27847,
                         "brimston"             => 17919,
                         "bringit"              => 11705,
                         "bringiton"            => 28834,
                         "bristol"              => 2298,
                         "bristol1"             => 22353,
                         "britania"             => 28665,
                         "britney"              => 677,
                         "britney1"             => 11589,
                         "britneys"             => 11399,
                         "britt1"               => 17501,
                         "brittan"              => 14113,
                         "brittany1"            => 17182,
                         "brodie"               => 3571,
                         "brody1"               => 25612,
                         "broken1"              => 22301,
                         "broker"               => 3749,
                         "bronc"                => 28897,
                         "bronco"               => 419,
                         "bronco1"              => 8961,
                         "bronco2"              => 17907,
                         "broncos"              => 390,
                         "broncos1"             => 3881,
                         "broncos2"             => 21668,
                         "broncos7"             => 11640,
                         "brondby"              => 26103,
                         "bronte"               => 10200,
                         "bronx1"               => 23053,
                         "broodwar"             => 9007,
                         "brooke1"              => 13049,
                         "brookie"              => 13000,
                         "brookly"              => 18639,
                         "brooklyn"             => 319,
                         "brooklyn1"            => 19439,
                         "brooks1"              => 14729,
                         "brooksie"             => 26071,
                         "brooze"               => 27684,
                         "brother1"             => 8815,
                         "brother2"             => 24207,
                         "brown1"               => 4457,
                         "brown2"               => 29803,
                         "browncow"             => 15890,
                         "browndog"             => 7014,
                         "browneye"             => 9476,
                         "browneyes"            => 29881,
                         "browni"               => 21747,
                         "brownie"              => 1300,
                         "brownie1"             => 14503,
                         "brownlov"             => 22341,
                         "brownn"               => 27033,
                         "browns"               => 830,
                         "browns1"              => 11414,
                         "browns99"             => 20037,
                         "browny"               => 18967,
                         "browseui"             => 28570,
                         "bruce1"               => 4496,
                         "bruce10"              => 18264,
                         "bruce123"             => 25541,
                         "bruce2"               => 15652,
                         "brucelee"             => 1652,
                         "bruces"               => 20860,
                         "brucew"               => 23690,
                         "brucewayne"           => 22686,
                         "brucey"               => 23404,
                         "brucie"               => 23176,
                         "bruin"                => 13575,
                         "bruins"               => 873,
                         "bruins1"              => 14246,
                         "bruins77"             => 22875,
                         "bruiser"              => 3992,
                         "bruiser1"             => 28293,
                         "brujah"               => 14375,
                         "bruno1"               => 3518,
                         "bruno12"              => 21308,
                         "bruno123"             => 8564,
                         "brunob"               => 26668,
                         "brunodog"             => 29475,
                         "brunos"               => 20051,
                         "brunswic"             => 20763,
                         "brutis"               => 9188,
                         "brutu"                => 27765,
                         "brutus"               => 547,
                         "brutus1"              => 9637,
                         "bryan1"               => 6409,
                         "bryan123"             => 27303,
                         "bryana"               => 28253,
                         "bryce1"               => 21321,
                         "bsheep75"             => 21807,
                         "bsmith"               => 21363,
                         "btnjey"               => 16987,
                         "bubba"                => 297,
                         "bubba1"               => 695,
                         "bubba11"              => 26376,
                         "bubba12"              => 22880,
                         "bubba123"             => 4906,
                         "bubba2"               => 7400,
                         "bubba22"              => 21380,
                         "bubba69"              => 3772,
                         "bubba8"               => 29143,
                         "bubbaa"               => 9633,
                         "bubbabub"             => 22898,
                         "bubbadog"             => 10997,
                         "bubbah"               => 28889,
                         "bubbaman"             => 26079,
                         "bubbas"               => 1974,
                         "bubber"               => 11848,
                         "bubbie"               => 19297,
                         "bubbl"                => 25662,
                         "bubble"               => 826,
                         "bubble1"              => 15907,
                         "bubblebox"            => 29064,
                         "bubblegu"             => 12860,
                         "bubblegum"            => 7775,
                         "bubbles"              => 360,
                         "bubbles1"             => 4924,
                         "bubbles2"             => 22189,
                         "bubby"                => 10625,
                         "bubby1"               => 16735,
                         "bublik"               => 10009,
                         "bubluk"               => 23608,
                         "buccanee"             => 16491,
                         "buceta"               => 4106,
                         "buck01"               => 29495,
                         "buck1"                => 16950,
                         "buck123"              => 23244,
                         "buck13"               => 28895,
                         "bucker"               => 6736,
                         "bucket"               => 2758,
                         "buckey"               => 11582,
                         "buckeye"              => 999,
                         "buckeye1"             => 7800,
                         "buckeyes"             => 991,
                         "buckfast"             => 14104,
                         "buckie"               => 10756,
                         "bucks1"               => 19751,
                         "buckshot"             => 2563,
                         "buckskin"             => 15709,
                         "buckster"             => 12154,
                         "buckwhea"             => 7425,
                         "buckwheat"            => 13913,
                         "buckwild"             => 21695,
                         "bucky"                => 5764,
                         "bucky1"               => 13610,
                         "bud420"               => 12726,
                         "budapest"             => 3572,
                         "budda"                => 10081,
                         "buddah"               => 2943,
                         "buddha"               => 494,
                         "buddha1"              => 9612,
                         "buddie"               => 3002,
                         "buddog"               => 23914,
                         "buddy"                => 323,
                         "buddy01"              => 22055,
                         "buddy1"               => 706,
                         "buddy12"              => 11449,
                         "buddy123"             => 4417,
                         "buddy2"               => 6668,
                         "buddy23"              => 19581,
                         "buddy3"               => 21617,
                         "buddy4"               => 24464,
                         "buddy7"               => 18660,
                         "buddyboy"             => 3502,
                         "buddycat"             => 18003,
                         "buddydog"             => 6374,
                         "buddylee"             => 16447,
                         "buddys"               => 6693,
                         "buddyy"               => 22403,
                         "budgie"               => 5717,
                         "budice"               => 11200,
                         "budlight"             => 542,
                         "budlite"              => 7432,
                         "budman"               => 1876,
                         "budman1"              => 22847,
                         "budster"              => 28779,
                         "budweise"             => 2476,
                         "budweiser"            => 4846,
                         "budwiser"             => 16348,
                         "buffa"                => 7080,
                         "buffa1"               => 28908,
                         "buffal"               => 25574,
                         "buffalo"              => 406,
                         "buffalo1"             => 4447,
                         "buffalos"             => 9103,
                         "buffer"               => 7541,
                         "buffet"               => 5299,
                         "buffett"              => 1489,
                         "buffett1"             => 17262,
                         "buffie"               => 15367,
                         "buffon"               => 26913,
                         "buffy1"               => 2869,
                         "buffy123"             => 15560,
                         "buffy16"              => 20488,
                         "buffy1ma"             => 28775,
                         "buffy2"               => 19773,
                         "buffys"               => 9182,
                         "bugaboo"              => 19530,
                         "bugaga"               => 11058,
                         "bugatti"              => 8439,
                         "bugeye"               => 20802,
                         "bugger"               => 1399,
                         "bugger1"              => 27229,
                         "buggy"                => 9356,
                         "bugman"               => 7456,
                         "bugmenot"             => 23519,
                         "bugsbunn"             => 7786,
                         "bugsbunny"            => 10086,
                         "bugssgub"             => 28817,
                         "bugsy"                => 10352,
                         "bugsy1"               => 22143,
                         "buheirf"              => 29214,
                         "buhjvfybz"            => 27541,
                         "buick"                => 8023,
                         "buick1"               => 16469,
                         "builder"              => 2667,
                         "bujhm"                => 16923,
                         "bujhm123"             => 27107,
                         "bujhmbujhm"           => 29698,
                         "bujhtr"               => 13901,
                         "bukkake"              => 4791,
                         "bukowski"             => 6208,
                         "buldog"               => 11062,
                         "buldozer"             => 26073,
                         "bulgakov"             => 21937,
                         "bull"                 => 1813,
                         "bulldawg"             => 7638,
                         "bulldo"               => 10900,
                         "bulldog"              => 132,
                         "bulldog1"             => 2866,
                         "bulldog2"             => 10689,
                         "bulldog5"             => 29388,
                         "bulldog7"             => 21373,
                         "bulldogg"             => 11282,
                         "bulldogs"             => 536,
                         "bulle"                => 17706,
                         "bullet"               => 617,
                         "bullet1"              => 13416,
                         "bullfrog"             => 3362,
                         "bullgod"              => 29049,
                         "bullhead"             => 12033,
                         "bullit"               => 6820,
                         "bullitt"              => 14689,
                         "bullnuts"             => 26000,
                         "bullride"             => 13641,
                         "bullrun"              => 26591,
                         "bulls"                => 3107,
                         "bulls1"               => 7972,
                         "bulls123"             => 20099,
                         "bulls23"              => 7828,
                         "bullseye"             => 2417,
                         "bullshi"              => 21513,
                         "bullshit"             => 306,
                         "bullwink"             => 7570,
                         "bullyboy"             => 22736,
                         "bulova"               => 11710,
                         "bultaco"              => 27583,
                         "bumble"               => 5263,
                         "bumblebe"             => 9810,
                         "bumblebee"            => 14340,
                         "bumerang"             => 17744,
                         "bumhole"              => 25832,
                         "bummer"               => 3647,
                         "bumper"               => 3930,
                         "bumsen"               => 27209,
                         "bunches"              => 17896,
                         "bundao"               => 29440,
                         "bundas"               => 18575,
                         "bungalow"             => 10400,
                         "bungee"               => 10485,
                         "bunghole"             => 1877,
                         "bungie"               => 10276,
                         "bungle"               => 5476,
                         "bunia3"               => 29904,
                         "bunkie"               => 24256,
                         "bunko18"              => 19126,
                         "bunky"                => 16877,
                         "bunky1"               => 24183,
                         "bunnie"               => 7290,
                         "bunnies"              => 3607,
                         "bunnies1"             => 29065,
                         "bunns"                => 20819,
                         "bunny"                => 912,
                         "bunny1"               => 2805,
                         "bunny123"             => 17295,
                         "bunny2"               => 19170,
                         "bunnyman"             => 23475,
                         "bunnys"               => 9221,
                         "bunyan"               => 25851,
                         "buratino"             => 8638,
                         "burberry"             => 18505,
                         "burbon"               => 28932,
                         "burger"               => 1045,
                         "burlpony"             => 26633,
                         "burltree"             => 26627,
                         "burly"                => 9338,
                         "burner"               => 5508,
                         "burnout"              => 5821,
                         "burrfoot"             => 28778,
                         "burrito"              => 3701,
                         "burrito1"             => 27157,
                         "burton1"              => 15110,
                         "burton12"             => 27055,
                         "burunduk"             => 15000,
                         "burzum"               => 26624,
                         "busdrive"             => 20079,
                         "busen"                => 22925,
                         "bushed"               => 9096,
                         "bushel"               => 8538,
                         "bushido"              => 3586,
                         "bushmast"             => 23159,
                         "bushwack"             => 28727,
                         "bushwick"             => 24084,
                         "busines"              => 26606,
                         "businessbabe"         => 7608,
                         "businka"              => 8972,
                         "busman"               => 21932,
                         "busta"                => 26454,
                         "bustanut"             => 13732,
                         "buste"                => 4610,
                         "buster"               => 41,
                         "buster01"             => 9248,
                         "buster1"              => 1687,
                         "buster11"             => 12167,
                         "buster12"             => 6097,
                         "buster123"            => 25126,
                         "buster2"              => 15420,
                         "buster21"             => 21841,
                         "buster22"             => 21667,
                         "buster3"              => 23757,
                         "buster69"             => 25070,
                         "buster88"             => 26153,
                         "buster99"             => 23097,
                         "busters"              => 22533,
                         "bustle"               => 6853,
                         "busty"                => 3949,
                         "busybee"              => 25282,
                         "butane"               => 27806,
                         "butch"                => 1900,
                         "butch1"               => 6935,
                         "butchie"              => 8428,
                         "butchy"               => 8626,
                         "buterfly"             => 18670,
                         "buthead"              => 17751,
                         "butkus"               => 5348,
                         "butt1"                => 22098,
                         "butter"               => 229,
                         "butter1"              => 10925,
                         "butter11"             => 29463,
                         "butterba"             => 18405,
                         "butterbean"           => 24678,
                         "buttercu"             => 3340,
                         "buttercup"            => 5531,
                         "butterfl"             => 983,
                         "butterfly"            => 882,
                         "butterfly1"           => 19270,
                         "buttface"             => 14515,
                         "buttfuck"             => 3654,
                         "butthea"              => 25240,
                         "butthead"             => 245,
                         "butthole"             => 1832,
                         "buttlove"             => 14750,
                         "buttman"              => 2321,
                         "buttmunc"             => 13563,
                         "buttmunch"            => 17690,
                         "buttnut"              => 19448,
                         "buttnutt"             => 22594,
                         "buttocks"             => 11452,
                         "buttons"              => 1372,
                         "buttons1"             => 13753,
                         "buttplug"             => 9303,
                         "buttsex"              => 10475,
                         "buttss"               => 28026,
                         "butttt"               => 29152,
                         "buzzard"              => 2811,
                         "buzzer"               => 5574,
                         "buzzers"              => 13210,
                         "buzzkill"             => 24661,
                         "buzzman"              => 21415,
                         "buzzsaw"              => 10920,
                         "buzzword"             => 25411,
                         "buzzy"                => 14452,
                         "buzzzz"               => 22865,
                         "bvgthbz"              => 20050,
                         "bvgthfnjh"            => 14378,
                         "bvlgari"              => 28693,
                         "bwana"                => 23358,
                         "bxdumb"               => 29112,
                         "byabybnb"             => 21696,
                         "byajhvfnbrf"          => 16163,
                         "bycnbnen"             => 22524,
                         "bydand"               => 28764,
                         "bykemo"               => 23440,
                         "bynthytn"             => 5501,
                         "byoung"               => 23752,
                         "bypop"                => 27864,
                         "byrjuybnj"            => 27086,
                         "byron1"               => 18496,
                         "bysunsu"              => 13540,
                         "byteme"               => 1386,
                         "byteme1"              => 24317,
                         "c00kie"               => 25267,
                         "c00li0"               => 20135,
                         "c00per"               => 29209,
                         "c0l0rad0"             => 28203,
                         "c0rvette"             => 21737,
                         "c12345"               => 20026,
                         "c123456"              => 15399,
                         "c2h5oh"               => 5272,
                         "c32649135"            => 29499,
                         "c3por2d2"             => 8769,
                         "c43dae874d"           => 23849,
                         "c43qpul5rz"           => 18068,
                         "c6h12o6"              => 11147,
                         "c7lrwu"               => 15641,
                         "cab4ma99"             => 13839,
                         "caball"               => 24584,
                         "caballer"             => 13007,
                         "caballo"              => 10747,
                         "cabbage"              => 2144,
                         "cabbages"             => 26718,
                         "cabbie"               => 12496,
                         "cabernet"             => 5100,
                         "cabezon"              => 21222,
                         "cabibble"             => 14774,
                         "cabible"              => 21381,
                         "cabin1"               => 26656,
                         "cabinboy"             => 17035,
                         "cable1"               => 13516,
                         "cabledog"             => 26014,
                         "cableguy"             => 9069,
                         "cableman"             => 19531,
                         "caboose"              => 8093,
                         "cabowabo"             => 13308,
                         "cabrio"               => 10869,
                         "cabron"               => 4163,
                         "cacapipi"             => 19174,
                         "cachero"              => 26431,
                         "cachondo"             => 11645,
                         "cachorro"             => 10704,
                         "cachou"               => 20699,
                         "cacique"              => 23841,
                         "cactus"               => 1173,
                         "cactus1"              => 24366,
                         "cadaver"              => 13629,
                         "caddis"               => 10278,
                         "caddy"                => 6439,
                         "cadence"              => 10139,
                         "cadillac"             => 825,
                         "cadman"               => 8506,
                         "cadr14nu"             => 12073,
                         "caesar"               => 704,
                         "caesar1"              => 12610,
                         "caeser"               => 15311,
                         "cafc91"               => 5184,
                         "caffreys"             => 23370,
                         "cagiva"               => 28822,
                         "cahek0980"            => 20010,
                         "caiman"               => 28685,
                         "caitlin1"             => 10488,
                         "cajun"                => 7278,
                         "cajun1"               => 15205,
                         "calamity"             => 8828,
                         "calavera"             => 13415,
                         "calbear"              => 22013,
                         "calbears"             => 21349,
                         "calcio"               => 10540,
                         "caleb1"               => 15160,
                         "caleb123"             => 27688,
                         "calgary"              => 2983,
                         "calgary1"             => 28573,
                         "cali"                 => 6632,
                         "caliban"              => 19097,
                         "calibra"              => 4536,
                         "calico"               => 2281,
                         "calida"               => 29692,
                         "calient"              => 16500,
                         "caliente"             => 1647,
                         "californ"             => 1373,
                         "californi"            => 14931,
                         "california1"          => 28464,
                         "caligula"             => 2437,
                         "calimer"              => 25427,
                         "calimero"             => 4628,
                         "calipso"              => 27484,
                         "call06"               => 27232,
                         "call911"              => 20167,
                         "calla"                => 24904,
                         "calli"                => 15876,
                         "calliope"             => 19084,
                         "callista"             => 21368,
                         "callisto"             => 4519,
                         "callme"               => 10444,
                         "callofduty"           => 7816,
                         "callum"               => 3669,
                         "calpoly"              => 24400,
                         "calvary"              => 10312,
                         "calvin1"              => 5712,
                         "calvin69"             => 19991,
                         "calypso"              => 6514,
                         "camaleon"             => 17705,
                         "camaleun"             => 22744,
                         "camar"                => 15063,
                         "camaro"               => 106,
                         "camaro1"              => 7105,
                         "camaro67"             => 19127,
                         "camaro69"             => 10191,
                         "camaron"              => 17209,
                         "camaross"             => 4902,
                         "camaroz2"             => 10208,
                         "camaroz28"            => 16921,
                         "camber"               => 5489,
                         "cambiami"             => 2723,
                         "cambria"              => 14321,
                         "cambridg"             => 5534,
                         "camden"               => 4867,
                         "came11"               => 6709,
                         "camel"                => 1631,
                         "camel1"               => 7336,
                         "camel123"             => 25307,
                         "cameleon"             => 17660,
                         "camell"               => 11751,
                         "camelo"               => 25046,
                         "camelot"              => 1642,
                         "camelot1"             => 8578,
                         "camels"               => 1845,
                         "cameltoe"             => 3225,
                         "camera1"              => 13231,
                         "camero"               => 4869,
                         "camero1"              => 6516,
                         "cameron"              => 237,
                         "cameron0"             => 26790,
                         "cameron1"             => 3291,
                         "cameron2"             => 22195,
                         "cameron7"             => 24427,
                         "camil"                => 5710,
                         "camilit"              => 29647,
                         "camill"               => 10017,
                         "camilla1"             => 26015,
                         "camille1"             => 16135,
                         "camilo"               => 8715,
                         "camino"               => 8145,
                         "camion"               => 24025,
                         "camneely"             => 27124,
                         "camp0017"             => 20598,
                         "campari"              => 19222,
                         "campeo"               => 19902,
                         "campeon"              => 15651,
                         "camper"               => 3128,
                         "campus100"            => 28977,
                         "camron"               => 20961,
                         "camry1"               => 29782,
                         "camster"              => 28639,
                         "camus1"               => 29182,
                         "canabis"              => 11630,
                         "canad"                => 10168,
                         "canada"               => 212,
                         "canada1"              => 5840,
                         "canada12"             => 25888,
                         "canada99"             => 23428,
                         "canadien"             => 11505,
                         "canalc"               => 27474,
                         "canard"               => 17669,
                         "canaries"             => 18391,
                         "canario"              => 28546,
                         "canary"               => 6614,
                         "canbeef"              => 24364,
                         "cance"                => 15587,
                         "cancer"               => 785,
                         "cancun"               => 2075,
                         "candela"              => 15106,
                         "candide"              => 21580,
                         "candies"              => 6779,
                         "candle"               => 2218,
                         "candlebo"             => 21498,
                         "cando"                => 24772,
                         "candoo"               => 28604,
                         "candy1"               => 4383,
                         "candy123"             => 13097,
                         "candy2"               => 12171,
                         "candyass"             => 5645,
                         "candybar"             => 16390,
                         "candycan"             => 12635,
                         "candycane"            => 19964,
                         "candyman"             => 1721,
                         "candys"               => 7864,
                         "canes"                => 11436,
                         "canes1"               => 12581,
                         "canesfan"             => 23172,
                         "cang"                 => 3556,
                         "canibus"              => 14044,
                         "canine"               => 6749,
                         "canman"               => 24649,
                         "cannabis"             => 3175,
                         "cannelle"             => 28491,
                         "cannibal"             => 5551,
                         "cannibus"             => 24575,
                         "canno"                => 26812,
                         "cannon1"              => 25939,
                         "cannonba"             => 20556,
                         "cannonda"             => 7990,
                         "cannondale"           => 15826,
                         "canon"                => 2195,
                         "canon1"               => 8471,
                         "canoneos"             => 24346,
                         "canseco"              => 10885,
                         "cantik"               => 17637,
                         "cantina"              => 25509,
                         "cantona"              => 1220,
                         "cantona1"             => 24163,
                         "cantona7"             => 5978,
                         "cantstop"             => 29946,
                         "canuck"               => 5044,
                         "canucks"              => 4816,
                         "canucks1"             => 20216,
                         "capa200"              => 10218,
                         "capcom"               => 5860,
                         "capecod"              => 4992,
                         "capetown"             => 4836,
                         "capital1"             => 7726,
                         "capital5"             => 24589,
                         "capitals"             => 5719,
                         "capitan"              => 11374,
                         "capoeira"             => 7195,
                         "capone"               => 1982,
                         "capone1"              => 25115,
                         "capri"                => 9015,
                         "capri50"              => 28392,
                         "capricor"             => 4776,
                         "capricorn"            => 4493,
                         "capslock"             => 3369,
                         "capstan"              => 22374,
                         "captain"              => 250,
                         "captain1"             => 4829,
                         "captain2"             => 28484,
                         "captaink"             => 27656,
                         "captiva"              => 17082,
                         "car123"               => 8863,
                         "car12345"             => 29734,
                         "caraca"               => 19377,
                         "caracas"              => 5872,
                         "caracol"              => 19168,
                         "caraj"                => 24573,
                         "carajo"               => 8063,
                         "caralho"              => 7815,
                         "caramba"              => 8739,
                         "caramel"              => 2386,
                         "caramelo"             => 15780,
                         "caramon"              => 24290,
                         "caravan"              => 3241,
                         "carbine"              => 11447,
                         "carcass"              => 10417,
                         "cardigan"             => 15734,
                         "cardinal"             => 630,
                         "cardman"              => 29723,
                         "cards1"               => 10387,
                         "cardss"               => 26314,
                         "care1839"             => 6326,
                         "carebear"             => 5304,
                         "carefree"             => 8953,
                         "carguy"               => 11247,
                         "caribe"               => 21338,
                         "carine"               => 13422,
                         "carioca"              => 10365,
                         "carisma"              => 29030,
                         "carla1"               => 11993,
                         "carla10"              => 16409,
                         "carla123"             => 22519,
                         "carla51"              => 19621,
                         "carling"              => 7113,
                         "carlit"               => 21611,
                         "carlito"              => 3464,
                         "carlitos"             => 3447,
                         "carlo1"               => 19493,
                         "carlos1"              => 4721,
                         "carlos12"             => 15921,
                         "carlos123"            => 19047,
                         "carlos2"              => 13911,
                         "carlos6"              => 25963,
                         "carlsbad"             => 23918,
                         "carlsberg"            => 20101,
                         "carlton1"             => 16956,
                         "carly1"               => 15915,
                         "carme"                => 6487,
                         "carmen1"              => 8820,
                         "carmex"               => 11259,
                         "carmex2"              => 3927,
                         "carnage"              => 3832,
                         "carnival"             => 4586,
                         "carol1"               => 9091,
                         "carolcox"             => 13731,
                         "carole1"              => 19213,
                         "carolina"             => 397,
                         "carolina1"            => 23093,
                         "caroline1"            => 19564,
                         "carolyn1"             => 14705,
                         "carpedie"             => 3286,
                         "carpediem"            => 6986,
                         "carpente"             => 4510,
                         "carpet"               => 1554,
                         "carpet1"              => 25580,
                         "carrera"              => 2305,
                         "carrera4"             => 14637,
                         "carrie1"              => 15246,
                         "carrot"               => 1291,
                         "carrot1"              => 26346,
                         "carrots"              => 5748,
                         "carson1"              => 20588,
                         "carsten"              => 6982,
                         "cartagen"             => 26659,
                         "carter1"              => 9856,
                         "carter12"             => 19911,
                         "carter15"             => 16620,
                         "carter80"             => 29138,
                         "carthage"             => 8985,
                         "cartma"               => 25212,
                         "cartman"              => 395,
                         "cartman1"             => 4852,
                         "cartman2"             => 25197,
                         "cartmen"              => 28324,
                         "cartoon"              => 1975,
                         "cartoons"             => 5403,
                         "carvin"               => 13679,
                         "carwash"              => 9567,
                         "carwash1"             => 29058,
                         "casablan"             => 10696,
                         "casablanca"           => 7174,
                         "casanova"             => 2763,
                         "cascada"              => 24002,
                         "caseih"               => 21227,
                         "caserta"              => 1081,
                         "casey1"               => 1968,
                         "casey123"             => 12969,
                         "casey2"               => 14195,
                         "casey22"              => 18259,
                         "caseyboy"             => 26518,
                         "caseydog"             => 8696,
                         "caseys"               => 19215,
                         "cash1"                => 22071,
                         "cash12"               => 17023,
                         "cashew"               => 7519,
                         "cashflow"             => 5953,
                         "cashmone"             => 5124,
                         "cashmoney"            => 5768,
                         "casino"               => 801,
                         "casio"                => 5621,
                         "casio1"               => 26033,
                         "casita"               => 27648,
                         "caspe"                => 8003,
                         "casper"               => 179,
                         "casper1"              => 4531,
                         "casper12"             => 16065,
                         "casper123"            => 28274,
                         "casper2"              => 16538,
                         "casper99"             => 19011,
                         "cassandr"             => 4750,
                         "cassidy1"             => 22695,
                         "cassie"               => 384,
                         "cassie1"              => 8021,
                         "cassie12"             => 25524,
                         "cassiope"             => 29527,
                         "cassis"               => 26533,
                         "cassius"              => 8744,
                         "castaway"             => 11877,
                         "caster"               => 5625,
                         "castill"              => 28677,
                         "castle1"              => 28465,
                         "cat123"               => 2540,
                         "cat222"               => 16963,
                         "catalin"              => 9925,
                         "catbert"              => 21866,
                         "catboy"               => 24121,
                         "catch2"               => 29651,
                         "catch22"              => 711,
                         "catcher"              => 5564,
                         "catchme"              => 28712,
                         "catdaddy"             => 8326,
                         "catdog"               => 1028,
                         "catdog1"              => 17885,
                         "caterham"             => 13932,
                         "caterpil"             => 19593,
                         "cateye"               => 22535,
                         "catfight"             => 6741,
                         "catfish"              => 810,
                         "catfish1"             => 10131,
                         "catfood"              => 7307,
                         "cathay"               => 26247,
                         "catherin"             => 1656,
                         "cathouse"             => 16695,
                         "cathy1"               => 10001,
                         "catinhat"             => 20017,
                         "catlover"             => 10613,
                         "catman"               => 2024,
                         "catmando"             => 15597,
                         "catnip"               => 5575,
                         "catrin"               => 29755,
                         "cats"                 => 1290,
                         "catsdogs"             => 15699,
                         "catsmeow"             => 16825,
                         "catsss"               => 28976,
                         "catter"               => 9170,
                         "catty"                => 16396,
                         "catwalk"              => 15026,
                         "catwoman"             => 4207,
                         "caustic"              => 23748,
                         "caution1"             => 28506,
                         "cavalier"             => 986,
                         "cavalla"              => 27237,
                         "cavalo"               => 20353,
                         "caveman"              => 2389,
                         "caveman1"             => 14838,
                         "cavscout"             => 17146,
                         "cayenne"              => 7646,
                         "cayman"               => 4530,
                         "cayuga"               => 15775,
                         "cazzo"                => 7033,
                         "cazzo1"               => 19697,
                         "cazzone"              => 7680,
                         "cb207sl"              => 22661,
                         "cba321"               => 22326,
                         "cbarkley"             => 27329,
                         "cbcmrb"               => 13453,
                         "cbcntvf"              => 22660,
                         "cbhbec"               => 13090,
                         "cbhtqa"               => 28695,
                         "cbhtym"               => 23851,
                         "cbkmdf"               => 28992,
                         "cbljhjdf"             => 26519,
                         "cbljhtyrj"            => 27029,
                         "cbr1000"              => 19180,
                         "cbr600"               => 2658,
                         "cbr600f3"             => 22379,
                         "cbr600f4"             => 24003,
                         "cbr600rr"             => 8376,
                         "cbr900"               => 5974,
                         "cbr900rr"             => 4098,
                         "cbr929"               => 20390,
                         "cbr929rr"             => 20591,
                         "cbrown"               => 19440,
                         "cbufhtnf"             => 24752,
                         "cbvjyf"               => 19411,
                         "ccbill"               => 1925,
                         "ccccc1"               => 11992,
                         "cccccc1"              => 7655,
                         "ccccccc1"             => 22766,
                         "cccdemo"              => 29099,
                         "cdavis"               => 21255,
                         "cde34rfv"             => 18018,
                         "cdexswzaq"            => 22500,
                         "cdfoli"               => 18694,
                         "cdjkjxm"              => 13102,
                         "cdtnbr"               => 3583,
                         "cdtnf"                => 27740,
                         "cdtnjxrf"             => 11243,
                         "cdtnkfy"              => 29163,
                         "cdtnkfyf"             => 1130,
                         "cdtnkfyrf"            => 21948,
                         "cdtnkzxjr"            => 28755,
                         "cdtnrf"               => 13173,
                         "cdznjckfd"            => 12825,
                         "ceasar"               => 4973,
                         "ceaser"               => 8187,
                         "cecili"               => 18137,
                         "cecilia1"             => 26803,
                         "ceckbr"               => 8861,
                         "ceejay"               => 16453,
                         "cegthgegth"           => 19066,
                         "cegthgfhjkm"          => 17884,
                         "ceilidh"              => 29127,
                         "ceisi123"             => 20985,
                         "celeb"                => 4077,
                         "celebrat"             => 22894,
                         "celebrit"             => 22296,
                         "celebs"               => 16081,
                         "celeron"              => 2702,
                         "celest"               => 14018,
                         "celeste1"             => 20693,
                         "celestia"             => 12684,
                         "celica"               => 1509,
                         "celicagt"             => 20882,
                         "celin"                => 14184,
                         "celine"               => 1619,
                         "cellphon"             => 12345,
                         "cellphone"            => 20247,
                         "celos1"               => 28409,
                         "celti"                => 16627,
                         "celtic"               => 387,
                         "celtic1"              => 11123,
                         "celtic1888"           => 22053,
                         "celtic67"             => 16662,
                         "celtic88"             => 15492,
                         "celticfc"             => 9332,
                         "celtics"              => 1737,
                         "celtics1"             => 11328,
                         "celula"               => 20214,
                         "celular"              => 22430,
                         "cement"               => 5353,
                         "ceng"                 => 3345,
                         "censor"               => 12057,
                         "centaur"              => 12128,
                         "centauri"             => 12103,
                         "centra"               => 27884,
                         "central1"             => 20940,
                         "centrino"             => 10059,
                         "centurion"            => 11106,
                         "cepseoun"             => 23556,
                         "cer980"               => 24518,
                         "cerber"               => 7795,
                         "cerbera"              => 11484,
                         "cerberus"             => 2804,
                         "cerebro"              => 27470,
                         "cerebus"              => 7210,
                         "cerise"               => 19514,
                         "cerulean"             => 21361,
                         "cerveza"              => 8877,
                         "cesare"               => 7025,
                         "cessna"               => 900,
                         "cessna1"              => 28238,
                         "cessna15"             => 23960,
                         "cessna17"             => 17361,
                         "cessna172"            => 24905,
                         "cestmoi"              => 23200,
                         "cevthrb"              => 4784,
                         "cexfhf"               => 29133,
                         "cezer121"             => 8599,
                         "cfdbyf"               => 28401,
                         "cfdtkbq"              => 16299,
                         "cfhfnjd"              => 10904,
                         "cfiekmrf"             => 27622,
                         "cfiekz"               => 9604,
                         "cfif123"              => 19187,
                         "cfitymrf"             => 2739,
                         "cfkfvfylhf"           => 20635,
                         "cfnfyf"               => 29158,
                         "cfrehf"               => 16723,
                         "cfvceyu"              => 6316,
                         "cfvehfq"              => 14212,
                         "cfvfhf"               => 14132,
                         "cfvjktn"              => 12037,
                         "cfvlehfr"             => 17366,
                         "cfymrf"               => 28952,
                         "cfytxrf"              => 16986,
                         "cgfhnfr"              => 2986,
                         "cghfdjxybr"           => 29580,
                         "cgtwbfkbcn"           => 24600,
                         "ch1tt1ck"             => 21541,
                         "ch33s3"               => 19790,
                         "ch5nmk"               => 12741,
                         "chablis"              => 16824,
                         "chacal"               => 9794,
                         "chach"                => 16565,
                         "chacha1"              => 22734,
                         "chachi"               => 6064,
                         "chaching"             => 21745,
                         "chacho"               => 23014,
                         "chaddy"               => 29011,
                         "chai"                 => 3167,
                         "chaika"               => 26497,
                         "chainsaw"             => 2487,
                         "chaise"               => 20655,
                         "chaka"                => 15901,
                         "chakra"               => 17197,
                         "chalky"               => 19783,
                         "challeng"             => 4888,
                         "chalupa"              => 11625,
                         "chamberl"             => 27819,
                         "chameleo"             => 17586,
                         "chamois"              => 18111,
                         "chamonix"             => 12556,
                         "champ"                => 2499,
                         "champ1"               => 5095,
                         "champ123"             => 26068,
                         "champagn"             => 9764,
                         "champio"              => 22271,
                         "champion"             => 463,
                         "champs"               => 1638,
                         "chanc"                => 26866,
                         "chance1"              => 8400,
                         "chancho"              => 27279,
                         "chandle"              => 29494,
                         "chane"                => 21845,
                         "chanel1"              => 27167,
                         "chanel5"              => 28508,
                         "changa"               => 27654,
                         "change1"              => 11214,
                         "change12"             => 26378,
                         "changeit"             => 11908,
                         "changeme"             => 658,
                         "changeme1"            => 26070,
                         "changepa"             => 18732,
                         "changer"              => 23978,
                         "chango"               => 7437,
                         "channel1"             => 24141,
                         "chantal1"             => 29119,
                         "chao"                 => 3024,
                         "chaos"                => 1350,
                         "chaos1"               => 5179,
                         "chaos666"             => 19787,
                         "chaoss"               => 11911,
                         "chaparra"             => 26487,
                         "chappie"              => 24979,
                         "chappy"               => 6229,
                         "chapstic"             => 20384,
                         "characte"             => 9646,
                         "charger"              => 1003,
                         "charger1"             => 12227,
                         "chargers"             => 1385,
                         "chargers1"            => 18082,
                         "charisma"             => 5456,
                         "charit"               => 25188,
                         "charl"                => 9862,
                         "charle"               => 6272,
                         "charle1"              => 19979,
                         "charlee"              => 18440,
                         "charles0"             => 29561,
                         "charles1"             => 2334,
                         "charles2"             => 9189,
                         "charles3"             => 17657,
                         "charless"             => 29830,
                         "charlest"             => 18533,
                         "charli"               => 2113,
                         "charlie"              => 45,
                         "charlie0"             => 18542,
                         "charlie1"             => 622,
                         "charlie123"           => 7743,
                         "charlie2"             => 5643,
                         "charlie3"             => 9350,
                         "charlie4"             => 14312,
                         "charlie5"             => 12527,
                         "charlie6"             => 12849,
                         "charlie7"             => 13196,
                         "charlie8"             => 17088,
                         "charlie9"             => 10858,
                         "charlieb"             => 15360,
                         "charliem"             => 28373,
                         "charlies"             => 9404,
                         "charlize"             => 28784,
                         "charlott"             => 1192,
                         "charlton"             => 2038,
                         "charlus"              => 27302,
                         "charly"               => 1420,
                         "charly1"              => 23817,
                         "charme"               => 17531,
                         "charmed"              => 1856,
                         "charmed1"             => 12125,
                         "charmin"              => 15766,
                         "charon"               => 5082,
                         "charro"               => 22398,
                         "charvel"              => 16821,
                         "chase1"               => 4055,
                         "chase123"             => 14531,
                         "chaser"               => 2148,
                         "chaser1"              => 27432,
                         "chasey"               => 10865,
                         "chasmo"               => 23953,
                         "chato"                => 15225,
                         "chaton"               => 15280,
                         "chatte"               => 10452,
                         "chaucer"              => 13148,
                         "chazz"                => 13934,
                         "chbjun"               => 15058,
                         "cheater"              => 3028,
                         "cheburashka"          => 15147,
                         "chech"                => 27791,
                         "check1"               => 11046,
                         "checker"              => 5548,
                         "checkers"             => 3100,
                         "checkit"              => 8864,
                         "checkito"             => 23699,
                         "checkm8"              => 25232,
                         "checkmat"             => 7013,
                         "cheddar"              => 4785,
                         "cheeba"               => 7377,
                         "cheech"               => 3236,
                         "cheeks"               => 3133,
                         "cheeky"               => 5308,
                         "cheer1"               => 11946,
                         "cheerio"              => 14025,
                         "cheerios"             => 12884,
                         "cheerlea"             => 21766,
                         "cheerleaers"          => 6083,
                         "cheers"               => 2032,
                         "chees"                => 7618,
                         "cheese"               => 67,
                         "cheese1"              => 2693,
                         "cheese12"             => 14021,
                         "cheese2"              => 21862,
                         "cheeseca"             => 19810,
                         "cheeser"              => 29725,
                         "cheesey"              => 24067,
                         "cheeta"               => 11203,
                         "cheetah"              => 2237,
                         "cheetah1"             => 24297,
                         "cheeto"               => 12327,
                         "cheetos"              => 16731,
                         "cheez"                => 23643,
                         "cheeze"               => 11211,
                         "cheezit"              => 26109,
                         "cheezy"               => 28930,
                         "chelios"              => 17255,
                         "chelle"               => 5438,
                         "chello"               => 28713,
                         "chelse"               => 4652,
                         "chelsea"              => 70,
                         "chelsea0"             => 16087,
                         "chelsea1"             => 1360,
                         "chelsea2"             => 11682,
                         "chelsea3"             => 24687,
                         "chelsea4"             => 20014,
                         "chelsea5"             => 26678,
                         "chelsea6"             => 17313,
                         "chelsea7"             => 23155,
                         "chelsea8"             => 17432,
                         "chelseaf"             => 16615,
                         "chelseafc"            => 11139,
                         "chelsi"               => 24100,
                         "chemist"              => 6062,
                         "chemistr"             => 9027,
                         "cheops"               => 24474,
                         "chernov"              => 28343,
                         "cheroke"              => 21981,
                         "cherokee"             => 512,
                         "cherr"                => 12481,
                         "cherries"             => 4797,
                         "cherry"               => 402,
                         "cherry1"              => 7958,
                         "cherry12"             => 27012,
                         "cherrypi"             => 26896,
                         "cherub"               => 13570,
                         "cheryl1"              => 18346,
                         "cheshire"             => 4449,
                         "chess1"               => 22723,
                         "chessie"              => 5472,
                         "chessman"             => 13462,
                         "chessmas"             => 26816,
                         "chessmaster"          => 16521,
                         "chessy"               => 22492,
                         "cheste"               => 7584,
                         "chester"              => 156,
                         "chester1"             => 2091,
                         "chester2"             => 11363,
                         "chester3"             => 26210,
                         "chester7"             => 19739,
                         "chester8"             => 29186,
                         "chesters"             => 29235,
                         "chesty"               => 9361,
                         "cheval"               => 10646,
                         "chevell"              => 18682,
                         "chevelle"             => 636,
                         "chevrole"             => 1691,
                         "chevrolet"            => 3381,
                         "chevy"                => 469,
                         "chevy01"              => 27257,
                         "chevy1"               => 1950,
                         "chevy11"              => 25087,
                         "chevy2"               => 8535,
                         "chevy3"               => 25671,
                         "chevy350"             => 20191,
                         "chevy454"             => 10892,
                         "chevy69"              => 25750,
                         "chevyman"             => 10472,
                         "chevys"               => 4226,
                         "chevys10"             => 6996,
                         "chevyss"              => 23770,
                         "chevytru"             => 21868,
                         "chevyy"               => 26276,
                         "chevyz71"             => 10620,
                         "chewbaca"             => 22426,
                         "chewbacc"             => 6304,
                         "chewbacca"            => 10052,
                         "chewey"               => 7473,
                         "chewie"               => 2072,
                         "chewy"                => 5440,
                         "chewy1"               => 7945,
                         "cheyanne"             => 8647,
                         "cheyenn"              => 22511,
                         "cheyenne"             => 691,
                         "cheyenne1"            => 25049,
                         "chgobndg"             => 12543,
                         "chiapet"              => 14728,
                         "chiar"                => 20533,
                         "chiara"               => 4198,
                         "chibears"             => 19255,
                         "chica1"               => 26691,
                         "chicag"               => 16891,
                         "chicago"              => 163,
                         "chicago0"             => 19622,
                         "chicago1"             => 2537,
                         "chicago2"             => 11068,
                         "chicago3"             => 28385,
                         "chicago5"             => 25594,
                         "chicago7"             => 17301,
                         "chicago9"             => 28815,
                         "chicano"              => 18854,
                         "chicas"               => 10713,
                         "chicc"                => 26880,
                         "chicca"               => 11380,
                         "chicco"               => 8335,
                         "chicco22"             => 21751,
                         "chich"                => 19160,
                         "chichi"               => 1070,
                         "chicho"               => 27643,
                         "chick1"               => 23010,
                         "chicke"               => 10291,
                         "chicken"              => 105,
                         "chicken0"             => 24892,
                         "chicken1"             => 2082,
                         "chicken123"           => 23137,
                         "chicken2"             => 11569,
                         "chicken6"             => 28944,
                         "chickens"             => 2160,
                         "chickenwing101"       => 6753,
                         "chicklet"             => 26899,
                         "chicks"               => 1090,
                         "chicky"               => 12643,
                         "chico"                => 2356,
                         "chico1"               => 8990,
                         "chico123"             => 24005,
                         "chicony"              => 26437,
                         "chicos"               => 14453,
                         "chicubs"              => 16161,
                         "chief1"               => 7550,
                         "chief123"             => 29961,
                         "chiefs"               => 998,
                         "chiefs1"              => 19461,
                         "chiefy"               => 29791,
                         "chigger"              => 14624,
                         "chihuahu"             => 16490,
                         "chiken"               => 17187,
                         "chiks"                => 8245,
                         "chilango"             => 17808,
                         "childre"              => 19064,
                         "children2"            => 23714,
                         "chile1"               => 22602,
                         "chileno"              => 29132,
                         "chilidog"             => 11400,
                         "chilis"               => 24272,
                         "chiller"              => 14636,
                         "chilli"               => 4168,
                         "chillin"              => 3908,
                         "chillout"             => 9337,
                         "chilly"               => 4006,
                         "chimaera"             => 12695,
                         "chimaira"             => 28374,
                         "chimay"               => 23927,
                         "chimera"              => 3312,
                         "chimpy"               => 13921,
                         "china1"               => 8622,
                         "chinacat"             => 12670,
                         "chinadol"             => 28617,
                         "chinaman"             => 13166,
                         "chinaski"             => 28920,
                         "chinatow"             => 22531,
                         "chinchil"             => 20518,
                         "chinese1"             => 19641,
                         "chinga"               => 28396,
                         "chingada"             => 27227,
                         "chingon"              => 7069,
                         "chingy"               => 16939,
                         "chinita"              => 19014,
                         "chinito"              => 21781,
                         "chinky"               => 23636,
                         "chinna"               => 25166,
                         "chinni"               => 28329,
                         "chinnu"               => 28407,
                         "chino"                => 7961,
                         "chino1"               => 19023,
                         "chinook"              => 3003,
                         "chiphi"               => 28268,
                         "chipie"               => 11619,
                         "chipmonk"             => 28738,
                         "chipmunk"             => 4071,
                         "chipper"              => 887,
                         "chipper1"             => 8433,
                         "chippers"             => 18096,
                         "chippy"               => 3397,
                         "chips1"               => 20038,
                         "chipster"             => 18001,
                         "chiqui"               => 24266,
                         "chiquit"              => 21078,
                         "chiro"                => 25885,
                         "chiron"               => 13756,
                         "chisel"               => 11150,
                         "chisox"               => 9447,
                         "chispa"               => 27171,
                         "chitarra"             => 20438,
                         "chitown"              => 6321,
                         "chitra"               => 25499,
                         "chiva"                => 17267,
                         "chivas"               => 2415,
                         "chivas1"              => 25314,
                         "chkdsk"               => 25677,
                         "chloe1"               => 3258,
                         "chloe123"             => 18989,
                         "chloes"               => 28851,
                         "chobits"              => 9433,
                         "chocha"               => 4833,
                         "chochoz"              => 14391,
                         "choclate"             => 12731,
                         "choco"                => 14381,
                         "chocobo"              => 9693,
                         "chocolat"             => 725,
                         "chocolate1"           => 9479,
                         "chode"                => 24123,
                         "chomper"              => 14343,
                         "chomsky"              => 17205,
                         "chongo"               => 19184,
                         "chooch"               => 7131,
                         "choochoo"             => 4078,
                         "chopin"               => 3542,
                         "choppe"               => 29573,
                         "chopper"              => 602,
                         "chopper1"             => 6337,
                         "choppers"             => 7809,
                         "choppy"               => 15059,
                         "chopsuey"             => 25186,
                         "chorizo"              => 18476,
                         "chosen1"              => 13031,
                         "chou"                 => 2945,
                         "choucho"              => 22467,
                         "chowder"              => 7703,
                         "chris01"              => 17132,
                         "chris1"               => 765,
                         "chris10"              => 23814,
                         "chris100"             => 29175,
                         "chris11"              => 15120,
                         "chris12"              => 7742,
                         "chris123"             => 4743,
                         "chris13"              => 20894,
                         "chris2"               => 7806,
                         "chris200"             => 27960,
                         "chris21"              => 15703,
                         "chris22"              => 13825,
                         "chris23"              => 18555,
                         "chris24"              => 29176,
                         "chris25"              => 24036,
                         "chris3"               => 19948,
                         "chris33"              => 28807,
                         "chris5"               => 26705,
                         "chris69"              => 15518,
                         "chris99"              => 16158,
                         "chris999"             => 28660,
                         "chrisa"               => 18679,
                         "chrisb"               => 8320,
                         "chrisbl"              => 27749,
                         "chrisbln"             => 2506,
                         "chrisbrown"           => 21277,
                         "chrisc"               => 13595,
                         "chrisd"               => 16095,
                         "chrisg"               => 23279,
                         "chrish"               => 24139,
                         "chrisj"               => 21552,
                         "chrisk"               => 17704,
                         "chrisl"               => 19292,
                         "chrism"               => 10393,
                         "chrisp"               => 13055,
                         "chrisrey"             => 25674,
                         "chriss"               => 3886,
                         "chrissi"              => 14657,
                         "chrissie"             => 13822,
                         "chrissy"              => 1042,
                         "chrissy1"             => 8873,
                         "christ"               => 596,
                         "christ1"              => 9329,
                         "christa1"             => 21867,
                         "christer"             => 15892,
                         "christi1"             => 26666,
                         "christia"             => 837,
                         "christiaan"           => 24894,
                         "christian1"           => 18686,
                         "christin"             => 385,
                         "christma"             => 3829,
                         "christo"              => 7140,
                         "christo1"             => 26272,
                         "christof"             => 12130,
                         "christop"             => 1123,
                         "christophe"           => 6708,
                         "christopher1"         => 17404,
                         "christos"             => 12813,
                         "christy1"             => 9009,
                         "chrisw"               => 29168,
                         "chrisx"               => 20116,
                         "chrome"               => 3078,
                         "chronic"              => 713,
                         "chronic1"             => 19092,
                         "chrono"               => 2569,
                         "chronos"              => 8667,
                         "chrysler"             => 3325,
                         "chuai"                => 3234,
                         "chuan"                => 7902,
                         "chuang"               => 2929,
                         "chubba"               => 20930,
                         "chubbs"               => 12332,
                         "chubby"               => 1364,
                         "chubby1"              => 14101,
                         "chucha"               => 9652,
                         "chuchi"               => 22174,
                         "chucho"               => 12318,
                         "chuck1"               => 6464,
                         "chuck123"             => 23056,
                         "chuckd"               => 28377,
                         "chucker"              => 18109,
                         "chuckie"              => 2935,
                         "chuckie1"             => 16691,
                         "chuckles"             => 2726,
                         "chucko"               => 26155,
                         "chucks"               => 16636,
                         "chucky"               => 1503,
                         "chui"                 => 3393,
                         "chula"                => 24361,
                         "chulita"              => 24083,
                         "chulo"                => 23730,
                         "chuluthu"             => 28750,
                         "chumly"               => 22763,
                         "chumpy"               => 29183,
                         "chunky"               => 2930,
                         "chunli"               => 22084,
                         "chuo"                 => 3323,
                         "chupa"                => 18932,
                         "church1"              => 26207,
                         "churchil"             => 7204,
                         "chutney"              => 16254,
                         "chuvak"               => 28594,
                         "chyna"                => 17691,
                         "chynna"               => 20978,
                         "cia123"               => 28627,
                         "cicci"                => 13642,
                         "ciccia"               => 28838,
                         "ciccio"               => 3396,
                         "ciccione"             => 26508,
                         "cicero"               => 2883,
                         "cichlid"              => 13075,
                         "cidkid86"             => 12245,
                         "cigar1"               => 12183,
                         "cigarett"             => 15353,
                         "cigars"               => 2443,
                         "cimbo"                => 24729,
                         "cimbom"               => 8716,
                         "cincinna"             => 22769,
                         "cinco"                => 19867,
                         "cindee"               => 24560,
                         "cinder"               => 2353,
                         "cinderel"             => 17111,
                         "cinders"              => 10936,
                         "cindy1"               => 3889,
                         "cindy2"               => 20602,
                         "cindy69"              => 22998,
                         "cindylou"             => 16915,
                         "cindys"               => 19594,
                         "cinemax"              => 27435,
                         "cingular"             => 13846,
                         "cinnamon"             => 2271,
                         "cinta"                => 23362,
                         "cintaku"              => 29608,
                         "cinzia"               => 14704,
                         "cious"                => 21020,
                         "cipher"               => 8926,
                         "cirrus"               => 5203,
                         "cisco1"               => 9629,
                         "cisco123"             => 16640,
                         "cisco69"              => 28902,
                         "ciscokid"             => 14949,
                         "citadel"              => 3687,
                         "citibank"             => 8004,
                         "citroen"              => 4357,
                         "citron"               => 8457,
                         "citrus"               => 7253,
                         "city1"                => 24943,
                         "cityboy"              => 23531,
                         "civic1"               => 16425,
                         "civic97"              => 29972,
                         "civicex"              => 16965,
                         "civics"               => 16323,
                         "civicsi"              => 6263,
                         "civilwar"             => 6381,
                         "cjcbcrf"              => 13024,
                         "cjdthitycndj"         => 25198,
                         "cjfrf"                => 24921,
                         "cjhjrf"               => 22337,
                         "cjkjdtq"              => 24763,
                         "cjkysir"              => 22332,
                         "cjkysirj"             => 692,
                         "cjkywt"               => 1257,
                         "cjlove"               => 20181,
                         "cjrjkjdf"             => 11060,
                         "cjxb2014"             => 18569,
                         "cjymrf"               => 25030,
                         "cjytxrf"              => 7308,
                         "cjytxrj"              => 20172,
                         "ck6znp42"             => 21774,
                         "ckfdbr"               => 9974,
                         "ckflrbq"              => 29193,
                         "ckjybr"               => 13220,
                         "clahay"               => 22506,
                         "claire1"              => 12300,
                         "claire2"              => 29102,
                         "clambake"             => 14360,
                         "clancy"               => 1703,
                         "clancy1"              => 26452,
                         "clapton"              => 2184,
                         "clapton1"             => 17029,
                         "clara1"               => 19285,
                         "claret"               => 19219,
                         "clarets"              => 20235,
                         "clarinet"             => 2750,
                         "clarion"              => 10171,
                         "clarisse"             => 22124,
                         "clark1"               => 14194,
                         "clarkie"              => 11899,
                         "clarkken"             => 19898,
                         "clarkkent"            => 25854,
                         "clarks"               => 17138,
                         "classact"             => 23113,
                         "classe"               => 29126,
                         "classi"               => 23406,
                         "classic"              => 682,
                         "classic1"             => 9872,
                         "classics"             => 3614,
                         "claude1"              => 20793,
                         "claudi"               => 3136,
                         "claudia1"             => 5977,
                         "claudiu"              => 29802,
                         "clave"                => 26992,
                         "claybird"             => 21847,
                         "claymore"             => 3098,
                         "clayton1"             => 15195,
                         "clean1"               => 18887,
                         "clearwat"             => 29178,
                         "clemence"             => 16717,
                         "clemson"              => 2166,
                         "clemson1"             => 12276,
                         "cleo123"              => 23796,
                         "cleocat"              => 24728,
                         "cleodog"              => 18435,
                         "cleopatr"             => 4270,
                         "cleric"               => 10459,
                         "clevelan"             => 2745,
                         "clicker"              => 15868,
                         "cliff1"               => 19836,
                         "cliffy"               => 8684,
                         "climax"               => 5350,
                         "climb7"               => 12216,
                         "climber"              => 4023,
                         "climbon"              => 18164,
                         "clint1"               => 17331,
                         "clinton1"             => 10251,
                         "clipper"              => 2312,
                         "clipper1"             => 19862,
                         "clippers"             => 4029,
                         "clips"                => 6003,
                         "clit"                 => 3827,
                         "clitlick"             => 9610,
                         "clitoris"             => 1729,
                         "clitring"             => 27879,
                         "clitty"               => 26002,
                         "clk430"               => 27706,
                         "clock1"               => 27194,
                         "clocker"              => 22691,
                         "clockwor"             => 26483,
                         "cloggy"               => 9374,
                         "close-up"             => 7031,
                         "closeup"              => 9868,
                         "cloud1"               => 19880,
                         "cloud9"               => 2079,
                         "clouds"               => 2984,
                         "cloudy"               => 6036,
                         "clove"                => 27947,
                         "clover"               => 1358,
                         "clovis"               => 5418,
                         "clown1"               => 18013,
                         "clownboy"             => 24430,
                         "clowns"               => 3689,
                         "clticic"              => 12988,
                         "clubber"              => 10176,
                         "clubpenguin"          => 14181,
                         "clutch"               => 4847,
                         "clyde1"               => 7772,
                         "cmc09"                => 20473,
                         "cmfnpu"               => 14061,
                         "cmgang1"              => 19582,
                         "cmoney"               => 20723,
                         "cmu9ggzh"             => 21307,
                         "cn42qj"               => 14211,
                         "cneltyn"              => 7876,
                         "cnfcbr"               => 10719,
                         "cnfhsq"               => 26284,
                         "cnfkrth"              => 6910,
                         "cnfnbcnbrf"           => 27918,
                         "cnfybckfd"            => 4183,
                         "cnhfcnm"              => 22035,
                         "cnhfyybr"             => 22820,
                         "cnhjbntkm"            => 14063,
                         "cnhjqrf"              => 11597,
                         "cnhtkjr"              => 22801,
                         "cnhtktw"              => 10700,
                         "cnhtrjpf"             => 14138,
                         "cnjvfnjkju"           => 10845,
                         "cntgfirf"             => 14241,
                         "cntgfy"               => 7538,
                         "cntgfyjdf"            => 23645,
                         "cnthdf"               => 10037,
                         "co2000"               => 23044,
                         "co437at"              => 20605,
                         "coach1"               => 9902,
                         "coastie"              => 28131,
                         "cobain"               => 3717,
                         "cobaka"               => 15227,
                         "cobalt"               => 3408,
                         "cobber"               => 18642,
                         "cobblers"             => 13869,
                         "cobra"                => 748,
                         "cobra1"               => 2442,
                         "cobra12"              => 25023,
                         "cobra123"             => 20145,
                         "cobra2"               => 17547,
                         "cobra427"             => 7184,
                         "cobra5"               => 29635,
                         "cobra777"             => 29425,
                         "cobrajet"             => 13807,
                         "cobras"               => 4041,
                         "cobraya"              => 9065,
                         "cobweb"               => 20599,
                         "cocacol"              => 6866,
                         "cocacola"             => 194,
                         "cocacola1"            => 18206,
                         "cocaine"              => 3140,
                         "cochino"              => 28619,
                         "cochise"              => 7910,
                         "cochon"               => 12625,
                         "cock"                 => 436,
                         "cock1"                => 15200,
                         "cock22"               => 23559,
                         "cock69"               => 18980,
                         "cocker"               => 4228,
                         "cockgobbler"          => 24214,
                         "cockman"              => 18457,
                         "cockring"             => 15900,
                         "cocks"                => 2192,
                         "cocksuck"             => 4189,
                         "cocksucker"           => 5425,
                         "coco11"               => 26094,
                         "coco12"               => 26041,
                         "coco123"              => 18570,
                         "cocoa1"               => 19660,
                         "cocodog"              => 16069,
                         "cocoloco"             => 13703,
                         "cocomo"               => 28987,
                         "coconut"              => 2105,
                         "cocopuff"             => 15855,
                         "cocorico"             => 14477,
                         "cocotte"              => 28080,
                         "cocteau"              => 15803,
                         "codeblue"             => 9505,
                         "codeman"              => 16258,
                         "codered"              => 4133,
                         "codered1"             => 27955,
                         "codfish"              => 15419,
                         "cody1"                => 22335,
                         "cody11"               => 25523,
                         "cody123"              => 28540,
                         "codydog"              => 15767,
                         "codyman"              => 20105,
                         "coffe"                => 11422,
                         "coffee"               => 148,
                         "coffee1"              => 9111,
                         "coffee11"             => 27892,
                         "coffee12"             => 28569,
                         "coffee2"              => 24857,
                         "coffees"              => 7567,
                         "cogito"               => 10964,
                         "cognit"               => 23964,
                         "cohiba"               => 2435,
                         "cojones"              => 14078,
                         "coke"                 => 2017,
                         "cokeisit"             => 22667,
                         "cokeman"              => 22929,
                         "cola"                 => 5818,
                         "coldbeer"             => 3454,
                         "coldfire"             => 12116,
                         "coldplay"             => 4488,
                         "colegiata"            => 29054,
                         "coleman1"             => 20689,
                         "coleta"               => 19623,
                         "colfax"               => 22970,
                         "colgate"              => 10195,
                         "colibri"              => 12364,
                         "colin1"               => 12794,
                         "colin123"             => 28231,
                         "collant"              => 16622,
                         "collants"             => 15415,
                         "collect1"             => 28372,
                         "collecti"             => 9022,
                         "collecto"             => 29482,
                         "colleen1"             => 11007,
                         "college1"             => 10172,
                         "collie"               => 5709,
                         "collingw"             => 16266,
                         "collins1"             => 16858,
                         "colnago"              => 4082,
                         "colole57"             => 15524,
                         "colombi"              => 9260,
                         "colombia"             => 1533,
                         "color1"               => 21946,
                         "colorado"             => 578,
                         "colors"               => 1051,
                         "colossus"             => 8146,
                         "colt1911"             => 11593,
                         "colt45"               => 1240,
                         "coltrane"             => 1442,
                         "colts1"               => 22029,
                         "colts18"              => 27096,
                         "columbo"              => 8022,
                         "comanche"             => 3991,
                         "comand"               => 24415,
                         "comander"             => 16990,
                         "comando"              => 22155,
                         "combat123654"         => 12378,
                         "comcast"              => 6847,
                         "comcast1"             => 13502,
                         "come2me"              => 22011,
                         "comein"               => 5401,
                         "comeon"               => 6432,
                         "comet"                => 2923,
                         "comet1"               => 14258,
                         "comets"               => 6834,
                         "comfort1"             => 25180,
                         "comicbook"            => 10783,
                         "comicbookdb"          => 7392,
                         "comicbooks"           => 25368,
                         "comicsans"            => 17060,
                         "command1"             => 21209,
                         "command2"             => 28227,
                         "commande"             => 4949,
                         "commando"             => 1722,
                         "commo"                => 27790,
                         "commodor"             => 9691,
                         "communit"             => 25976,
                         "compa"                => 10402,
                         "compac"               => 29458,
                         "compaq"               => 136,
                         "compaq1"              => 4358,
                         "compaq12"             => 13670,
                         "compaq123"            => 26601,
                         "compaq3"              => 20670,
                         "compass"              => 4033,
                         "compass1"             => 27113,
                         "compusa"              => 10905,
                         "computador"           => 13735,
                         "computadora"          => 19794,
                         "compute"              => 2570,
                         "compute1"             => 18523,
                         "computer"             => 51,
                         "computer1"            => 5577,
                         "conair"               => 18130,
                         "conan"                => 4311,
                         "conan1"               => 9369,
                         "concac"               => 20760,
                         "concord"              => 3764,
                         "concorde"             => 3592,
                         "concordi"             => 16930,
                         "concrete"             => 1117,
                         "conditio"             => 28391,
                         "condom"               => 2187,
                         "condor"               => 1267,
                         "conducto"             => 25466,
                         "conehead"             => 17722,
                         "conej"                => 23574,
                         "conejo"               => 10305,
                         "confiden"             => 17136,
                         "config"               => 10907,
                         "cong"                 => 3081,
                         "congas"               => 26448,
                         "conker"               => 9662,
                         "conman"               => 9740,
                         "connect"              => 1145,
                         "connect1"             => 10174,
                         "connecte"             => 25029,
                         "connecti"             => 14215,
                         "conner1"              => 28962,
                         "connery"              => 11882,
                         "conni"                => 19119,
                         "connie1"              => 10219,
                         "conno"                => 28422,
                         "connor"               => 579,
                         "connor1"              => 13644,
                         "connor11"             => 26515,
                         "connor12"             => 29820,
                         "conny"                => 25664,
                         "conor1"               => 23716,
                         "conrad1"              => 29930,
                         "conrail"              => 15466,
                         "consense"             => 15211,
                         "constanc"             => 21904,
                         "construc"             => 16224,
                         "consulta"             => 27064,
                         "consumer"             => 1038,
                         "containe"             => 18557,
                         "contax"               => 28006,
                         "contex"               => 27973,
                         "contortionist"        => 7242,
                         "contour"              => 6284,
                         "contra"               => 5586,
                         "contrasena"           => 26400,
                         "contrera"             => 22790,
                         "contro"               => 26138,
                         "control1"             => 7899,
                         "control2"             => 26465,
                         "coochie"              => 6760,
                         "cooker"               => 8456,
                         "cooki"                => 7609,
                         "cookie"               => 95,
                         "cookie1"              => 3885,
                         "cookie11"             => 27780,
                         "cookie12"             => 13766,
                         "cookie123"            => 27927,
                         "cookie13"             => 26685,
                         "cookie2"              => 23715,
                         "cookie59"             => 16183,
                         "cookies"              => 905,
                         "cookies1"             => 11845,
                         "cooking1"             => 23145,
                         "cool-ca"              => 26860,
                         "cool1"                => 8948,
                         "cool11"               => 19990,
                         "cool12"               => 6692,
                         "cool123"              => 6420,
                         "cool1234"             => 23262,
                         "cool22"               => 26978,
                         "cool23"               => 29376,
                         "cool69"               => 21016,
                         "cool99"               => 12287,
                         "coolbean"             => 9305,
                         "coolbeans"            => 15913,
                         "coolboy"              => 9028,
                         "coolbree"             => 27720,
                         "coolcat"              => 4564,
                         "cooldude"             => 1230,
                         "cooler"               => 1590,
                         "coolfool"             => 24723,
                         "coolgirl"             => 8032,
                         "coolguy"              => 2516,
                         "coolguy1"             => 20344,
                         "coolhand"             => 6063,
                         "coolie"               => 12192,
                         "coolio"               => 1299,
                         "coolio1"              => 24021,
                         "coolkid"              => 14672,
                         "coolman"              => 1938,
                         "coolman1"             => 20572,
                         "coolness"             => 3392,
                         "coolone"              => 9130,
                         "coolwhip"             => 24219,
                         "coonass"              => 13489,
                         "coondog"              => 14901,
                         "cooool"               => 17322,
                         "coope"                => 12029,
                         "cooper1"              => 5509,
                         "cooper11"             => 26674,
                         "cooper12"             => 23787,
                         "cooper2"              => 26450,
                         "coopers"              => 10509,
                         "coors"                => 5067,
                         "coors1"               => 21763,
                         "coorslig"             => 13864,
                         "coorslight"           => 19418,
                         "coorslit"             => 26432,
                         "cooter"               => 2131,
                         "cootie"               => 26482,
                         "copenhag"             => 6257,
                         "copernic"             => 27137,
                         "copper"               => 335,
                         "copper1"              => 8501,
                         "copter"               => 15487,
                         "corazo"               => 6343,
                         "core2duo"             => 29621,
                         "corey1"               => 12371,
                         "corgan"               => 8289,
                         "corgi"                => 23309,
                         "corkey"               => 19165,
                         "corkie"               => 26988,
                         "corky1"               => 18906,
                         "corleone"             => 3307,
                         "cormac"               => 22291,
                         "cornbrea"             => 12989,
                         "cornbread"            => 16637,
                         "corndog"              => 4252,
                         "cornel"               => 20537,
                         "corneliu"             => 23702,
                         "cornell1"             => 17591,
                         "cornet"               => 15474,
                         "cornfed"              => 21749,
                         "cornflak"             => 16780,
                         "cornhole"             => 6939,
                         "cornholi"             => 10906,
                         "cornholio"            => 16416,
                         "cornhusk"             => 24270,
                         "corolla"              => 3643,
                         "corona"               => 847,
                         "corona1"              => 20688,
                         "coronas"              => 24492,
                         "corone"               => 27204,
                         "coronet"              => 12975,
                         "corperfmonsy"         => 24832,
                         "corporat"             => 29823,
                         "corpsman"             => 16975,
                         "corrado"              => 2162,
                         "corrado1"             => 20631,
                         "corran"               => 12803,
                         "corsa"                => 18446,
                         "corsair"              => 3317,
                         "corsair1"             => 28652,
                         "corsano"              => 29157,
                         "corset"               => 14761,
                         "corsica"              => 8919,
                         "cortina"              => 8413,
                         "cortland"             => 12077,
                         "corvair"              => 15183,
                         "corvet"               => 17355,
                         "corvet07"             => 7525,
                         "corvett"              => 7724,
                         "corvett1"             => 14399,
                         "corvette"             => 76,
                         "corvette1"            => 24495,
                         "corvus"               => 11805,
                         "cosette"              => 29177,
                         "cosita"               => 11624,
                         "cosmic"               => 3329,
                         "cosmo"                => 2109,
                         "cosmo1"               => 6952,
                         "cosmo123"             => 26625,
                         "cosmodog"             => 25280,
                         "cosmos"               => 1271,
                         "cossie"               => 16408,
                         "costaric"             => 7900,
                         "costarica"            => 12756,
                         "costco"               => 20482,
                         "cosworth"             => 1760,
                         "cottage1"             => 24837,
                         "cotton1"              => 25153,
                         "cougar"               => 556,
                         "cougar1"              => 12137,
                         "cougars"              => 3402,
                         "cougars1"             => 26632,
                         "couger"               => 23454,
                         "counchac"             => 15190,
                         "count0"               => 12874,
                         "countach"             => 11652,
                         "counte"               => 25444,
                         "counter1"             => 18903,
                         "counterstrike"        => 9355,
                         "countr"               => 28275,
                         "country1"             => 10303,
                         "countryb"             => 28840,
                         "countyli"             => 13537,
                         "court1"               => 26723,
                         "courtne"              => 22087,
                         "courtney1"            => 12721,
                         "cousteau"             => 24403,
                         "coventry"             => 4275,
                         "covingto"             => 28842,
                         "cowabung"             => 22632,
                         "cowbo"                => 14638,
                         "cowboy"               => 111,
                         "cowboy1"              => 3310,
                         "cowboy12"             => 23578,
                         "cowboy22"             => 22911,
                         "cowboys"              => 141,
                         "cowboys0"             => 28651,
                         "cowboys1"             => 1572,
                         "cowboys2"             => 15418,
                         "cowboyup"             => 7462,
                         "cowd00d"              => 23331,
                         "cowdog"               => 29411,
                         "cowgirl"              => 5043,
                         "cowman"               => 9718,
                         "cowpie"               => 17645,
                         "coyote"               => 874,
                         "coyote1"              => 26409,
                         "coyotes"              => 10430,
                         "cozumel"              => 12660,
                         "cptnz062"             => 21295,
                         "cq2kph"               => 16924,
                         "cqnwhy"               => 18017,
                         "cqub6553"             => 26762,
                         "cr250r"               => 17968,
                         "crabby"               => 10275,
                         "crabcake"             => 19831,
                         "crack1"               => 12611,
                         "cracker"              => 1392,
                         "cracker1"             => 12172,
                         "crackhea"             => 13736,
                         "crackhead"            => 15806,
                         "cracksevi"            => 11656,
                         "cracky"               => 29259,
                         "crafty"               => 8108,
                         "craig1"               => 10063,
                         "craig123"             => 26385,
                         "craiger"              => 24806,
                         "craigs"               => 26191,
                         "cramps"               => 3840,
                         "cranberr"             => 13112,
                         "crapola"              => 13882,
                         "crapper"              => 15792,
                         "crappie"              => 9663,
                         "crash1"               => 7017,
                         "crasher"              => 15235,
                         "craving"              => 6312,
                         "crawdad"              => 20128,
                         "crawfish"             => 16272,
                         "crawler"              => 15978,
                         "craxxxs"              => 18816,
                         "crayfish"             => 17693,
                         "crayola"              => 15771,
                         "crayon"               => 8627,
                         "crazy1"               => 1990,
                         "crazy123"             => 13881,
                         "crazy2"               => 29957,
                         "crazy4u"              => 20757,
                         "crazy8"               => 10028,
                         "crazybab"             => 2175,
                         "crazyboy"             => 16493,
                         "crazyc"               => 28881,
                         "crazycat"             => 17713,
                         "crazyd"               => 25913,
                         "crazyfrog"            => 21310,
                         "crazyj"               => 28172,
                         "crazyman"             => 6530,
                         "crazyzil"             => 12143,
                         "crazzy"               => 24384,
                         "cream1"               => 22866,
                         "creampie"             => 1622,
                         "creamy"               => 2132,
                         "creamyou"             => 20685,
                         "creatine"             => 9288,
                         "creativ"              => 10381,
                         "creativ1"             => 26357,
                         "creative"             => 298,
                         "creative1"            => 18132,
                         "creaven"              => 15541,
                         "creed1"               => 17526,
                         "creek1"               => 23058,
                         "creeper"              => 7449,
                         "creepers"             => 6717,
                         "creosote"             => 16034,
                         "crescent"             => 5876,
                         "cressida"             => 28065,
                         "cresta"               => 11530,
                         "cretin"               => 9426,
                         "crevette"             => 18444,
                         "crevice"              => 8889,
                         "crewcom"              => 11161,
                         "crf450"               => 18693,
                         "crfnbyf"              => 22025,
                         "crfprf"               => 9161,
                         "crhbgrf"              => 26230,
                         "cribbage"             => 21318,
                         "cricke"               => 15928,
                         "cricket"              => 362,
                         "cricket1"             => 4173,
                         "crickett"             => 19288,
                         "crimson"              => 1261,
                         "crimson1"             => 9406,
                         "crippler"             => 14015,
                         "crisco"               => 17922,
                         "crispy"               => 6338,
                         "cristia"              => 10448,
                         "cristiano"            => 9209,
                         "cristo"               => 11258,
                         "critter"              => 2377,
                         "critter1"             => 28609,
                         "critters"             => 13971,
                         "crjhgbjy"             => 2812,
                         "crjhjcnm"             => 22478,
                         "crm0624"              => 29420,
                         "crm114"               => 13728,
                         "croaker"              => 23300,
                         "croco"                => 21291,
                         "crocodil"             => 8630,
                         "crocus"               => 17298,
                         "cronaldo"             => 21127,
                         "cronic"               => 8378,
                         "cronos"               => 13907,
                         "cross1"               => 18336,
                         "crossfir"             => 17794,
                         "crossroa"             => 24206,
                         "croucher"             => 15037,
                         "crouton"              => 20190,
                         "crowbar"              => 8836,
                         "crowes"               => 12376,
                         "crownvic"             => 14154,
                         "cruella"              => 21021,
                         "cruise"               => 2104,
                         "cruiser"              => 2458,
                         "cruiser1"             => 18183,
                         "crumbs"               => 6703,
                         "crumpet"              => 19078,
                         "crunch"               => 2080,
                         "crunchy"              => 8951,
                         "crusader"             => 1395,
                         "crusher"              => 3615,
                         "crushme"              => 17611,
                         "crusty"               => 4806,
                         "cruzazul"             => 11765,
                         "cruzer"               => 14996,
                         "crybaby"              => 10326,
                         "crypto"               => 11903,
                         "crysis"               => 2371,
                         "crystal0"             => 27056,
                         "crystal1"             => 2782,
                         "crystal2"             => 22810,
                         "crystal7"             => 29409,
                         "csfbr5yy"             => 14749,
                         "csm101"               => 26785,
                         "cstock"               => 26642,
                         "cstrike"              => 10641,
                         "csyekmrf"             => 28455,
                         "csyekz"               => 7426,
                         "csyjxtr"              => 7175,
                         "ctcnhf"               => 17173,
                         "ctdfcnjgjkm"          => 9850,
                         "cthlwt"               => 23169,
                         "cthtuf"               => 3624,
                         "cthulhu"              => 1972,
                         "cthulhu1"             => 27067,
                         "cthulu"               => 13762,
                         "cthutq"               => 844,
                         "cthuttdbx"            => 14123,
                         "cthuttdf"             => 24159,
                         "cthuttdyf"            => 11490,
                         "ctrhtn"               => 4048,
                         "ctrhtnyj"             => 27582,
                         "ctvtyjd"              => 18417,
                         "ctvtyjdf"             => 24737,
                         "cuan"                 => 3777,
                         "cubalibr"             => 21641,
                         "cubalibre"            => 23410,
                         "cubana"               => 26369,
                         "cubano"               => 9580,
                         "cubase"               => 13571,
                         "cubbie"               => 14200,
                         "cubbies"              => 2649,
                         "cubbies1"             => 15242,
                         "cubby"                => 15605,
                         "cubby1"               => 26585,
                         "cubfan"               => 14398,
                         "cubs"                 => 5335,
                         "cubsfan"              => 27422,
                         "cubswin"              => 2988,
                         "cubswin1"             => 16384,
                         "cucciolo"             => 16413,
                         "cucina"               => 28460,
                         "cuckold"              => 13778,
                         "cucumber"             => 5347,
                         "cuddles"              => 1757,
                         "cuddles1"             => 13899,
                         "cueball"              => 8478,
                         "cuervo"               => 5060,
                         "cujo31"               => 18748,
                         "culebra"              => 24179,
                         "culero"               => 22317,
                         "culinary"             => 6152,
                         "culito"               => 22721,
                         "cum123"               => 18188,
                         "cum2me"               => 23296,
                         "cum4me"               => 10264,
                         "cumalot"              => 12214,
                         "cumberla"             => 27052,
                         "cumeater"             => 9016,
                         "cumface"              => 11635,
                         "cumhard"              => 26756,
                         "cumload"              => 10339,
                         "cumlover"             => 20311,
                         "cumm"                 => 6181,
                         "cummer"               => 7355,
                         "cummin"               => 13250,
                         "cumming"              => 1204,
                         "cumnow"               => 14686,
                         "cumonme"              => 9379,
                         "cumquat"              => 27606,
                         "cumshot"              => 525,
                         "cumshot1"             => 25884,
                         "cumshots"             => 14357,
                         "cumslut"              => 5257,
                         "cumsuck"              => 22134,
                         "cumsucker"            => 20409,
                         "cumulus"              => 12534,
                         "cunningh"             => 27858,
                         "cunt"                 => 560,
                         "cunt1"                => 26165,
                         "cunt69"               => 16618,
                         "cuntfinger"           => 25301,
                         "cunthole"             => 27205,
                         "cuntlick"             => 10461,
                         "cunts"                => 2402,
                         "cuntsoup"             => 11539,
                         "cup2006"              => 11850,
                         "cupcake"              => 1912,
                         "cupcake1"             => 11167,
                         "cupoi"                => 5799,
                         "curious"              => 1217,
                         "curious1"             => 15799,
                         "curitiba"             => 19223,
                         "curiva"               => 26845,
                         "curlew"               => 25236,
                         "curly1"               => 16462,
                         "currahee"             => 25736,
                         "curtis1"              => 11752,
                         "custard"              => 7610,
                         "custom"               => 2589,
                         "cutegirl"             => 13536,
                         "cutie1"               => 15617,
                         "cutiepie"             => 4599,
                         "cuties"               => 10690,
                         "cutlass"              => 2006,
                         "cutlass1"             => 26384,
                         "cutter"               => 1909,
                         "cuxldv"               => 18016,
                         "cv141ab"              => 22807,
                         "cvbhyjd"              => 9049,
                         "cvbhyjdf"             => 7991,
                         "cvbn123"              => 25357,
                         "cvetok"               => 14161,
                         "cvthnm"               => 5143,
                         "cvtifhbrb"            => 13801,
                         "cvzefh1gk"            => 23595,
                         "cvzefh1gkc"           => 10185,
                         "cwoui"                => 9540,
                         "cx18ka"               => 28375,
                         "cxfcnkbdfz"           => 8297,
                         "cxfcnm"               => 16142,
                         "cxfcnmt"              => 1674,
                         "cxfcnmttcnm"          => 11927,
                         "cxzdsaewq"            => 19624,
                         "cyber"                => 2542,
                         "cyber1"               => 10477,
                         "cyberia"              => 18699,
                         "cyberman"             => 16199,
                         "cybernet"             => 18701,
                         "cyberonline"          => 10147,
                         "cybersex"             => 7460,
                         "cyborg"               => 4320,
                         "cybrthc"              => 29493,
                         "cycle1"               => 28475,
                         "cyclone"              => 2255,
                         "cyclone1"             => 22742,
                         "cyclones"             => 6099,
                         "cyclops"              => 2383,
                         "cyclops1"             => 16009,
                         "cyecvevhbr"           => 16053,
                         "cyfqgth"              => 20359,
                         "cygnus"               => 3528,
                         "cygnusx1"             => 4644,
                         "cyjdsvujljv"          => 15303,
                         "cyklone"              => 28199,
                         "cynthi"               => 26212,
                         "cynthia1"             => 7932,
                         "cypher"               => 6193,
                         "cypress"              => 2498,
                         "cypress1"             => 29274,
                         "cyrano"               => 5859,
                         "cyrus1"               => 16629,
                         "cytuehjxrf"           => 22208,
                         "cytujdbr"             => 20597,
                         "cyzkhw"               => 15783,
                         "czarny"               => 26703,
                         "czekolada"            => 24456,
                         "d0ct0r"               => 22654,
                         "d12345"               => 9313,
                         "d123456"              => 9709,
                         "d1234567"             => 26023,
                         "d1d2d3"               => 26202,
                         "d1i2m3a4"             => 13590,
                         "d1lakiss"             => 14007,
                         "d2000lb"              => 17883,
                         "d50gnn"               => 25324,
                         "d6o8pm"               => 12467,
                         "d6wnro"               => 12798,
                         "d78unhxq"             => 17634,
                         "d9ebk7"               => 16475,
                         "d9ungl"               => 16107,
                         "dabears"              => 3693,
                         "dabl1125"             => 29805,
                         "dabomb"               => 5108,
                         "daboss"               => 13296,
                         "daboys"               => 18210,
                         "dabulls"              => 7215,
                         "dad123"               => 24088,
                         "dad2ownu"             => 11529,
                         "daddie"               => 16365,
                         "daddio"               => 12778,
                         "daddy1"               => 2000,
                         "daddy123"             => 10537,
                         "daddy2"               => 17965,
                         "daddy69"              => 29019,
                         "daddymac"             => 24519,
                         "daddyo"               => 4978,
                         "daddys"               => 6702,
                         "daddysgirl"           => 29542,
                         "daddyy"               => 17842,
                         "daedalus"             => 7270,
                         "daemon"               => 3415,
                         "daewoo"               => 2595,
                         "daffodil"             => 9050,
                         "daffy"                => 6506,
                         "daffyduc"             => 19169,
                         "daffyduck"            => 26755,
                         "daftpunk"             => 18930,
                         "dagestan"             => 9798,
                         "dagger"               => 1378,
                         "dagger1"              => 27998,
                         "dagobah"              => 24129,
                         "dagobert"             => 7407,
                         "dagwood"              => 10658,
                         "dahc1"                => 11127,
                         "daimon"               => 29230,
                         "daishi"               => 27519,
                         "daisie"               => 20324,
                         "daisuke"              => 20321,
                         "daisy1"               => 1987,
                         "daisy123"             => 12266,
                         "daisy2"               => 17245,
                         "daisy3112"            => 29572,
                         "daisydog"             => 5423,
                         "daisymae"             => 9820,
                         "daisymay"             => 17671,
                         "daisys"               => 17628,
                         "dak001"               => 26892,
                         "dakine"               => 9148,
                         "daking"               => 15477,
                         "dakot"                => 13931,
                         "dakota"               => 117,
                         "dakota01"             => 17648,
                         "dakota1"              => 4329,
                         "dakota12"             => 17186,
                         "dakota2"              => 24132,
                         "dakota99"             => 27346,
                         "dalamar"              => 17582,
                         "dale03"               => 9997,
                         "dale3"                => 26229,
                         "dale33"               => 28523,
                         "dale38"               => 28904,
                         "dale88"               => 18375,
                         "dalejr"               => 2524,
                         "dalejr8"              => 8174,
                         "dalejr88"             => 20849,
                         "dalglish"             => 18299,
                         "dalla"                => 14293,
                         "dallas"               => 71,
                         "dallas01"             => 20011,
                         "dallas1"              => 2426,
                         "dallas11"             => 18203,
                         "dallas12"             => 14525,
                         "dallas21"             => 15526,
                         "dallas22"             => 6307,
                         "dallastx"             => 12308,
                         "dalmatio"             => 17758,
                         "dalshe"               => 4120,
                         "damage11"             => 9966,
                         "damager"              => 9971,
                         "daman"                => 5153,
                         "daman1"               => 29506,
                         "dameon"               => 24562,
                         "damia"                => 13841,
                         "damian1"              => 25638,
                         "damilola"             => 26308,
                         "damir"                => 20913,
                         "dammit"               => 2368,
                         "damned69"             => 18036,
                         "damngood"             => 17412,
                         "damnit"               => 2283,
                         "damnyou"              => 21907,
                         "damocles"             => 19562,
                         "damon1"               => 16368,
                         "dan123"               => 5891,
                         "danang"               => 25803,
                         "danbury"              => 19741,
                         "dance1"               => 9119,
                         "dance123"             => 24930,
                         "dancer"               => 567,
                         "dancer1"              => 7150,
                         "dancer2"              => 24170,
                         "dandelio"             => 29466,
                         "dandelion"            => 26125,
                         "dandfa"               => 9956,
                         "dandie"               => 29889,
                         "dang"                 => 2547,
                         "dangel"               => 29393,
                         "danger"               => 632,
                         "danger1"              => 19909,
                         "dangerou"             => 8353,
                         "dangit"               => 29375,
                         "danie"                => 2005,
                         "daniel0"              => 24182,
                         "daniel01"             => 21487,
                         "daniel1"              => 1837,
                         "daniel10"             => 29851,
                         "daniel11"             => 23956,
                         "daniel12"             => 6943,
                         "daniel123"            => 11386,
                         "daniel2"              => 11444,
                         "daniel20"             => 29629,
                         "daniel21"             => 23346,
                         "daniel26"             => 29514,
                         "daniel3"              => 22183,
                         "daniel4"              => 21190,
                         "daniel5"              => 27496,
                         "daniel6"              => 27974,
                         "daniel7"              => 27512,
                         "daniel9"              => 27300,
                         "daniela1"             => 10565,
                         "danielit"             => 10031,
                         "danielle1"            => 17196,
                         "daniil"               => 1861,
                         "danijela"             => 14664,
                         "danil"                => 7974,
                         "danil8098"            => 13816,
                         "danila"               => 1939,
                         "danilka"              => 6511,
                         "danilov"              => 17847,
                         "danilova"             => 29354,
                         "danimal"              => 12698,
                         "dank"                 => 6202,
                         "dank420"              => 13877,
                         "danman"               => 7837,
                         "danmark"              => 9225,
                         "danni"                => 1334,
                         "danni1"               => 10795,
                         "danniash"             => 26609,
                         "dannii"               => 29399,
                         "danno"                => 27989,
                         "dannon"               => 21365,
                         "dannon4"              => 11478,
                         "danny001"             => 24355,
                         "danny1"               => 3457,
                         "danny123"             => 15954,
                         "danny2"               => 17240,
                         "dannyb"               => 20476,
                         "dannyboy"             => 1851,
                         "dannyd"               => 25789,
                         "dannyg"               => 29091,
                         "dannym88"             => 27427,
                         "dannys"               => 29309,
                         "danone"               => 20916,
                         "dante1"               => 6979,
                         "dante123"             => 16972,
                         "dantes"               => 8676,
                         "danthema"             => 12688,
                         "dantheman"            => 13854,
                         "dantist"              => 14112,
                         "danzig"               => 2560,
                         "dapimp"               => 17465,
                         "dapper"               => 9233,
                         "dapzu455"             => 12199,
                         "darby1"               => 17898,
                         "darcy1"               => 22861,
                         "daredevi"             => 6213,
                         "daredevil"            => 6734,
                         "darian"               => 6676,
                         "darien"               => 11786,
                         "darina"               => 5779,
                         "darion"               => 21790,
                         "dark1"                => 20960,
                         "dark123"              => 19045,
                         "dark666"              => 20403,
                         "darkange"             => 5250,
                         "darkangel"            => 4763,
                         "darkelf"              => 6285,
                         "darken"               => 12078,
                         "darkfire"             => 28771,
                         "darkhors"             => 23539,
                         "darkjedi"             => 11210,
                         "darkknig"             => 15281,
                         "darkknight"           => 10307,
                         "darklord"             => 3555,
                         "darkmage"             => 29364,
                         "darkman"              => 3009,
                         "darkmanx"             => 18605,
                         "darkmoon"             => 9776,
                         "darknes"              => 7629,
                         "darkness"             => 333,
                         "darkness1"            => 24780,
                         "darknigh"             => 21294,
                         "darknight"            => 15610,
                         "darknite"             => 28861,
                         "darkone"              => 6032,
                         "darkseed"             => 27283,
                         "darkside"             => 679,
                         "darksoul"             => 17879,
                         "darksta"              => 25636,
                         "darkstar"             => 751,
                         "darksun"              => 26354,
                         "darkwing"             => 10356,
                         "darkwolf"             => 12957,
                         "darling1"             => 29715,
                         "darock"               => 15608,
                         "darre"                => 15049,
                         "darren1"              => 20977,
                         "darrian"              => 14551,
                         "darter"               => 14747,
                         "darth"                => 7116,
                         "darth1"               => 23717,
                         "darthmau"             => 12537,
                         "darthmaul"            => 27788,
                         "darthvad"             => 6232,
                         "darthvader"           => 8653,
                         "dartmout"             => 19734,
                         "daruma"               => 20744,
                         "darwin1"              => 21752,
                         "dasani"               => 6412,
                         "dasboot"              => 21800,
                         "dascha"               => 22728,
                         "dasein"               => 27065,
                         "dasha"                => 6724,
                         "dasha1"               => 15403,
                         "dasha123"             => 12586,
                         "dasha2010"            => 27371,
                         "dashadasha"           => 11347,
                         "dashenka"             => 17730,
                         "dashit"               => 20362,
                         "dashka"               => 8359,
                         "dastan"               => 13047,
                         "datalife"             => 13990,
                         "datalore"             => 14057,
                         "datnigga"             => 15229,
                         "datsun"               => 4502,
                         "daulet"               => 18661,
                         "dauren"               => 13786,
                         "dav123"               => 26027,
                         "dave01"               => 27379,
                         "dave1"                => 10178,
                         "dave12"               => 14546,
                         "dave123"              => 9836,
                         "dave1234"             => 24776,
                         "dave13"               => 19569,
                         "dave2"                => 29585,
                         "dave22"               => 29760,
                         "dave55"               => 26644,
                         "dave69"               => 18654,
                         "dave99"               => 19743,
                         "davecole"             => 9542,
                         "daveman"              => 19214,
                         "davex"                => 16219,
                         "daveyboy"             => 16509,
                         "david01"              => 18007,
                         "david1"               => 1023,
                         "david10"              => 26004,
                         "david11"              => 26613,
                         "david12"              => 8917,
                         "david123"             => 4524,
                         "david13"              => 22696,
                         "david2"               => 9741,
                         "david21"              => 24963,
                         "david26"              => 21023,
                         "david3"               => 18912,
                         "david4"               => 26008,
                         "david5"               => 21095,
                         "david69"              => 13299,
                         "david7"               => 17383,
                         "david77"              => 22772,
                         "david777"             => 27252,
                         "david9"               => 26690,
                         "davidb"               => 8147,
                         "davidc"               => 8184,
                         "davidd"               => 8856,
                         "davide"               => 3132,
                         "davidg"               => 15852,
                         "davidh"               => 16746,
                         "davidj"               => 9745,
                         "davidk"               => 14036,
                         "davidkin"             => 14508,
                         "davidl"               => 11352,
                         "davidlee"             => 17835,
                         "davidm"               => 10003,
                         "davido"               => 14026,
                         "davidoff"             => 8316,
                         "davidp"               => 17041,
                         "davidr"               => 18250,
                         "davidruiz"            => 17972,
                         "davids"               => 2108,
                         "davids1"              => 18845,
                         "davidt"               => 27673,
                         "davidw"               => 22761,
                         "davinchi"             => 25465,
                         "davinci"              => 5145,
                         "davion"               => 16823,
                         "davis1"               => 7965,
                         "davros"               => 13599,
                         "dawg"                 => 1777,
                         "dawg1"                => 10514,
                         "dawggy"               => 10863,
                         "dawgs"                => 7003,
                         "dawgs1"               => 8907,
                         "dawid1"               => 25764,
                         "dawidek"              => 18622,
                         "dawns"                => 8843,
                         "daxter"               => 26957,
                         "dayan"                => 18093,
                         "dayana"               => 18806,
                         "daydream"             => 7125,
                         "daystar"              => 26695,
                         "daytek"               => 7879,
                         "daytona"              => 1303,
                         "daytona1"             => 17293,
                         "daywalker"            => 23810,
                         "dazed"                => 20970,
                         "dazzle"               => 8307,
                         "dazzler"              => 29720,
                         "dbacks"               => 17159,
                         "dbityrf"              => 16191,
                         "dbjktnnf"             => 12651,
                         "dblock"               => 18800,
                         "dbm123dm"             => 29484,
                         "dbnfkbq"              => 8865,
                         "dbnfkbr"              => 5533,
                         "dbnfkz"               => 8903,
                         "dbrbyu"               => 26981,
                         "dbrecz"               => 8527,
                         "dbrekz"               => 12666,
                         "dbrf134"              => 10424,
                         "dbrnjh"               => 2874,
                         "dbrnjhbz"             => 762,
                         "dbrnjhjdbx"           => 12260,
                         "dbrnjhjdyf"           => 15075,
                         "dbrown"               => 19722,
                         "dbyjuhfl"             => 18182,
                         "dc3ubn"               => 22601,
                         "dclxvi"               => 26325,
                         "dcowboys"             => 16373,
                         "dcp500"               => 24784,
                         "dcpugh"               => 12736,
                         "dctdjkjl"             => 24350,
                         "dctktyyfz"            => 19700,
                         "dctulf"               => 23800,
                         "dctvcjcfnm"           => 29602,
                         "dctvgbplf"            => 29837,
                         "dctvghbdf"            => 20662,
                         "dctvghbdtn"           => 21162,
                         "dcunited"             => 14199,
                         "ddd123"               => 27705,
                         "ddddd1"               => 7675,
                         "dddddd1"              => 9216,
                         "ddddddd1"             => 12922,
                         "dddsss"               => 27696,
                         "ddgirls"              => 17604,
                         "de1987ma"             => 21121,
                         "de7mdf"               => 16124,
                         "deacons"              => 12168,
                         "dead1"                => 26894,
                         "dead13"               => 25436,
                         "deaddog"              => 15174,
                         "deadend"              => 20843,
                         "deadeye"              => 11042,
                         "deadfish"             => 28174,
                         "deadhead"             => 1607,
                         "deadlift"             => 12066,
                         "deadlock"             => 17578,
                         "deadman"              => 1943,
                         "deadman1"             => 17525,
                         "deadmau5"             => 27318,
                         "deadmeat"             => 12094,
                         "deadmoin"             => 27985,
                         "deadpool"             => 3279,
                         "deadsexy"             => 20516,
                         "deadsoul"             => 27738,
                         "deadspin"             => 6385,
                         "deadwood"             => 14303,
                         "deadzone"             => 29487,
                         "deagle"               => 19369,
                         "deamon"               => 12626,
                         "dean1"                => 29359,
                         "deano"                => 17477,
                         "death1"               => 2470,
                         "death123"             => 10341,
                         "death13"              => 29284,
                         "death2"               => 29854,
                         "death6"               => 28533,
                         "death666"             => 4002,
                         "deathnote"            => 6253,
                         "deathrow"             => 8620,
                         "deathsta"             => 12925,
                         "deathstar"            => 18918,
                         "debbie1"              => 8366,
                         "debbie69"             => 22012,
                         "debeers"              => 28119,
                         "deborah1"             => 7979,
                         "debra1"               => 26842,
                         "debugger"             => 29845,
                         "decatur"              => 10146,
                         "decembe"              => 19389,
                         "december1"            => 22250,
                         "decembre"             => 25404,
                         "decimal"              => 6775,
                         "declan"               => 10534,
                         "dedalus"              => 22429,
                         "dedham"               => 27454,
                         "dedhed"               => 19277,
                         "deebee"               => 27239,
                         "deedlit"              => 25895,
                         "deejay"               => 2642,
                         "deeman"               => 27468,
                         "deep111"              => 21919,
                         "deepak"               => 7926,
                         "deepblue"             => 8796,
                         "deepdive"             => 18976,
                         "deepika"              => 26732,
                         "deeppurple"           => 17863,
                         "deepsea"              => 11671,
                         "deepthro"             => 7579,
                         "deepthroat"           => 2450,
                         "deepwate"             => 21682,
                         "deere"                => 10908,
                         "deerhunt"             => 6283,
                         "deerhunter"           => 14149,
                         "deerpark"             => 19689,
                         "deeznuts"             => 1947,
                         "deeznutz"             => 2751,
                         "def456"               => 22956,
                         "defamer"              => 12894,
                         "default"              => 5164,
                         "default1"             => 27842,
                         "defcon"               => 8513,
                         "defcon1"              => 15102,
                         "defcon4"              => 24252,
                         "defender"             => 778,
                         "defiant"              => 1598,
                         "defiant1"             => 11153,
                         "defjam"               => 11717,
                         "deflep"               => 25974,
                         "deflep27"             => 21402,
                         "deftone"              => 16626,
                         "deftones"             => 937,
                         "degauss"              => 21037,
                         "dehpye"               => 13249,
                         "dei008"               => 24808,
                         "deicide"              => 8299,
                         "deidara"              => 24075,
                         "deimos"               => 10061,
                         "deion21"              => 16584,
                         "deisel"               => 27173,
                         "dejavu"               => 4965,
                         "dekal"                => 25952,
                         "delasoul"             => 15263,
                         "delboy"               => 7172,
                         "delenn"               => 20095,
                         "delerium"             => 26513,
                         "deles"                => 23915,
                         "delete"               => 1362,
                         "delfi"                => 18529,
                         "delfin"               => 4970,
                         "deliciou"             => 21035,
                         "delight"              => 3950,
                         "delite"               => 25815,
                         "dell11"               => 24907,
                         "dell123"              => 21865,
                         "dell50"               => 23481,
                         "delonge"              => 28485,
                         "delorean"             => 10584,
                         "delphi"               => 3039,
                         "delphin"              => 8658,
                         "delpiero"             => 5739,
                         "delray"               => 22793,
                         "delsol"               => 7843,
                         "delta"                => 1191,
                         "delta1"               => 1725,
                         "delta12"              => 29500,
                         "delta123"             => 15835,
                         "delta2"               => 16511,
                         "delta4"               => 16498,
                         "delta5"               => 26720,
                         "delta6"               => 21943,
                         "delta7"               => 26254,
                         "delta88"              => 28381,
                         "delta9"               => 15631,
                         "deltachi"             => 19117,
                         "deltaforce"           => 15433,
                         "deltaone"             => 17112,
                         "deltas"               => 6287,
                         "deltasig"             => 19479,
                         "deltic"               => 19627,
                         "deluge"               => 15305,
                         "deluxe"               => 2954,
                         "dembel"               => 20151,
                         "demeter"              => 15038,
                         "demetri"              => 25660,
                         "demetrio"             => 20815,
                         "demetriu"             => 28800,
                         "demian"               => 12355,
                         "demigod"              => 14991,
                         "demo"                 => 4079,
                         "demolay"              => 19263,
                         "demoman"              => 27146,
                         "demon1"               => 6431,
                         "demon123"             => 21112,
                         "demon6"               => 25405,
                         "demon666"             => 6004,
                         "demona"               => 25873,
                         "demond"               => 16222,
                         "den123"               => 10499,
                         "den12345"             => 25866,
                         "denali"               => 2059,
                         "denali1"              => 27135,
                         "deneme"               => 12491,
                         "deng"                 => 3214,
                         "denhaag"              => 24099,
                         "deniro"               => 5351,
                         "denis1"               => 7099,
                         "denis123"             => 10786,
                         "denis1984"            => 26953,
                         "denis1988"            => 26121,
                         "denis2011"            => 29924,
                         "denisa"               => 10410,
                         "denise1"              => 10363,
                         "deniska"              => 2239,
                         "denisov"              => 16727,
                         "deniss"               => 19744,
                         "denman85"             => 17284,
                         "denni"                => 7472,
                         "dennis1"              => 9398,
                         "dennis12"             => 29797,
                         "dennis2"              => 24303,
                         "denny1"               => 23776,
                         "dennys"               => 22126,
                         "denver1"              => 11912,
                         "denver7"              => 25076,
                         "denwer"               => 19796,
                         "denzel"               => 18518,
                         "depeche"              => 2366,
                         "depeche1"             => 22653,
                         "depechemode"          => 12415,
                         "derby1"               => 21856,
                         "derek1"               => 11920,
                         "dereks"               => 29452,
                         "derevo"               => 9605,
                         "derf"                 => 5071,
                         "derparol"             => 4550,
                         "derrek"               => 27119,
                         "derren"               => 25821,
                         "derrick1"             => 9463,
                         "derrickh"             => 20435,
                         "dervish"              => 21858,
                         "desade"               => 13202,
                         "desant"               => 17973,
                         "desdemon"             => 29234,
                         "desember"             => 23895,
                         "desert"               => 1816,
                         "design1"              => 23684,
                         "designer"             => 1940,
                         "desire"               => 1108,
                         "deskjet"              => 1961,
                         "deskjet1"             => 23835,
                         "deskpro"              => 22049,
                         "desktop"              => 5991,
                         "desperad"             => 10493,
                         "desperado"            => 7874,
                         "desperados"           => 14405,
                         "dessar"               => 26916,
                         "destin"               => 4277,
                         "destinee"             => 27966,
                         "destini"              => 20764,
                         "destiny"              => 368,
                         "destiny1"             => 4964,
                         "destiny2"             => 25136,
                         "destiny7"             => 29882,
                         "destro"               => 11273,
                         "destroye"             => 9451,
                         "detectiv"             => 7563,
                         "dethklok"             => 29490,
                         "detlef"               => 17952,
                         "detroit"              => 732,
                         "detroit1"             => 6947,
                         "deuce"                => 8006,
                         "deuce1"               => 24157,
                         "deuce22"              => 26445,
                         "deusex"               => 11335,
                         "deutsch"              => 3331,
                         "deutschl"             => 29897,
                         "deutschland"          => 8514,
                         "deviant"              => 13889,
                         "devil"                => 1357,
                         "devil1"               => 7408,
                         "devil123"             => 20442,
                         "devil666"             => 3119,
                         "devil69"              => 25079,
                         "devilboy"             => 18309,
                         "devildog"             => 890,
                         "devildriver"          => 12727,
                         "devilish"             => 18692,
                         "devilman"             => 7008,
                         "devilmay"             => 23114,
                         "devilmaycry"          => 7556,
                         "devilmaycry4"         => 12673,
                         "devils"               => 700,
                         "devils1"              => 9951,
                         "devils2"              => 21496,
                         "devin1"               => 14144,
                         "devlt4"               => 18370,
                         "devo"                 => 4600,
                         "devo2706"             => 16586,
                         "devochka"             => 24767,
                         "devon1"               => 20256,
                         "dewalt"               => 6762,
                         "dewars"               => 27196,
                         "dewdrop"              => 24117,
                         "dewey1"               => 20733,
                         "dexte"                => 14659,
                         "dexter"               => 293,
                         "dexter1"              => 10398,
                         "dextur"               => 24650,
                         "dezember"             => 21562,
                         "dfadan"               => 22746,
                         "dfcbkbcf"             => 5680,
                         "dfcbkbq"              => 3076,
                         "dfcbkmtd"             => 12801,
                         "dfcbkmtdf"            => 14791,
                         "dfcbktr"              => 16236,
                         "dfcmrf"               => 12568,
                         "dfcz123"              => 21153,
                         "dfghjc"               => 9585,
                         "dfhdfhf"              => 6763,
                         "dfhtybr"              => 27365,
                         "dfhtymt"              => 20185,
                         "dfkmltvfh"            => 28996,
                         "dfkmrbhbz"            => 14887,
                         "dfkthbq"              => 14742,
                         "dfkthbr"              => 29085,
                         "dfkthbz"              => 2028,
                         "dfkthf"               => 2365,
                         "dfktyjr"              => 13346,
                         "dfktynby"             => 4702,
                         "dfktynbyf"            => 2441,
                         "dfktynbyrf"           => 22804,
                         "dfktyrb"              => 27463,
                         "dflbvrf"              => 14282,
                         "dfnheirf"             => 17875,
                         "dfvgbh"               => 913,
                         "dfyjdf846"            => 24496,
                         "dfymrf"               => 28772,
                         "dfytxrf"              => 6189,
                         "dga9la"               => 18238,
                         "dgl70460"             => 12409,
                         "dgoins"               => 27307,
                         "dgthtl"               => 22259,
                         "dharma"               => 2601,
                         "dhip6a"               => 10825,
                         "dhjnvytyjub"          => 8265,
                         "dhtlbyf"              => 21352,
                         "diabl"                => 9824,
                         "diablo"               => 130,
                         "diablo1"              => 7110,
                         "diablo11"             => 19246,
                         "diablo2"              => 4921,
                         "diablo23"             => 27017,
                         "diablo66"             => 14350,
                         "diablo666"            => 16997,
                         "diablo69"             => 29122,
                         "diablos"              => 19385,
                         "diabolic"             => 18708,
                         "diabolik"             => 29415,
                         "diabolo"              => 12995,
                         "diadora"              => 23782,
                         "dialer"               => 19597,
                         "dialog"               => 3382,
                         "diamant"              => 7461,
                         "diamante"             => 7380,
                         "diamon"               => 5987,
                         "diamond"              => 82,
                         "diamond0"             => 26776,
                         "diamond1"             => 1706,
                         "diamond2"             => 24734,
                         "diamond3"             => 18004,
                         "diamond4"             => 26469,
                         "diamond6"             => 22641,
                         "diamond7"             => 21738,
                         "diamondb"             => 24707,
                         "diamondd"             => 22234,
                         "diamonds"             => 997,
                         "diana1"               => 5968,
                         "diana123"             => 21059,
                         "diana2"               => 24630,
                         "dianas"               => 21977,
                         "diane1"               => 10167,
                         "dianka"               => 11878,
                         "dianne1"              => 23867,
                         "dianochka"            => 26784,
                         "diao"                 => 3045,
                         "diapason"             => 25766,
                         "diaper"               => 4514,
                         "diavolo"              => 23609,
                         "dicanio"              => 14434,
                         "diceman"              => 10914,
                         "diciembr"             => 13449,
                         "dick"                 => 211,
                         "dick1"                => 6364,
                         "dick12"               => 16156,
                         "dick123"              => 23245,
                         "dick69"               => 10215,
                         "dicker"               => 6146,
                         "dickface"             => 10024,
                         "dickhead"             => 405,
                         "dickie"               => 3180,
                         "dickies"              => 15529,
                         "dickless"             => 11956,
                         "dicklick"             => 20997,
                         "dickme"               => 17734,
                         "dicks"                => 2220,
                         "dickster"             => 25878,
                         "dicksuck"             => 17021,
                         "dickweed"             => 7830,
                         "dicky"                => 5547,
                         "dictiona"             => 15788,
                         "diddle"               => 9366,
                         "diddy"                => 18707,
                         "didier"               => 6639,
                         "didit"                => 13671,
                         "diego1"               => 13832,
                         "diego123"             => 22961,
                         "diehard"              => 2710,
                         "diese"                => 13043,
                         "diesel"               => 464,
                         "diesel1"              => 10386,
                         "diesirae"             => 28236,
                         "dietcoke"             => 1168,
                         "dieter"               => 3186,
                         "dietmar"              => 26020,
                         "differen"             => 23199,
                         "digdug"               => 15168,
                         "digge"                => 18356,
                         "digger"               => 554,
                         "digger1"              => 12600,
                         "diggers"              => 16410,
                         "diggity"              => 15060,
                         "diggler"              => 3053,
                         "digimon"              => 3787,
                         "digita"               => 17877,
                         "digital"              => 371,
                         "digital1"             => 2993,
                         "digital2"             => 28013,
                         "digitalprodu"         => 17485,
                         "digitex"              => 26611,
                         "digiview"             => 12337,
                         "digler"               => 27834,
                         "dignity7"             => 17754,
                         "digweed"              => 17363,
                         "dilara"               => 26349,
                         "dilbert"              => 836,
                         "dilbert1"             => 5296,
                         "dildo"                => 2246,
                         "dildo1"               => 24293,
                         "dildos"               => 8834,
                         "dilligaf"             => 1875,
                         "dilligas"             => 19793,
                         "dillinge"             => 29207,
                         "dillweed"             => 8773,
                         "dilnoza"              => 29873,
                         "dilshod"              => 12691,
                         "dima"                 => 1379,
                         "dima12"               => 13388,
                         "dima123"              => 5502,
                         "dima1234"             => 15382,
                         "dima12345"            => 14718,
                         "dima1985"             => 21236,
                         "dima1989"             => 22751,
                         "dima1990"             => 18448,
                         "dima1991"             => 29518,
                         "dima1992"             => 18338,
                         "dima1993"             => 15405,
                         "dima1994"             => 19940,
                         "dima1995"             => 7039,
                         "dima1996"             => 10354,
                         "dima1997"             => 14285,
                         "dima1998"             => 23029,
                         "dima1999"             => 18479,
                         "dima2000"             => 15380,
                         "dima2009"             => 23605,
                         "dima2010"             => 15199,
                         "dima55"               => 7780,
                         "dima777"              => 25650,
                         "dimabilan"            => 29860,
                         "diman"                => 26727,
                         "dimanche"             => 27290,
                         "dimarik"              => 10960,
                         "dimas"                => 4590,
                         "dimasik"              => 9547,
                         "dimebag"              => 9878,
                         "dimedrol"             => 18997,
                         "dimensio"             => 12233,
                         "dimidrol"             => 21853,
                         "dimitri"              => 5801,
                         "dimitris"             => 20065,
                         "dimitry"              => 28711,
                         "dimo4ka"              => 26143,
                         "dimochka"             => 18012,
                         "dimon"                => 15782,
                         "dimon4ik"             => 17253,
                         "dimon95"              => 25809,
                         "dimples"              => 4675,
                         "dimsum"               => 16995,
                         "dimwit"               => 18254,
                         "dinamit"              => 25758,
                         "dinamite"             => 21875,
                         "dinamo"               => 2267,
                         "dinara"               => 4195,
                         "dindom"               => 4380,
                         "dinero"               => 7092,
                         "dinesh"               => 14505,
                         "ding"                 => 2379,
                         "dingbat"              => 6325,
                         "dingdong"             => 1390,
                         "dingo"                => 5333,
                         "dingo1"               => 8346,
                         "dingos"               => 19591,
                         "dinkle"               => 15818,
                         "dinkus"               => 29253,
                         "dinky1"               => 25740,
                         "dinmamma"             => 16595,
                         "dino12"               => 27272,
                         "dinosaur"             => 2138,
                         "dinsdale"             => 19671,
                         "diogenes"             => 11199,
                         "dionis"               => 19080,
                         "dionysus"             => 15678,
                         "diosesamo"            => 13754,
                         "dipascuc"             => 28200,
                         "diplom"               => 19765,
                         "dipper"               => 5939,
                         "dipset"               => 5965,
                         "dipshit"              => 3410,
                         "dipstick"             => 6290,
                         "direktor"             => 18921,
                         "direwolf"             => 10771,
                         "dirkpitt"             => 16468,
                         "dirt49"               => 23227,
                         "dirtbag"              => 9491,
                         "dirtball"             => 17176,
                         "dirtbike"             => 3191,
                         "dirty1"               => 4723,
                         "dirtybir"             => 24138,
                         "dirtyboy"             => 12854,
                         "dirtyd"               => 15084,
                         "dirtydog"             => 6713,
                         "dirtygirl"            => 23204,
                         "dirtyman"             => 19509,
                         "discgolf"             => 14986,
                         "discman"              => 28179,
                         "disco"                => 4980,
                         "disco1"               => 10585,
                         "discover"             => 1461,
                         "discus"               => 5884,
                         "diskette"             => 17542,
                         "disne"                => 23193,
                         "disney"               => 543,
                         "disney1"              => 7079,
                         "disturbe"             => 13132,
                         "ditka"                => 24149,
                         "diva"                 => 6118,
                         "divad"                => 26021,
                         "divedeep"             => 24574,
                         "diver"                => 2822,
                         "diver1"               => 5858,
                         "divers"               => 6628,
                         "diversio"             => 20968,
                         "divin"                => 28077,
                         "divine"               => 2315,
                         "divine1"              => 27558,
                         "divine5"              => 23189,
                         "divx1"                => 7246,
                         "dixie1"               => 5602,
                         "dixiedog"             => 12398,
                         "dixon1"               => 25724,
                         "dizzle"               => 28643,
                         "dizzy1"               => 13983,
                         "djamaal"              => 14790,
                         "django"               => 4827,
                         "djctvm"               => 28097,
                         "djdjxrf"              => 8281,
                         "djdxbr"               => 13197,
                         "djembe"               => 16647,
                         "djg4bb4b"             => 15521,
                         "djgabbab"             => 12530,
                         "djghjc"               => 16684,
                         "djhjyf"               => 14237,
                         "djhvbrc"              => 16461,
                         "djkjlz"               => 7867,
                         "djkrjd"               => 29015,
                         "djkrjdf"              => 16625,
                         "djkrjlfd"             => 14652,
                         "djkujuhfl"            => 15918,
                         "djkxbwf"              => 27868,
                         "djljgfl"              => 20996,
                         "djljktq"              => 13627,
                         "djohn11"              => 15296,
                         "djtiesto"             => 27716,
                         "dkalis"               => 23533,
                         "dkflbckfd"            => 2424,
                         "dkflbdjcnjr"          => 19112,
                         "dkflbr"               => 4779,
                         "dkflbvbh"             => 1398,
                         "dkflbvbhjdbx"         => 8483,
                         "dkflbvbhjdyf"         => 8935,
                         "dkjfghdk"             => 25704,
                         "dknight"              => 29417,
                         "dlanod"               => 16561,
                         "dlanor"               => 25720,
                         "dm6tzsgp"             => 22410,
                         "dmb2010"              => 16015,
                         "dmb2011"              => 23550,
                         "dmband"               => 8126,
                         "dmfxhkju"             => 27571,
                         "dmh415"               => 20807,
                         "dmitriev"             => 15172,
                         "dmitrii"              => 10591,
                         "dmitrij"              => 24965,
                         "dmitriy"              => 4589,
                         "dmitry"               => 9545,
                         "dmoney"               => 11434,
                         "dnevnik"              => 23932,
                         "dnomyar"              => 29373,
                         "dnsadm"               => 5899,
                         "dnstuff"              => 15944,
                         "dobber"               => 8502,
                         "doberman"             => 1769,
                         "dobie"                => 25949,
                         "doc123"               => 14115,
                         "dochka"               => 21986,
                         "docker"               => 14786,
                         "dockers"              => 11535,
                         "docto"                => 12294,
                         "doctor"               => 246,
                         "doctor1"              => 10932,
                         "doctorj"              => 21545,
                         "doctorwh"             => 27270,
                         "doda99"               => 26278,
                         "dodge1"               => 2634,
                         "dodger"               => 1096,
                         "dodger1"              => 12465,
                         "dodgeram"             => 1539,
                         "dodgers"              => 771,
                         "dodgers1"             => 3906,
                         "dodges"               => 8384,
                         "dodgeviper"           => 16969,
                         "doedel"               => 18226,
                         "doesit"               => 29865,
                         "dog123"               => 3444,
                         "dogballs"             => 18528,
                         "dogbert"              => 3975,
                         "dogbert1"             => 24835,
                         "dogbite"              => 12146,
                         "dogbone"              => 5236,
                         "dogboy"               => 3855,
                         "dogbreat"             => 13434,
                         "dogbreath"            => 19345,
                         "dogcat"               => 3801,
                         "dogday"               => 15864,
                         "dogdays"              => 29081,
                         "dogface"              => 4377,
                         "dogfart"              => 6618,
                         "dogfight"             => 13001,
                         "dogfish"              => 10560,
                         "dogfood"              => 2968,
                         "dogfuck"              => 23902,
                         "dogg"                 => 1571,
                         "dogger"               => 3753,
                         "dogggg"               => 8273,
                         "dogggy"               => 29120,
                         "doggie"               => 416,
                         "doggie1"              => 13368,
                         "doggies"              => 5057,
                         "doggone"              => 9871,
                         "doggy"                => 1058,
                         "doggy1"               => 4818,
                         "doggy123"             => 26190,
                         "doggydog"             => 8377,
                         "doggys"               => 7845,
                         "doggysty"             => 13739,
                         "doggystyle"           => 8533,
                         "doghead"              => 26726,
                         "doghot"               => 19088,
                         "doghouse"             => 2939,
                         "dogleg"               => 28716,
                         "doglover"             => 16860,
                         "dogma"                => 8417,
                         "dogma1"               => 21200,
                         "dogman"               => 1930,
                         "dogman1"              => 26172,
                         "dogmeat"              => 6330,
                         "dogphil3650"          => 25600,
                         "dogpile"              => 29404,
                         "dogpound"             => 4804,
                         "dogs"                 => 1281,
                         "dogs1"                => 27621,
                         "dogshit"              => 3429,
                         "dogstar"              => 13022,
                         "dogstyle"             => 18242,
                         "dogwood"              => 4923,
                         "dohcvtec"             => 17618,
                         "doit"                 => 5261,
                         "doitnow"              => 3146,
                         "dokken"               => 7868,
                         "doktor"               => 5314,
                         "dolemit1"             => 17548,
                         "dolemite"             => 5183,
                         "dolfan"               => 11664,
                         "dolfin"               => 17540,
                         "dolina"               => 19843,
                         "dolittle"             => 13208,
                         "dolla"                => 26223,
                         "dollar"               => 877,
                         "dollar1"              => 19267,
                         "dollarbi"             => 19563,
                         "doller"               => 23268,
                         "dollface"             => 11500,
                         "dolly1"               => 9280,
                         "dolomite"             => 13933,
                         "dolore"               => 25975,
                         "dolphi"               => 7975,
                         "dolphin"              => 258,
                         "dolphin1"             => 3037,
                         "dolphin2"             => 13406,
                         "dolphin9"             => 23731,
                         "dolphins"             => 249,
                         "dolphins1"            => 19423,
                         "doma77ns"             => 11595,
                         "domainlock2005"       => 8259,
                         "domani"               => 16287,
                         "dome69"               => 18046,
                         "domenico"             => 6998,
                         "domenow"              => 10193,
                         "domin"                => 14821,
                         "dominati"             => 20396,
                         "dominator"            => 9393,
                         "doming"               => 25681,
                         "domini"               => 7341,
                         "dominic1"             => 10087,
                         "dominik"              => 4498,
                         "dominika"             => 7104,
                         "dominion"             => 4545,
                         "dominiqu"             => 5264,
                         "domino"               => 541,
                         "domino1"              => 13956,
                         "dominos"              => 11862,
                         "dominus"              => 10409,
                         "domodedovo"           => 29336,
                         "domodo"               => 22843,
                         "domovoy"              => 27084,
                         "don123"               => 19763,
                         "donal"                => 21320,
                         "donald1"              => 8765,
                         "donaldduck"           => 25127,
                         "donaldo"              => 27082,
                         "donatello"            => 25684,
                         "doneit"               => 22005,
                         "donger"               => 12062,
                         "dongle"               => 13564,
                         "donjuan"              => 5969,
                         "donke"                => 27727,
                         "donkey"               => 364,
                         "donkey1"              => 9897,
                         "donkeykong"           => 25708,
                         "donking"              => 28557,
                         "donna1"               => 6010,
                         "donna123"             => 23945,
                         "donnas"               => 13168,
                         "donner"               => 5295,
                         "donsdad"              => 23896,
                         "dont4get"             => 13053,
                         "dontae"               => 17562,
                         "dontask"              => 19764,
                         "dontcare"             => 20276,
                         "dontdoit"             => 29796,
                         "dontforg"             => 25512,
                         "dontgotm"             => 25526,
                         "donthate"             => 22039,
                         "dontknow"             => 4622,
                         "donttell"             => 25653,
                         "donuts"               => 2672,
                         "doober"               => 15642,
                         "doobie"               => 1945,
                         "doodad"               => 21490,
                         "doodah"               => 9809,
                         "doodie"               => 9443,
                         "doodle"               => 1404,
                         "doodle1"              => 23594,
                         "doodlebu"             => 28747,
                         "doodles"              => 6473,
                         "doofer"               => 21094,
                         "doofus"               => 3931,
                         "doogie"               => 2625,
                         "doogie1"              => 28694,
                         "doogle"               => 18494,
                         "doohan"               => 28708,
                         "dooker"               => 18433,
                         "dookie"               => 1469,
                         "doom12"               => 27016,
                         "doomer"               => 19757,
                         "doomsday"             => 3646,
                         "dooper"               => 23182,
                         "doorknob"             => 7555,
                         "doors1"               => 25894,
                         "doozer"               => 12715,
                         "dopehead"             => 22420,
                         "dopeman"              => 24211,
                         "doqvq3"               => 11407,
                         "doraemon"             => 11788,
                         "doremi"               => 11131,
                         "doright"              => 29648,
                         "dorina"               => 15250,
                         "doris1"               => 13186,
                         "doritos"              => 11327,
                         "dorkus"               => 18948,
                         "doroga"               => 12068,
                         "doromich"             => 15029,
                         "dorota"               => 20361,
                         "doroth"               => 17948,
                         "dorothee"             => 24821,
                         "dorothy1"             => 17314,
                         "dorsai"               => 18355,
                         "dortmund"             => 6053,
                         "dotcom"               => 3384,
                         "dothedew"             => 11755,
                         "dotnet"               => 29398,
                         "doubled"              => 5364,
                         "douche"               => 6038,
                         "doudo"                => 12162,
                         "doug1"                => 21903,
                         "dougal"               => 6203,
                         "doughboy"             => 1833,
                         "dougie"               => 4979,
                         "dougla"               => 23673,
                         "douglas1"             => 6973,
                         "dovajb"               => 20170,
                         "dover1"               => 15583,
                         "dovetail"             => 19224,
                         "dowjones"             => 22616,
                         "downhill"             => 6306,
                         "downlow"              => 15149,
                         "downunde"             => 19978,
                         "dozer1"               => 18634,
                         "dposton"              => 22416,
                         "dr8350"               => 27683,
                         "drache"               => 17039,
                         "drachen"              => 26029,
                         "draco"                => 5460,
                         "draco1"               => 28318,
                         "dracon"               => 15668,
                         "draconis"             => 15781,
                         "dracul"               => 21086,
                         "dracula"              => 1956,
                         "dracula1"             => 27473,
                         "drag0n"               => 6394,
                         "dragan"               => 13360,
                         "dragnet"              => 15088,
                         "drago"                => 1751,
                         "dragon"               => 10,
                         "dragon0"              => 14573,
                         "dragon00"             => 15145,
                         "dragon01"             => 6781,
                         "dragon05"             => 28675,
                         "dragon1"              => 745,
                         "dragon10"             => 11999,
                         "dragon11"             => 8641,
                         "dragon12"             => 3077,
                         "dragon123"            => 7127,
                         "dragon13"             => 8722,
                         "dragon19"             => 28592,
                         "dragon2"              => 11796,
                         "dragon20"             => 21979,
                         "dragon21"             => 12852,
                         "dragon22"             => 10676,
                         "dragon23"             => 11923,
                         "dragon25"             => 19052,
                         "dragon3"              => 17807,
                         "dragon33"             => 29624,
                         "dragon4"              => 28297,
                         "dragon5"              => 13580,
                         "dragon6"              => 21268,
                         "dragon64"             => 19443,
                         "dragon66"             => 11750,
                         "dragon666"            => 23677,
                         "dragon69"             => 5134,
                         "dragon7"              => 9661,
                         "dragon76"             => 11252,
                         "dragon77"             => 16010,
                         "dragon88"             => 9973,
                         "dragon9"              => 18027,
                         "dragon98"             => 26053,
                         "dragon99"             => 9565,
                         "dragonage"            => 26979,
                         "dragonba"             => 3348,
                         "dragonball"           => 3033,
                         "dragonballz"          => 5853,
                         "dragonfi"             => 22334,
                         "dragonfire"           => 15996,
                         "dragonfl"             => 5481,
                         "dragonfly"            => 6509,
                         "dragonla"             => 26740,
                         "dragonma"             => 29781,
                         "dragons"              => 858,
                         "dragons1"             => 10253,
                         "dragonss"             => 29883,
                         "dragonz"              => 8053,
                         "dragoon"              => 2106,
                         "dragoon1"             => 23388,
                         "dragos"               => 15112,
                         "dragrace"             => 7719,
                         "dragstar"             => 28862,
                         "dragster"             => 5505,
                         "dragula"              => 16259,
                         "drahcir"              => 13962,
                         "drakcap"              => 27803,
                         "drake1"               => 13960,
                         "draken"               => 13513,
                         "drakkar"              => 13612,
                         "drako"                => 29940,
                         "drakon"               => 3609,
                         "drakula"              => 13101,
                         "dranreb"              => 29669,
                         "draven"               => 4411,
                         "drawde"               => 18814,
                         "drdoom"               => 11481,
                         "dreads"               => 17400,
                         "dream1"               => 9006,
                         "dream2"               => 29880,
                         "dreamcas"             => 5721,
                         "dreamcast"            => 7170,
                         "dreame"               => 27670,
                         "dreamer"              => 616,
                         "dreamer1"             => 7458,
                         "dreamer2"             => 20302,
                         "dreamers"             => 9686,
                         "dreamgirl"            => 23256,
                         "dreamon"              => 12035,
                         "dreams"               => 425,
                         "dreams1"              => 15861,
                         "dreday"               => 17608,
                         "dresden"              => 5777,
                         "dressage"             => 16143,
                         "drevil"               => 8811,
                         "drew1"                => 25616,
                         "drew11"               => 27397,
                         "drewman"              => 17535,
                         "drexel"               => 12843,
                         "drgonzo"              => 12598,
                         "dribble"              => 12076,
                         "drifter"              => 4094,
                         "driller"              => 5544,
                         "drinker"              => 8234,
                         "dripik"               => 22194,
                         "driver"               => 288,
                         "driver1"              => 10474,
                         "driver8"              => 11175,
                         "drizzit"              => 20971,
                         "drizzt"               => 1239,
                         "drizzt1"              => 22114,
                         "drjynfrnt"            => 8593,
                         "drlove"               => 17333,
                         "dro8smwq"             => 24071,
                         "drogba"               => 17936,
                         "drongo"               => 27390,
                         "droopy"               => 2631,
                         "dropdead"             => 8726,
                         "dropkick"             => 7531,
                         "dropzone"             => 15165,
                         "drowssap"             => 452,
                         "drpepper"             => 1007,
                         "drstrang"             => 29965,
                         "druid"                => 8382,
                         "druids"               => 17396,
                         "drum66"               => 23687,
                         "drumandbass"          => 25757,
                         "drumer"               => 22571,
                         "drumline"             => 11657,
                         "drummer"              => 458,
                         "drummer1"             => 3784,
                         "drummers"             => 12263,
                         "drumnbass"            => 19666,
                         "drums1"               => 19143,
                         "drumset"              => 14356,
                         "drumss"               => 17564,
                         "drunk1"               => 14767,
                         "druss"                => 21259,
                         "druuna"               => 19997,
                         "drwho"                => 19949,
                         "drywall"              => 7333,
                         "ds7zamnw"             => 24471,
                         "dshade"               => 8735,
                         "dsmith"               => 25254,
                         "dsobwick"             => 27580,
                         "dtcyeirf"             => 26672,
                         "dte4uw"               => 10579,
                         "dtheyxbr"             => 29319,
                         "dthjxrf"              => 10047,
                         "dthjybrf"             => 1902,
                         "dthjybxrf"            => 23243,
                         "dthyjcnm"             => 12011,
                         "dtkjcbgtl"            => 6260,
                         "dtlmvf"               => 14623,
                         "dtnfkm"               => 17626,
                         "dtxyjcnm"             => 6395,
                         "dtythf"               => 10667,
                         "dually"               => 14731,
                         "duan"                 => 3426,
                         "duane1"               => 22056,
                         "dubesor"              => 27653,
                         "dublin"               => 1408,
                         "ducat"                => 20568,
                         "ducati"               => 577,
                         "ducati1"              => 18343,
                         "ducati74"             => 22711,
                         "ducati99"             => 8933,
                         "duchess"              => 2285,
                         "duchess1"             => 22324,
                         "duck"                 => 1536,
                         "duck1"                => 26574,
                         "duckey"               => 21882,
                         "duckhunt"             => 8191,
                         "duckie"               => 3815,
                         "duckling"             => 11537,
                         "duckman"              => 5871,
                         "duckpond"             => 29339,
                         "ducks"                => 4602,
                         "ducks1"               => 14794,
                         "ducksoup"             => 9220,
                         "ducky"                => 7042,
                         "ducky1"               => 15715,
                         "ducttape"             => 22428,
                         "dudder"               => 25605,
                         "dude1"                => 20505,
                         "dude11"               => 21184,
                         "dude12"               => 23905,
                         "dude123"              => 8663,
                         "dude1234"             => 24453,
                         "dude1998"             => 19494,
                         "dude69"               => 23514,
                         "dudelove"             => 16474,
                         "dudeman"              => 5376,
                         "duder"                => 28958,
                         "dudley1"              => 25160,
                         "duende"               => 17813,
                         "duetto"               => 29229,
                         "duffbeer"             => 11728,
                         "duffer"               => 5767,
                         "duffman"              => 4790,
                         "duffy1"               => 15816,
                         "dugan1"               => 25133,
                         "dugway"               => 28969,
                         "duhast"               => 18697,
                         "duke01"               => 17105,
                         "duke1"                => 15109,
                         "duke11"               => 16552,
                         "duke12"               => 26162,
                         "duke123"              => 19861,
                         "duke33"               => 28198,
                         "duke3d"               => 13979,
                         "dukeblue"             => 20468,
                         "dukedog"              => 13952,
                         "dukenuke"             => 27068,
                         "dukenukem"            => 25624,
                         "dukers"               => 23793,
                         "dukester"             => 16232,
                         "dukey"                => 25350,
                         "dukies"               => 24613,
                         "duluth"               => 11779,
                         "dumass"               => 22488,
                         "dumbass"              => 1457,
                         "dumbass1"             => 17330,
                         "dumbfuck"             => 26164,
                         "dummie"               => 19244,
                         "dummies"              => 12059,
                         "dummy1"               => 12252,
                         "dummys"               => 22788,
                         "dumpy"                => 29439,
                         "dun6sm"               => 18716,
                         "dunamis"              => 13704,
                         "dunca"                => 21057,
                         "duncan1"              => 13262,
                         "duncan21"             => 17903,
                         "dunce1"               => 13552,
                         "dundee"               => 3536,
                         "dune2000"             => 25355,
                         "dungeon"              => 4539,
                         "dunhill"              => 7004,
                         "dupa123"              => 19985,
                         "dupont24"             => 14329,
                         "duracell"             => 7520,
                         "duramax"              => 25384,
                         "durandal"             => 21305,
                         "durango"              => 1770,
                         "durango1"             => 11951,
                         "durdom"               => 26717,
                         "durex"                => 28940,
                         "duster"               => 2309,
                         "dustin1"              => 21914,
                         "dustin23"             => 22020,
                         "dustoff"              => 11148,
                         "dusty1"               => 3795,
                         "dusty123"             => 20467,
                         "dusty197"             => 17872,
                         "dustydog"             => 9392,
                         "dutch1"               => 12588,
                         "dutches"              => 19512,
                         "dutchess"             => 3005,
                         "dutchie"              => 28219,
                         "dutchman"             => 7046,
                         "dutchy"               => 13080,
                         "dvader"               => 9521,
                         "dvdcom"               => 28956,
                         "dwarf1"               => 21983,
                         "dwdrums"              => 21804,
                         "dwl610"               => 24395,
                         "dwml9f"               => 18062,
                         "dyanna"               => 23513,
                         "dylan1"               => 5169,
                         "dylan2"               => 27930,
                         "dylandog"             => 27083,
                         "dylans"               => 28418,
                         "dynamite"             => 3660,
                         "dynamo"               => 3686,
                         "dynastar"             => 13737,
                         "dynomite"             => 21896,
                         "dynxyu"               => 18369,
                         "dzakuni"              => 17288,
                         "dzxtckfd"             => 9967,
                         "e12345"               => 27811,
                         "e3w2q1"               => 18213,
                         "e5pftu"               => 17425,
                         "e6z8jh"               => 18635,
                         "ea53g5"               => 17509,
                         "eadgbe"               => 11054,
                         "eae21157"             => 14545,
                         "eagle"                => 488,
                         "eagle1"               => 445,
                         "eagle123"             => 14125,
                         "eagle2"               => 6826,
                         "eagle21"              => 23983,
                         "eagle3"               => 13940,
                         "eagle5"               => 14239,
                         "eagle7"               => 19792,
                         "eagle99"              => 22782,
                         "eagleeye"             => 12469,
                         "eagleman"             => 26017,
                         "eagleone"             => 12319,
                         "eagles"               => 120,
                         "eagles05"             => 14456,
                         "eagles1"              => 2955,
                         "eagles11"             => 29605,
                         "eagles12"             => 25565,
                         "eagles20"             => 22747,
                         "earlgrey"             => 26420,
                         "earn381"              => 21717,
                         "earnhard"             => 3850,
                         "earth1"               => 22125,
                         "earthlin"             => 7214,
                         "earthlink"            => 4934,
                         "earwig"               => 18751,
                         "eastbay"              => 24638,
                         "eastern1"             => 18695,
                         "eastside"             => 2492,
                         "eastwest"             => 16728,
                         "eastwood"             => 3449,
                         "easy1"                => 26106,
                         "easy123"              => 11781,
                         "easy1234"             => 24704,
                         "easygo"               => 22264,
                         "easypass"             => 26573,
                         "easypay"              => 8520,
                         "easyride"             => 20134,
                         "eatass"               => 23612,
                         "eatcum"               => 16018,
                         "eather"               => 25686,
                         "eatit"                => 17418,
                         "eatme"                => 833,
                         "eatme1"               => 7036,
                         "eatme2"               => 8705,
                         "eatme69"              => 7679,
                         "eatmeat"              => 25760,
                         "eatmee"               => 10407,
                         "eatmenow"             => 5879,
                         "eatmeraw"             => 11180,
                         "eatmyass"             => 24836,
                         "eatpussy"             => 1977,
                         "eatshit"              => 1443,
                         "eatshit1"             => 21260,
                         "ebonee"               => 26736,
                         "ebony1"               => 8581,
                         "echo45"               => 10787,
                         "eclips"               => 23506,
                         "eclipse"              => 393,
                         "eclipse1"             => 4759,
                         "eclipse2"             => 21396,
                         "eclipse9"             => 19235,
                         "economia"             => 27039,
                         "ecosse"               => 27535,
                         "ecstacy"              => 16492,
                         "edcrfv"               => 6602,
                         "edcwsxqaz"            => 25879,
                         "eddie1"               => 3398,
                         "eddie123"             => 22331,
                         "eddie2"               => 28586,
                         "eddie666"             => 28514,
                         "eddies"               => 15489,
                         "edelweis"             => 13129,
                         "edgar1"               => 23403,
                         "edgard"               => 17837,
                         "edgewise"             => 12177,
                         "edgewood"             => 18574,
                         "edibey"               => 23366,
                         "edifier"              => 29222,
                         "edinburg"             => 8475,
                         "edoardo"              => 17221,
                         "edthom"               => 8103,
                         "eduard"               => 1699,
                         "eduard1"              => 15432,
                         "eduardo1"             => 19058,
                         "educatio"             => 19101,
                         "edvard"               => 16285,
                         "edwar"                => 10923,
                         "edward1"              => 2891,
                         "edward11"             => 24796,
                         "edward12"             => 14023,
                         "edward2"              => 21746,
                         "edwards1"             => 29596,
                         "edwardss"             => 10323,
                         "eeeee1"               => 10714,
                         "eeeeee1"              => 11349,
                         "eeeeeee1"             => 17135,
                         "eetfuk"               => 26405,
                         "eeyore"               => 2142,
                         "eeyore1"              => 23589,
                         "efbcapa201"           => 12737,
                         "efremov"              => 21820,
                         "efyreg"               => 15188,
                         "eggbert"              => 15745,
                         "egghead"              => 5175,
                         "eggman"               => 4414,
                         "eggplant"             => 4814,
                         "egoist"               => 12708,
                         "egoiste"              => 25243,
                         "egor123"              => 29942,
                         "egorka"               => 6131,
                         "egorov"               => 9972,
                         "egorova"              => 10442,
                         "egroeg"               => 20400,
                         "egypt1"               => 27310,
                         "eider"                => 29063,
                         "eieio"                => 13699,
                         "eight8"               => 8892,
                         "eight888"             => 26933,
                         "eightbal"             => 7880,
                         "eightball"            => 11000,
                         "einstei"              => 26341,
                         "einstein"             => 448,
                         "eintrach"             => 13147,
                         "eintritt"             => 26551,
                         "eistee"               => 14056,
                         "ejaculation"          => 7154,
                         "ekaterina"            => 1327,
                         "ekaterina20"          => 19254,
                         "ekbnrf"               => 26280,
                         "ekilpool"             => 20808,
                         "eklhigcz"             => 23723,
                         "ekmzyf"               => 6352,
                         "eknock"               => 19646,
                         "el345612"             => 27978,
                         "el546218"             => 16519,
                         "elain"                => 21942,
                         "elaine1"              => 19577,
                         "elaine22"             => 11668,
                         "elaman"               => 25535,
                         "elbarto"              => 20164,
                         "elbereth"             => 8204,
                         "elcamino"             => 4503,
                         "eldar"                => 15832,
                         "eldiablo"             => 6422,
                         "eldorado"             => 3421,
                         "eldritch"             => 22285,
                         "eleanor1"             => 23439,
                         "electr"               => 23463,
                         "electra"              => 3099,
                         "electra1"             => 20797,
                         "electric"             => 663,
                         "electro"              => 3823,
                         "electron"             => 3117,
                         "elefant"              => 4494,
                         "elefante"             => 14610,
                         "elektra"              => 7475,
                         "elektrik"             => 15808,
                         "elektro"              => 13124,
                         "element"              => 1061,
                         "element1"             => 8201,
                         "elementa"             => 14120,
                         "elena1"               => 10040,
                         "elena123"             => 22688,
                         "elena1971"            => 29353,
                         "elena2010"            => 25531,
                         "elenberg"             => 15895,
                         "elendil"              => 17554,
                         "elenka"               => 13950,
                         "elephan"              => 12828,
                         "elephant"             => 275,
                         "elephant1"            => 27600,
                         "elessar"              => 24948,
                         "eleven11"             => 8729,
                         "elfquest"             => 13441,
                         "elfstone"             => 14614,
                         "elgato"               => 8971,
                         "elgordo"              => 27510,
                         "elguapo"              => 15970,
                         "elisabet"             => 5276,
                         "elise1"               => 24679,
                         "eliston"              => 18354,
                         "elite1"               => 9523,
                         "elite11"              => 10694,
                         "eliza1"               => 18048,
                         "elizabet"             => 588,
                         "elizabeth1"           => 13755,
                         "elizaveta"            => 3242,
                         "eljefe"               => 13303,
                         "elkcit"               => 21464,
                         "ellada"               => 23239,
                         "elland"               => 22342,
                         "ellehcim"             => 24502,
                         "ellen1"               => 10854,
                         "ellie1"               => 11271,
                         "elliott1"             => 22818,
                         "ellis1"               => 18470,
                         "ellobo"               => 18770,
                         "elloco"               => 16115,
                         "elmer1"               => 24958,
                         "elmer251"             => 20528,
                         "elmers"               => 22115,
                         "elnino"               => 11246,
                         "elocin"               => 16045,
                         "elodi"                => 20852,
                         "elodie"               => 7053,
                         "elohim"               => 10639,
                         "elpaso"               => 6595,
                         "elric"                => 12622,
                         "elric1"               => 26984,
                         "elrond"               => 9388,
                         "eltoro"               => 10743,
                         "elvir"                => 25265,
                         "elvira26"             => 10947,
                         "elvis1"               => 1677,
                         "elvis123"             => 8002,
                         "elvis69"              => 22295,
                         "elvis77"              => 21595,
                         "elvis99"              => 29788,
                         "elvisp"               => 5312,
                         "elviss"               => 15331,
                         "elway"                => 6194,
                         "elway07"              => 25761,
                         "elway1"               => 28785,
                         "elway7"               => 5152,
                         "elysium"              => 13867,
                         "emachine"             => 10685,
                         "emachines"            => 9813,
                         "emanue"               => 25734,
                         "emanuela"             => 15456,
                         "emanuele"             => 13677,
                         "emb377"               => 21821,
                         "embalm"               => 29906,
                         "embalmer"             => 7259,
                         "emerald"              => 1057,
                         "emerald1"             => 14117,
                         "emergenc"             => 24225,
                         "emerica"              => 17276,
                         "emerson1"             => 18586,
                         "emili"                => 7393,
                         "emiliano"             => 14574,
                         "emilka"               => 24363,
                         "emily1"               => 2123,
                         "emily123"             => 21931,
                         "emily2"               => 20422,
                         "emilyann"             => 27248,
                         "emilyb"               => 21945,
                         "emilys"               => 21058,
                         "emine"                => 7373,
                         "eminem"               => 313,
                         "eminem1"              => 12023,
                         "eminem12"             => 21290,
                         "emma01"               => 25268,
                         "emma22"               => 25685,
                         "emmajane"             => 23573,
                         "emmanue"              => 18796,
                         "emmitt22"             => 8688,
                         "emokid"               => 26500,
                         "empire"               => 619,
                         "empire1"              => 7391,
                         "empire11"             => 27355,
                         "empires"              => 9519,
                         "emyeuanh"             => 13613,
                         "enamorad"             => 15844,
                         "encarta"              => 21117,
                         "encore"               => 5984,
                         "ender"                => 6682,
                         "ender1"               => 16162,
                         "endgame"              => 22280,
                         "enduro"               => 21008,
                         "endymion"             => 15508,
                         "endzone"              => 19118,
                         "energia"              => 29799,
                         "energie"              => 15906,
                         "energize"             => 10840,
                         "energizer"            => 21838,
                         "energy1"              => 19321,
                         "energy12"             => 29026,
                         "enfant"               => 26294,
                         "enfield"              => 10207,
                         "enforcer"             => 4549,
                         "engage"               => 1949,
                         "engine1"              => 16701,
                         "engine2"              => 23088,
                         "engine3"              => 25362,
                         "engineer"             => 744,
                         "englan"               => 13254,
                         "england1"             => 5775,
                         "english1"             => 26438,
                         "enigm"                => 25934,
                         "enigma"               => 430,
                         "enigma1"              => 14221,
                         "enigma2"              => 28240,
                         "enjoy1"               => 29075,
                         "enjoyit"              => 21488,
                         "enkeli"               => 10774,
                         "enkidu"               => 25135,
                         "enlighte"             => 24964,
                         "enolagay"             => 28415,
                         "enrico"               => 3879,
                         "enriqu"               => 15681,
                         "enrique1"             => 28868,
                         "enron714"             => 27266,
                         "enter"                => 190,
                         "enter1"               => 2475,
                         "enter123"             => 7502,
                         "enter2"               => 16339,
                         "enterme"              => 4375,
                         "enternow"             => 5027,
                         "enterpri"             => 952,
                         "enterprise"           => 1892,
                         "entertai"             => 23979,
                         "entrada"              => 28589,
                         "entrar"               => 23161,
                         "entropy"              => 3459,
                         "envision"             => 8399,
                         "epatb1"               => 29905,
                         "epaulson"             => 10367,
                         "epervier"             => 26127,
                         "epiphone"             => 11135,
                         "episode1"             => 14751,
                         "epsilon"              => 4000,
                         "epsilon1"             => 26227,
                         "epson"                => 8185,
                         "epson1"               => 29438,
                         "epvjb6"               => 13683,
                         "epwr49"               => 16064,
                         "equinox"              => 6402,
                         "eragon"               => 8420,
                         "eraser"               => 2948,
                         "erasmus"              => 9394,
                         "erasure"              => 8548,
                         "erathia"              => 25347,
                         "erbol"                => 16832,
                         "ercole"               => 24193,
                         "erdfcv"               => 27259,
                         "erdna"                => 29768,
                         "erebus"               => 14722,
                         "erection"             => 5934,
                         "ereiamjh"             => 20243,
                         "erevan"               => 16073,
                         "erfolg"               => 9520,
                         "erhfbyf"              => 13223,
                         "eric1"                => 9728,
                         "eric11"               => 27984,
                         "eric12"               => 16153,
                         "eric123"              => 19611,
                         "eric1234"             => 18715,
                         "eric99"               => 27002,
                         "erica1"               => 8348,
                         "ericsson"             => 2155,
                         "erika1"               => 11884,
                         "erkina"               => 17954,
                         "erlan"                => 16837,
                         "ermine"               => 23743,
                         "ern3sto"              => 21011,
                         "ernes"                => 29767,
                         "ernest1"              => 23830,
                         "ernie1"               => 11053,
                         "ernies"               => 20492,
                         "erotic"               => 1037,
                         "erotica"              => 2620,
                         "erotik"               => 21133,
                         "erreway"              => 19690,
                         "ersatz"               => 19879,
                         "erwin1"               => 24220,
                         "erxtgb"               => 27801,
                         "esbjerg"              => 26770,
                         "escada"               => 18180,
                         "escaflowne"           => 27885,
                         "escalade"             => 5419,
                         "escape1"              => 29761,
                         "escher"               => 8466,
                         "escola"               => 29746,
                         "escorpio"             => 6882,
                         "escorpion"            => 17516,
                         "escort"               => 967,
                         "escort1"              => 25432,
                         "escrima"              => 27359,
                         "esenin"               => 29557,
                         "eshort"               => 21686,
                         "eskimo"               => 5171,
                         "esmerald"             => 14440,
                         "esmith"               => 29277,
                         "espace"               => 17940,
                         "espana"               => 6089,
                         "espanol"              => 15297,
                         "esperanz"             => 12714,
                         "espero"               => 22447,
                         "espresso"             => 4969,
                         "esprit"               => 6695,
                         "esquire"              => 5384,
                         "essayons"             => 20621,
                         "essendon"             => 9330,
                         "esteba"               => 15984,
                         "estefan"              => 19026,
                         "estefani"             => 21101,
                         "esthe"                => 27395,
                         "estoppel"             => 29136,
                         "estreet"              => 29910,
                         "estrela"              => 27859,
                         "estrell"              => 6100,
                         "estrellit"            => 22262,
                         "eternal"              => 2836,
                         "eternal1"             => 14530,
                         "eternity"             => 1226,
                         "ethan1"               => 7072,
                         "ethernet"             => 7802,
                         "etnies"               => 10304,
                         "etoile"               => 11396,
                         "etower"               => 13745,
                         "ettore"               => 19183,
                         "etvww4"               => 14667,
                         "euclid"               => 7073,
                         "euclid90"             => 27186,
                         "eudora"               => 21725,
                         "eugen"                => 11234,
                         "eugene1"              => 17915,
                         "eugeni"               => 11763,
                         "eumesmo"              => 18488,
                         "euphoria"             => 7011,
                         "eureka"               => 3085,
                         "euro2000"             => 24097,
                         "eurocard"             => 20265,
                         "euroline"             => 29510,
                         "europ"                => 27545,
                         "europa"               => 2502,
                         "eus1sue1"             => 22813,
                         "euskadi"              => 16178,
                         "ev700"                => 26206,
                         "evan1"                => 28707,
                         "evanescence"          => 7325,
                         "evangeli"             => 6902,
                         "evangelion"           => 4391,
                         "evbukb"               => 26924,
                         "eveli"                => 20273,
                         "evely"                => 11488,
                         "evenflow"             => 10748,
                         "evenpar"              => 26398,
                         "everclea"             => 24352,
                         "everest"              => 2211,
                         "everest1"             => 19605,
                         "evergree"             => 7909,
                         "everlast"             => 4316,
                         "everlong"             => 19580,
                         "evermore"             => 16078,
                         "everques"             => 7605,
                         "everquest"            => 8440,
                         "everto"               => 24320,
                         "everton"              => 570,
                         "everton1"             => 7628,
                         "evertonf"             => 16398,
                         "everythi"             => 14632,
                         "evets"                => 14676,
                         "evgeni"               => 16284,
                         "evgenia"              => 13955,
                         "evgenii"              => 9331,
                         "evgeniy"              => 5050,
                         "evgeniya"             => 9900,
                         "evgeny"               => 14924,
                         "evgesha"              => 13206,
                         "evh5150"              => 26809,
                         "evil1"                => 29983,
                         "evil666"              => 8980,
                         "evildead"             => 7564,
                         "evilone"              => 7157,
                         "evolutio"             => 5252,
                         "evropa"               => 26582,
                         "ewelina"              => 12115,
                         "ewing33"              => 26466,
                         "ewq321"               => 20244,
                         "ewtosi"               => 11254,
                         "ewyuza"               => 14752,
                         "exbntkm"              => 17270,
                         "excalibe"             => 14888,
                         "excaliber"            => 25730,
                         "excalibu"             => 1904,
                         "excalibur"            => 3651,
                         "excel1"               => 29779,
                         "excell"               => 10683,
                         "excellen"             => 8358,
                         "excelsio"             => 17692,
                         "excite"               => 4446,
                         "exciter"              => 24880,
                         "exclusiv"             => 22849,
                         "executiv"             => 15528,
                         "executor"             => 18815,
                         "exigen"               => 1174,
                         "exigent"              => 1768,
                         "exocet"               => 21390,
                         "exodus"               => 2118,
                         "exotic"               => 3719,
                         "expediti"             => 19094,
                         "exploite"             => 9964,
                         "exploiter"            => 19340,
                         "explore1"             => 17843,
                         "explorer"             => 374,
                         "explorer1"            => 27646,
                         "express"              => 897,
                         "express1"             => 8260,
                         "express2"             => 26936,
                         "extacy"               => 15005,
                         "extasy"               => 14190,
                         "extensa"              => 7169,
                         "extra1"               => 20653,
                         "extra300"             => 21654,
                         "extra330"             => 29747,
                         "extrem"               => 15184,
                         "extreme"              => 605,
                         "extreme1"             => 13387,
                         "eybdthcbntn"          => 25044,
                         "eyeball"              => 8224,
                         "eyecandy"             => 11267,
                         "eyedoc"               => 21778,
                         "eyespy"               => 15244,
                         "eyphed"               => 14665,
                         "ezmoney"              => 29233,
                         "f**k"                 => 2987,
                         "f00b4r"               => 18102,
                         "f00bar"               => 11832,
                         "f00tball"             => 4554,
                         "f12345"               => 22965,
                         "f123456"              => 15544,
                         "f14tomcat"            => 24949,
                         "f15eagle"             => 8526,
                         "f1f2f3"               => 18127,
                         "f1f2f3f4"             => 27154,
                         "f22raptor"            => 27979,
                         "f3gh65"               => 12800,
                         "f56307"               => 28737,
                         "f8yruxoj"             => 21049,
                         "f9lmwd"               => 12188,
                         "fabfive"              => 23741,
                         "fabia"                => 7884,
                         "fabiana"              => 16534,
                         "fabie"                => 2076,
                         "fabien"               => 11963,
                         "fabienn"              => 5826,
                         "fabienne"             => 8872,
                         "fabio"                => 5281,
                         "fabiol"               => 8695,
                         "fabolous"             => 14469,
                         "fabregas"             => 11737,
                         "fabric"               => 2514,
                         "fabrice"              => 12908,
                         "fabrika"              => 20792,
                         "fabrizi"              => 16402,
                         "facefuck"             => 8612,
                         "faceoff"              => 11446,
                         "facesit"              => 13965,
                         "facial"               => 2439,
                         "facial1"              => 27595,
                         "facile"               => 16648,
                         "fackyou"              => 22853,
                         "faerie"               => 17157,
                         "fafnir"               => 24314,
                         "fagget"               => 27220,
                         "faggot"               => 2299,
                         "fahayek"              => 26458,
                         "fahbrf"               => 19768,
                         "fahjlbnf"             => 20383,
                         "failsafe"             => 8816,
                         "failte"               => 22864,
                         "fairchil"             => 24861,
                         "fairfiel"             => 15860,
                         "fairlady"             => 20290,
                         "fairlane"             => 4429,
                         "fairmont"             => 13467,
                         "fairview"             => 10020,
                         "fairway"              => 9410,
                         "faisal"               => 7602,
                         "faith1"               => 4958,
                         "faith123"             => 22579,
                         "faith2"               => 24590,
                         "faithy"               => 28922,
                         "fajita"               => 20625,
                         "fakepass"             => 8008,
                         "faktor"               => 21851,
                         "falco02"              => 25258,
                         "falcon"               => 110,
                         "falcon01"             => 29990,
                         "falcon1"              => 3849,
                         "falcon11"             => 21783,
                         "falcon12"             => 22258,
                         "falcon16"             => 11209,
                         "falcon2"              => 17506,
                         "falcon3"              => 27129,
                         "falcon69"             => 26181,
                         "falcon7"              => 29396,
                         "falcons"              => 1719,
                         "falcons1"             => 12848,
                         "falcor"               => 17681,
                         "fall99"               => 28037,
                         "fallen"               => 1842,
                         "fallen1"              => 18500,
                         "fallenangel"          => 22516,
                         "fallengun"            => 27557,
                         "fallout"              => 2483,
                         "fallout1"             => 29345,
                         "fallout2"             => 13879,
                         "fallout3"             => 15265,
                         "falloutboy"           => 27549,
                         "falstaff"             => 7954,
                         "famil"                => 6819,
                         "famili"               => 9584,
                         "familia"              => 8568,
                         "familie"              => 20866,
                         "family01"             => 20175,
                         "family1"              => 8447,
                         "family5"              => 20731,
                         "familyguy"            => 14409,
                         "fanatic"              => 8446,
                         "fanatik"              => 27528,
                         "fanboy"               => 22044,
                         "fanclub"              => 28327,
                         "fancy1"               => 24868,
                         "fandango"             => 3796,
                         "fang"                 => 2444,
                         "fannies"              => 27988,
                         "fanny1"               => 19490,
                         "fanta"                => 17263,
                         "fantas"               => 23695,
                         "fantasia"             => 4225,
                         "fantasma"             => 16907,
                         "fantasti"             => 7362,
                         "fantasy"              => 537,
                         "fantasy1"             => 7255,
                         "fantasy7"             => 19075,
                         "fantik"               => 17258,
                         "fantom"               => 6744,
                         "fantomas"             => 4433,
                         "fantomen"             => 15893,
                         "far7766"              => 19233,
                         "faramir"              => 23408,
                         "faraon"               => 6752,
                         "farcry"               => 9858,
                         "farfalla"             => 22129,
                         "fargus"               => 25860,
                         "farhad"               => 13225,
                         "farhan"               => 12411,
                         "farida"               => 7018,
                         "farkle"               => 15453,
                         "farmall"              => 12664,
                         "farmboy"              => 5648,
                         "farmer1"              => 14733,
                         "farooq"               => 29784,
                         "farouk"               => 29379,
                         "farout"               => 17103,
                         "farscape"             => 3251,
                         "farside"              => 1828,
                         "farside1"             => 12749,
                         "fart"                 => 2234,
                         "farter"               => 9841,
                         "fartface"             => 14553,
                         "farting"              => 11873,
                         "fartman"              => 7662,
                         "fartripper"           => 11366,
                         "fast1"                => 23275,
                         "fastback"             => 12316,
                         "fastball"             => 3496,
                         "fastcar"              => 7468,
                         "fastcars"             => 8756,
                         "fastdraw"             => 24555,
                         "fasted"               => 16297,
                         "faster"               => 1202,
                         "fastfood"             => 14388,
                         "fastfun"              => 28959,
                         "fastlane"             => 12939,
                         "fastman"              => 23316,
                         "fastone"              => 18750,
                         "fatal1ty"             => 28501,
                         "fatass"               => 1625,
                         "fatb0y"               => 29208,
                         "fatback"              => 20954,
                         "fatbitch"             => 25690,
                         "fatbob"               => 18143,
                         "fatboy"               => 908,
                         "fatboy1"              => 27452,
                         "fatcat"               => 1103,
                         "fatcat1"              => 14898,
                         "fatcock"              => 11551,
                         "fatdaddy"             => 16942,
                         "fatdick"              => 23863,
                         "fatdog"               => 14325,
                         "fatfree"              => 26447,
                         "fatgirl"              => 25391,
                         "fatgirls"             => 22498,
                         "fathe"                => 17762,
                         "fathead"              => 8001,
                         "fathead1"             => 23763,
                         "father1"              => 22190,
                         "fatim"                => 10256,
                         "fatjoe"               => 13369,
                         "fatkid"               => 19834,
                         "fatluvr69"            => 10295,
                         "fatman"               => 1728,
                         "fatman1"              => 26234,
                         "fatmike"              => 25311,
                         "fatone"               => 21556,
                         "fatpussy"             => 10012,
                         "fatrat"               => 19349,
                         "fatty"                => 4317,
                         "fatty1"               => 12426,
                         "faustus"              => 21797,
                         "favorit"              => 10874,
                         "favorite2"            => 6946,
                         "favorite3"            => 19099,
                         "favorite4"            => 27754,
                         "favorite5"            => 11938,
                         "favorite6"            => 5506,
                         "favorite7"            => 9596,
                         "favorite8"            => 9623,
                         "favre"                => 14560,
                         "favre4"               => 10324,
                         "fbi11213"             => 21069,
                         "fcazmj"               => 18772,
                         "fcbarcelona"          => 17401,
                         "fcbayern"             => 10850,
                         "fcc5nky2"             => 24119,
                         "fcgbhby"              => 29142,
                         "fcporto"              => 13063,
                         "fdfnfh"               => 15393,
                         "fdhjhf"               => 19372,
                         "fdm7ed"               => 13843,
                         "fduecn"               => 5877,
                         "fe126fd"              => 19077,
                         "feanor"               => 8069,
                         "fearless"             => 4406,
                         "fearme"               => 25946,
                         "feather"              => 2392,
                         "feather1"             => 22224,
                         "feathers"             => 6120,
                         "feb2000"              => 13515,
                         "februar"              => 18508,
                         "federic"              => 11464,
                         "federica"             => 8958,
                         "federov"              => 28731,
                         "fedora"               => 16841,
                         "fedorov"              => 8067,
                         "fedorova"             => 13584,
                         "feeder"               => 7921,
                         "feedme"               => 8938,
                         "feelgood"             => 5814,
                         "feelme"               => 17065,
                         "fefolico"             => 22789,
                         "feldspar"             => 24274,
                         "felici"               => 25170,
                         "felicia1"             => 29702,
                         "felicida"             => 18219,
                         "felicidade"           => 26245,
                         "feliks"               => 13709,
                         "felina"               => 21288,
                         "feline"               => 6319,
                         "felip"                => 11491,
                         "felipe1"              => 20990,
                         "felix1"               => 3768,
                         "felix123"             => 22249,
                         "felixx"               => 11633,
                         "felixxxx"             => 25589,
                         "fellatio"             => 5386,
                         "fellini"              => 14622,
                         "fellowes"             => 10364,
                         "femmes"               => 9513,
                         "fencer"               => 10518,
                         "fende"                => 17433,
                         "fender"               => 168,
                         "fender1"              => 3851,
                         "fender12"             => 28113,
                         "fenerbahce"           => 14498,
                         "feng"                 => 2909,
                         "fengshui"             => 27005,
                         "feniks"               => 8137,
                         "fenix"                => 9322,
                         "fenomen"              => 27162,
                         "fenomeno"             => 28860,
                         "fenrir"               => 19515,
                         "fenris"               => 4809,
                         "fenster"              => 12494,
                         "fenway"               => 4367,
                         "ferari"               => 12339,
                         "ferarri"              => 24409,
                         "ferdi"                => 24682,
                         "ferdinan"             => 13194,
                         "fergie"               => 3273,
                         "fergus"               => 3724,
                         "ferien12"             => 28869,
                         "fermat"               => 10861,
                         "fermer"               => 21283,
                         "fernand"              => 2003,
                         "ferndale"             => 16632,
                         "fernie"               => 27311,
                         "ferrar"               => 8693,
                         "ferrari"              => 109,
                         "ferrari1"             => 2577,
                         "ferrari2"             => 12486,
                         "ferrari3"             => 11390,
                         "ferrari5"             => 17503,
                         "ferraris"             => 24552,
                         "ferret"               => 1215,
                         "ferret1"              => 21332,
                         "ferrets"              => 14588,
                         "ferrina"              => 26640,
                         "ferrum"               => 21334,
                         "fester"               => 2879,
                         "festina"              => 21293,
                         "festiva"              => 26078,
                         "festus"               => 6267,
                         "fetish"               => 917,
                         "fetish01"             => 16713,
                         "fetish69"             => 19339,
                         "fettish"              => 8674,
                         "feuerweh"             => 22490,
                         "feuerwehr"            => 20914,
                         "fevral"               => 25343,
                         "feyenoor"             => 22544,
                         "feyenoord"            => 10731,
                         "feynman"              => 13526,
                         "ffff1"                => 20543,
                         "fffff1"               => 10988,
                         "ffffff1"              => 12204,
                         "fffffff1"             => 12607,
                         "ffggyyo"              => 24693,
                         "ffvdj474"             => 13908,
                         "fgdfgdfg"             => 21148,
                         "fghbjhb"              => 20627,
                         "fghtkm"               => 2652,
                         "fgjcnjk"              => 28282,
                         "fgjrfkbgcbc"          => 11077,
                         "fgntrf"               => 12811,
                         "fgtkmcby"             => 3458,
                         "fhbirf"               => 18840,
                         "fhbyjxrf"             => 28888,
                         "fhctybq"              => 7251,
                         "fhifdby"              => 20013,
                         "fhnehxbr"             => 19710,
                         "fhntv1998"            => 13714,
                         "fhntvbq"              => 13198,
                         "fhntvrf"              => 6959,
                         "fhrflbq"              => 26411,
                         "fhutynbyf"            => 25731,
                         "fhvfutljy"            => 7202,
                         "fialka"               => 7506,
                         "fibonacci"            => 23458,
                         "ficken"               => 960,
                         "ficker"               => 17967,
                         "ficktjuv"             => 18843,
                         "fiction6"             => 29338,
                         "fiction7"             => 14244,
                         "fiddle"               => 6104,
                         "fiddler"              => 12044,
                         "fidelio"              => 4089,
                         "fidelis"              => 11015,
                         "fidelity"             => 5711,
                         "fidget"               => 11868,
                         "fidodido"             => 28628,
                         "field1"               => 25390,
                         "fiesta"               => 2274,
                         "fietsbel"             => 26218,
                         "fifa2008"             => 20189,
                         "fifa2010"             => 25145,
                         "fifa2011"             => 26102,
                         "fifnfy"               => 29316,
                         "fifty5"               => 29009,
                         "fifty50"              => 22365,
                         "figaro"               => 2064,
                         "fight1"               => 26541,
                         "fightclu"             => 11602,
                         "fightclub"            => 9385,
                         "fighter"              => 1344,
                         "fighter1"             => 14844,
                         "fighting54"           => 20650,
                         "fighton"              => 13632,
                         "figment"              => 10883,
                         "figure8"              => 29656,
                         "figvam"               => 28384,
                         "fihdfv"               => 18274,
                         "filatova"             => 27176,
                         "filbert"              => 12314,
                         "filibert"             => 14366,
                         "filimon"              => 9293,
                         "filipe"               => 14787,
                         "filipp"               => 12190,
                         "filippo"              => 7738,
                         "filles"               => 25756,
                         "filmstar"             => 27324,
                         "filter"               => 1895,
                         "finalfan"             => 10896,
                         "finalfantasy"         => 6531,
                         "finance1"             => 17753,
                         "financia"             => 29508,
                         "finbar"               => 17390,
                         "finder"               => 5793,
                         "findme"               => 12750,
                         "findout"              => 13161,
                         "findus"               => 28399,
                         "fine1"                => 25591,
                         "finger"               => 1156,
                         "finger1"              => 23103,
                         "finnland"             => 24564,
                         "finster"              => 15831,
                         "fiocco"               => 26185,
                         "fiona1"               => 17421,
                         "firdaus"              => 27255,
                         "fire"                 => 383,
                         "fire1"                => 9251,
                         "fire12"               => 28980,
                         "fire123"              => 29100,
                         "fire1234"             => 28914,
                         "fire13"               => 28404,
                         "fire69"               => 21921,
                         "fire777"              => 14605,
                         "fire911"              => 15878,
                         "fireball"             => 749,
                         "firebird"             => 729,
                         "fireblad"             => 5305,
                         "fireblade"            => 7544,
                         "fireboy"              => 23057,
                         "firecat"              => 18222,
                         "firedawg"             => 22836,
                         "firedept"             => 27775,
                         "firedog"              => 6608,
                         "firefigh"             => 4647,
                         "firefighter"          => 11545,
                         "firefly"              => 1478,
                         "firefly1"             => 16051,
                         "firefox"              => 1929,
                         "firegod"              => 27923,
                         "firehawk"             => 6955,
                         "firehose"             => 21102,
                         "firehous"             => 17700,
                         "fireman"              => 557,
                         "fireman1"             => 7258,
                         "firenze"              => 5148,
                         "fireplug"             => 25536,
                         "firestar"             => 7834,
                         "firestarter"          => 15574,
                         "fireston"             => 29653,
                         "firestor"             => 10328,
                         "firestorm"            => 6896,
                         "firetruc"             => 11093,
                         "firetruck"            => 16270,
                         "firewall"             => 3770,
                         "firewire"             => 18026,
                         "firework"             => 9572,
                         "first1"               => 8545,
                         "firstone"             => 17233,
                         "firstone123"          => 23211,
                         "firstson"             => 20984,
                         "firsttim"             => 20182,
                         "fische"               => 16271,
                         "fish"                 => 350,
                         "fish1"                => 11109,
                         "fish123"              => 16613,
                         "fish1234"             => 14267,
                         "fish99"               => 23864,
                         "fishbait"             => 15941,
                         "fishbone"             => 4024,
                         "fishboy"              => 16624,
                         "fishcake"             => 6478,
                         "fishe"                => 21830,
                         "fishead"              => 29470,
                         "fisher1"              => 16675,
                         "fisherma"             => 6563,
                         "fisherman"            => 5863,
                         "fishers"              => 21957,
                         "fishes"               => 2419,
                         "fishface"             => 7478,
                         "fishfood"             => 13226,
                         "fishhead"             => 4156,
                         "fishhook"             => 22237,
                         "fishie"               => 20642,
                         "fishin"               => 3826,
                         "fishing"              => 180,
                         "fishing1"             => 2937,
                         "fishka"               => 18878,
                         "fishlips"             => 21673,
                         "fishnet"              => 10102,
                         "fishon"               => 5197,
                         "fishpond"             => 28025,
                         "fishtank"             => 6270,
                         "fishy"                => 6475,
                         "fishy1"               => 15118,
                         "fister"               => 6497,
                         "fistfuck"             => 10645,
                         "fisting"              => 3059,
                         "fitnes"               => 27104,
                         "fitness"              => 1809,
                         "fitness1"             => 22534,
                         "fitta"                => 24485,
                         "fittan"               => 19589,
                         "fitte"                => 22283,
                         "fitter"               => 5679,
                         "fitzgera"             => 28196,
                         "five55"               => 28052,
                         "fiveiron"             => 26142,
                         "fivestar"             => 6482,
                         "fixit"                => 12449,
                         "fizika"               => 24013,
                         "fizzle"               => 17642,
                         "fj1200"               => 18612,
                         "fjdksl"               => 26426,
                         "fjnq8915"             => 24812,
                         "fk8bhydb"             => 17917,
                         "fkbcrf"               => 22400,
                         "fkbyf001"             => 15636,
                         "fkbyjxrf"             => 4933,
                         "fkbyrf"               => 7985,
                         "fkg7h4f3v6"           => 15669,
                         "fkmnthyfnbdf"         => 9746,
                         "fkojn6gb"             => 22199,
                         "fkrjujkbr"            => 27250,
                         "fktdnbyf"             => 16496,
                         "fktif6115"            => 29982,
                         "fktirf"               => 22470,
                         "fktrcfyl"             => 24443,
                         "fktrcfylh"            => 551,
                         "fktrcfylh1"           => 21893,
                         "fktrcfylhf"           => 2171,
                         "fktrcfylhjd"          => 25039,
                         "fktrcfylhjdbx"        => 10738,
                         "fktrcfylhjdf"         => 29615,
                         "fktrcfylhjdyf"        => 10734,
                         "fktrcfylth"           => 29920,
                         "fktrctq"              => 1030,
                         "fktrcttd"             => 20484,
                         "fktrcttdf"            => 26587,
                         "fktyeirf"             => 7752,
                         "fktyjxrf"             => 12724,
                         "fktyrf"               => 4877,
                         "flaco1"               => 24101,
                         "flagman"              => 22128,
                         "flame1"               => 15947,
                         "flameboy"             => 16228,
                         "flamengo"             => 5318,
                         "flameon"              => 24235,
                         "flamer"               => 10072,
                         "flames"               => 1534,
                         "flamingo"             => 1928,
                         "flange"               => 7730,
                         "flanker"              => 4220,
                         "flapjack"             => 10140,
                         "flapper"              => 9226,
                         "flappy"               => 26380,
                         "flaquit"              => 28224,
                         "flash"                => 755,
                         "flash1"               => 2362,
                         "flash123"             => 15197,
                         "flash2"               => 26340,
                         "flash33"              => 29501,
                         "flashbac"             => 18902,
                         "flasher"              => 4904,
                         "flashg"               => 19451,
                         "flashman"             => 6875,
                         "flashnet"             => 25295,
                         "flatbush"             => 19517,
                         "flathead"             => 6808,
                         "flatland"             => 19567,
                         "flatline"             => 13183,
                         "flatron"              => 1142,
                         "flatron1"             => 22626,
                         "flatus"               => 21364,
                         "flavi"                => 25955,
                         "flavio"               => 13618,
                         "flblfc"               => 20548,
                         "fldjrfn"              => 21666,
                         "fleetwoo"             => 14915,
                         "fleshbot"             => 29888,
                         "fletch"               => 2277,
                         "fletch1"              => 25294,
                         "flexible"             => 3250,
                         "flexscan"             => 23332,
                         "flhrci"               => 28167,
                         "flhtyfkby"            => 9676,
                         "flibble"              => 24143,
                         "flicka"               => 12842,
                         "flicks"               => 5230,
                         "flight1"              => 17210,
                         "flimflam"             => 18384,
                         "flint1"               => 21458,
                         "flintsto"             => 9014,
                         "flintstone"           => 19005,
                         "fliper"               => 28547,
                         "flipflop"             => 5380,
                         "flipmode"             => 8381,
                         "flipoff"              => 26648,
                         "flippe"               => 24968,
                         "flipper"              => 896,
                         "flipper1"             => 6052,
                         "flippy"               => 8319,
                         "flipside"             => 11285,
                         "flipyou"              => 16006,
                         "flogger"              => 11184,
                         "floppy"               => 2401,
                         "flopsy"               => 27969,
                         "flore"                => 12272,
                         "floren"               => 25447,
                         "florenc"              => 11310,
                         "florenci"             => 22350,
                         "florent"              => 21047,
                         "flori"                => 22698,
                         "florian"              => 2357,
                         "florian1"             => 16593,
                         "florid"               => 12117,
                         "florida"              => 239,
                         "florida1"             => 2585,
                         "florida2"             => 15696,
                         "florin"               => 13070,
                         "flossy"               => 9934,
                         "flotsam"              => 15790,
                         "flounder"             => 2515,
                         "flowe"                => 6791,
                         "flower"               => 181,
                         "flower1"              => 6121,
                         "flower12"             => 21413,
                         "flower2"              => 5598,
                         "flowers1"             => 8247,
                         "floyd1"               => 9155,
                         "fltkbyf"              => 21485,
                         "flubber"              => 8673,
                         "fluff"                => 5671,
                         "fluffy"               => 394,
                         "fluffy1"              => 9713,
                         "flute1"               => 25065,
                         "flutie"               => 15711,
                         "flvbhfk"              => 21843,
                         "flvbybcnhfnjh"        => 6116,
                         "flyaway"              => 10490,
                         "flyboy"               => 1739,
                         "flyboy1"              => 25161,
                         "flyer"                => 5963,
                         "flyer1"               => 15687,
                         "flyers"               => 412,
                         "flyers1"              => 9124,
                         "flyers88"             => 6014,
                         "flyers99"             => 27808,
                         "flyfish"              => 4148,
                         "flyfishi"             => 24959,
                         "flyguy"               => 7705,
                         "flyhigh"              => 11159,
                         "flyingv"              => 20486,
                         "flyman"               => 19585,
                         "flynavy"              => 25156,
                         "flyrod"               => 18357,
                         "flyvholm"             => 25735,
                         "flywheel"             => 25713,
                         "fm12mn12"             => 27155,
                         "fmale"                => 6945,
                         "fnkfynblf"            => 10316,
                         "fnord"                => 15710,
                         "focus1"               => 9319,
                         "fodase"               => 21608,
                         "foghat"               => 24248,
                         "foghorn"              => 9814,
                         "foiegras"             => 18515,
                         "fokker"               => 7664,
                         "folgers"              => 27094,
                         "folgore"              => 26649,
                         "followme"             => 12547,
                         "fomoco"               => 9538,
                         "fonzie"               => 10155,
                         "foobar"               => 914,
                         "foodie"               => 21899,
                         "fooey"                => 28630,
                         "foofight"             => 18709,
                         "foolio"               => 11296,
                         "footbal"              => 2755,
                         "footbal1"             => 9508,
                         "football"             => 14,
                         "football1"            => 2254,
                         "football12"           => 15856,
                         "football123"          => 28729,
                         "football2"            => 16116,
                         "footboy"              => 22409,
                         "footer"               => 15593,
                         "foothill"             => 14927,
                         "footie"               => 26620,
                         "footjob"              => 5120,
                         "footlong"             => 14122,
                         "footlove"             => 8752,
                         "footman"              => 7227,
                         "footsie"              => 16883,
                         "footslav"             => 25485,
                         "forall"               => 7485,
                         "forbidde"             => 14781,
                         "forbin"               => 22722,
                         "force1"               => 9680,
                         "ford01"               => 22141,
                         "ford1"                => 11681,
                         "ford11"               => 25898,
                         "ford123"              => 21675,
                         "ford150"              => 11831,
                         "ford22"               => 20753,
                         "ford350"              => 29022,
                         "ford4x4"              => 21179,
                         "ford50"               => 28796,
                         "ford9402"             => 15769,
                         "fordf150"             => 2054,
                         "fordf250"             => 8042,
                         "fordf350"             => 7344,
                         "fordfocus"            => 26146,
                         "fordgt"               => 25874,
                         "fordgt40"             => 29454,
                         "fordman"              => 10399,
                         "fordtruc"             => 7311,
                         "fordtruck"            => 15343,
                         "foreplay"             => 6427,
                         "foreskin"             => 6636,
                         "forest"               => 461,
                         "forest1"              => 12439,
                         "forest11"             => 13085,
                         "forest99"             => 23660,
                         "foreve"               => 4065,
                         "forever"              => 160,
                         "forever1"             => 4855,
                         "forever21"            => 19929,
                         "forfree"              => 15859,
                         "forfun"               => 2473,
                         "forgetit"             => 5269,
                         "forgetme"             => 27164,
                         "forgotit"             => 17325,
                         "forgotte"             => 13842,
                         "forklift"             => 9282,
                         "forlife"              => 5862,
                         "formatters"           => 25014,
                         "forme"                => 8050,
                         "formel1"              => 23206,
                         "formula"              => 1527,
                         "formula1"             => 1511,
                         "fornow"               => 17831,
                         "forplay"              => 25593,
                         "forrest1"             => 18399,
                         "forsaken"             => 3704,
                         "forsale"              => 28308,
                         "forsure"              => 20890,
                         "fortis"               => 17908,
                         "fortknox"             => 28676,
                         "fortun"               => 18363,
                         "fortuna"              => 2039,
                         "fortunat"             => 21493,
                         "fortune1"             => 24632,
                         "fortune12"            => 12686,
                         "forty1"               => 28886,
                         "forty2"               => 15203,
                         "fortytwo"             => 12346,
                         "forum1"               => 22136,
                         "forumwp"              => 9334,
                         "forward1"             => 22316,
                         "foryou"               => 3032,
                         "forzaroma"            => 27001,
                         "forzima"              => 17830,
                         "fosgate"              => 18198,
                         "fossil"               => 1241,
                         "foster1"              => 25445,
                         "fosters"              => 5510,
                         "fostex"               => 28463,
                         "fotball"              => 22974,
                         "fotograf"             => 21405,
                         "fotze"                => 27663,
                         "foucault"             => 12730,
                         "foundati"             => 18328,
                         "four20"               => 7882,
                         "fourkids"             => 27181,
                         "fourplay"             => 23637,
                         "fourstar"             => 25918,
                         "fourx4"               => 26602,
                         "fox123"               => 21354,
                         "foxbat"               => 12457,
                         "foxcg33"              => 8679,
                         "foxfire"              => 6552,
                         "foxglove"             => 14192,
                         "foxhound"             => 9134,
                         "foxmulder"            => 29245,
                         "foxs14"               => 20152,
                         "foxtrot"              => 1275,
                         "foxtrot1"             => 11863,
                         "foxwoods"             => 19468,
                         "foxy"                 => 3892,
                         "foxylady"             => 4535,
                         "foxyroxy"             => 22363,
                         "fozzie"               => 7297,
                         "fozzy"                => 28539,
                         "fqkw5m"               => 15677,
                         "fractal"              => 16194,
                         "fractals"             => 25139,
                         "fraggle"              => 7279,
                         "frame1"               => 25285,
                         "framer"               => 10439,
                         "franc"                => 4090,
                         "franca"               => 12359,
                         "france1"              => 16070,
                         "france98"             => 23678,
                         "frances1"             => 19189,
                         "francesc"             => 2691,
                         "franchis"             => 18367,
                         "franci"               => 7386,
                         "francis1"             => 8681,
                         "francisc"             => 4691,
                         "franco1"              => 24960,
                         "francoi"              => 15702,
                         "francy"               => 16768,
                         "frank1"               => 1597,
                         "frank12"              => 21600,
                         "frank123"             => 7938,
                         "frank2"               => 15407,
                         "frank69"              => 21844,
                         "franka"               => 19518,
                         "franken"              => 19210,
                         "frankfur"             => 10810,
                         "franki"               => 9346,
                         "frankie1"             => 5670,
                         "franky"               => 1859,
                         "franky1"              => 26716,
                         "franny"               => 11358,
                         "franzi"               => 25239,
                         "frasse"               => 28347,
                         "frdfhbev"             => 12038,
                         "frdfkfyu"             => 20507,
                         "fre_ak8yj"            => 29434,
                         "freak1"               => 10486,
                         "freakboy"             => 28801,
                         "freaker"              => 21325,
                         "freakme"              => 22451,
                         "freakout"             => 17561,
                         "freaks"               => 1948,
                         "freaksho"             => 22759,
                         "freakshow"            => 16166,
                         "freaky"               => 848,
                         "freaky1"              => 16489,
                         "freckles"             => 1595,
                         "fred01"               => 16634,
                         "fred1"                => 7881,
                         "fred11"               => 18896,
                         "fred12"               => 11174,
                         "fred123"              => 9224,
                         "fred1234"             => 7835,
                         "fred20"               => 26951,
                         "fred22"               => 19812,
                         "fred69"               => 14883,
                         "fred99"               => 16938,
                         "fredd"                => 10656,
                         "freddd"               => 15937,
                         "fredderf"             => 11471,
                         "freddi"               => 20398,
                         "freddie1"             => 12098,
                         "freddy"               => 289,
                         "freddy1"              => 5421,
                         "freddy12"             => 16367,
                         "freder"               => 25840,
                         "frederi"              => 11104,
                         "frederik"             => 5686,
                         "frederiksberg"        => 22659,
                         "fredi"                => 13876,
                         "fredie"               => 27319,
                         "fredonia"             => 26419,
                         "fredrau"              => 25495,
                         "fredy"                => 21857,
                         "free1"                => 19469,
                         "free12"               => 28786,
                         "free123"              => 19459,
                         "free30"               => 26616,
                         "free4all"             => 11514,
                         "free4me"              => 19952,
                         "freebie"              => 12764,
                         "freebird"             => 3973,
                         "freecell"             => 25189,
                         "freeclus"             => 27876,
                         "freedo"               => 6177,
                         "freedom"              => 58,
                         "freedom0"             => 25458,
                         "freedom1"             => 895,
                         "freedom2"             => 7198,
                         "freedom3"             => 13118,
                         "freedom4"             => 19546,
                         "freedom5"             => 18313,
                         "freedom7"             => 11088,
                         "freedom8"             => 26335,
                         "freedom9"             => 21357,
                         "freee"                => 5541,
                         "freeee"               => 16799,
                         "freefall"             => 4606,
                         "freehand"             => 19198,
                         "freek"                => 18135,
                         "freelanc"             => 13845,
                         "freelove"             => 11424,
                         "freema"               => 21139,
                         "freemail"             => 16989,
                         "freeman1"             => 12548,
                         "freeme"               => 9160,
                         "freenet"              => 11904,
                         "freeones"             => 22618,
                         "freepass"             => 720,
                         "freeporn"             => 2256,
                         "freeport"             => 15352,
                         "freeride"             => 13190,
                         "freesex"              => 4157,
                         "freespace"            => 18680,
                         "freestuff"            => 15612,
                         "freestyl"             => 11216,
                         "freetime"             => 10089,
                         "freeuse"              => 29451,
                         "freeuser"             => 583,
                         "freeway"              => 3446,
                         "freeway1"             => 28768,
                         "freewill"             => 6932,
                         "fregat"               => 23948,
                         "frehley"              => 11019,
                         "freiheit"             => 8591,
                         "fremont"              => 7700,
                         "french1"              => 24040,
                         "frenchfr"             => 17728,
                         "frenchie"             => 6965,
                         "frenchy"              => 5606,
                         "frequenc"             => 17460,
                         "fresca"               => 10727,
                         "fresh1"               => 8944,
                         "fresher"              => 19068,
                         "fresno"               => 6641,
                         "freude"               => 26983,
                         "freya"                => 14617,
                         "freyja"               => 28854,
                         "frfltvbz"             => 16062,
                         "friday"               => 466,
                         "friday1"              => 8283,
                         "friday13"             => 6580,
                         "fridolin"             => 17633,
                         "friedric"             => 15349,
                         "frien"                => 12186,
                         "friend1"              => 14509,
                         "friends1"             => 7128,
                         "friendste"            => 12557,
                         "friendster"           => 5292,
                         "fright"               => 2230,
                         "frigid"               => 11997,
                         "frisbee"              => 6117,
                         "frisco"               => 2173,
                         "friskie"              => 15805,
                         "frisky"               => 2877,
                         "fritos"               => 19452,
                         "fritter"              => 12546,
                         "fritz1"               => 8097,
                         "fritzy"               => 19523,
                         "fritzz"               => 22664,
                         "frnhbcf"              => 16139,
                         "frodo"                => 2532,
                         "frodo1"               => 5255,
                         "frodo2"               => 28576,
                         "frog"                 => 1296,
                         "frog1"                => 25416,
                         "frogg"                => 23442,
                         "frogger"              => 1611,
                         "frogger1"             => 17629,
                         "froggie"              => 6699,
                         "froggies"             => 13748,
                         "froggy"               => 611,
                         "froggy1"              => 11097,
                         "froglegs"             => 15158,
                         "frogman"              => 4135,
                         "frogman1"             => 26072,
                         "frogs"                => 5543,
                         "frogss"               => 26796,
                         "froinlaven"           => 17708,
                         "frolov"               => 19539,
                         "frolova"              => 11753,
                         "fromage"              => 12637,
                         "fromhell"             => 20648,
                         "fromme"               => 22557,
                         "fromv"                => 17375,
                         "fromvermine"          => 28481,
                         "front242"             => 1718,
                         "frontera"             => 9818,
                         "frontier"             => 1831,
                         "frontosa"             => 26480,
                         "frosch"               => 5616,
                         "frost1996"            => 28273,
                         "frostbit"             => 22401,
                         "frosty"               => 1292,
                         "frosty1"              => 19728,
                         "frosya"               => 29174,
                         "frozenfish"           => 29643,
                         "fruitbat"             => 7272,
                         "fruitcak"             => 16463,
                         "fruity"               => 6084,
                         "frxtgb"               => 28577,
                         "fsd9shtyu"            => 23976,
                         "fsunoles"             => 23304,
                         "fuaqz4"               => 12700,
                         "fubar"                => 2188,
                         "fubar1"               => 7097,
                         "fubar123"             => 26931,
                         "fubared"              => 29308,
                         "fucing"               => 9295,
                         "fuck"                 => 65,
                         "fuck0ff"              => 9731,
                         "fuck1"                => 4412,
                         "fuck11"               => 18717,
                         "fuck12"               => 10589,
                         "fuck123"              => 4801,
                         "fuck1234"             => 16213,
                         "fuck666"              => 23310,
                         "fuck69"               => 5198,
                         "fuck777"              => 10561,
                         "fuck_inside"          => 1459,
                         "fuckall"              => 8888,
                         "fuckass"              => 12400,
                         "fucke"                => 9507,
                         "fucked"               => 964,
                         "fuckedup"             => 8476,
                         "fuckem"               => 8427,
                         "fucker"               => 85,
                         "fucker1"              => 5382,
                         "fucker11"             => 14111,
                         "fucker12"             => 28166,
                         "fucker69"             => 13222,
                         "fuckers"              => 1793,
                         "fuckface"             => 1519,
                         "fuckfest"             => 9755,
                         "fuckgirl"             => 23630,
                         "fuckhard"             => 14186,
                         "fuckhead"             => 4174,
                         "fuckher"              => 2394,
                         "fuckhole"             => 14890,
                         "fuckina"              => 11725,
                         "fucking"              => 309,
                         "fucking1"             => 26087,
                         "fuckinside"           => 4053,
                         "fuckit"               => 777,
                         "fuckit1"              => 25769,
                         "fuckitall"            => 24288,
                         "fucklife"             => 20043,
                         "fucklove"             => 11881,
                         "fuckm"                => 7892,
                         "fuckme"               => 48,
                         "fuckme1"              => 3779,
                         "fuckme2"              => 5479,
                         "fuckme69"             => 5733,
                         "fuckmeha"             => 12977,
                         "fuckmehard"           => 7619,
                         "fuckmeno"             => 22591,
                         "fuckmenow"            => 12215,
                         "fuckmyass"            => 22855,
                         "fuckmylife"           => 26834,
                         "fucknut"              => 18541,
                         "fucknuts"             => 20414,
                         "fuckof"               => 8324,
                         "fuckoff"              => 157,
                         "fuckoff1"             => 3067,
                         "fuckoff2"             => 21614,
                         "fuckshit"             => 8100,
                         "fuckslut"             => 11006,
                         "fuckthat"             => 7691,
                         "fuckthem"             => 24379,
                         "fuckthemall"          => 26359,
                         "fucktheworld"         => 15245,
                         "fuckthis"             => 2370,
                         "fucktoy"              => 25702,
                         "fucku"                => 2661,
                         "fucku2"               => 2522,
                         "fuckuall"             => 26237,
                         "fuckup"               => 9458,
                         "fuckwit"              => 18794,
                         "fucky"                => 23412,
                         "fuckya"               => 29657,
                         "fuckyeah"             => 8198,
                         "fuckyo"               => 3499,
                         "fuckyou"              => 30,
                         "fuckyou!"             => 17783,
                         "fuckyou0"             => 20578,
                         "fuckyou1"             => 1161,
                         "fuckyou12"            => 21045,
                         "fuckyou123"           => 9445,
                         "fuckyou2"             => 933,
                         "fuckyou6"             => 22330,
                         "fuckyou69"            => 15372,
                         "fuckyou7"             => 13510,
                         "fuckyou8"             => 25281,
                         "fuckyoubitch"         => 19704,
                         "fuckyouguys"          => 22988,
                         "fucmy69"              => 7651,
                         "fudge1"               => 15653,
                         "fuente"               => 12351,
                         "fuerte"               => 24134,
                         "fuesse"               => 27841,
                         "fufnfrhbcnb"          => 28734,
                         "fugazi"               => 2177,
                         "fuhrfzgc"             => 17738,
                         "fujifilm"             => 6722,
                         "fujimo"               => 29225,
                         "fujitsu"              => 5754,
                         "fuking"               => 7924,
                         "fulcrum"              => 8111,
                         "fulham"               => 3438,
                         "fulhamfc"             => 28099,
                         "fullback"             => 7168,
                         "fulle"                => 18852,
                         "fullhous"             => 22538,
                         "fullmetal"            => 15843,
                         "fullmoon"             => 3709,
                         "fullred"              => 22940,
                         "fullsail"             => 13435,
                         "fumanchu"             => 14823,
                         "fun123"               => 11360,
                         "fun4all"              => 28259,
                         "fun4me"               => 8387,
                         "funbags"              => 20066,
                         "funboy"               => 18312,
                         "funfunfu"             => 23341,
                         "fungus"               => 6271,
                         "funguy"               => 10621,
                         "funhouse"             => 9919,
                         "funkey"               => 21711,
                         "funkie"               => 23875,
                         "funkster"             => 19252,
                         "funky"                => 5113,
                         "funky1"               => 8998,
                         "funny1"               => 6291,
                         "funnyguy"             => 21103,
                         "funnyman"             => 9884,
                         "funone"               => 29801,
                         "funsex"               => 11615,
                         "funstuff"             => 5090,
                         "funtik"               => 7728,
                         "funtime"              => 1214,
                         "funtime1"             => 17721,
                         "funtimes"             => 6958,
                         "furball"              => 5820,
                         "furelise"             => 29738,
                         "furka"                => 23219,
                         "furnitur"             => 28479,
                         "fusion"               => 1369,
                         "fussbal"              => 11297,
                         "fussball"             => 4823,
                         "futbol"               => 2762,
                         "futur"                => 17914,
                         "futura"               => 10284,
                         "futurama"             => 5216,
                         "future1"              => 10529,
                         "futuro"               => 18847,
                         "futyn007"             => 7124,
                         "fuzzball"             => 6991,
                         "fuzzie"               => 24168,
                         "fuzzy"                => 3210,
                         "fuzzy1"               => 6637,
                         "fvcnthlfv"            => 18824,
                         "fvfnjhb"              => 24699,
                         "fvthbrf"              => 15717,
                         "fwsadn"               => 15794,
                         "fx3tuo"               => 15081,
                         "fy.njxrf"             => 21014,
                         "fy.nrf"               => 9613,
                         "fyabcf"               => 14775,
                         "fyfcnfcbz"            => 642,
                         "fyfnjkbq"             => 4419,
                         "fyfnjkmtdbx"          => 29224,
                         "fyfnjkmtdyf"          => 25155,
                         "fyfrjylf"             => 14558,
                         "fyfyfc"               => 18156,
                         "fylh.irf"             => 19779,
                         "fylhjvtlf"            => 14768,
                         "fylhsq"               => 25901,
                         "fylhtq"               => 615,
                         "fylhtq1"              => 24238,
                         "fylhtq123"            => 29061,
                         "fylhtq95"             => 24810,
                         "fylhtqrf"             => 11477,
                         "fylhttdf"             => 22607,
                         "fynfyfyfhbde"         => 21266,
                         "fynjif"               => 13344,
                         "fynjirf"              => 6387,
                         "fynjy"                => 29570,
                         "fynjy123"             => 29093,
                         "fynjybj"              => 20820,
                         "fynjybyf"             => 8048,
                         "fynjyjdf"             => 28825,
                         "fytxrf"               => 3043,
                         "fyutk"                => 25417,
                         "fyutkbyf"             => 3267,
                         "fyutkjr"              => 10711,
                         "fyutkjxtr"            => 5429,
                         "fyyeirf"              => 7582,
                         "fzappa"               => 7191,
                         "fzr600"               => 28596,
                         "g00ber"               => 11415,
                         "g00gle"               => 16209,
                         "g0away"               => 28234,
                         "g0dz1ll4"             => 26209,
                         "g12345"               => 13460,
                         "g123456"              => 21374,
                         "g1234567"             => 25558,
                         "g3ujwg"               => 11628,
                         "g5wks9"               => 24454,
                         "g9zns4"               => 13659,
                         "gabber"               => 5191,
                         "gabbie"               => 12095,
                         "gabby1"               => 7384,
                         "gabrie"               => 2034,
                         "gabriel1"             => 3332,
                         "gabriel12"            => 28856,
                         "gabriel2"             => 13451,
                         "gabriell"             => 2810,
                         "gadfly"               => 29370,
                         "gadget"               => 3460,
                         "gadina"               => 28788,
                         "gadzooks"             => 15098,
                         "gaell"                => 4894,
                         "gaelle"               => 13742,
                         "gaetan"               => 15956,
                         "gaetano"              => 10633,
                         "gaffer"               => 10271,
                         "gagarin"              => 6596,
                         "gagged"               => 4901,
                         "gagger"               => 14354,
                         "gagging"              => 4239,
                         "gagher"               => 18179,
                         "gaijin"               => 8702,
                         "galactic"             => 9812,
                         "galactus"             => 13430,
                         "galadriel"            => 9403,
                         "galahad"              => 10082,
                         "galant"               => 4777,
                         "galary"               => 6463,
                         "galatasara"           => 21999,
                         "galatasaray"          => 10058,
                         "galatea"              => 23109,
                         "galax"                => 18730,
                         "galaxie"              => 9399,
                         "galaxy"               => 950,
                         "galaxy1"              => 13008,
                         "galena"               => 11869,
                         "galeries"             => 8166,
                         "galileo"              => 6433,
                         "galina"               => 655,
                         "galinka"              => 21518,
                         "gallaghe"             => 13614,
                         "gallaries"            => 6259,
                         "galore"               => 581,
                         "galvesto"             => 24332,
                         "gambit"               => 924,
                         "gambit1"              => 19856,
                         "gambler"              => 4439,
                         "gameboy"              => 3878,
                         "gamecock"             => 3569,
                         "gamecocks"            => 22584,
                         "gamecube"             => 3079,
                         "gameday"              => 20096,
                         "gamemaster"           => 26536,
                         "gameon"               => 12689,
                         "gameover"             => 3044,
                         "gamer"                => 8087,
                         "gamer1"               => 18863,
                         "gamera"               => 11859,
                         "gamers"               => 11421,
                         "games1"               => 12141,
                         "gamess"               => 21242,
                         "gametime"             => 12039,
                         "gamgee"               => 26318,
                         "gamlet"               => 19116,
                         "gamma"                => 5559,
                         "gamma1"               => 16257,
                         "gammas"               => 20264,
                         "gandal"               => 14879,
                         "gandalf"              => 188,
                         "gandalf0"             => 24961,
                         "gandalf1"             => 2203,
                         "gandalf2"             => 11827,
                         "gandalf3"             => 22668,
                         "gandalf7"             => 26851,
                         "gandolf"              => 7702,
                         "gandon"               => 8932,
                         "ganesh"               => 3742,
                         "ganesha"              => 9653,
                         "gangbang"             => 1744,
                         "gangbanged"           => 6558,
                         "gangrel"              => 9136,
                         "gangst"               => 14792,
                         "gangsta"              => 1483,
                         "gangsta1"             => 13948,
                         "gangstar"             => 14777,
                         "gangste"              => 17703,
                         "gangster"             => 1382,
                         "gangster1"            => 25017,
                         "ganibal"              => 28492,
                         "ganja"                => 6209,
                         "ganjaman"             => 8645,
                         "ganjubas"             => 9879,
                         "gannibal"             => 5628,
                         "gansta"               => 18979,
                         "ganster"              => 10768,
                         "ganymede"             => 11187,
                         "garand"               => 12613,
                         "garbage1"             => 20707,
                         "garci"                => 11617,
                         "garcia1"              => 15035,
                         "garden"               => 1010,
                         "garden1"              => 19387,
                         "gardenia"             => 11982,
                         "garena"               => 22795,
                         "gareth"               => 5837,
                         "garfiel"              => 12309,
                         "garfield"             => 305,
                         "garfield1"            => 17493,
                         "garfild"              => 22994,
                         "gargamel"             => 11795,
                         "gargoyle"             => 2551,
                         "garibald"             => 21987,
                         "garion"               => 3934,
                         "garnier"              => 20585,
                         "garrett1"             => 10879,
                         "garten"               => 10427,
                         "garter"               => 8565,
                         "garuda"               => 20487,
                         "gary123"              => 21775,
                         "gasman"               => 4011,
                         "gasto"                => 23767,
                         "gatech"               => 11943,
                         "gatekeep"             => 18290,
                         "gatewa"               => 20986,
                         "gateway"              => 125,
                         "gateway1"             => 1584,
                         "gateway2"             => 4950,
                         "gateway3"             => 20577,
                         "gateway9"             => 23555,
                         "gateways"             => 11101,
                         "gatinho"              => 23359,
                         "gatit"                => 5714,
                         "gatita"               => 19283,
                         "gatito"               => 7838,
                         "gator"                => 1723,
                         "gator1"               => 2999,
                         "gator2"               => 21963,
                         "gatorade"             => 3285,
                         "gatorman"             => 17688,
                         "gators"               => 292,
                         "gators1"              => 5457,
                         "gators96"             => 28483,
                         "gatsby"               => 5631,
                         "gattaca"              => 21404,
                         "gattone"              => 20090,
                         "gaucho"               => 7045,
                         "gaudeamus"            => 25856,
                         "gauloise"             => 22357,
                         "gauntlet"             => 14591,
                         "gaurav"               => 16100,
                         "gautam"               => 23258,
                         "gauthie"              => 22687,
                         "gautie"               => 22417,
                         "gavaec"               => 25174,
                         "gavin1"               => 19358,
                         "gaviota"              => 29172,
                         "gavrik"               => 13649,
                         "gavrilov"             => 25492,
                         "gawker"               => 3243,
                         "gawker1"              => 20856,
                         "gayathri"             => 28632,
                         "gayboy"               => 7280,
                         "gaydar"               => 17230,
                         "gayguy"               => 27941,
                         "gaymen"               => 6365,
                         "gaysex"               => 10559,
                         "gazelle"              => 8422,
                         "gazeta"               => 21504,
                         "gazza"                => 11771,
                         "gazza1"               => 18982,
                         "gb15kv99"             => 22830,
                         "gbcmrf"               => 8200,
                         "gbgbcmrf"             => 8858,
                         "gbhcf2"               => 16114,
                         "gbhfvblf"             => 4281,
                         "gbjyth"               => 21408,
                         "gbkbuhbv"             => 28081,
                         "gblfhfc"              => 20251,
                         "gblfhfcbyf"           => 19429,
                         "gblfhfcs"             => 12921,
                         "gbljhfc"              => 28436,
                         "gbljhfcs"             => 25237,
                         "gborv526"             => 25266,
                         "gbpacker"             => 13588,
                         "gbplf123"             => 24603,
                         "gbpltw"               => 1913,
                         "gbpltw123"            => 24899,
                         "gbrfxe"               => 22166,
                         "gbyudby"              => 8397,
                         "gcheckou"             => 22680,
                         "gcheckout"            => 23878,
                         "gdtrfb"               => 6803,
                         "gearhead"             => 11413,
                         "gecko"                => 7695,
                         "gecko1"               => 11880,
                         "geckos"               => 20397,
                         "geddylee"             => 17232,
                         "geek01d"              => 17593,
                         "geekboy"              => 30000,
                         "geeman"               => 16082,
                         "geemoney"             => 21530,
                         "geeque"               => 28087,
                         "geetha"               => 25109,
                         "geezer"               => 5121,
                         "gefest"               => 22892,
                         "geforce"              => 15464,
                         "gegcbr"               => 2697,
                         "geheim"               => 1212,
                         "gehenna"              => 23354,
                         "gehrig"               => 11730,
                         "geibcnbr"             => 7649,
                         "geilesau"             => 18169,
                         "geirby"               => 12108,
                         "geisha"               => 9799,
                         "gembird"              => 18330,
                         "gemeni"               => 24975,
                         "gemin"                => 10673,
                         "gemini"               => 236,
                         "gemini1"              => 7547,
                         "gemini12"             => 28744,
                         "gemini13"             => 29600,
                         "gemini69"             => 21219,
                         "gemma1"               => 14789,
                         "gemstone"             => 10149,
                         "gen0303"              => 20884,
                         "gendalf"              => 28321,
                         "general1"             => 6687,
                         "generic"              => 3478,
                         "generic1"             => 17959,
                         "genesi"               => 10772,
                         "genesis"              => 438,
                         "genesis1"             => 4025,
                         "genesis2"             => 26364,
                         "geneve"               => 16076,
                         "geneviev"             => 10794,
                         "geng"                 => 3455,
                         "genghis"              => 8454,
                         "genial"               => 23921,
                         "geniu"                => 11056,
                         "genius"               => 407,
                         "genius1"              => 16094,
                         "geniusnet"            => 16786,
                         "gennadiy"             => 22526,
                         "geoffre"              => 29522,
                         "geolog"               => 18307,
                         "geolog323"            => 21684,
                         "geordie"              => 12980,
                         "georg"                => 3595,
                         "george01"             => 13890,
                         "george1"              => 2396,
                         "george11"             => 17589,
                         "george12"             => 10432,
                         "george13"             => 25062,
                         "george2"              => 12220,
                         "george3"              => 18942,
                         "georgi"               => 9655,
                         "georgia1"             => 6721,
                         "georgia2"             => 26712,
                         "georgin"              => 18763,
                         "georgiy"              => 14895,
                         "gepard"               => 16805,
                         "geral"                => 25117,
                         "gerald1"              => 17048,
                         "geraldin"             => 8775,
                         "gerar"                => 27701,
                         "gerasim"              => 13492,
                         "gerasimova"           => 27156,
                         "gerbera"              => 25525,
                         "gerbil"               => 5484,
                         "gerhard"              => 6822,
                         "gericom"              => 24212,
                         "gerlinde"             => 20833,
                         "germa"                => 19806,
                         "german1"              => 17206,
                         "germania"             => 15936,
                         "germany1"             => 7993,
                         "geroin"               => 24667,
                         "geronim"              => 27971,
                         "geronimo"             => 1083,
                         "geronto"              => 17181,
                         "gerrard"              => 4909,
                         "gerrard8"             => 19318,
                         "gerri1"               => 29645,
                         "gerrit"               => 19561,
                         "gerrity1"             => 14426,
                         "gerry1"               => 13906,
                         "gerryber"             => 29429,
                         "geryfe"               => 14000,
                         "gesperrt"             => 2841,
                         "getalife"             => 11313,
                         "getbent"              => 15785,
                         "getdown"              => 18637,
                         "getfucked"            => 23036,
                         "gethigh"              => 16579,
                         "getin"                => 8682,
                         "getinnow"             => 29937,
                         "getit"                => 6732,
                         "getiton"              => 14127,
                         "getlaid"              => 13692,
                         "getlost"              => 6829,
                         "getmein"              => 8671,
                         "getmoney"             => 2478,
                         "getnaked"             => 14633,
                         "getoff"               => 6248,
                         "getout"               => 4039,
                         "getpaid"              => 16160,
                         "getreal"              => 19013,
                         "getrich"              => 18195,
                         "getsdown"             => 9213,
                         "getsmart"             => 14126,
                         "getsome"              => 1329,
                         "getsum"               => 22508,
                         "gettysbu"             => 23186,
                         "geujdrf"              => 19840,
                         "gevaudan"             => 22167,
                         "gevorg"               => 20126,
                         "geyser"               => 18795,
                         "gfccdjhl"             => 12965,
                         "gfccgjhn"             => 23759,
                         "gfcgjhn"              => 9126,
                         "gfdkbr"               => 9200,
                         "gfdkjd"               => 28812,
                         "gfdkjdf"              => 13171,
                         "gfg65h7"              => 26205,
                         "gfgekz"               => 21149,
                         "gfgf1234"             => 23930,
                         "gfgfif"               => 28412,
                         "gfgfrfhkj"            => 21950,
                         "gfgfvfvf"             => 6942,
                         "gfghbrf"              => 26032,
                         "gfgjxrf"              => 11324,
                         "gfhfcjkmrf"           => 21300,
                         "gfhfdjp"              => 20129,
                         "gfhfif"               => 11215,
                         "gfhfljrc"             => 9460,
                         "gfhfpbn"              => 25440,
                         "gfhfvgfvgfv"          => 26406,
                         "gfhfyjbr"             => 24685,
                         "gfhfyjqz"             => 29749,
                         "gfhfyjz"              => 17123,
                         "gfhjdjp"              => 7389,
                         "gfhjk"                => 18957,
                         "gfhjkbot"             => 19093,
                         "gfhjkm"               => 88,
                         "gfhjkm007"            => 16899,
                         "gfhjkm1"              => 2994,
                         "gfhjkm11"             => 19060,
                         "gfhjkm12"             => 7457,
                         "gfhjkm123"            => 2431,
                         "gfhjkm13"             => 21178,
                         "gfhjkm135"            => 22109,
                         "gfhjkm2"              => 15802,
                         "gfhjkm22"             => 17798,
                         "gfhjkm777"            => 28106,
                         "gfhjkmgfhjkm"         => 3383,
                         "gfhjkmm"              => 14009,
                         "gfhjkmxbr"            => 11713,
                         "gfhjkzytn"            => 9133,
                         "gfhkfvtyn"            => 10659,
                         "gfhnbpfy"             => 10580,
                         "gfhreh"               => 10953,
                         "gfif1991"             => 14548,
                         "gfitymrf"             => 28430,
                         "gfkmvf"               => 21056,
                         "gfnhbjn"              => 9166,
                         "gfnhbr"               => 12434,
                         "gforce"               => 7940,
                         "gfvznm"               => 22924,
                         "gfxqx686"             => 17987,
                         "gfyfcjybr"            => 15132,
                         "gfynthf"              => 6830,
                         "gggg1"                => 22648,
                         "ggggg1"               => 11356,
                         "gggggg1"              => 10462,
                         "ggggggg1"             => 18551,
                         "ghandi"               => 11078,
                         "ghbcnfd"              => 29094,
                         "ghbdfn"               => 18615,
                         "ghbdt"                => 16028,
                         "ghbdtn"               => 191,
                         "ghbdtn1"              => 11333,
                         "ghbdtn12"             => 9848,
                         "ghbdtn123"            => 4321,
                         "ghbdtnbr"             => 1190,
                         "ghbdtnbr1"            => 13606,
                         "ghbdtnbrb"            => 11330,
                         "ghbdtndctv"           => 6889,
                         "ghbdtnghbdtn"         => 11411,
                         "ghbdtngjrf"           => 17260,
                         "ghbdtnrfrltkf"        => 6546,
                         "ghbhjlf"              => 12650,
                         "ghbjhbntn"            => 21508,
                         "ghblehjr"             => 3219,
                         "ghblehrb"             => 10660,
                         "ghbphfr"              => 17841,
                         "ghbrjk"               => 5178,
                         "ghbrjkbcn"            => 9699,
                         "ghbrjkmyj"            => 10939,
                         "ghbynth"              => 12291,
                         "ghbywtccf"            => 4170,
                         "ghetto"               => 2361,
                         "ghfdlf"               => 10414,
                         "ghfgjh"               => 25091,
                         "ghfplybr"             => 20230,
                         "ghhh47hj764"          => 16253,
                         "ghhh47hj7649"         => 4976,
                         "ghibli"               => 24903,
                         "ghislain"             => 28867,
                         "ghjatccjh"            => 29383,
                         "ghjcgtrn"             => 22395,
                         "ghjcnb"               => 15596,
                         "ghjcnbnenrf"          => 5958,
                         "ghjcnbvtyz"           => 19709,
                         "ghjcnj"               => 1482,
                         "ghjcnj123"            => 13113,
                         "ghjcnjabkz"           => 25409,
                         "ghjcnjgbpltw"         => 23698,
                         "ghjcnjgfhjkm"         => 4336,
                         "ghjcnjghjcnj"         => 9669,
                         "ghjcnjnf"             => 18817,
                         "ghjcnjnfr"            => 2539,
                         "ghjcnjnfr1"           => 20798,
                         "ghjcnjq"              => 6108,
                         "ghjcnjqgfhjkm"        => 21476,
                         "ghjcnjrdfibyj"        => 13782,
                         "ghjcnjrdfif"          => 18596,
                         "ghjcnjz"              => 21400,
                         "ghjdthrf"             => 7657,
                         "ghjgecr"              => 14630,
                         "ghjgfufylf"           => 29188,
                         "ghjhjr"               => 19102,
                         "ghjkju"               => 11373,
                         "ghjnbdjcnjzybt"       => 29468,
                         "ghjnjnbg"             => 7836,
                         "ghjnjrjk"             => 9498,
                         "ghjrehfnehf"          => 16980,
                         "ghjrehjh"             => 21795,
                         "ghjrjgtyrj"           => 24223,
                         "ghjtrn"               => 25794,
                         "ghjuhfvbcn"           => 27461,
                         "ghjuhfvvbcn"          => 29644,
                         "ghjuhfvvf"            => 4603,
                         "ghjuhtcc"             => 18956,
                         "ghjvtntq"             => 9137,
                         "ghost"                => 1289,
                         "ghost1"               => 3632,
                         "ghost123"             => 14330,
                         "ghost16"              => 21403,
                         "ghostdog"             => 13777,
                         "ghoster"              => 29535,
                         "ghostly"              => 19446,
                         "ghostman"             => 10314,
                         "ghostrid"             => 12051,
                         "ghostrider"           => 3139,
                         "ghosty"               => 19705,
                         "ghtktcnm"             => 9578,
                         "ghtlfntkm"            => 26291,
                         "ghtpbltyn"            => 13591,
                         "ghzybr"               => 12485,
                         "giacomo"              => 9159,
                         "giallo"               => 24554,
                         "giancarlo"            => 22247,
                         "gianluca"             => 6176,
                         "gianni"               => 5415,
                         "giant1"               => 13228,
                         "giantess"             => 17652,
                         "giants"               => 267,
                         "giants1"              => 5830,
                         "giants56"             => 18935,
                         "gibbon"               => 10668,
                         "giblet"               => 14681,
                         "gibso"                => 28012,
                         "gibson1"              => 6915,
                         "gibsonsg"             => 11533,
                         "giddyup"              => 10078,
                         "gideon"               => 4473,
                         "gigabyte"             => 6093,
                         "gigant"               => 23942,
                         "gigante"              => 18623,
                         "gigemags"             => 24817,
                         "giggalo"              => 22768,
                         "giggle"               => 6035,
                         "giggles"              => 4560,
                         "giggs11"              => 13094,
                         "giggsy"               => 15286,
                         "gigolo"               => 11760,
                         "gijoe"                => 24765,
                         "gilber"               => 21407,
                         "gilbert1"             => 16567,
                         "gilead"               => 28763,
                         "gilgames"             => 14179,
                         "gilgamesh"            => 23619,
                         "gilles"               => 3926,
                         "gillian1"             => 19253,
                         "gilly"                => 15327,
                         "gimlet"               => 15012,
                         "gimmesum"             => 24841,
                         "gimpy"                => 28040,
                         "gineok"               => 28353,
                         "ginge"                => 8576,
                         "ginger"               => 62,
                         "ginger1"              => 2747,
                         "ginger11"             => 16733,
                         "ginger12"             => 10189,
                         "ginger123"            => 23205,
                         "ginger2"              => 15379,
                         "ginger69"             => 28613,
                         "ginnie"               => 25360,
                         "ginny1"               => 24033,
                         "ginola"               => 8345,
                         "ginscoot"             => 8734,
                         "ginseng"              => 20950,
                         "gintonic"             => 25131,
                         "ginuwine"             => 12608,
                         "giorgi"               => 2114,
                         "giorgia"              => 12868,
                         "giorgio"              => 3588,
                         "giotto"               => 29189,
                         "giovann"              => 10549,
                         "gipper"               => 13289,
                         "giraffe"              => 3988,
                         "girdle"               => 11008,
                         "girfriend"            => 7949,
                         "girl1"                => 25701,
                         "girl78"               => 16303,
                         "girlie"               => 6173,
                         "girlies"              => 6446,
                         "girls"                => 340,
                         "girls1"               => 6441,
                         "girls4me"             => 26778,
                         "girls69"              => 24883,
                         "girlss"               => 13355,
                         "girlz"                => 14524,
                         "girsl"                => 8355,
                         "gisel"                => 24769,
                         "gismo"                => 21877,
                         "gitara"               => 7497,
                         "gitler"               => 12638,
                         "giuli"                => 21438,
                         "giulia"               => 5644,
                         "giuliana"             => 21435,
                         "giulio"               => 11944,
                         "giusepp"              => 16738,
                         "giveit"               => 25287,
                         "giveitup"             => 8886,
                         "giveme"               => 7441,
                         "gixxer"               => 9803,
                         "gizmo"                => 891,
                         "gizmo1"               => 1899,
                         "gizmo123"             => 11715,
                         "gizmo2"               => 26187,
                         "gizmo69"              => 17184,
                         "gizmodo"              => 1644,
                         "gizmodo1"             => 6449,
                         "gizmodo2"             => 23288,
                         "gizmos"               => 6396,
                         "gizzmo"               => 6060,
                         "gjdtkbntkm"           => 29807,
                         "gjgeufq"              => 10578,
                         "gjgjdf"               => 21869,
                         "gjgjxrf"              => 28049,
                         "gjhjctyjr"            => 14028,
                         "gjhjkm"               => 8494,
                         "gjikbdctyf"           => 20035,
                         "gjkbyf"               => 1796,
                         "gjkbyjxrf"            => 13694,
                         "gjkbyrf"              => 18125,
                         "gjkrjdybr"            => 20477,
                         "gjkysqgbpltw"         => 20497,
                         "gjkzrjdf"             => 25843,
                         "gjlcnfdf"             => 29849,
                         "gjlfhjr"              => 24407,
                         "gjmptw"               => 17356,
                         "gjpbnbd"              => 25639,
                         "gjrtvjy"              => 16035,
                         "gjvbljh"              => 18087,
                         "gjytltkmybr"          => 19598,
                         "gjyxbr"               => 13056,
                         "gkfdfybt"             => 27917,
                         "gkfnjy"               => 29939,
                         "gkfytnf"              => 19529,
                         "glacius"              => 28489,
                         "gladbach"             => 27860,
                         "gladiato"             => 4437,
                         "gladiator"            => 2728,
                         "gladiolus"            => 23253,
                         "gladston"             => 14972,
                         "glamis"               => 24362,
                         "glamour"              => 4513,
                         "glamur"               => 10083,
                         "glasgow1"             => 24008,
                         "glasha"               => 26543,
                         "glasnost"             => 24711,
                         "glass1"               => 25365,
                         "glassjaw"             => 24561,
                         "glasss"               => 20465,
                         "glavine"              => 15911,
                         "gldmeo"               => 12207,
                         "glencoe"              => 19229,
                         "glendale"             => 6917,
                         "glenn1"               => 21559,
                         "glenn74"              => 22944,
                         "glennwei"             => 8091,
                         "glenny"               => 27159,
                         "glenwood"             => 8751,
                         "glider"               => 8155,
                         "glist"                => 11930,
                         "glitter"              => 6238,
                         "global1"              => 13470,
                         "globus"               => 5056,
                         "glock"                => 4472,
                         "glock1"               => 20725,
                         "glock17"              => 9722,
                         "glock19"              => 17108,
                         "glock21"              => 13030,
                         "glock22"              => 14280,
                         "glock23"              => 17001,
                         "glock40"              => 25176,
                         "glock45"              => 28715,
                         "glock9"               => 26907,
                         "glock9mm"             => 20093,
                         "glori"                => 15964,
                         "gloria1"              => 24657,
                         "glory1"               => 18040,
                         "glotest"              => 12118,
                         "glowworm"             => 27642,
                         "gmctruck"             => 15004,
                         "gmcz71"               => 19668,
                         "gmoney"               => 2207,
                         "gn56gn56"             => 1276,
                         "gnaget"               => 11631,
                         "gnarly"               => 18914,
                         "gnasher"              => 26667,
                         "gnasher23"            => 11914,
                         "gnatsum"              => 13833,
                         "gnbxrf"               => 12261,
                         "gnocca"               => 20215,
                         "gnomik"               => 18739,
                         "gnorman"              => 21201,
                         "gnosis"               => 12529,
                         "gnusmas"              => 11331,
                         "go1234"               => 12338,
                         "go2hell"              => 8339,
                         "go4it"                => 18402,
                         "goahead"              => 27132,
                         "goalie"               => 2455,
                         "goarmy"               => 7209,
                         "goat"                 => 3637,
                         "goatboy"              => 7891,
                         "goater"               => 24197,
                         "goathead"             => 24598,
                         "goatman"              => 15966,
                         "goats"                => 7266,
                         "goaway"               => 3134,
                         "gobama"               => 15649,
                         "gobbler"              => 15983,
                         "gobears"              => 3776,
                         "gobigred"             => 7978,
                         "gobills"              => 13305,
                         "goblin"               => 1315,
                         "goblue"               => 638,
                         "goblue1"              => 12733,
                         "goblues"              => 20417,
                         "gobrowns"             => 11975,
                         "gobruins"             => 17937,
                         "gobucks"              => 3123,
                         "gobucs"               => 9921,
                         "gobuffs"              => 16424,
                         "gobuffs2"             => 18462,
                         "gobulls"              => 23931,
                         "gocanes"              => 13803,
                         "gocards"              => 16794,
                         "gocart"               => 27191,
                         "gocats"               => 7357,
                         "gococks"              => 18527,
                         "gocubs"               => 5130,
                         "god123"               => 24180,
                         "god666"               => 27731,
                         "godawgs"              => 6658,
                         "godbless"             => 6132,
                         "godboy"               => 12265,
                         "goddes"               => 23545,
                         "goddess"              => 1066,
                         "goddess1"             => 13637,
                         "goddog"               => 13985,
                         "godeep"               => 20307,
                         "godess"               => 21902,
                         "godfathe"             => 2960,
                         "godfather"            => 2670,
                         "godflesh"             => 28899,
                         "godhead"              => 23195,
                         "godisgoo"             => 16324,
                         "godisgood"            => 13539,
                         "godisgreat"           => 20885,
                         "godislov"             => 19041,
                         "godislove"            => 11231,
                         "godiva"               => 6681,
                         "godlike"              => 4822,
                         "godloves"             => 16865,
                         "godofwar"             => 10099,
                         "godogs"               => 22238,
                         "godown"               => 28359,
                         "godpasi"              => 19701,
                         "godsgift"             => 25737,
                         "godslove"             => 12986,
                         "godsmack"             => 1787,
                         "godspeed"             => 6634,
                         "godswill"             => 20012,
                         "goducks"              => 28550,
                         "goduke"               => 16971,
                         "godzila"              => 15378,
                         "godzilla"             => 320,
                         "goeagles"             => 18280,
                         "goethe"               => 7466,
                         "gofast"               => 5594,
                         "gofaster"             => 22455,
                         "gofish"               => 2014,
                         "goforit"              => 1044,
                         "goforit1"             => 17117,
                         "gogators"             => 5816,
                         "gogeta"               => 9195,
                         "gogetit"              => 13402,
                         "gogetter"             => 28555,
                         "gogiants"             => 15979,
                         "gogirl"               => 15070,
                         "gogolf"               => 28473,
                         "gogosox"              => 22370,
                         "gogreen"              => 12175,
                         "gohabsgo"             => 18139,
                         "gohan"                => 8165,
                         "gohawks"              => 10848,
                         "goheels"              => 9455,
                         "gohogs"               => 9771,
                         "gohome"               => 5398,
                         "goirish"              => 3668,
                         "goirish1"             => 29110,
                         "gojets"               => 15585,
                         "gojira"               => 13817,
                         "gokart"               => 17833,
                         "goku"                 => 2140,
                         "golakers"             => 14002,
                         "gold1"                => 15154,
                         "gold12"               => 20027,
                         "gold123"              => 13027,
                         "golde"                => 12824,
                         "golden"               => 193,
                         "golden1"              => 4824,
                         "goldenbo"             => 24582,
                         "goldenboy"            => 26204,
                         "goldeney"             => 5473,
                         "goldeneye"            => 6025,
                         "goldfing"             => 4907,
                         "goldfinger"           => 9250,
                         "goldfish"             => 812,
                         "goldi"                => 24377,
                         "goldie1"              => 22917,
                         "goldmine"             => 10111,
                         "goldorak"             => 18038,
                         "goldrush"             => 7694,
                         "goldsink"             => 15438,
                         "goldstar"             => 2576,
                         "goldtree"             => 22737,
                         "goldwing"             => 2809,
                         "goleafs"              => 16301,
                         "goleafsg"             => 20303,
                         "goleta"               => 23611,
                         "golf"                 => 300,
                         "golf01"               => 21873,
                         "golf1"                => 8753,
                         "golf11"               => 17223,
                         "golf12"               => 11493,
                         "golf123"              => 20494,
                         "golf1234"             => 25695,
                         "golf18"               => 11641,
                         "golf56"               => 20315,
                         "golf69"               => 13229,
                         "golf72"               => 12014,
                         "golf99"               => 17950,
                         "golfball"             => 1881,
                         "golfcart"             => 16471,
                         "golfclub"             => 8479,
                         "golfe"                => 15871,
                         "golfer"               => 91,
                         "golfer01"             => 24683,
                         "golfer1"              => 3424,
                         "golfer11"             => 25782,
                         "golfer12"             => 17592,
                         "golfer23"             => 14097,
                         "golfers"              => 16110,
                         "golfgti"              => 5441,
                         "golfin"               => 14518,
                         "golfing"              => 1565,
                         "golfing1"             => 9078,
                         "golfman"              => 8009,
                         "golfnut"              => 6683,
                         "golfpro"              => 6273,
                         "golfvr6"              => 15155,
                         "golgo13"              => 10922,
                         "goliath"              => 2270,
                         "golions"              => 20139,
                         "golive"               => 28017,
                         "gollum"               => 2725,
                         "golova"               => 12508,
                         "gomango"              => 25852,
                         "gomer"                => 11918,
                         "gomer1"               => 28790,
                         "gomets"               => 8414,
                         "gomez1"               => 21637,
                         "gonads"               => 9132,
                         "gonavy"               => 3057,
                         "gonchar"              => 25441,
                         "gondolin"             => 19963,
                         "gondor"               => 15416,
                         "gonefish"             => 11228,
                         "gong"                 => 2989,
                         "goniners"             => 28839,
                         "gonoles"              => 14984,
                         "gonzal"               => 20127,
                         "gonzale"              => 11844,
                         "gonzo"                => 2454,
                         "gonzo1"               => 5492,
                         "gonzo123"             => 26402,
                         "gonzos"               => 23449,
                         "goobe"                => 24455,
                         "goober"               => 429,
                         "goober1"              => 12230,
                         "goober12"             => 19231,
                         "goobers"              => 11485,
                         "goochi"               => 8407,
                         "good1"                => 16351,
                         "good123"              => 23185,
                         "good12345"            => 12773,
                         "good123654"           => 4100,
                         "good2go"              => 10886,
                         "good4me"              => 28028,
                         "good4now"             => 27704,
                         "good4u"               => 9312,
                         "good4you"             => 23688,
                         "goodbeer"             => 17864,
                         "goodboss"             => 23648,
                         "goodboy"              => 2765,
                         "goodby"               => 25537,
                         "goodbye1"             => 25338,
                         "goodday"              => 5239,
                         "gooddog"              => 8824,
                         "goodfell"             => 8313,
                         "goodfellas"           => 13653,
                         "goodfood"             => 11462,
                         "goodgame"             => 19825,
                         "goodgirl"             => 4885,
                         "goodgod"              => 18744,
                         "goodguy"              => 7986,
                         "goodhead"             => 13715,
                         "goodie"               => 4931,
                         "goodison"             => 8797,
                         "goodjob"              => 26066,
                         "goodlife"             => 7964,
                         "goodlove"             => 28995,
                         "goodluck"             => 1444,
                         "goodmorning"          => 28380,
                         "goodnews"             => 10630,
                         "goodone"              => 9441,
                         "goodpussy"            => 21817,
                         "goodsex"              => 7753,
                         "goodstuf"             => 9487,
                         "goodstuff"            => 28342,
                         "goodtime"             => 1649,
                         "goodtimes"            => 10049,
                         "goodtogo"             => 13111,
                         "goodwood"             => 14189,
                         "goodyear"             => 5929,
                         "goofball"             => 6811,
                         "goofus"               => 24186,
                         "goofy"                => 2785,
                         "goofy1"               => 6877,
                         "googie"               => 20304,
                         "googl"                => 15447,
                         "google"               => 473,
                         "google1"              => 7589,
                         "google10"             => 29407,
                         "google12"             => 12521,
                         "google123"            => 12008,
                         "google2"              => 29424,
                         "goomba"               => 15476,
                         "goomie"               => 20245,
                         "gooner"               => 3440,
                         "gooner1"              => 18204,
                         "gooners"              => 18115,
                         "goonie"               => 18549,
                         "goonies"              => 8523,
                         "goose"                => 1761,
                         "goose1"               => 6400,
                         "goose2"               => 20168,
                         "goose5"               => 29326,
                         "gooseman"             => 8660,
                         "gooses"               => 20975,
                         "goosey"               => 18231,
                         "gopack"               => 8480,
                         "gopher"               => 1944,
                         "gophers"              => 8779,
                         "gopinath"             => 28356,
                         "gopnik"               => 23562,
                         "gopokes"              => 23320,
                         "gorams"               => 17565,
                         "gorbunov"             => 28955,
                         "gordit"               => 23861,
                         "gordito"              => 11773,
                         "gordo"                => 4440,
                         "gordo1"               => 11973,
                         "gordolee85"           => 19927,
                         "gordon1"              => 8826,
                         "gordon2"              => 23622,
                         "gordon24"             => 2004,
                         "gorgon"               => 11876,
                         "gorila"               => 25481,
                         "gorilla"              => 1452,
                         "gorilla1"             => 14274,
                         "gorilla9"             => 29577,
                         "gorillaz"             => 7549,
                         "gorodok"              => 16748,
                         "goshawk"              => 24716,
                         "goshen"               => 13073,
                         "gosia"                => 14975,
                         "goskins"              => 25829,
                         "gosling"              => 21632,
                         "gostate"              => 21953,
                         "gostosa"              => 20327,
                         "gostoso"              => 18065,
                         "gotcha"               => 1406,
                         "goteam"               => 28890,
                         "goten"                => 4351,
                         "gotenks"              => 5945,
                         "goterps"              => 13829,
                         "goth"                 => 4954,
                         "gotham"               => 5450,
                         "gothic"               => 1342,
                         "gothic1"              => 28009,
                         "gotigers"             => 8720,
                         "gotika"               => 16488,
                         "gotime"               => 25142,
                         "gotit"                => 15348,
                         "gotlove"              => 11556,
                         "gotmilk"              => 4963,
                         "gotohell"             => 2317,
                         "gotoit"               => 19028,
                         "gotribe"              => 5352,
                         "gotrice"              => 22554,
                         "gotti"                => 15995,
                         "gotyoass"             => 8139,
                         "gotyou"               => 23236,
                         "govinda"              => 18920,
                         "govols"               => 2127,
                         "gowest"               => 14732,
                         "gowings"              => 16540,
                         "gowron"               => 25700,
                         "gr00vy"               => 18791,
                         "gr8ful"               => 10789,
                         "gr8one"               => 12203,
                         "grabber"              => 24663,
                         "grace1"               => 5546,
                         "grace123"             => 19020,
                         "grace17"              => 21105,
                         "gracelan"             => 15071,
                         "graci"                => 19860,
                         "gracie1"              => 16280,
                         "graffix"              => 20535,
                         "grafix"               => 29550,
                         "graham1"              => 17510,
                         "graikos"              => 18560,
                         "gramma"               => 5964,
                         "gramps"               => 8460,
                         "granada"              => 5282,
                         "granat"               => 24436,
                         "grand1"               => 13938,
                         "grandad"              => 14976,
                         "grandam"              => 5127,
                         "grandam1"             => 24923,
                         "grandma1"             => 22057,
                         "grandorgue"           => 20873,
                         "grandpri"             => 8144,
                         "grandprix"            => 10539,
                         "granit"               => 16693,
                         "granny"               => 1700,
                         "granp"                => 17670,
                         "grant1"               => 9473,
                         "granvill"             => 25553,
                         "grapeape"             => 8675,
                         "grapes"               => 2391,
                         "graphix"              => 21924,
                         "grappa"               => 27888,
                         "grapple"              => 26734,
                         "grappler"             => 17685,
                         "grass1"               => 26944,
                         "grasshop"             => 10911,
                         "grassy"               => 10025,
                         "gratis"               => 4900,
                         "gravedig"             => 25778,
                         "gravis"               => 8033,
                         "gravy1"               => 23167,
                         "grayfox"              => 22294,
                         "graywolf"             => 6792,
                         "grazia"               => 25348,
                         "gre69kik"             => 29618,
                         "grease"               => 3305,
                         "greaser"              => 19070,
                         "great1"               => 2408,
                         "great123"             => 29283,
                         "greatdan"             => 24039,
                         "greatgoo"             => 24698,
                         "greatman"             => 27601,
                         "greatone"             => 2245,
                         "greats"               => 15958,
                         "greatsex"             => 8529,
                         "greatwhi"             => 25022,
                         "greatzyo"             => 28277,
                         "greddy"               => 12271,
                         "greedisgood"          => 6067,
                         "greedo"               => 10097,
                         "greek1"               => 20859,
                         "greekgod"             => 19179,
                         "green1"               => 1232,
                         "green11"              => 13577,
                         "green12"              => 9904,
                         "green123"             => 3720,
                         "green15"              => 28915,
                         "green17"              => 25423,
                         "green2"               => 12138,
                         "green22"              => 17943,
                         "green23"              => 18400,
                         "green3"               => 12343,
                         "green33"              => 27943,
                         "green4"               => 26489,
                         "green420"             => 25459,
                         "green45"              => 26088,
                         "green5"               => 12827,
                         "green55"              => 26131,
                         "green6"               => 18907,
                         "green69"              => 19193,
                         "green7"               => 15169,
                         "green77"              => 21656,
                         "green8"               => 22869,
                         "green9"               => 29958,
                         "green99"              => 15960,
                         "greenbay"             => 2071,
                         "greenbud"             => 11417,
                         "greenda"              => 24804,
                         "greenday"             => 740,
                         "greenday1"            => 20738,
                         "greendog"             => 15293,
                         "greenegg"             => 22689,
                         "greener"              => 16478,
                         "greenery"             => 24310,
                         "greeneye"             => 12303,
                         "greeneyes"            => 22893,
                         "greenie"              => 19129,
                         "greenlan"             => 25187,
                         "greenlantern"         => 24774,
                         "greenman"             => 6297,
                         "greenn"               => 22781,
                         "greenpea"             => 29121,
                         "greens"               => 2139,
                         "greentea"             => 7320,
                         "greentre"             => 21195,
                         "greentree"            => 23877,
                         "greenwoo"             => 11439,
                         "greeny"               => 10422,
                         "greese"               => 26095,
                         "greg78"               => 29774,
                         "greggy"               => 15847,
                         "gregor"               => 2962,
                         "gregory1"             => 7094,
                         "gremio"               => 12476,
                         "gremlin"              => 1581,
                         "gremlins"             => 9854,
                         "grendal"              => 22658,
                         "grendel"              => 1288,
                         "grendel1"             => 13348,
                         "grenden"              => 22389,
                         "grepw"                => 29764,
                         "greshnik"             => 22086,
                         "greta1"               => 26241,
                         "gretsch"              => 13538,
                         "gretzky"              => 2721,
                         "gretzky9"             => 20696,
                         "greyfox"              => 20726,
                         "greyhoun"             => 8949,
                         "greywolf"             => 6139,
                         "gridlock"             => 16250,
                         "griffey"              => 1479,
                         "griffey1"             => 17736,
                         "griffin1"             => 13886,
                         "griffins"             => 14798,
                         "griffon"              => 9796,
                         "griffy"               => 13896,
                         "grifter"              => 9668,
                         "grigio"               => 12185,
                         "grigoryan"            => 23469,
                         "grils"                => 7930,
                         "grimace"              => 6148,
                         "grime"                => 8207,
                         "grimlock"             => 11047,
                         "grimmy"               => 18919,
                         "grimreap"             => 23601,
                         "grin"                 => 5402,
                         "grinch"               => 4623,
                         "grinder"              => 7374,
                         "grinders"             => 21480,
                         "gringo"               => 2193,
                         "gripper"              => 16311,
                         "grisha"               => 5669,
                         "grisou"               => 28243,
                         "grizli"               => 11107,
                         "grizz"                => 20147,
                         "grizzley"             => 20122,
                         "grizzlie"             => 25801,
                         "grizzly"              => 1414,
                         "grizzly1"             => 11948,
                         "grizzy"               => 23411,
                         "grolsch"              => 22222,
                         "gromit"               => 3040,
                         "grommit"              => 13459,
                         "gromova"              => 27783,
                         "groove"               => 2815,
                         "groovy"               => 1301,
                         "groovy1"              => 23002,
                         "grouch"               => 12933,
                         "groucho"              => 2509,
                         "groucho1"             => 24675,
                         "groundho"             => 25262,
                         "groupd2013"           => 6928,
                         "grouper"              => 15434,
                         "grouse"               => 16961,
                         "growler"              => 8423,
                         "grubber"              => 11898,
                         "grumble"              => 19239,
                         "grumpy"               => 2047,
                         "grumpy1"              => 24150,
                         "grundle"              => 21549,
                         "grunge"               => 11536,
                         "grunt"                => 5718,
                         "grunt1"               => 17388,
                         "grunts"               => 16863,
                         "gruppa"               => 27323,
                         "gryphon"              => 4370,
                         "gsewfmck"             => 17252,
                         "gsgba368"             => 15056,
                         "gshock"               => 18871,
                         "gspot"                => 8891,
                         "gstring"              => 7510,
                         "gsxr1000"             => 5020,
                         "gsxr11"               => 13645,
                         "gsxr1100"             => 13191,
                         "gsxr600"              => 9496,
                         "gsxr750"              => 2938,
                         "gtfullam"             => 12555,
                         "gthcbr"               => 5208,
                         "gthtcnhjqrf"          => 16548,
                         "gthtrhtcnjr"          => 23171,
                         "gti16v"               => 24886,
                         "gtivr6"               => 15414,
                         "gtkmvtyb"             => 11851,
                         "gtkmvtym"             => 9682,
                         "gtnhjczy"             => 26421,
                         "gtnhjd"               => 19343,
                         "gtnhjdbx"             => 4233,
                         "gtnhjdf"              => 11336,
                         "gtnhjdyf"             => 24279,
                         "gtnhjpfdjlcr"         => 25703,
                         "gtogto43"             => 23883,
                         "gtxtymrf"             => 11583,
                         "guadalup"             => 15577,
                         "guai"                 => 3261,
                         "guan"                 => 6584,
                         "guang"                => 3541,
                         "guardian"             => 1407,
                         "guatemal"             => 11566,
                         "gubber"               => 9775,
                         "gucci"                => 6704,
                         "gucci1"               => 19729,
                         "guderian"             => 10979,
                         "guenter"              => 24056,
                         "guess1"               => 10467,
                         "guessit"              => 11648,
                         "guesss"               => 29894,
                         "guesswho"             => 8287,
                         "guest1"               => 17019,
                         "guido1"               => 15092,
                         "guido8"               => 18831,
                         "guildwars"            => 19981,
                         "guilherme"            => 22419,
                         "guillaum"             => 5527,
                         "guille"               => 24713,
                         "guillerm"             => 6616,
                         "guiness"              => 2359,
                         "guinnes"              => 13381,
                         "guinness"             => 379,
                         "guinness1"            => 22624,
                         "guita"                => 13260,
                         "guitar"               => 103,
                         "guitar01"             => 28701,
                         "guitar1"              => 3255,
                         "guitar11"             => 27110,
                         "guitar12"             => 16902,
                         "guitar69"             => 27849,
                         "guitare"              => 26761,
                         "guitarma"             => 21567,
                         "guitarman"            => 25061,
                         "guitarra"             => 10807,
                         "guitars"              => 3955,
                         "gulfstre"             => 27959,
                         "gulla"                => 28345,
                         "gullit"               => 27993,
                         "gulliver"             => 8254,
                         "gulmira"              => 14568,
                         "gulnar"               => 24604,
                         "gulnara"              => 7139,
                         "gulnaz"               => 9102,
                         "gulnur"               => 17620,
                         "gumball"              => 9212,
                         "gumbo"                => 8119,
                         "gumby"                => 5635,
                         "gumby1"               => 8230,
                         "gumdrop"              => 23599,
                         "gumper"               => 22585,
                         "gumshoe"              => 18833,
                         "gunblade"             => 22848,
                         "gundam"               => 734,
                         "gundam00"             => 25033,
                         "gundog"               => 26571,
                         "gungadin"             => 28917,
                         "gungho"               => 12722,
                         "gunite"               => 23997,
                         "gunnar"               => 2582,
                         "gunner"               => 304,
                         "gunner1"              => 8870,
                         "gunners"              => 2485,
                         "gunners1"             => 17449,
                         "gunny"                => 19417,
                         "gunny1"               => 25640,
                         "gunship"              => 18039,
                         "gunsling"             => 9129,
                         "gunslinger"           => 15275,
                         "gunsmith"             => 29343,
                         "gunsmoke"             => 9654,
                         "gunther1"             => 16807,
                         "guppie"               => 20328,
                         "guppy"                => 16526,
                         "gurkan"               => 21929,
                         "gusev"                => 25095,
                         "gusher"               => 15180,
                         "gustav"               => 1890,
                         "gustavo1"             => 20616,
                         "guster"               => 12973,
                         "gutentag"             => 24144,
                         "gutierre"             => 20489,
                         "guy123"               => 25102,
                         "guybrush"             => 26474,
                         "guyute"               => 10053,
                         "guyver"               => 3833,
                         "gwbush"               => 20310,
                         "gwbush1"              => 20379,
                         "gwendoli"             => 28008,
                         "gwju3g"               => 13574,
                         "gxlmxbewym"           => 23547,
                         "gy3yt2rgls"           => 9437,
                         "gymnast"              => 4839,
                         "gymnast1"             => 29462,
                         "gymnastic"            => 8293,
                         "gypsy"                => 4102,
                         "gypsy1"               => 9855,
                         "gznfxjr"              => 29046,
                         "gznybwf13"            => 12399,
                         "h00ters"              => 16149,
                         "h200svrm"             => 28656,
                         "h2opolo"              => 9116,
                         "h2oski"               => 22690,
                         "h2slca"               => 16983,
                         "h397pnvr"             => 28894,
                         "h4x3d"                => 12569,
                         "h9iymxmc"             => 26960,
                         "ha8fyp"               => 14145,
                         "habana"               => 10245,
                         "habanero"             => 18310,
                         "habari"               => 18454,
                         "habibi"               => 4202,
                         "hack"                 => 3476,
                         "hacke"                => 22505,
                         "hacked"               => 2865,
                         "hacked1"              => 28237,
                         "hackedit"             => 28891,
                         "hacker"               => 805,
                         "hacker1"              => 14618,
                         "hackers"              => 7145,
                         "hackerz"              => 8890,
                         "hacking"              => 5956,
                         "hackme"               => 13898,
                         "hadoken"              => 11791,
                         "hadrian"              => 12672,
                         "hagakure"             => 20478,
                         "haggis"               => 3694,
                         "hagrid"               => 20195,
                         "haha123"              => 10813,
                         "hahah"                => 11643,
                         "hahaha1"              => 16407,
                         "haileris"             => 26126,
                         "hailey1"              => 23237,
                         "hairball"             => 5140,
                         "hairpie"              => 19532,
                         "hairy"                => 2686,
                         "hairy1"               => 17058,
                         "hajime"               => 16699,
                         "hakan"                => 22132,
                         "hakaone"              => 28361,
                         "hakeem"               => 11364,
                         "hakkinen"             => 12923,
                         "hakr"                 => 6170,
                         "hal2000"              => 24307,
                         "hal9000"              => 2290,
                         "halberd"              => 29204,
                         "halcyon"              => 8135,
                         "haley1"               => 9600,
                         "halflife"             => 1488,
                         "halflife2"            => 10675,
                         "halfmoon"             => 9712,
                         "halfpint"             => 11275,
                         "halibut"              => 9176,
                         "halifax"              => 3445,
                         "halima"               => 22945,
                         "hallo"                => 1614,
                         "hallo1"               => 7987,
                         "hallo12"              => 25464,
                         "hallo123"             => 4862,
                         "hallodu"              => 23196,
                         "halloo"               => 25452,
                         "hallow"               => 16086,
                         "hallowboy"            => 22415,
                         "hallowee"             => 5587,
                         "halo123"              => 15757,
                         "halogen"              => 15998,
                         "haloreach"            => 20275,
                         "hambone"              => 2548,
                         "hambone1"             => 24092,
                         "hambur"               => 25947,
                         "hamburg"              => 1741,
                         "hamburg1"             => 14885,
                         "hamburge"             => 11733,
                         "hamish"               => 3389,
                         "hamlet"               => 981,
                         "hammarby"             => 12297,
                         "hamme"                => 15306,
                         "hammer"               => 84,
                         "hammer01"             => 28053,
                         "hammer1"              => 3920,
                         "hammer11"             => 26598,
                         "hammer12"             => 26623,
                         "hammer22"             => 23091,
                         "hammer69"             => 25787,
                         "hammer99"             => 23188,
                         "hammerhe"             => 9651,
                         "hammers"              => 1954,
                         "hammers1"             => 11120,
                         "hammertime"           => 24437,
                         "hammie"               => 26669,
                         "hamper"               => 6447,
                         "hampster"             => 25190,
                         "hamradio"             => 12935,
                         "hamster"              => 1022,
                         "hamster1"             => 14070,
                         "hamzah"               => 23919,
                         "hanako"               => 28427,
                         "handbag"              => 6179,
                         "handbags"             => 16320,
                         "handball"             => 4381,
                         "handcuff"             => 10465,
                         "handily"              => 25004,
                         "handjob"              => 16830,
                         "handsoff"             => 22212,
                         "handy1"               => 24587,
                         "handyman"             => 2980,
                         "hang10"               => 20583,
                         "hangman"              => 9141,
                         "hangten"              => 22387,
                         "hanibal"              => 25530,
                         "hank1"                => 24250,
                         "hankster"             => 22803,
                         "hanna1"               => 12913,
                         "hannah"               => 131,
                         "hannah01"             => 16170,
                         "hannah1"              => 3712,
                         "hannah11"             => 22168,
                         "hannah12"             => 25820,
                         "hannah22"             => 29609,
                         "hannelor"             => 21472,
                         "hannes"               => 5595,
                         "hannibal"             => 1339,
                         "hannover"             => 8741,
                         "hanse"                => 26782,
                         "hansol"               => 5630,
                         "hansolo"              => 1136,
                         "hansolo1"             => 10841,
                         "hanswurst"            => 25746,
                         "hanter"               => 14958,
                         "hanuman"              => 5794,
                         "hapkido"              => 14124,
                         "happie"               => 26182,
                         "happines"             => 6436,
                         "happy1"               => 634,
                         "happy100"             => 20179,
                         "happy12"              => 15986,
                         "happy123"             => 2134,
                         "happy13"              => 28637,
                         "happy2"               => 4925,
                         "happy5"               => 21303,
                         "happy6"               => 25129,
                         "happy69"              => 12043,
                         "happy7"               => 15821,
                         "happy8"               => 28414,
                         "happy99"              => 22604,
                         "happyboy"             => 12510,
                         "happyday"             => 2141,
                         "happydays"            => 11632,
                         "happydog"             => 8606,
                         "happyface"            => 27321,
                         "happyguy"             => 24783,
                         "happyhap"             => 26590,
                         "happyjoy"             => 20989,
                         "happylife"            => 28215,
                         "happyman"             => 6358,
                         "happyme"              => 12964,
                         "happyness"            => 26313,
                         "happyone"             => 14150,
                         "happys"               => 12072,
                         "happytim"             => 27027,
                         "happyy"               => 19987,
                         "harakiri"             => 24004,
                         "harald"               => 5363,
                         "harami"               => 19526,
                         "harcore"              => 6363,
                         "hard1"                => 11145,
                         "hard4u"               => 16669,
                         "hard69"               => 27921,
                         "hardass"              => 18292,
                         "hardball"             => 5075,
                         "hardbody"             => 16443,
                         "hardc0re"             => 27340,
                         "hardcock"             => 2956,
                         "hardcor"              => 13895,
                         "hardcor1"             => 29634,
                         "hardcore"             => 140,
                         "hardcore1"            => 12515,
                         "harddick"             => 4655,
                         "harddriv"             => 22816,
                         "hardguy"              => 23510,
                         "hardhat"              => 13541,
                         "hardhead"             => 11248,
                         "hardline"             => 17090,
                         "hardon"               => 743,
                         "hardon1"              => 19886,
                         "hardone"              => 4775,
                         "hardpack"             => 23117,
                         "hardrock"             => 2189,
                         "hardtail"             => 16978,
                         "hardtime"             => 13615,
                         "hardtoon"             => 22320,
                         "hardup"               => 21241,
                         "hardwareid"           => 23314,
                         "hardwood"             => 5932,
                         "hardwork"             => 8241,
                         "hardy1"               => 23969,
                         "haribo"               => 9639,
                         "haribol"              => 23132,
                         "hariom"               => 18263,
                         "harish"               => 29671,
                         "harle"                => 5982,
                         "harlee"               => 21437,
                         "harlem"               => 4471,
                         "harlequi"             => 28450,
                         "harley"               => 38,
                         "harley01"             => 11172,
                         "harley03"             => 28348,
                         "harley1"              => 1636,
                         "harley11"             => 15337,
                         "harley12"             => 13349,
                         "harley13"             => 23525,
                         "harley2"              => 17351,
                         "harley20"             => 28963,
                         "harley69"             => 17682,
                         "harley88"             => 29898,
                         "harley99"             => 19789,
                         "harleyd"              => 15284,
                         "harlock"              => 23785,
                         "harmony1"             => 17868,
                         "harold1"              => 19201,
                         "harpo"                => 21511,
                         "harpoon"              => 6561,
                         "harpua"               => 8789,
                         "harri"                => 15100,
                         "harrie"               => 12845,
                         "harrier"              => 5356,
                         "harris1"              => 14535,
                         "harriso"              => 17777,
                         "harrison1"            => 18512,
                         "harry1"               => 2657,
                         "harry123"             => 11240,
                         "harry2"               => 21913,
                         "harry5"               => 29743,
                         "harryb"               => 19745,
                         "harrydog"             => 21671,
                         "harryp"               => 26219,
                         "harrypot"             => 11644,
                         "harrypotter"          => 3847,
                         "harrys"               => 7967,
                         "harsingh"             => 28155,
                         "hartland"             => 15705,
                         "haruka"               => 29412,
                         "harumi"               => 26168,
                         "harve"                => 13468,
                         "harvest"              => 3863,
                         "harvey1"              => 12368,
                         "harvick"              => 13114,
                         "hasbeen"              => 29893,
                         "hashem"               => 17269,
                         "hasher"               => 20579,
                         "hashish"              => 16903,
                         "haslo"                => 22203,
                         "haslo1"               => 16084,
                         "hastur"               => 24037,
                         "hatebree"             => 27071,
                         "hatelove"             => 22321,
                         "hateme"               => 9464,
                         "hater"                => 14480,
                         "haters"               => 10334,
                         "hatesyou"             => 15644,
                         "hateyou"              => 17084,
                         "hatman"               => 24041,
                         "hatrick"              => 24926,
                         "hatteras"             => 8575,
                         "hattrick"             => 5022,
                         "haustool"             => 26522,
                         "havana"               => 3883,
                         "havefun"              => 2650,
                         "havefun1"             => 27755,
                         "havok"                => 26491,
                         "havvoc"               => 23327,
                         "hawai"                => 27524,
                         "hawaii"               => 444,
                         "hawaii1"              => 13853,
                         "hawaii50"             => 3621,
                         "hawaiian"             => 2967,
                         "hawaiiguy"            => 29874,
                         "hawkdog79"            => 15383,
                         "hawker"               => 8543,
                         "hawkey"               => 23468,
                         "hawkeye"              => 807,
                         "hawkeye1"             => 8624,
                         "hawkeyes"             => 2761,
                         "hawking"              => 15988,
                         "hawkman"              => 17018,
                         "hawkmoon"             => 13656,
                         "hawks1"               => 8356,
                         "hawkwind"             => 8835,
                         "hawkwood"             => 29371,
                         "hawthorn"             => 7100,
                         "hax0red"              => 13518,
                         "hayabusa"             => 2819,
                         "hayastan"             => 15261,
                         "hayduke"              => 17158,
                         "haylee"               => 18975,
                         "hazel1"               => 16220,
                         "hazel5"               => 27109,
                         "hazelnut"             => 13600,
                         "hazmat"               => 7878,
                         "hball"                => 24720,
                         "hbhlair"              => 18613,
                         "hbxfhl"               => 13927,
                         "hcleeb"               => 12164,
                         "hd764nw5d7e1vb1"      => 8512,
                         "hdbiker"              => 21955,
                         "hea666"               => 17598,
                         "head1"                => 29198,
                         "headcase"             => 14807,
                         "headers"              => 17488,
                         "headhunt"             => 19134,
                         "headless"             => 8322,
                         "headroom"             => 29678,
                         "headshot"             => 8854,
                         "heart1"               => 10075,
                         "heartbre"             => 21010,
                         "hearts"               => 1566,
                         "heat7777"             => 19922,
                         "heater"               => 3301,
                         "heathe"               => 7627,
                         "heather1"             => 1468,
                         "heather2"             => 7686,
                         "heather4"             => 29043,
                         "heather6"             => 23732,
                         "heather7"             => 27752,
                         "heather9"             => 27053,
                         "heathers"             => 12191,
                         "heathrow"             => 14213,
                         "heatwave"             => 16667,
                         "heaven"               => 355,
                         "heaven1"              => 11888,
                         "heavy1"               => 20888,
                         "heavyd"               => 12728,
                         "heavymet"             => 26044,
                         "heavymetal"           => 26037,
                         "hecate"               => 11030,
                         "heccrbq"              => 29184,
                         "heckfy"               => 3004,
                         "heckfyf"              => 24076,
                         "heckfyxbr"            => 23086,
                         "hecnfv"               => 13365,
                         "hecto"                => 26766,
                         "hedgehog"             => 2216,
                         "hedimaptfcor"         => 16372,
                         "hedj2n4q"             => 25615,
                         "hedonism"             => 21949,
                         "hedonist"             => 19173,
                         "heehaw"               => 27063,
                         "heeled"               => 7496,
                         "heffer"               => 21968,
                         "heidi1"               => 4292,
                         "heidie"               => 25151,
                         "heidis"               => 22910,
                         "heiko"                => 21561,
                         "heimdall"             => 23166,
                         "heineken"             => 2919,
                         "heinlein"             => 7898,
                         "heinz57"              => 22028,
                         "hej123"               => 15865,
                         "hejmeddig"            => 24027,
                         "hejsan"               => 4815,
                         "hektor"               => 27467,
                         "helen1"               => 8157,
                         "helge"                => 25219,
                         "helicopt"             => 13247,
                         "helios"               => 6361,
                         "helium"               => 6989,
                         "hell666"              => 8282,
                         "hellas"               => 5869,
                         "hellbent"             => 11070,
                         "hellbound"            => 28048,
                         "hellboy"              => 4096,
                         "hellcat"              => 11777,
                         "hellfire"             => 746,
                         "hellgate"             => 20661,
                         "hellhoun"             => 29485,
                         "hellion"              => 10301,
                         "hellno"               => 7240,
                         "hello"                => 83,
                         "hello1"               => 443,
                         "hello101"             => 25748,
                         "hello11"              => 27628,
                         "hello12"              => 5310,
                         "hello123"             => 603,
                         "hello1234"            => 15290,
                         "hello2"               => 5511,
                         "hello22"              => 22771,
                         "hello23"              => 25026,
                         "hello2u"              => 10638,
                         "hello3"               => 19138,
                         "hello5"               => 14019,
                         "hello6"               => 24396,
                         "hello69"              => 18522,
                         "hello9"               => 17755,
                         "hello99"              => 16233,
                         "helloall"             => 20367,
                         "hellohel"             => 7514,
                         "hellokit"             => 9806,
                         "hellokitty"           => 4932,
                         "helloman"             => 15181,
                         "hellome"              => 9892,
                         "hellomoto"            => 12602,
                         "helloo"               => 2412,
                         "hellos"               => 3354,
                         "hellothe"             => 10769,
                         "hellothere"           => 13972,
                         "hellou"               => 11837,
                         "hellow"               => 8772,
                         "helloween"            => 16014,
                         "helloworld"           => 12788,
                         "helloyou"             => 10618,
                         "hellrais"             => 14011,
                         "hellraiser"           => 12236,
                         "hellsing"             => 5194,
                         "hellspaw"             => 18525,
                         "hellspawn"            => 14094,
                         "hellya"               => 11379,
                         "hellyea"              => 22186,
                         "hellyeah"             => 2212,
                         "hellyes"              => 17951,
                         "helmet"               => 2867,
                         "helmut"               => 4919,
                         "help123"              => 25476,
                         "helpdesk"             => 11703,
                         "helper"               => 4467,
                         "helpm"                => 20728,
                         "helpme"               => 259,
                         "helpme1"              => 8755,
                         "helpme2"              => 23115,
                         "helter"               => 23146,
                         "heman"                => 16512,
                         "hemi426"              => 19442,
                         "hemicuda"             => 10710,
                         "hemingwa"             => 25031,
                         "hemligt"              => 21238,
                         "hemlock"              => 5903,
                         "hemmelig"             => 18116,
                         "hen3ry"               => 18963,
                         "henderso"             => 9727,
                         "hendrix"              => 669,
                         "hendrix1"             => 10060,
                         "heng"                 => 3864,
                         "henkie"               => 29275,
                         "henriett"             => 17617,
                         "henrik"               => 5405,
                         "henrique"             => 17080,
                         "henry1"               => 3673,
                         "henry12"              => 29748,
                         "henry123"             => 20326,
                         "henry14"              => 12692,
                         "henry5"               => 28549,
                         "henry8"               => 22149,
                         "henrys"               => 16295,
                         "hentai"               => 574,
                         "henti"                => 7303,
                         "hepcat"               => 16724,
                         "herber"               => 24655,
                         "herbert1"             => 18711,
                         "herbie"               => 1800,
                         "herbie1"              => 28267,
                         "hercule"              => 8511,
                         "hercules"             => 683,
                         "hereiam"              => 23920,
                         "heretic"              => 9017,
                         "herewego"             => 5332,
                         "hergood"              => 23735,
                         "herkules"             => 16353,
                         "herman1"              => 16435,
                         "hermes"               => 1755,
                         "hermes1"              => 20782,
                         "hermione"             => 8314,
                         "hermit"               => 10384,
                         "hermos"               => 11782,
                         "hermosa"              => 13894,
                         "hernan"               => 18458,
                         "hernande"             => 7593,
                         "hero63"               => 21890,
                         "herons"               => 11605,
                         "herpderp"             => 15654,
                         "hershey"              => 1308,
                         "hershey1"             => 7778,
                         "hershil"              => 27047,
                         "herson"               => 14076,
                         "herve"                => 16517,
                         "heskey"               => 17250,
                         "heslo"                => 17770,
                         "hesoyam"              => 995,
                         "hesoyam1"             => 25103,
                         "hesoyam123"           => 25431,
                         "hetfield"             => 4620,
                         "hevnm4"               => 15139,
                         "hevonen"              => 20322,
                         "hewlett"              => 4051,
                         "hexagon"              => 20257,
                         "hextall"              => 24990,
                         "heybaby"              => 11853,
                         "heydude"              => 27148,
                         "heyjoe"               => 15760,
                         "heyjude"              => 21658,
                         "heynow"               => 3517,
                         "heythere"             => 13463,
                         "heyyou"               => 6638,
                         "hfccbz"               => 17605,
                         "hfccdtn"              => 19889,
                         "hfcgbplzq"            => 16046,
                         "hfcnfvfy"             => 25372,
                         "hfgcjlbz"             => 12042,
                         "hfleuf"               => 9593,
                         "hfljcnm"              => 7453,
                         "hfnfneq"              => 23783,
                         "hfpdjl"               => 28440,
                         "hfpldfnhb"            => 28735,
                         "hfrtnf"               => 21572,
                         "hfvbkm"               => 20143,
                         "hfytnrb"              => 5935,
                         "hhhhh1"               => 11980,
                         "hhhhhh1"              => 14374,
                         "hhhhhhh1"             => 11707,
                         "hiawatha"             => 15287,
                         "hibees"               => 15417,
                         "hibernia"             => 9701,
                         "hibiscus"             => 20453,
                         "hiccup"               => 24392,
                         "hickory"              => 8463,
                         "hidden"               => 1820,
                         "hideki"               => 28320,
                         "hifive"               => 26306,
                         "higgins1"             => 25080,
                         "highball"             => 14743,
                         "highbury"             => 4112,
                         "highfive"             => 19009,
                         "highheel"             => 3805,
                         "highjump"             => 23977,
                         "highland"             => 1001,
                         "highlander"           => 4293,
                         "highlife"             => 5936,
                         "highspee"             => 25784,
                         "hightech"             => 29620,
                         "hightime"             => 16683,
                         "highway1"             => 27538,
                         "highwind"             => 15073,
                         "hiheels"              => 28244,
                         "hihje863"             => 12142,
                         "hijinx"               => 27789,
                         "hijodeputa"           => 27703,
                         "hikari"               => 15055,
                         "hikaru"               => 12987,
                         "hiking"               => 5720,
                         "hilfiger"             => 8959,
                         "hillary1"             => 29291,
                         "hillbill"             => 6090,
                         "hillcres"             => 20153,
                         "hillside"             => 6857,
                         "hilltop"              => 6493,
                         "himera"               => 13176,
                         "himitsu"              => 20425,
                         "himmel"               => 13730,
                         "himura"               => 17482,
                         "hinata"               => 12998,
                         "hingis"               => 16878,
                         "hip-hop"              => 15800,
                         "hipho"                => 18848,
                         "hiphop"               => 656,
                         "hiphop1"              => 13970,
                         "hippie"               => 3311,
                         "hippo"                => 6884,
                         "hippo1"               => 25956,
                         "hippos"               => 9019,
                         "hipster"              => 19081,
                         "hiromi"               => 22156,
                         "hiroshi"              => 9920,
                         "hiroyuki"             => 17699,
                         "hirsute"              => 20777,
                         "hisashi"              => 13244,
                         "history1"             => 12255,
                         "hitachi"              => 4295,
                         "hitech"               => 12934,
                         "hithere"              => 2243,
                         "hithere1"             => 23352,
                         "hitler"               => 1707,
                         "hitman"               => 478,
                         "hitman1"              => 19395,
                         "hitman47"             => 8727,
                         "hitme"                => 27568,
                         "hitmen"               => 19386,
                         "hitomi"               => 10160,
                         "hiziad"               => 5430,
                         "hj8z6e"               => 21272,
                         "hjccbz"               => 3645,
                         "hjcnbckfd"            => 23017,
                         "hjcnjd"               => 20972,
                         "hjlbjy"               => 22926,
                         "hjlbntkb"             => 29639,
                         "hjlbyf"               => 13673,
                         "hjvfirf"              => 898,
                         "hjvfy"                => 27636,
                         "hjvfyjdf"             => 11532,
                         "hjvfynbrf"            => 24319,
                         "hjvjxrf"              => 23802,
                         "hkger286"             => 23297,
                         "hoagie"               => 16506,
                         "hoangen"              => 27037,
                         "hobbes"               => 640,
                         "hobbes1"              => 12901,
                         "hobbes12"             => 28495,
                         "hobbit"               => 1035,
                         "hobie"                => 18006,
                         "hobiecat"             => 13497,
                         "hocke"                => 7228,
                         "hockey"               => 50,
                         "hockey1"              => 2696,
                         "hockey10"             => 16766,
                         "hockey11"             => 17407,
                         "hockey12"             => 11679,
                         "hockey123"            => 29419,
                         "hockey13"             => 26912,
                         "hockey14"             => 26986,
                         "hockey19"             => 19111,
                         "hockey2"              => 16370,
                         "hockey21"             => 20274,
                         "hockey22"             => 24241,
                         "hockey33"             => 29691,
                         "hockey4"              => 25247,
                         "hockey69"             => 25802,
                         "hockey9"              => 26604,
                         "hockey99"             => 13403,
                         "hoddle"               => 10749,
                         "hoddling"             => 24171,
                         "hofner"               => 26994,
                         "hogan1"               => 12267,
                         "hogger"               => 15943,
                         "hoghead"              => 23821,
                         "hogtie"               => 24426,
                         "hogtied"              => 5878,
                         "hogwarts"             => 7871,
                         "hokie"                => 18792,
                         "hokies"               => 2800,
                         "hokuto"               => 26752,
                         "hola"                 => 4595,
                         "hola123"              => 29442,
                         "holas"                => 15580,
                         "holde"                => 26594,
                         "holdem"               => 8402,
                         "holden1"              => 14400,
                         "holdon"               => 29276,
                         "holein1"              => 5105,
                         "holeinon"             => 10115,
                         "holen1"               => 15712,
                         "holera"               => 19934,
                         "holeshot"             => 23184,
                         "holger"               => 5923,
                         "holida"               => 17939,
                         "holiday"              => 698,
                         "holiday1"             => 8908,
                         "holio"                => 27264,
                         "holla"                => 6102,
                         "hollage"              => 28858,
                         "holland1"             => 15686,
                         "holliste"             => 16148,
                         "hollister1"           => 26795,
                         "holly1"               => 2550,
                         "holly123"             => 16436,
                         "holly2"               => 25728,
                         "hollyb"               => 17193,
                         "hollydog"             => 11227,
                         "hollys"               => 19628,
                         "hollywoo"             => 1181,
                         "hollywood1"           => 25529,
                         "hollyy"               => 25367,
                         "holycow"              => 4469,
                         "holycrap"             => 29505,
                         "holymoly"             => 14840,
                         "holyshit"             => 2145,
                         "hombre"               => 7889,
                         "home1"                => 29902,
                         "home12"               => 22481,
                         "home123"              => 10880,
                         "home77"               => 25057,
                         "homebase"             => 10318,
                         "homeboy"              => 3568,
                         "homebrew"             => 7337,
                         "homedepo"             => 16128,
                         "homefree"             => 25251,
                         "homegrow"             => 15982,
                         "homely"               => 7035,
                         "homemade"             => 5370,
                         "homepage"             => 6057,
                         "homer1"               => 1754,
                         "homer123"             => 8150,
                         "homer2"               => 14424,
                         "homer22"              => 29613,
                         "homer69"              => 24234,
                         "homerj"               => 3552,
                         "homerjay"             => 20294,
                         "homero"               => 25185,
                         "homers"               => 1839,
                         "homersim"             => 11692,
                         "homerun"              => 1752,
                         "homerun1"             => 24834,
                         "homewood"             => 15957,
                         "homeworld"            => 19982,
                         "homies"               => 10112,
                         "hommer"               => 10226,
                         "homyak"               => 28748,
                         "honda"                => 527,
                         "honda01"              => 27020,
                         "honda1"               => 1520,
                         "honda123"             => 22983,
                         "honda2"               => 15673,
                         "honda200"             => 23208,
                         "honda250"             => 16740,
                         "honda450"             => 24809,
                         "honda99"              => 19416,
                         "hondacar"             => 21164,
                         "hondacbr"             => 6560,
                         "hondaciv"             => 15823,
                         "hondacivic"           => 9767,
                         "hondacr"              => 24610,
                         "hondacrv"             => 22509,
                         "hondacrx"             => 10527,
                         "hondaman"             => 23008,
                         "hondas"               => 3483,
                         "hondas2000"           => 25872,
                         "hondavfr"             => 24300,
                         "hondo"                => 10790,
                         "hondo1"               => 15252,
                         "honey1"               => 2767,
                         "honey12"              => 28033,
                         "honey123"             => 16668,
                         "honey2"               => 17354,
                         "honey69"              => 27602,
                         "honeyb"               => 12742,
                         "honeybea"             => 16355,
                         "honeybear"            => 16760,
                         "honeybee"             => 4430,
                         "honeybun"             => 6646,
                         "honeydew"             => 7690,
                         "honeydog"             => 28266,
                         "honeypie"             => 23124,
                         "honeypot"             => 13255,
                         "honeys"               => 5221,
                         "hongkong"             => 1198,
                         "honker"               => 20666,
                         "honkey"               => 18917,
                         "honolulu"             => 3940,
                         "honor1"               => 23343,
                         "hooch"                => 10152,
                         "hooch1"               => 16473,
                         "hoochie"              => 6919,
                         "hoodoo"               => 20068,
                         "hookah"               => 21378,
                         "hookedup"             => 18579,
                         "hookem"               => 4095,
                         "hooker"               => 929,
                         "hooker1"              => 25090,
                         "hookers"              => 6617,
                         "hookup"               => 3911,
                         "hooligan"             => 3617,
                         "hoopla"               => 11433,
                         "hoople"               => 28458,
                         "hoops"                => 4890,
                         "hoops1"               => 12517,
                         "hoopstar"             => 11526,
                         "hoopster"             => 10909,
                         "hoosier"              => 2685,
                         "hoosier1"             => 26399,
                         "hoosiers"             => 2898,
                         "hooter"               => 2287,
                         "hooters"              => 361,
                         "hooters1"             => 6905,
                         "hooters6"             => 28138,
                         "hootie"               => 3144,
                         "hooyah"               => 6351,
                         "hopalong"             => 21915,
                         "hopeful"              => 3473,
                         "hopeful1"             => 21846,
                         "hopefull"             => 11706,
                         "hopkig"               => 13814,
                         "hopkins1"             => 13954,
                         "hoppel"               => 28421,
                         "hopper1"              => 29428,
                         "hoppers"              => 21506,
                         "hoppie"               => 27445,
                         "hoppy"                => 14550,
                         "horatio"              => 6715,
                         "hores"                => 5926,
                         "horizon"              => 2466,
                         "horizon1"             => 26157,
                         "hornball"             => 22062,
                         "horndog"              => 1774,
                         "horndog1"             => 18072,
                         "horndogg"             => 27366,
                         "hornet"               => 990,
                         "hornet1"              => 21972,
                         "hornets"              => 4272,
                         "hornets1"             => 26511,
                         "horney"               => 540,
                         "horney1"              => 16920,
                         "hornie"               => 14997,
                         "hornier"              => 28355,
                         "horny"                => 207,
                         "horny1"               => 1701,
                         "horny123"             => 16376,
                         "horny2"               => 13411,
                         "horny69"              => 10567,
                         "hornyboy"             => 9821,
                         "hornydog"             => 16273,
                         "hornyguy"             => 8101,
                         "hornyman"             => 7791,
                         "hornyone"             => 14489,
                         "hornys"               => 28284,
                         "horosho"              => 28588,
                         "horse"                => 701,
                         "horse1"               => 6870,
                         "horseman"             => 7148,
                         "horsemen"             => 7021,
                         "horses"               => 423,
                         "horses1"              => 14305,
                         "horsesho"             => 13117,
                         "horsey"               => 9235,
                         "horus"                => 9546,
                         "hoschi"               => 18786,
                         "hosehead"             => 12403,
                         "hoseman"              => 13105,
                         "hoser"                => 8088,
                         "hoser1"               => 19048,
                         "hot123"               => 9297,
                         "hot2trot"             => 10800,
                         "hot4you"              => 16951,
                         "hotass"               => 5599,
                         "hotbabe"              => 9876,
                         "hotbabes"             => 8046,
                         "hotbitch"             => 25805,
                         "hotbod"               => 15633,
                         "hotbody"              => 18341,
                         "hotboi"               => 22835,
                         "hotbot"               => 24001,
                         "hotbox"               => 3093,
                         "hotboy"               => 1504,
                         "hotboys"              => 14052,
                         "hotchick"             => 8904,
                         "hotchkis"             => 27438,
                         "hotcock"              => 10124,
                         "hotcum"               => 17590,
                         "hotcunt"              => 24993,
                         "hotdamn"              => 12853,
                         "hotdick"              => 24595,
                         "hotdog"               => 270,
                         "hotdog1"              => 13298,
                         "hotdog12"             => 28654,
                         "hotdogs"              => 7578,
                         "hotel1"               => 19430,
                         "hotel6"               => 10679,
                         "hotfeet"              => 21239,
                         "hotfun"               => 24347,
                         "hotgirl"              => 6251,
                         "hotgirls"             => 4903,
                         "hotguy"               => 12225,
                         "hotlanta"             => 23972,
                         "hotlegs"              => 8117,
                         "hotlips"              => 6418,
                         "hotlove"              => 23749,
                         "hotmale"              => 18565,
                         "hotmama"              => 7269,
                         "hotman"               => 8477,
                         "hotmom"               => 13859,
                         "hotmove"              => 18869,
                         "hotness"              => 29943,
                         "hotone"               => 4289,
                         "hotpants"             => 10877,
                         "hotpussy"             => 2643,
                         "hotrats"              => 6315,
                         "hotred"               => 2641,
                         "hotrod"               => 467,
                         "hotrod1"              => 11774,
                         "hotsauce"             => 9544,
                         "hotsex"               => 1002,
                         "hotsex69"             => 19535,
                         "hotshit"              => 7946,
                         "hotshot"              => 2393,
                         "hotshot1"             => 26213,
                         "hotspot"              => 13028,
                         "hotspur"              => 6994,
                         "hotspurs"             => 23209,
                         "hotstuf"              => 18427,
                         "hotstuff"             => 921,
                         "hott"                 => 5023,
                         "hotti"                => 19464,
                         "hottie"               => 880,
                         "hottie1"              => 10170,
                         "hotties"              => 4425,
                         "hottub"               => 8814,
                         "hottuna"              => 23941,
                         "hotty"                => 8657,
                         "hotwater"             => 15097,
                         "hotwheel"             => 10500,
                         "hotwheels"            => 17556,
                         "hotwife"              => 10068,
                         "houdini"              => 5162,
                         "hound1"               => 15458,
                         "hounddog"             => 4003,
                         "houndog"              => 24034,
                         "hounds"               => 9571,
                         "house1"               => 3399,
                         "house12"              => 29703,
                         "house123"             => 12595,
                         "house2"               => 15330,
                         "housebed"             => 21852,
                         "housecat"             => 19086,
                         "housepen"             => 18378,
                         "housewife"            => 7929,
                         "housewifes"           => 6879,
                         "houston1"             => 5064,
                         "hovepark"             => 20159,
                         "hover"                => 3303,
                         "howard1"              => 11384,
                         "howdie"               => 23019,
                         "howdy1"               => 13071,
                         "howhigh"              => 27402,
                         "howies"               => 26801,
                         "howler"               => 11486,
                         "howlin"               => 27201,
                         "hownow"               => 20872,
                         "hoyasaxa"             => 26322,
                         "hpk2qc"               => 13788,
                         "hpmrbm41"             => 22292,
                         "hpvteb"               => 27415,
                         "hr3ytm"               => 10968,
                         "hrfzlz"               => 9985,
                         "hrothgar"             => 20987,
                         "hrvatska"             => 9766,
                         "hshfd4n279"           => 15685,
                         "htcnjhfy"             => 23990,
                         "htlbcrf"              => 15236,
                         "htubcnhfwbz"          => 5058,
                         "htubyf"               => 9602,
                         "htyfnf"               => 23431,
                         "huai"                 => 3275,
                         "hubbahub"             => 19447,
                         "hubertus"             => 25883,
                         "hufmqw"               => 11819,
                         "hugecock"             => 10473,
                         "hugedick"             => 18305,
                         "hugetits"             => 6806,
                         "hugger"               => 12379,
                         "huggies"              => 22764,
                         "hugoboss"             => 6593,
                         "hugues"               => 29237,
                         "huligan"              => 23665,
                         "hulkster"             => 7732,
                         "hullcity"             => 17199,
                         "humbug"               => 6712,
                         "humme"                => 22164,
                         "hummer"               => 517,
                         "hummer1"              => 16993,
                         "hummerh2"             => 20238,
                         "humper"               => 11874,
                         "humpin"               => 25096,
                         "humpty"               => 10051,
                         "humtum"               => 23847,
                         "hun999"               => 10076,
                         "hunden"               => 26441,
                         "hunglow"              => 26248,
                         "hungwell"             => 18882,
                         "hunnie"               => 19920,
                         "hunny"                => 25455,
                         "hunnybun"             => 29457,
                         "hunt0802"             => 28773,
                         "hunt4red"             => 21292,
                         "hunte"                => 5144,
                         "hunter"               => 37,
                         "hunter01"             => 11177,
                         "hunter1"              => 1672,
                         "hunter11"             => 13750,
                         "hunter12"             => 7106,
                         "hunter123"            => 14067,
                         "hunter2"              => 8036,
                         "hunter22"             => 20608,
                         "hunter69"             => 19420,
                         "hunter99"             => 18339,
                         "hunting"              => 1050,
                         "hunting1"             => 12222,
                         "huntress"             => 24425,
                         "hurrican"             => 1896,
                         "hurryup"              => 25696,
                         "hurtme"               => 13265,
                         "husker"               => 1720,
                         "husker1"              => 15444,
                         "huskerdu"             => 25698,
                         "huskers"              => 1071,
                         "huskers1"             => 6041,
                         "huskie"               => 20162,
                         "huskies"              => 2048,
                         "huskies1"             => 13524,
                         "husky"                => 6908,
                         "husky1"               => 12372,
                         "hussar"               => 21546,
                         "hustler"              => 2026,
                         "hustler1"             => 15740,
                         "hvidovre"             => 24126,
                         "hxp4life"             => 18009,
                         "hxxrvwcy"             => 21254,
                         "hydepark"             => 25098,
                         "hydro"                => 6428,
                         "hygge"                => 24386,
                         "hymen"                => 25353,
                         "hyper1"               => 17352,
                         "hyperion"             => 2097,
                         "hyperlit"             => 29210,
                         "hypnodanny"           => 17257,
                         "hyundai"              => 5615,
                         "hzze929b"             => 13602,
                         "i12345"               => 22915,
                         "i62gbq"               => 16331,
                         "i81b4u"               => 21692,
                         "i81u812"              => 14745,
                         "iaapptfcor"           => 15226,
                         "iambigal"             => 28578,
                         "iamcool"              => 7539,
                         "iamfree"              => 20904,
                         "iamgay"               => 12064,
                         "iamgod"               => 3196,
                         "iamgreat"             => 24827,
                         "iamhappy"             => 15991,
                         "iamhere"              => 17667,
                         "iamhorny"             => 19696,
                         "iamking"              => 28901,
                         "iampurehaha2"         => 25625,
                         "iamsam"               => 23280,
                         "iamsexy"              => 20330,
                         "iamthe1"              => 24232,
                         "iamthema"             => 15411,
                         "iamtheman"            => 21194,
                         "iamtheone"            => 14663,
                         "ias100"               => 12406,
                         "iawgk2"               => 9706,
                         "ib6ub9"               => 2882,
                         "ibanez"               => 944,
                         "ibelieve"             => 26177,
                         "ibill"                => 14032,
                         "ibill01"              => 9789,
                         "ibill123"             => 11423,
                         "ibilljpf"             => 9695,
                         "ibilltes"             => 7484,
                         "ibragim"              => 13356,
                         "ibxnsm"               => 15763,
                         "icam4usb"             => 24876,
                         "icandoit"             => 23602,
                         "icarus"               => 6331,
                         "icculus"              => 20981,
                         "icebaby"              => 26903,
                         "icebear"              => 26680,
                         "iceberg"              => 3490,
                         "icecold"              => 6743,
                         "icecrea"              => 16639,
                         "icecream"             => 786,
                         "icecube"              => 5825,
                         "icecube1"             => 22548,
                         "icehouse"             => 3843,
                         "icema"                => 24306,
                         "iceman"               => 138,
                         "iceman1"              => 5986,
                         "iceman11"             => 29329,
                         "iceman44"             => 29173,
                         "iceman69"             => 12619,
                         "icepick"              => 20886,
                         "icequeen"             => 27294,
                         "icetea"               => 7745,
                         "icewater"             => 26268,
                         "icewind"              => 17743,
                         "ichabod"              => 11887,
                         "ichbin"               => 22975,
                         "ichbins"              => 14554,
                         "ichiban"              => 15850,
                         "ichigo"               => 15620,
                         "ichiro"               => 11793,
                         "ichwill"              => 27722,
                         "icicle"               => 23705,
                         "icu812"               => 3746,
                         "iddqd"                => 9996,
                         "iddqdiddqd"           => 23318,
                         "iddqdidkfa"           => 12941,
                         "idefix"               => 5160,
                         "ididit"               => 21450,
                         "idinahui"             => 23415,
                         "idiom"                => 10605,
                         "idiot1"               => 20337,
                         "idiota"               => 17127,
                         "idkfa"                => 17373,
                         "idlewild"             => 18513,
                         "idontcare"            => 14389,
                         "idontkno"             => 3017,
                         "idontknow"            => 2663,
                         "idontno"              => 22523,
                         "idteul"               => 18285,
                         "idunno"               => 4014,
                         "iecnhbr"              => 20479,
                         "ifghjb"               => 18047,
                         "ifiksr"               => 27035,
                         "ifoptfcor"            => 25977,
                         "iforget"              => 4573,
                         "iforgot"              => 1683,
                         "iforgot1"             => 16541,
                         "iforgotit"            => 20705,
                         "ifufkbyf"             => 21928,
                         "iggypop"              => 16345,
                         "ignatius"             => 7683,
                         "ignatz"               => 16242,
                         "igor"                 => 1893,
                         "igor123"              => 18235,
                         "igor1234"             => 25248,
                         "igor1994"             => 26065,
                         "igorek"               => 8878,
                         "igromania"            => 15729,
                         "iguana"               => 1846,
                         "ihateu"               => 11103,
                         "ihateyou"             => 1865,
                         "ihateyou1"            => 27553,
                         "iiiii1"               => 11585,
                         "iiiiii1"              => 11699,
                         "iiiiiii1"             => 21211,
                         "iiyama"               => 7356,
                         "ijrjkfl"              => 4461,
                         "ijrjkflrf"            => 8585,
                         "ikalcr"               => 18627,
                         "ikarus"               => 12949,
                         "ikilz083"             => 13811,
                         "iklo"                 => 5834,
                         "ikmvw103"             => 26902,
                         "ilaria"               => 14417,
                         "ilford"               => 26562,
                         "ilike69"              => 25915,
                         "ilikeit"              => 5656,
                         "ilikepie"             => 5136,
                         "ilikeporn"            => 28311,
                         "ilikepussy"           => 25727,
                         "ilikesex"             => 8107,
                         "ilikeyou"             => 17327,
                         "ilkaev"               => 28671,
                         "illest"               => 29864,
                         "illini"               => 2121,
                         "illini1"              => 18666,
                         "illmatic"             => 7194,
                         "illumina"             => 9245,
                         "illuminati"           => 20291,
                         "illusion"             => 2890,
                         "ilonka"               => 18545,
                         "ilove"                => 5041,
                         "ilove69"              => 10572,
                         "iloveamy"             => 12155,
                         "iloveass"             => 17776,
                         "iloveboobies"         => 24113,
                         "ilovecock"            => 25216,
                         "ilovedick"            => 26682,
                         "ilovegirls"           => 17467,
                         "ilovegod"             => 5013,
                         "iloveher"             => 9743,
                         "ilovehim"             => 13107,
                         "iloveit"              => 8655,
                         "ilovejen"             => 14065,
                         "ilovejes"             => 19973,
                         "ilovejesus"           => 19923,
                         "ilovekim"             => 12385,
                         "ilovelife"            => 16096,
                         "iloveluc"             => 24863,
                         "ilovelucy"            => 27234,
                         "ilovemar"             => 23453,
                         "iloveme"              => 3699,
                         "iloveme1"             => 18702,
                         "iloveme2"             => 21465,
                         "ilovemom"             => 12382,
                         "ilovemusic"           => 20945,
                         "ilovemyfamily"        => 27447,
                         "ilovemylife"          => 22947,
                         "ilovemyself"          => 10043,
                         "ilovepor"             => 11112,
                         "iloveporn"            => 8044,
                         "ilovepus"             => 15851,
                         "ilovepussy"           => 5687,
                         "ilovesex"             => 1201,
                         "ilovetit"             => 29862,
                         "ilovetits"            => 28590,
                         "iloveu"               => 856,
                         "iloveu1"              => 18809,
                         "iloveu2"              => 9427,
                         "iloveyo"              => 2002,
                         "iloveyou"             => 47,
                         "iloveyou!"            => 11568,
                         "iloveyou1"            => 4528,
                         "iloveyou11"           => 28382,
                         "iloveyou12"           => 27920,
                         "iloveyou123"          => 19914,
                         "iloveyou2"            => 4060,
                         "ilusha"               => 22977,
                         "iluv69"               => 19759,
                         "iluvit"               => 29148,
                         "iluvme"               => 28722,
                         "iluvporn"             => 14074,
                         "iluvsex"              => 11369,
                         "iluvtits"             => 22421,
                         "iluvu"                => 25172,
                         "ilya1234"             => 6759,
                         "ilya1992"             => 9315,
                         "im2cool"              => 24368,
                         "imaccess"             => 23706,
                         "image1"               => 24236,
                         "imagine1"             => 18173,
                         "imajica"              => 19108,
                         "imaloser"             => 27572,
                         "imani"                => 25621,
                         "imation"              => 3684,
                         "imback"               => 10566,
                         "imbue"                => 28948,
                         "imcool"               => 9684,
                         "imesh"                => 18207,
                         "imfree"               => 21044,
                         "imhere"               => 15498,
                         "imhome"               => 25916,
                         "imhorny"              => 8632,
                         "imhotep"              => 13076,
                         "imissu"               => 27632,
                         "imissyou"             => 12189,
                         "imladris"             => 25909,
                         "immortal"             => 1163,
                         "imogen"               => 10803,
                         "impala"               => 926,
                         "impalass"             => 7661,
                         "impaler"              => 18316,
                         "imperator"            => 12591,
                         "imperia"              => 26375,
                         "imperium"             => 9931,
                         "implants"             => 5937,
                         "importan"             => 23264,
                         "impossib"             => 25506,
                         "impreza"              => 4744,
                         "imtheman"             => 7436,
                         "imzadi"               => 8931,
                         "inandout"             => 24420,
                         "inbed"                => 21803,
                         "incest"               => 9113,
                         "incognit"             => 19854,
                         "incognito"            => 11766,
                         "incubus"              => 1546,
                         "incubus1"             => 15196,
                         "indahous"             => 10154,
                         "indahouse"            => 24243,
                         "indain"               => 6898,
                         "independ"             => 14168,
                         "india1"               => 15272,
                         "india123"             => 6621,
                         "indian1"              => 19618,
                         "indiana"              => 956,
                         "indiana1"             => 9100,
                         "indiana7"             => 27408,
                         "indianali"            => 12047,
                         "indianer"             => 25412,
                         "indians"              => 993,
                         "indians1"             => 10330,
                         "indica"               => 9627,
                         "indien"               => 28188,
                         "indig"                => 25516,
                         "indiglo"              => 10948,
                         "indigo"               => 989,
                         "indigo1"              => 18564,
                         "indon"                => 6833,
                         "indonesi"             => 27697,
                         "indy500"              => 8780,
                         "indycar"              => 8950,
                         "inessa"               => 14030,
                         "inetcfg"              => 28674,
                         "inferno"              => 1143,
                         "inferno1"             => 12929,
                         "infidel"              => 26614,
                         "infinit"              => 13503,
                         "infiniti"             => 1758,
                         "infinity"             => 534,
                         "infix"                => 26753,
                         "inflames"             => 10095,
                         "informat"             => 14643,
                         "infotech"             => 25016,
                         "ingenier"             => 29014,
                         "ingersol"             => 23957,
                         "ingodwetrust"         => 17475,
                         "ingram01"             => 14594,
                         "ingres"               => 28136,
                         "inheat"               => 22559,
                         "inhere"               => 20638,
                         "inhouse"              => 16423,
                         "inkjet"               => 11949,
                         "inkognito"            => 15346,
                         "inlove"               => 5463,
                         "innova"               => 28310,
                         "innow"                => 15974,
                         "inout"                => 25762,
                         "insane"               => 1016,
                         "insane1"              => 16670,
                         "insert"               => 2688,
                         "insertion"            => 8860,
                         "insertions"           => 8662,
                         "inside1"              => 19774,
                         "insider"              => 7617,
                         "insomnia"             => 3544,
                         "inspecto"             => 14088,
                         "inspiron"             => 3685,
                         "install"              => 3966,
                         "installdevic"         => 17483,
                         "installsqlst"         => 21630,
                         "installutil"          => 16712,
                         "insuranc"             => 14250,
                         "integra"              => 854,
                         "integra1"             => 10390,
                         "integrit"             => 20801,
                         "intel"                => 2963,
                         "intel1"               => 17303,
                         "intelinside"          => 22860,
                         "intell"               => 11794,
                         "inter1"               => 26427,
                         "interacial"           => 6398,
                         "intercourse"          => 5036,
                         "interex"              => 9826,
                         "intermilan"           => 24016,
                         "internat"             => 10090,
                         "interne"              => 5478,
                         "internet"             => 89,
                         "internet1"            => 9893,
                         "intersta"             => 22184,
                         "intheass"             => 12745,
                         "intheend"             => 18212,
                         "intj3a"               => 13806,
                         "intoit"               => 21680,
                         "intranet"             => 13796,
                         "intrepid"             => 1310,
                         "intruder"             => 2549,
                         "inuyash"              => 17218,
                         "inuyasha"             => 3029,
                         "invader"              => 10192,
                         "invalidp"             => 14979,
                         "invernes"             => 25469,
                         "invest1"              => 22144,
                         "invictus"             => 7848,
                         "invis"                => 9194,
                         "invisibl"             => 25425,
                         "ioanna"               => 24365,
                         "iomega"               => 3295,
                         "iop890"               => 23075,
                         "iownyou"              => 21425,
                         "ipanema"              => 16060,
                         "iphone"               => 7395,
                         "ipswich"              => 3195,
                         "ipswich1"             => 22857,
                         "ipvteb"               => 28472,
                         "iqzzt580"             => 13789,
                         "iraffert"             => 26670,
                         "irakli"               => 7934,
                         "ireland1"             => 5967,
                         "irene1"               => 26320,
                         "iridium"              => 15299,
                         "irina"                => 1060,
                         "irina1"               => 23966,
                         "irina123"             => 25011,
                         "irina1991"            => 26890,
                         "irinka"               => 4188,
                         "irish1"               => 2033,
                         "irish123"             => 23774,
                         "irish88"              => 29612,
                         "irisha"               => 7833,
                         "irishka"              => 4426,
                         "irishman"             => 3959,
                         "iriska"               => 5091,
                         "irland"               => 12269,
                         "irnbru"               => 27409,
                         "iro4ka"               => 22311,
                         "irochka"              => 15157,
                         "irock"                => 20708,
                         "irock."               => 20750,
                         "irocz28"              => 21081,
                         "ironbird"             => 18934,
                         "ironchef"             => 20376,
                         "ironcity"             => 27101,
                         "irondesk"             => 29543,
                         "irondoor"             => 16979,
                         "ironfish"             => 25128,
                         "ironfist"             => 24381,
                         "ironhead"             => 10799,
                         "ironhors"             => 8225,
                         "ironhorse"            => 22645,
                         "ironlung"             => 23386,
                         "ironmaid"             => 10429,
                         "ironmaiden"           => 4962,
                         "ironman"              => 544,
                         "ironman1"             => 7552,
                         "ironman2"             => 18403,
                         "ironmike"             => 18360,
                         "ironpony"             => 13334,
                         "ironroad"             => 16333,
                         "ironside"             => 19910,
                         "ironsink"             => 18723,
                         "irontree"             => 13942,
                         "is3yeusc"             => 25950,
                         "is_a_bot"             => 21727,
                         "isaac1"               => 15179,
                         "isabe"                => 9432,
                         "isabel1"              => 23048,
                         "isabella1"            => 17607,
                         "isacs155"             => 10286,
                         "isaeva"               => 18407,
                         "isaia"                => 24724,
                         "isaiah1"              => 19251,
                         "isakov"               => 20060,
                         "isbest"               => 26595,
                         "iscool"               => 3207,
                         "isdead"               => 26750,
                         "iseedeadpeople"       => 12746,
                         "iseeyou"              => 17014,
                         "isengard"             => 19008,
                         "isgay"                => 17290,
                         "isgod"                => 26771,
                         "isgood"               => 16221,
                         "isgreat"              => 10183,
                         "ishikawa"             => 10588,
                         "ishmael"              => 8060,
                         "ishot"                => 12279,
                         "ishtar"               => 11124,
                         "isidor"               => 24030,
                         "iskander"             => 11072,
                         "island1"              => 10720,
                         "islander"             => 3606,
                         "ismail"               => 6005,
                         "isolde"               => 26838,
                         "isotwe"               => 20146,
                         "israe"                => 12609,
                         "issmall"              => 25288,
                         "issue43"              => 13724,
                         "istanbul"             => 3358,
                         "isthebes"             => 23307,
                         "istheman"             => 5698,
                         "istina"               => 29705,
                         "itachi"               => 10596,
                         "itali"                => 20318,
                         "italia"               => 1048,
                         "italia1"              => 23560,
                         "italian1"             => 19015,
                         "italiano"             => 5854,
                         "italien"              => 21536,
                         "italy1"               => 13830,
                         "itdoes"               => 29303,
                         "itdxtyrj"             => 15122,
                         "itisme"               => 5742,
                         "itout"                => 20348,
                         "its420"               => 11784,
                         "itsasecret"           => 29444,
                         "itsme"                => 4191,
                         "itsmine"              => 17003,
                         "itstime"              => 12771,
                         "itworks"              => 10516,
                         "iubire"               => 27069,
                         "ivan123"              => 14567,
                         "ivan1985"             => 25891,
                         "ivan2010"             => 19414,
                         "ivanhoe"              => 8464,
                         "ivanka"               => 18126,
                         "ivanna"               => 15103,
                         "ivanov"               => 1764,
                         "ivanova"              => 2346,
                         "iverso"               => 23276,
                         "iverson"              => 1384,
                         "iverson3"             => 3566,
                         "iwanna"               => 12962,
                         "iwantin"              => 11229,
                         "iwantit"              => 15753,
                         "iwantsex"             => 9827,
                         "iwantu"               => 183,
                         "iwantyou"             => 10214,
                         "iwojima"              => 22883,
                         "iyaayas"              => 18631,
                         "iyaoyas"              => 21079,
                         "izabella"             => 10859,
                         "izumrud"              => 22897,
                         "izzicam"              => 10503,
                         "j0nathan"             => 22085,
                         "j0shua"               => 26503,
                         "j10e5d4"              => 29431,
                         "j12345"               => 14314,
                         "j123456"              => 19113,
                         "j1234567"             => 24512,
                         "j1964"                => 29194,
                         "j3qq4h7h2v"           => 7452,
                         "ja0000"               => 26917,
                         "jabari"               => 27633,
                         "jabba"                => 10150,
                         "jabba1"               => 18890,
                         "jabbar"               => 19362,
                         "jabber"               => 5558,
                         "jabberwo"             => 29347,
                         "jabell"               => 22336,
                         "jabroni"              => 2546,
                         "jabroni1"             => 25572,
                         "jachin"               => 7000,
                         "jack01"               => 15030,
                         "jack1"                => 8678,
                         "jack10"               => 18789,
                         "jack11"               => 13457,
                         "jack12"               => 12712,
                         "jack123"              => 10197,
                         "jack1234"             => 13143,
                         "jack2000"             => 27116,
                         "jack22"               => 14846,
                         "jack23"               => 28726,
                         "jack5225"             => 26631,
                         "jack99"               => 23686,
                         "jackal"               => 1606,
                         "jackaroo"             => 22642,
                         "jackas"               => 21333,
                         "jackass"              => 279,
                         "jackass1"             => 4249,
                         "jackdani"             => 14058,
                         "jackdaniels"          => 19226,
                         "jackdog"              => 8942,
                         "jackel"               => 9594,
                         "jacker"               => 8905,
                         "jackfros"             => 27777,
                         "jackfrost"            => 26281,
                         "jackhamm"             => 23485,
                         "jackie01"             => 28819,
                         "jackie1"              => 6460,
                         "jackie2"              => 28885,
                         "jackie69"             => 25306,
                         "jackiech"             => 26941,
                         "jackin"               => 18673,
                         "jackme"               => 28213,
                         "jackmeof"             => 26261,
                         "jacko"                => 7999,
                         "jackoff"              => 1233,
                         "jackoff1"             => 25998,
                         "jackpot"              => 3403,
                         "jackpot1"             => 20789,
                         "jackryan"             => 15972,
                         "jackso"               => 9815,
                         "jackson1"             => 1822,
                         "jackson2"             => 10726,
                         "jackson5"             => 3194,
                         "jackson6"             => 27769,
                         "jackson9"             => 28185,
                         "jackster"             => 21389,
                         "jacky"                => 12354,
                         "jackyl"               => 19640,
                         "jacob1"               => 2456,
                         "jacob123"             => 18566,
                         "jacob2"               => 19278,
                         "jacob6"               => 15194,
                         "jacqueli"             => 12830,
                         "jadakiss"             => 12357,
                         "jade1"                => 26140,
                         "jaden"                => 26617,
                         "jadzia"               => 9685,
                         "jager1"               => 29721,
                         "jagged"               => 17712,
                         "jagger"               => 2821,
                         "jagman"               => 22933,
                         "jagr68"               => 9881,
                         "jagua"                => 17803,
                         "jaguar"               => 252,
                         "jaguar1"              => 6404,
                         "jaguars"              => 4701,
                         "jaguarxj"             => 27208,
                         "jahbless"             => 27455,
                         "jahlove"              => 29679,
                         "jaiden"               => 22581,
                         "jaihind"              => 21446,
                         "jailbait"             => 12648,
                         "jailbird"             => 10609,
                         "jaimatadi"            => 16289,
                         "jaime1"               => 15108,
                         "jakarta"              => 5459,
                         "jake01"               => 12322,
                         "jake1"                => 11117,
                         "jake11"               => 17273,
                         "jake12"               => 10712,
                         "jake123"              => 11075,
                         "jake1234"             => 20547,
                         "jake5253"             => 24984,
                         "jake99"               => 19250,
                         "jakedog"              => 10733,
                         "jakeman"              => 19209,
                         "jakers"               => 9992,
                         "jakester"             => 7951,
                         "jakeyboy"             => 25779,
                         "jalal123"             => 16442,
                         "jalapeno"             => 16885,
                         "jam123"               => 17292,
                         "jamaic"               => 26774,
                         "jamaica"              => 1157,
                         "jamaica1"             => 8912,
                         "jamal1"               => 22877,
                         "jambo"                => 12440,
                         "jambos"               => 26848,
                         "james00"              => 22454,
                         "james007"             => 2813,
                         "james01"              => 14629,
                         "james1"               => 794,
                         "james10"              => 26919,
                         "james11"              => 13293,
                         "james12"              => 16342,
                         "james123"             => 4125,
                         "james13"              => 27758,
                         "james19"              => 29975,
                         "james2"               => 7862,
                         "james22"              => 25318,
                         "james23"              => 12387,
                         "james3"               => 20308,
                         "james4"               => 26768,
                         "james5"               => 16223,
                         "james6"               => 25763,
                         "james69"              => 15505,
                         "james7"               => 14133,
                         "james99"              => 15741,
                         "jamesa"               => 27387,
                         "jamesb"               => 8142,
                         "jamesbon"             => 1991,
                         "jamesbond"            => 2421,
                         "jamesbond007"         => 12887,
                         "jamesc"               => 14811,
                         "jamesd"               => 9072,
                         "jamesdea"             => 27624,
                         "jamese"               => 25633,
                         "jamesg"               => 28183,
                         "jamesh"               => 27690,
                         "jamesk"               => 20207,
                         "jamesl"               => 28595,
                         "jamesm"               => 25585,
                         "jameson1"             => 13217,
                         "jamesp"               => 18218,
                         "jamesr"               => 14277,
                         "jamess"               => 4616,
                         "jamest"               => 9933,
                         "jamesw"               => 24751,
                         "jamesy"               => 27744,
                         "jamie1"               => 2850,
                         "jamie123"             => 14040,
                         "jamielee"             => 13376,
                         "jamies"               => 11195,
                         "jamjar"               => 29249,
                         "jammer"               => 1696,
                         "jammin"               => 3131,
                         "jamshid"              => 23380,
                         "jan123"               => 25972,
                         "janbam"               => 21340,
                         "janet1"               => 7677,
                         "janets"               => 25392,
                         "janeway"              => 7922,
                         "janice1"              => 23102,
                         "janne"                => 26451,
                         "jansport"             => 19994,
                         "januar"               => 9063,
                         "januari"              => 23293,
                         "january1"             => 8536,
                         "january2"             => 16226,
                         "janus"                => 9738,
                         "janus1"               => 26050,
                         "janvier"              => 19600,
                         "japan1"               => 10438,
                         "japan10"              => 29483,
                         "japanees"             => 7241,
                         "japanes"              => 10782,
                         "jared1"               => 8844,
                         "jaredleto"            => 15022,
                         "jarhead"              => 2102,
                         "jarhead1"             => 20988,
                         "jarule"               => 20770,
                         "jas4an"               => 27838,
                         "jasmi"                => 27902,
                         "jasmin1"              => 25263,
                         "jasmina"              => 21473,
                         "jasmine"              => 182,
                         "jasmine1"             => 2096,
                         "jasmine123"           => 29545,
                         "jasmine2"             => 17767,
                         "jasmine3"             => 26457,
                         "jasmine5"             => 18898,
                         "jasmine7"             => 25121,
                         "jasmine9"             => 28811,
                         "jason1"               => 1322,
                         "jason11"              => 25532,
                         "jason12"              => 15531,
                         "jason123"             => 8379,
                         "jason13"              => 23828,
                         "jason2"               => 14228,
                         "jason22"              => 23973,
                         "jason25"              => 18485,
                         "jason3"               => 19511,
                         "jason5"               => 18559,
                         "jason69"              => 29847,
                         "jasonb"               => 11867,
                         "jasonc"               => 18171,
                         "jasond"               => 15811,
                         "jasong"               => 27357,
                         "jasonj"               => 26098,
                         "jasonk"               => 28386,
                         "jasonm"               => 17000,
                         "jasonn"               => 17568,
                         "jasonp"               => 18199,
                         "jasonr"               => 17145,
                         "jasons"               => 7420,
                         "jasont"               => 17545,
                         "jasonx"               => 18228,
                         "jaspe"                => 11522,
                         "jasper"               => 169,
                         "jasper1"              => 7353,
                         "jasper12"             => 16831,
                         "jasper2"              => 29962,
                         "java"                 => 2418,
                         "javabean"             => 19197,
                         "javaman"              => 13717,
                         "javelin"              => 5226,
                         "javie"                => 7160,
                         "javier1"              => 24665,
                         "jawa350"              => 26401,
                         "jawbreak"             => 26152,
                         "jaxson"               => 27335,
                         "jay123"               => 11264,
                         "jaybee"               => 14778,
                         "jaybird"              => 2926,
                         "jayboy"               => 24080,
                         "jaycee"               => 8140,
                         "jayde"                => 28593,
                         "jaydee"               => 9107,
                         "jayden"               => 3066,
                         "jaydog"               => 19685,
                         "jaydog472"            => 23425,
                         "jayhawk"              => 2384,
                         "jayhawk1"             => 25446,
                         "jayhawks"             => 3414,
                         "jayjay1"              => 19516,
                         "jaylen"               => 23395,
                         "jayman"               => 8132,
                         "jayman1"              => 20255,
                         "jaysoncj"             => 21805,
                         "jaytee"               => 28580,
                         "jazmyn"               => 23970,
                         "jazz1234"             => 26846,
                         "jazzbass"             => 15167,
                         "jazzbo"               => 13064,
                         "jazzer"               => 13687,
                         "jazzie"               => 15125,
                         "jazzman"              => 2222,
                         "jazzman1"             => 24506,
                         "jazzmin"              => 22760,
                         "jazzy"                => 5640,
                         "jazzy1"               => 8569,
                         "jazzzz"               => 18600,
                         "jb007"                => 19966,
                         "jbaby"                => 17350,
                         "jbird"                => 18834,
                         "jblaze"               => 18477,
                         "jblpro"               => 28698,
                         "jbond007"             => 8364,
                         "jbruton"              => 22952,
                         "jcnhjd"               => 17771,
                         "jdeere"               => 12107,
                         "jeadmi"               => 8288,
                         "jeanluc"              => 13224,
                         "jeanmarc"             => 29831,
                         "jeanpaul"             => 15838,
                         "jearly"               => 17790,
                         "jed1054"              => 27193,
                         "jedi"                 => 2128,
                         "jedi01"               => 28367,
                         "jediknig"             => 7023,
                         "jediknight"           => 9484,
                         "jedimast"             => 10306,
                         "jedimaster"           => 28104,
                         "jeebus"               => 28681,
                         "jeep"                 => 1515,
                         "jeep95"               => 18265,
                         "jeep99"               => 25203,
                         "jeepcj5"              => 16483,
                         "jeepcj7"              => 10425,
                         "jeeper"               => 5940,
                         "jeepers"              => 6758,
                         "jeepin"               => 21540,
                         "jeepman"              => 12097,
                         "jeepster"             => 5387,
                         "jeeves"               => 9918,
                         "jeff1"                => 15045,
                         "jeff12"               => 25587,
                         "jeff123"              => 19380,
                         "jeff1234"             => 19433,
                         "jeff24"               => 13358,
                         "jeffer"               => 15755,
                         "jefferso"             => 3990,
                         "jeffery1"             => 25084,
                         "jeffhardy"            => 26995,
                         "jeffre"               => 17297,
                         "jeffrey1"             => 6666,
                         "jeffrey4"             => 26966,
                         "jeffro"               => 8654,
                         "jegr2d2"              => 24647,
                         "jehova"               => 18252,
                         "jehovah"              => 5706,
                         "jelena"               => 7672,
                         "jello"                => 5570,
                         "jello1"               => 14099,
                         "jelly"                => 3561,
                         "jelly1"               => 9726,
                         "jellybea"             => 3603,
                         "jellybean"            => 5300,
                         "jellyfis"             => 12139,
                         "jelszo"               => 20280,
                         "jemima"               => 18580,
                         "jemoeder"             => 11084,
                         "jenmt3"               => 18015,
                         "jenn"                 => 3010,
                         "jenna1"               => 8338,
                         "jenna123"             => 29968,
                         "jennaj"               => 5110,
                         "jennan"               => 28214,
                         "jennife"              => 3925,
                         "jennife1"             => 11711,
                         "jennifer1"            => 6079,
                         "jenny1"               => 2030,
                         "jenny123"             => 15731,
                         "jenny2"               => 17739,
                         "jenny69"              => 11487,
                         "jennyb"               => 17002,
                         "jennyc"               => 24299,
                         "jennyff"              => 13242,
                         "jennyk"               => 27810,
                         "jennys"               => 11800,
                         "jenova"               => 12693,
                         "jerbear"              => 26114,
                         "jerem"                => 9816,
                         "jeremi"               => 28687,
                         "jeremia"              => 20663,
                         "jeremy1"              => 4248,
                         "jergens"              => 29443,
                         "jericho"              => 1309,
                         "jericho1"             => 13098,
                         "jerico"               => 13961,
                         "jerkin"               => 25051,
                         "jerkoff"              => 2265,
                         "jerky1"               => 18149,
                         "jerkyboy"             => 23577,
                         "jeroen"               => 13170,
                         "jerom"                => 20830,
                         "jerome1"              => 19085,
                         "jeronimo"             => 10357,
                         "jerry1"               => 4031,
                         "jerry2"               => 22484,
                         "jerry69"              => 29541,
                         "jerryb"               => 24530,
                         "jerryg"               => 10227,
                         "jerrylee"             => 11966,
                         "jerrys"               => 10325,
                         "jersey1"              => 20225,
                         "jertoot"              => 19707,
                         "jerusale"             => 15387,
                         "jesper"               => 6094,
                         "jesse1"               => 6264,
                         "jesse123"             => 22173,
                         "jessejames"           => 29938,
                         "jessic"               => 2645,
                         "jessica0"             => 12365,
                         "jessica1"             => 928,
                         "jessica2"             => 6827,
                         "jessica3"             => 26558,
                         "jessica6"             => 24991,
                         "jessica7"             => 16300,
                         "jessica8"             => 16056,
                         "jessicam"             => 21434,
                         "jessicas"             => 16464,
                         "jessie1"              => 8258,
                         "jessy"                => 18085,
                         "jester"               => 457,
                         "jester1"              => 13243,
                         "jesucrist"            => 11284,
                         "jesus1"               => 1019,
                         "jesus12"              => 14612,
                         "jesus123"             => 5642,
                         "jesus2"               => 19652,
                         "jesus3"               => 16144,
                         "jesus33"              => 24135,
                         "jesus4me"             => 26304,
                         "jesus7"               => 7818,
                         "jesus777"             => 6611,
                         "jesusc"               => 9326,
                         "jesuschr"             => 23512,
                         "jesuschris"           => 26214,
                         "jesuschrist"          => 10298,
                         "jesusgod"             => 29361,
                         "jesusis"              => 13414,
                         "jesusis1"             => 21764,
                         "jesusislord"          => 17346,
                         "jesuss"               => 8989,
                         "jesussaves"           => 24203,
                         "jetaime"              => 10296,
                         "jetbalance"           => 14715,
                         "jetblack"             => 20249,
                         "jetblue"              => 21196,
                         "jetboat"              => 29549,
                         "jeter1"               => 29950,
                         "jeter2"               => 5913,
                         "jethro"               => 1891,
                         "jethro1"              => 29273,
                         "jetlag"               => 19930,
                         "jetman"               => 17715,
                         "jets"                 => 3914,
                         "jetset"               => 12516,
                         "jetski"               => 3176,
                         "jetson"               => 9456,
                         "jetta1"               => 18954,
                         "jettas"               => 29835,
                         "jewboy"               => 9834,
                         "jewel1"               => 15885,
                         "jewels"               => 2699,
                         "jezebel"              => 3600,
                         "jg3h4hfn"             => 13375,
                         "jgjesq"               => 29348,
                         "jgordon"              => 21512,
                         "jgthfnjh"             => 17757,
                         "jgtxzbhr"             => 27018,
                         "jhereg"               => 25943,
                         "jhnjgtl12"            => 26352,
                         "jhonny"               => 28030,
                         "jhrl0821"             => 25006,
                         "jiang"                => 3228,
                         "jiao"                 => 3599,
                         "jibber"               => 22838,
                         "jibxhq"               => 18672,
                         "jigei743ks"           => 18546,
                         "jigga"                => 7264,
                         "jigga1"               => 21210,
                         "jiggaman"             => 3608,
                         "jigger"               => 11427,
                         "jiggle"               => 12956,
                         "jiggy"                => 10077,
                         "jigsaw"               => 8099,
                         "jillian1"             => 16111,
                         "jilly"                => 27388,
                         "jim123"               => 9703,
                         "jimandanne"           => 23021,
                         "jimbeam"              => 6357,
                         "jimbo"                => 1592,
                         "jimbo1"               => 3817,
                         "jimbo123"             => 26381,
                         "jimbo2"               => 24988,
                         "jimbo69"              => 25923,
                         "jimbob"               => 1558,
                         "jimbob1"              => 26442,
                         "jimboo"               => 22608,
                         "jimbos"               => 11988,
                         "jimboy"               => 20845,
                         "jimdavis"             => 22821,
                         "jiminy"               => 15085,
                         "jimjam"               => 15787,
                         "jimkirk"              => 29512,
                         "jimmer"               => 15770,
                         "jimmy1"               => 1823,
                         "jimmy12"              => 22775,
                         "jimmy123"             => 9074,
                         "jimmy2"               => 10570,
                         "jimmy6"               => 28121,
                         "jimmy69"              => 21108,
                         "jimmy99"              => 23168,
                         "jimmyb"               => 13297,
                         "jimmyboy"             => 18633,
                         "jimmyc"               => 15945,
                         "jimmyd"               => 14301,
                         "jimmyg"               => 15329,
                         "jimmyj"               => 18940,
                         "jimmyjam"             => 19148,
                         "jimmyp"               => 28781,
                         "jimmypag"             => 28972,
                         "jimmys"               => 5734,
                         "jimmyz"               => 26973,
                         "jing"                 => 3296,
                         "jingle"               => 3790,
                         "jingles"              => 6018,
                         "jiong"                => 3347,
                         "jitter"               => 29414,
                         "jitterbu"             => 24337,
                         "jiujitsu"             => 11610,
                         "jjjdsl"               => 23708,
                         "jjjjj1"               => 10458,
                         "jjjjjj1"              => 12184,
                         "jjjjjjj1"             => 13465,
                         "jjjkkk"               => 18112,
                         "jjones"               => 21648,
                         "jjvwd4"               => 23413,
                         "jkbvgbflf"            => 25498,
                         "jkelly"               => 27372,
                         "jkl123"               => 21621,
                         "jkmuf"                => 12668,
                         "jkmxbr"               => 24442,
                         "jkne9y"               => 20081,
                         "jktxrf"               => 4861,
                         "jktymrf"              => 3074,
                         "jkz123"               => 23160,
                         "jlaudio"              => 12518,
                         "jlbyjxrf"             => 19336,
                         "jlbyjxtcndj"          => 21451,
                         "jledfyxbr"            => 11468,
                         "jlettier"             => 27761,
                         "jlhanes"              => 15243,
                         "jmh1978"              => 19946,
                         "jmol01"               => 20551,
                         "jmoney"               => 12735,
                         "jmzacf"               => 18078,
                         "jndfkb"               => 24065,
                         "jnrhjqcz"             => 26554,
                         "jo9k2jw2"             => 15189,
                         "joakim"               => 22032,
                         "joanna1"              => 23376,
                         "joanne1"              => 27587,
                         "joaqui"               => 22572,
                         "job314"               => 17780,
                         "jobber"               => 12890,
                         "jobsearc"             => 18322,
                         "jochen"               => 13384,
                         "jocker"               => 13616,
                         "jockey"               => 3287,
                         "jockstra"             => 27836,
                         "jodeci"               => 9247,
                         "joe123"               => 4509,
                         "joeblack"             => 18536,
                         "joeblow"              => 7994,
                         "joebob"               => 4330,
                         "joeboo"               => 20499,
                         "joeboy"               => 12046,
                         "joecool"              => 5112,
                         "joedog"               => 18621,
                         "joemama"              => 5225,
                         "joeman"               => 18060,
                         "joesakic"             => 16041,
                         "joesmith"             => 22900,
                         "joey1"                => 15774,
                         "joey123"              => 18468,
                         "joey21"               => 22834,
                         "johann"               => 3124,
                         "johanna1"             => 13815,
                         "johannes"             => 2559,
                         "john01"               => 19212,
                         "john1"                => 5924,
                         "john10"               => 26697,
                         "john11"               => 11847,
                         "john12"               => 8162,
                         "john123"              => 4752,
                         "john1234"             => 10495,
                         "john22"               => 20472,
                         "john23"               => 22806,
                         "john31"               => 18607,
                         "john316"              => 1716,
                         "john33"               => 22333,
                         "john44"               => 22903,
                         "john55"               => 24696,
                         "john69"               => 17033,
                         "john77"               => 27869,
                         "john99"               => 18110,
                         "johnatha"             => 23210,
                         "johnboy"              => 2748,
                         "johncena"             => 4793,
                         "johnd"                => 24231,
                         "johndeer"             => 3943,
                         "johndeere"            => 8968,
                         "johndoe"              => 4871,
                         "johngalt"             => 4484,
                         "johnmish"             => 10955,
                         "johnn"                => 9720,
                         "johnnn"               => 25598,
                         "johnny1"              => 4208,
                         "johnny12"             => 29203,
                         "johnny5"              => 5452,
                         "johnny69"             => 14479,
                         "johnny99"             => 17571,
                         "johnnyb"              => 16125,
                         "johnnybo"             => 23001,
                         "johnnyd"              => 24563,
                         "johnpaul"             => 12617,
                         "johnsmith"            => 23042,
                         "johnso"               => 13002,
                         "johnson1"             => 4199,
                         "johnson2"             => 16334,
                         "johnson4"             => 23006,
                         "johnwayn"             => 22732,
                         "johny"                => 24588,
                         "jojo12"               => 14351,
                         "jojo123"              => 24619,
                         "joker"                => 876,
                         "joker1"               => 2783,
                         "joker12"              => 22640,
                         "joker123"             => 13836,
                         "joker13"              => 23625,
                         "joker666"             => 18690,
                         "joker69"              => 13330,
                         "joker7"               => 15289,
                         "joker777"             => 24710,
                         "jokerr"               => 22006,
                         "jokers"               => 2336,
                         "jollymon"             => 25389,
                         "jomama"               => 5180,
                         "jonass"               => 29903,
                         "jonatha"              => 6533,
                         "jonathan1"            => 11059,
                         "jonboy"               => 7322,
                         "jones1"               => 3486,
                         "jones2"               => 25521,
                         "joness"               => 10938,
                         "jonesy"               => 6541,
                         "jonny"                => 4362,
                         "jonny1"               => 19203,
                         "jonny5"               => 15032,
                         "jonnyb"               => 19556,
                         "jonnyboy"             => 22345,
                         "joonas"               => 11768,
                         "jor23dan"             => 18237,
                         "jorda"                => 3550,
                         "jordan"               => 32,
                         "jordan01"             => 16781,
                         "jordan1"              => 1810,
                         "jordan10"             => 29597,
                         "jordan11"             => 15724,
                         "jordan12"             => 11677,
                         "jordan123"            => 17901,
                         "jordan18"             => 24950,
                         "jordan2"              => 5875,
                         "jordan20"             => 27481,
                         "jordan22"             => 16708,
                         "jordan23"             => 195,
                         "jordan45"             => 25018,
                         "jordan7"              => 20966,
                         "jordan9"              => 26806,
                         "jordan99"             => 20647,
                         "jordana"              => 24548,
                         "jordans"              => 13768,
                         "jordyn"               => 8525,
                         "jorel"                => 24304,
                         "jorge1"               => 23985,
                         "joschi"               => 13180,
                         "jose1"                => 19915,
                         "jose12"               => 23464,
                         "jose98"               => 22381,
                         "josefin"              => 20455,
                         "joselit"              => 27831,
                         "joselito"             => 19291,
                         "joselui"              => 10707,
                         "joseluis"             => 9095,
                         "josep"                => 6697,
                         "joseph1"              => 3981,
                         "joseph10"             => 15619,
                         "joseph11"             => 27049,
                         "joseph12"             => 17312,
                         "joseph2"              => 24087,
                         "josepha"              => 29367,
                         "josephin"             => 4004,
                         "josh1"                => 16888,
                         "josh12"               => 25278,
                         "joshie"               => 19152,
                         "joshman"              => 23338,
                         "joshu"                => 4724,
                         "joshua0"              => 26471,
                         "joshua01"             => 16947,
                         "joshua1"              => 2627,
                         "joshua10"             => 28434,
                         "joshua11"             => 28364,
                         "joshua12"             => 9414,
                         "joshua19"             => 25907,
                         "joshua2"              => 13585,
                         "joshua3"              => 22930,
                         "joshua5"              => 28730,
                         "joshua99"             => 26277,
                         "josie1"               => 16377,
                         "josiew"               => 26724,
                         "jossie"               => 24970,
                         "joung"                => 8252,
                         "journey1"             => 26526,
                         "jowgnx"               => 15138,
                         "joxury8f"             => 25157,
                         "joy123"               => 16085,
                         "joyce1"               => 9781,
                         "joyful"               => 8167,
                         "joyride"              => 10045,
                         "joystick"             => 6837,
                         "jpthjdf"              => 25356,
                         "jq24nc"               => 14344,
                         "jr1234"               => 29290,
                         "jrcfyf"               => 1834,
                         "jrcfyjxrf"            => 18223,
                         "jsbach"               => 4222,
                         "jscript"              => 27500,
                         "jsmith"               => 20343,
                         "jtkirk"               => 19928,
                         "jtuac3my"             => 20080,
                         "juanas"               => 20346,
                         "juancarlo"            => 9454,
                         "juancarlos"           => 27023,
                         "juancho"              => 18544,
                         "juanit"               => 17550,
                         "juanito"              => 8694,
                         "juanjo"               => 29592,
                         "juanjose"             => 22399,
                         "juanma"               => 20857,
                         "juanpabl"             => 28684,
                         "jubilee"              => 3865,
                         "judit"                => 29952,
                         "juehtw"               => 16578,
                         "juergen"              => 11382,
                         "juggalo"              => 2423,
                         "juggalo1"             => 20674,
                         "jugger"               => 19919,
                         "juggerna"             => 20874,
                         "juggernaut"           => 14772,
                         "juggle"               => 10157,
                         "juggler"              => 23081,
                         "juggs"                => 11326,
                         "jughead"              => 5447,
                         "juhani"               => 23111,
                         "juice"                => 1149,
                         "juice1"               => 13236,
                         "juice2"               => 12847,
                         "juiceman"             => 20427,
                         "juicer"               => 13263,
                         "juicey"               => 16797,
                         "juicy"                => 4138,
                         "juicy1"               => 13743,
                         "juillet"              => 16147,
                         "jujitsu"              => 14760,
                         "jujube"               => 20430,
                         "julemand"             => 27431,
                         "julia1"               => 6027,
                         "julia123"             => 17397,
                         "julian1"              => 16391,
                         "julias"               => 26599,
                         "julie1"               => 3807,
                         "julie123"             => 27928,
                         "julie456"             => 16770,
                         "julieb"               => 16867,
                         "julien"               => 4124,
                         "julies"               => 11693,
                         "julija"               => 24461,
                         "julio1"               => 20094,
                         "julius1"              => 17888,
                         "juliya"               => 19888,
                         "july1"                => 25931,
                         "july16"               => 24359,
                         "july20"               => 22137,
                         "july21"               => 25958,
                         "july23"               => 12836,
                         "july27"               => 26767,
                         "jumanji"              => 7360,
                         "jumble"               => 11922,
                         "jumbo"                => 4936,
                         "jumbo1"               => 20002,
                         "jumbos"               => 26123,
                         "jump23"               => 20015,
                         "jumper"               => 1199,
                         "jumpjet"              => 23745,
                         "jumpman"              => 11451,
                         "jumpman23"            => 17577,
                         "jumpshot"             => 26495,
                         "jumpup"               => 29423,
                         "junaid"               => 26292,
                         "june12"               => 24053,
                         "june14"               => 25743,
                         "june15"               => 27734,
                         "june17"               => 17020,
                         "june21"               => 19413,
                         "june22"               => 14826,
                         "june23"               => 29863,
                         "june24"               => 20508,
                         "june26"               => 25038,
                         "june27"               => 19587,
                         "june28"               => 24371,
                         "june29"               => 15784,
                         "juneau"               => 8209,
                         "junebug"              => 2176,
                         "junebug1"             => 20694,
                         "junfan"               => 11032,
                         "jungfrau"             => 21213,
                         "jungle"               => 1018,
                         "jungle1"              => 26056,
                         "junglist"             => 16686,
                         "juninho"              => 12601,
                         "junio"                => 5116,
                         "junior"               => 133,
                         "junior01"             => 24382,
                         "junior1"              => 3984,
                         "junior12"             => 20434,
                         "junior123"            => 21406,
                         "junior13"             => 26830,
                         "junior2"              => 16872,
                         "junior24"             => 21574,
                         "junior8"              => 28498,
                         "juniper"              => 6015,
                         "junkfood"             => 24516,
                         "junkie"               => 4407,
                         "junkmail"             => 5617,
                         "junkman"              => 19146,
                         "junkyard"             => 9402,
                         "juntas"               => 27393,
                         "jupiler"              => 17372,
                         "jupite"               => 21070,
                         "jupiter"              => 522,
                         "jupiter1"             => 5614,
                         "jupiter2"             => 6294,
                         "jurassic"             => 6106,
                         "juris01"              => 22992,
                         "just4fun"             => 3461,
                         "just4me"              => 2977,
                         "just4u"               => 27822,
                         "just4you"             => 12134,
                         "justdoit"             => 1623,
                         "juster"               => 11338,
                         "justforf"             => 25631,
                         "justforfun"           => 15625,
                         "justfun"              => 17742,
                         "justi"                => 6034,
                         "justic"               => 20974,
                         "justice"              => 561,
                         "justice1"             => 5688,
                         "justice2"             => 26531,
                         "justin01"             => 23238,
                         "justin1"              => 2185,
                         "justin10"             => 22255,
                         "justin11"             => 15887,
                         "justin12"             => 9907,
                         "justin123"            => 24614,
                         "justinb"              => 29771,
                         "justinbiebe"          => 19431,
                         "justinbieber"         => 7051,
                         "justine1"             => 25332,
                         "justlook"             => 27328,
                         "justme"               => 1040,
                         "justme1"              => 28774,
                         "justonce"             => 27344,
                         "justyna"              => 14856,
                         "juventu"              => 11463,
                         "juventus"             => 580,
                         "juvis123"             => 26264,
                         "jvtuepip"             => 22600,
                         "jxfhjdfirf"           => 24452,
                         "jyothi"               => 28278,
                         "jys6wz"               => 10405,
                         "jzf7qf2e"             => 28537,
                         "k.jdm"                => 8760,
                         "k.ljxrf"              => 27661,
                         "k.lvbkf"              => 4844,
                         "k1200rs"              => 23911,
                         "k12345"               => 13328,
                         "k123456"              => 9493,
                         "k1234567"             => 16296,
                         "k123456789"           => 20641,
                         "k1ller"               => 17560,
                         "k2trix"               => 9688,
                         "k9dls02a"             => 16549,
                         "kablam"               => 26798,
                         "kaboom"               => 5636,
                         "kabuki"               => 9030,
                         "kabuto"               => 26780,
                         "kacper"               => 12755,
                         "kadett"               => 11288,
                         "kafedra"              => 25457,
                         "kafka1"               => 28974,
                         "kagome"               => 16403,
                         "kahala"               => 24325,
                         "kahlan"               => 29488,
                         "kahless"              => 26250,
                         "kahlua"               => 5745,
                         "kahuna"               => 2493,
                         "kailayu"              => 25668,
                         "kailey"               => 11182,
                         "kailua"               => 10396,
                         "kairat"               => 17515,
                         "kairos"               => 19884,
                         "kaitlynn"             => 21245,
                         "kaizen"               => 13456,
                         "kajak"                => 8823,
                         "kajlas"               => 25985,
                         "kaka22"               => 25667,
                         "kakadu"               => 11311,
                         "kakaha"               => 29984,
                         "kakarot"              => 7048,
                         "kakaroto"             => 10921,
                         "kakashi"              => 6369,
                         "kakashka"             => 3432,
                         "kakawka"              => 19686,
                         "kakka"                => 14833,
                         "kakosja"              => 24282,
                         "kaktus"               => 1673,
                         "kaktys"               => 16762,
                         "kalamazo"             => 19970,
                         "kalambur"             => 26962,
                         "kalani"               => 13969,
                         "kalash"               => 27707,
                         "kaleka"               => 20317,
                         "kalel"                => 20183,
                         "kalender"             => 27441,
                         "kalifornia"           => 29739,
                         "kaligula"             => 20864,
                         "kalima"               => 16589,
                         "kalimera"             => 23620,
                         "kalina"               => 4287,
                         "kalinin"              => 18867,
                         "kalinina"             => 17335,
                         "kalinka"              => 13770,
                         "kalle"                => 10394,
                         "kalle1"               => 22791,
                         "kalleank"             => 25928,
                         "kalleanka"            => 20220,
                         "kallisti"             => 22854,
                         "kaluga"               => 22369,
                         "kalyani"              => 22808,
                         "kamakazi"             => 27929,
                         "kamakiri"             => 29129,
                         "kamasutr"             => 14867,
                         "kamasutra"            => 5339,
                         "kamaz"                => 26455,
                         "kamehame"             => 10784,
                         "kamehameha"           => 13870,
                         "kamelia2011"          => 27687,
                         "kameron"              => 20092,
                         "kamikadze"            => 6216,
                         "kamikaze"             => 1942,
                         "kamikazi"             => 28648,
                         "kamil"                => 11151,
                         "kamil1"               => 17040,
                         "kamila"               => 3780,
                         "kamilek"              => 24602,
                         "kamilka"              => 29569,
                         "kamilla"              => 5920,
                         "kamran"               => 13676,
                         "kanabis"              => 29980,
                         "kanada"               => 12153,
                         "kanako"               => 24611,
                         "kanat"                => 24023,
                         "kaneda"               => 11503,
                         "kangaroo"             => 1497,
                         "kangol"               => 28150,
                         "kangoo"               => 20785,
                         "kanker"               => 16876,
                         "kanmax1994"           => 26568,
                         "kannan"               => 14627,
                         "kansas"               => 1319,
                         "kansas1"              => 17978,
                         "kantot"               => 29156,
                         "kapitan"              => 19547,
                         "kappa"                => 6050,
                         "kappa1"               => 19204,
                         "kappaman"             => 25886,
                         "kappas"               => 18298,
                         "kappasig"             => 16260,
                         "kapusta"              => 10231,
                         "karabas"              => 21599,
                         "karachi"              => 4438,
                         "karaganda"            => 12891,
                         "karamba"              => 7123,
                         "karamel"              => 14891,
                         "karamelka"            => 9993,
                         "karandash"            => 18704,
                         "karaoke"              => 6112,
                         "karapuz"              => 9885,
                         "karat"                => 18799,
                         "karate"               => 994,
                         "karate1"              => 18659,
                         "kardinal"             => 18498,
                         "kardon"               => 10827,
                         "kareena"              => 27225,
                         "kareltje"             => 28836,
                         "karen1"               => 3816,
                         "karen123"             => 18632,
                         "karen2"               => 17520,
                         "karens"               => 14271,
                         "karenw"               => 26837,
                         "kareta"               => 26161,
                         "karimov"              => 18362,
                         "karimova"             => 21796,
                         "karin1"               => 21474,
                         "karina"               => 552,
                         "karina1"              => 17819,
                         "karinka"              => 15142,
                         "karishma"             => 18268,
                         "kariya"               => 13850,
                         "karizma"              => 26435,
                         "karla1"               => 20138,
                         "karlito"              => 28752,
                         "karlmarx"             => 20279,
                         "karlmasc"             => 23214,
                         "karlos"               => 11727,
                         "karma1"               => 14581,
                         "karman"               => 15320,
                         "karmann"              => 26549,
                         "karol1"               => 29979,
                         "karolin"              => 28603,
                         "karolina"             => 2233,
                         "karolina1"            => 17518,
                         "karolinka"            => 27123,
                         "karpov"               => 13003,
                         "karpova"              => 23552,
                         "kartal"               => 15634,
                         "karthik"              => 18247,
                         "karting"              => 20077,
                         "kartoshka"            => 18389,
                         "karuna"               => 27540,
                         "karups"               => 13310,
                         "kasey1"               => 21313,
                         "kashif"               => 18291,
                         "kashmir"              => 2927,
                         "kasia"                => 26283,
                         "kasia1"               => 11540,
                         "kasimir"              => 15820,
                         "kaskad"               => 14987,
                         "kasparov"             => 11263,
                         "kasper"               => 1685,
                         "kasperok"             => 27102,
                         "kassidy"              => 20858,
                         "kasumi"               => 9023,
                         "kat123"               => 25047,
                         "katana"               => 723,
                         "katana1"              => 11140,
                         "katarina"             => 3705,
                         "katemoss"             => 26637,
                         "katenka"              => 22304,
                         "katenok"              => 10816,
                         "katerin"              => 22598,
                         "katerina"             => 1453,
                         "katerinka"            => 14765,
                         "katharin"             => 9376,
                         "kathryn1"             => 24782,
                         "kathy1"               => 5490,
                         "katie1"               => 2159,
                         "katie123"             => 12099,
                         "katie2"               => 28448,
                         "katieb"               => 20629,
                         "katiebug"             => 26477,
                         "katiedog"             => 24045,
                         "katiee"               => 29675,
                         "katieh"               => 19540,
                         "katies"               => 13291,
                         "katinas"              => 29787,
                         "katinka"              => 27491,
                         "katja"                => 14045,
                         "katmandu"             => 15609,
                         "katoom"               => 27726,
                         "katrin"               => 1608,
                         "katrina1"             => 10007,
                         "katrine"              => 18487,
                         "katten"               => 8189,
                         "katter"               => 26864,
                         "katuha"               => 25138,
                         "katusha"              => 11165,
                         "katya"                => 7621,
                         "katya123"             => 22901,
                         "katydid"              => 23069,
                         "katyusha"             => 26134,
                         "katze"                => 12645,
                         "katzen"               => 8215,
                         "kaulitz"              => 14964,
                         "kavita"               => 16531,
                         "kavitha"              => 15300,
                         "kavkaz"               => 7418,
                         "kawaii"               => 10451,
                         "kawasak"              => 15412,
                         "kawasaki"             => 555,
                         "kawika"               => 23283,
                         "kayak"                => 8827,
                         "kayak1"               => 14522,
                         "kayaker"              => 15423,
                         "kayaking"             => 14827,
                         "kayaks"               => 21003,
                         "kayla1"               => 7850,
                         "kayla123"             => 21529,
                         "kayley"               => 17140,
                         "kaylie"               => 17859,
                         "kaylin"               => 23758,
                         "kaytee"               => 29395,
                         "kazak"                => 21264,
                         "kazakov"              => 17124,
                         "kazakova"             => 21607,
                         "kazama"               => 24388,
                         "kazanova"             => 7749,
                         "kazantip"             => 3590,
                         "kazbek"               => 13860,
                         "kazumi"               => 19034,
                         "kazuya"               => 28638,
                         "kban667"              => 10730,
                         "kbcbxrf"              => 14171,
                         "kbctyjr"              => 7841,
                         "kbdthgekm"            => 19337,
                         "kbkbxrf"              => 29387,
                         "kbnthfnehf"           => 17969,
                         "kbpfdtnf"             => 28853,
                         "kbpjxrf"              => 24902,
                         "kbytqrf"              => 11558,
                         "kcchiefs"             => 6076,
                         "kcj9wx5n"             => 2372,
                         "kcmfwesg"             => 22439,
                         "kd189nlcih"           => 23007,
                         "kd5396b"              => 27866,
                         "keebler"              => 12605,
                         "keegan1"              => 29737,
                         "keeper"               => 1274,
                         "keeper1"              => 14758,
                         "keepout"              => 4687,
                         "keines"               => 13258,
                         "keith1"               => 5808,
                         "keith123"             => 21087,
                         "keithb"               => 19893,
                         "keiths"               => 20995,
                         "keksa12"              => 8558,
                         "keksa2"               => 27665,
                         "kekskek1"             => 22931,
                         "kelebek"              => 29915,
                         "keli_14"              => 19463,
                         "kelli1"               => 27503,
                         "kellie1"              => 21596,
                         "kelly001"             => 11749,
                         "kelly1"               => 2051,
                         "kelly123"             => 10629,
                         "kelly2"               => 13963,
                         "kelly69"              => 16338,
                         "kellyann"             => 16145,
                         "kellyb"               => 12010,
                         "kellyj"               => 28083,
                         "kellym"               => 17595,
                         "kellys"               => 11069,
                         "kelse"                => 27721,
                         "kelsey1"              => 15391,
                         "kemerovo"             => 29262,
                         "kenaidog"             => 23996,
                         "kendall1"             => 22302,
                         "kender"               => 14766,
                         "keng"                 => 3868,
                         "kenned"               => 24488,
                         "kennedy1"             => 13029,
                         "kennet"               => 12018,
                         "kenneth1"             => 6496,
                         "kenneth2"             => 28298,
                         "kennwort"             => 7372,
                         "kenny1"               => 5275,
                         "kenny123"             => 14468,
                         "kennyb"               => 22017,
                         "kennyg"               => 18184,
                         "kennys"               => 17574,
                         "kenobi"               => 5666,
                         "kenpo"                => 21643,
                         "kenpo1"               => 26295,
                         "kensai"               => 20876,
                         "kenshin"              => 2259,
                         "kenshin1"             => 23888,
                         "kenshiro"             => 15428,
                         "kensingt"             => 23651,
                         "kentavr"              => 16742,
                         "kenwood"              => 1569,
                         "kenwood1"             => 21619,
                         "kenworth"             => 2137,
                         "kenya1"               => 22560,
                         "kenzie"               => 6728,
                         "kerberos"             => 26758,
                         "kermit1"              => 9002,
                         "kernel"               => 4688,
                         "kernow"               => 27373,
                         "kerouac"              => 4682,
                         "kerry1"               => 17243,
                         "kestrel"              => 4808,
                         "ketamine"             => 21836,
                         "kevin1"               => 1665,
                         "kevin11"              => 27492,
                         "kevin12"              => 18638,
                         "kevin123"             => 7532,
                         "kevin2"               => 21636,
                         "kevin69"              => 25507,
                         "kevinb"               => 20211,
                         "kevinc"               => 22165,
                         "kevind"               => 28402,
                         "keving"               => 20069,
                         "kevinh"               => 26835,
                         "kevink"               => 19635,
                         "kevinm"               => 24192,
                         "kevinn"               => 27263,
                         "kevinr"               => 27380,
                         "kevins"               => 9768,
                         "kevlar"               => 11590,
                         "kewell"               => 27308,
                         "keyboard"             => 1496,
                         "keylargo"             => 20084,
                         "keyman"               => 21151,
                         "keystone"             => 1926,
                         "keywest"              => 2288,
                         "keywest1"             => 23606,
                         "kfcnjxrf"             => 7288,
                         "kfgecbr"              => 29697,
                         "kfgeirf"              => 29035,
                         "kfgekz"               => 13089,
                         "kfgjxrf"              => 4662,
                         "kfhbcf"               => 3655,
                         "kfnju842"             => 21639,
                         "kfvgjxrf"             => 11678,
                         "kfylsi"               => 13041,
                         "kgvebmqy"             => 26200,
                         "khaled"               => 11194,
                         "khalid"               => 9383,
                         "khalif"               => 27544,
                         "khongbiet"            => 28608,
                         "khorne"               => 14907,
                         "khushi"               => 21495,
                         "kiba1z"               => 26434,
                         "kiborg"               => 27767,
                         "kickass"              => 2407,
                         "kickass1"             => 15341,
                         "kickbutt"             => 22327,
                         "kicker"               => 1814,
                         "kicker1"              => 24044,
                         "kickflip"             => 7401,
                         "kickit"               => 11801,
                         "kickme"               => 13058,
                         "kicksass"             => 5882,
                         "kidman"               => 15614,
                         "kidrock"              => 3876,
                         "kieran"               => 4302,
                         "kierra"               => 24026,
                         "kikimora"             => 6455,
                         "kikiriki"             => 21029,
                         "kikker"               => 17639,
                         "kilbosik"             => 22457,
                         "kiler"                => 21892,
                         "kill666"              => 18273,
                         "killa"                => 5518,
                         "killa1"               => 13980,
                         "killabee"             => 17062,
                         "killah"               => 8318,
                         "killall"              => 12983,
                         "killas"               => 25111,
                         "killbill"             => 2263,
                         "kille"                => 4424,
                         "killem"               => 24146,
                         "killemal"             => 20263,
                         "killemall"            => 9958,
                         "killer"               => 35,
                         "killer00"             => 28566,
                         "killer01"             => 22154,
                         "killer1"              => 1763,
                         "killer11"             => 17882,
                         "killer12"             => 3638,
                         "killer123"            => 5205,
                         "killer13"             => 24673,
                         "killer2"              => 12701,
                         "killer23"             => 17891,
                         "killer66"             => 16121,
                         "killer666"            => 15501,
                         "killer69"             => 18736,
                         "killer7"              => 12104,
                         "killer77"             => 25005,
                         "killer99"             => 17416,
                         "killerb"              => 21861,
                         "killerbe"             => 15889,
                         "killerbee"            => 27341,
                         "killerman"            => 28146,
                         "killers"              => 3026,
                         "killians"             => 14380,
                         "killie"               => 14100,
                         "killit"               => 28039,
                         "killjoy"              => 3866,
                         "killme"               => 1936,
                         "killroy"              => 9177,
                         "killswit"             => 24385,
                         "killyou"              => 9807,
                         "killzone"             => 8180,
                         "kilroy"               => 3412,
                         "kils123"              => 19145,
                         "kim123"               => 15152,
                         "kimba"                => 16313,
                         "kimber1"              => 28288,
                         "kimber45"             => 14324,
                         "kimberl"              => 15050,
                         "kimberle"             => 12320,
                         "kimberly1"            => 18201,
                         "kimbo"                => 24115,
                         "kimbo1"               => 21926,
                         "kimchee"              => 14410,
                         "kimchi"               => 8700,
                         "kimmi"                => 28935,
                         "kimmie"               => 4015,
                         "kimmy"                => 8229,
                         "kimmy1"               => 13060,
                         "kimota"               => 21688,
                         "kindbud"              => 10742,
                         "kindbuds"             => 15127,
                         "king1"                => 13195,
                         "king10"               => 29826,
                         "king11"               => 28742,
                         "king12"               => 17287,
                         "king123"              => 10501,
                         "king1234"             => 15684,
                         "king69"               => 16146,
                         "king99"               => 23697,
                         "kingair"              => 10332,
                         "kingdom1"             => 16703,
                         "kinger"               => 13608,
                         "kingfish"             => 2318,
                         "kingfisher"           => 16706,
                         "kingkong"             => 1141,
                         "kinglear"             => 24906,
                         "kingme"               => 13099,
                         "kingpin"              => 1801,
                         "kingpins"             => 29517,
                         "kingrat"              => 26858,
                         "kingrich"             => 10166,
                         "kings1"               => 9702,
                         "kingshit"             => 28653,
                         "kingsize"             => 9077,
                         "kingss"               => 23829,
                         "kingston"             => 1589,
                         "kingsx"               => 13201,
                         "kingtut"              => 8490,
                         "kinkos"               => 15369,
                         "kinky"                => 2382,
                         "kinky1"               => 11403,
                         "kinkysex"             => 29995,
                         "kipelov"              => 18073,
                         "kipling"              => 11866,
                         "kipper"               => 2316,
                         "kipper1"              => 26875,
                         "kiran"                => 16602,
                         "kirby1"               => 8994,
                         "kirbys"               => 25345,
                         "kiril"                => 17056,
                         "kirill"               => 621,
                         "kirill123"            => 11116,
                         "kirpich"              => 25024,
                         "kirsten1"             => 22718,
                         "kirsty"               => 3653,
                         "kishore"              => 17008,
                         "kiska"                => 18032,
                         "kismet"               => 6328,
                         "kiss123"              => 27926,
                         "kissa"                => 25908,
                         "kissarmy"             => 14180,
                         "kissass"              => 14917,
                         "kisses"               => 1629,
                         "kissfan"              => 23893,
                         "kisska"               => 10599,
                         "kissme"               => 1052,
                         "kissme1"              => 20814,
                         "kissmyas"             => 6535,
                         "kissmyass"            => 3509,
                         "kissss"               => 13774,
                         "kissthis"             => 24110,
                         "kisulya"              => 28793,
                         "kitana"               => 12024,
                         "kitcat"               => 21884,
                         "kiteboy"              => 5309,
                         "kitkat"               => 1550,
                         "kitsune"              => 15473,
                         "kitte"                => 13866,
                         "kitten"               => 325,
                         "kitten1"              => 10718,
                         "kittens"              => 3835,
                         "kitties"              => 6843,
                         "kitty"                => 511,
                         "kitty1"               => 1988,
                         "kitty123"             => 9446,
                         "kitty2"               => 11418,
                         "kittycat"             => 1428,
                         "kittykat"             => 3049,
                         "kittykit"             => 24086,
                         "kittys"               => 5584,
                         "kiwi"                 => 5369,
                         "kjgfnf"               => 11822,
                         "kjifhf"               => 8497,
                         "kjiflm"               => 7536,
                         "kjiflrf"              => 16826,
                         "kjkbnf"               => 15310,
                         "kjkszpj"              => 3994,
                         "kjrjvjnbd"            => 4076,
                         "kki177hk"             => 28204,
                         "kkk666"               => 25083,
                         "kkkddd"               => 27504,
                         "kkkkk1"               => 12657,
                         "kkkkkk1"              => 17829,
                         "kkkkkkk1"             => 27244,
                         "kl?benhavn"           => 28211,
                         "klaatu"               => 7766,
                         "klapaucius"           => 21076,
                         "klaste"               => 4561,
                         "klaster"              => 55,
                         "klaudia"              => 8425,
                         "klaudia1"             => 23301,
                         "klaus1"               => 22483,
                         "klausi"               => 14062,
                         "kleaner"              => 22589,
                         "kleenex"              => 8603,
                         "klem1"                => 14595,
                         "kleopatra"            => 3179,
                         "klepto"               => 26386,
                         "klesko"               => 21740,
                         "klimenko"             => 13868,
                         "klimova"              => 21789,
                         "klingon"              => 2445,
                         "klingon1"             => 14083,
                         "klinker"              => 21582,
                         "klipsch"              => 18133,
                         "klizma"               => 5218,
                         "klondike"             => 5072,
                         "klootzak"             => 11113,
                         "klopik"               => 8629,
                         "klubnika"             => 21640,
                         "kluivert"             => 21348,
                         "kmdtyjr"              => 24989,
                         "kmfdm"                => 12229,
                         "kmfdm1"               => 23072,
                         "kmg365"               => 14963,
                         "kmn5hc"               => 24009,
                         "knarf"                => 10881,
                         "knickerless"          => 7283,
                         "knickers"             => 2613,
                         "knicks"               => 931,
                         "knicks1"              => 15611,
                         "knigh"                => 19001,
                         "knight1"              => 4959,
                         "knight12"             => 19331,
                         "knight99"             => 22787,
                         "knights"              => 1416,
                         "knights1"             => 20897,
                         "knobby"               => 16335,
                         "knocker"              => 11650,
                         "knockers"             => 3407,
                         "knopfler"             => 26169,
                         "knopka"               => 2154,
                         "knopo4ka"             => 22323,
                         "knothead"             => 29018,
                         "knotty"               => 20336,
                         "knowledg"             => 11295,
                         "knuckles"             => 4593,
                         "knuddel"              => 23116,
                         "knulla"               => 9658,
                         "koala"                => 8264,
                         "koala1"               => 19248,
                         "koalas"               => 28680,
                         "kobayash"             => 27618,
                         "kobe08"               => 9970,
                         "kobe24"               => 12782,
                         "kobebryant"           => 20355,
                         "kocham"               => 12489,
                         "kochamcie"            => 9526,
                         "kochanie"             => 10370,
                         "kociak"               => 27603,
                         "kodaira52"            => 14102,
                         "kodak"                => 8537,
                         "kodeord"              => 23249,
                         "kodiak"               => 719,
                         "kodiak1"              => 8462,
                         "koetsu13"             => 14385,
                         "koffie"               => 13319,
                         "kohsamui"             => 23848,
                         "koichi"               => 24931,
                         "kojak"                => 4661,
                         "kokain"               => 23509,
                         "kokaine"              => 29877,
                         "kokakola"             => 13350,
                         "kokanee"              => 15445,
                         "koketka"              => 25810,
                         "kokomo"               => 4703,
                         "kokot"                => 25178,
                         "koks888"              => 18662,
                         "kolawole"             => 26307,
                         "kolbasa"              => 5453,
                         "kolding"              => 23980,
                         "koldun"               => 18937,
                         "kolesnik"             => 20005,
                         "koleso"               => 7368,
                         "kolia123"             => 23526,
                         "kolibri"              => 8554,
                         "kolobok"              => 1435,
                         "kolokol"              => 5451,
                         "kolonka"              => 25850,
                         "kolort"               => 25663,
                         "kolosov"              => 25494,
                         "kolovrat"             => 17519,
                         "kolya"                => 14311,
                         "kolya1"               => 20193,
                         "kolyan"               => 12704,
                         "komarov"              => 27030,
                         "komarova"             => 15591,
                         "komatsu"              => 15202,
                         "kombat"               => 7518,
                         "komlos"               => 21202,
                         "komodo"               => 4134,
                         "kompas"               => 25020,
                         "komputer"             => 7151,
                         "kondom25"             => 16984,
                         "kondor"               => 14832,
                         "konfeta"              => 23685,
                         "konfetka"             => 10723,
                         "kongen"               => 12089,
                         "konica"               => 22265,
                         "konijn"               => 16982,
                         "konnichi"             => 25130,
                         "kononenko"            => 18348,
                         "konoplya"             => 29185,
                         "konovalov"            => 19993,
                         "konstantin"           => 4166,
                         "kontakt"              => 6746,
                         "kontiki"              => 27608,
                         "kontol"               => 6586,
                         "konyor"               => 7262,
                         "kookie"               => 7486,
                         "kool"                 => 2884,
                         "koolaid"              => 5214,
                         "koolhaas"             => 22010,
                         "koolio"               => 13158,
                         "koolkat"              => 29190,
                         "kordell1"             => 4669,
                         "koresh"               => 24715,
                         "korn"                 => 2596,
                         "kornet"               => 27188,
                         "korolev"              => 23858,
                         "koroleva"             => 4113,
                         "korona"               => 14875,
                         "korova"               => 4754,
                         "korsar"               => 17478,
                         "korvin"               => 17494,
                         "koshechka"            => 14788,
                         "koshka"               => 2183,
                         "koskesh"              => 24260,
                         "kosmos"               => 2742,
                         "kosova"               => 9183,
                         "kosssss"              => 25003,
                         "kosta1"               => 29818,
                         "kostas"               => 9314,
                         "kostik"               => 7523,
                         "kostya"               => 2479,
                         "kostyan"              => 19876,
                         "kot123"               => 21734,
                         "kotaku"               => 3346,
                         "koteczek"             => 16758,
                         "kotek1"               => 19350,
                         "kotenok"              => 1874,
                         "kotopes"              => 17053,
                         "kotova"               => 25904,
                         "kotton"               => 27236,
                         "koufax"               => 13074,
                         "koufax32"             => 29843,
                         "kourniko"             => 23099,
                         "kovalenko"            => 9431,
                         "kovalev"              => 17231,
                         "kozerog"              => 11299,
                         "kozlov"               => 11220,
                         "kozlova"              => 11637,
                         "kpcofgs"              => 27845,
                         "kpydskcw"             => 22220,
                         "kqigb7"               => 16576,
                         "kr9z40sy"             => 20144,
                         "kracker"              => 27958,
                         "krakatoa"             => 26197,
                         "kraken"               => 7190,
                         "kramer1"              => 10866,
                         "kramit"               => 26081,
                         "krasavica"            => 18483,
                         "krasnodar"            => 9515,
                         "krasota"              => 8015,
                         "krasotka"             => 4126,
                         "kratos"               => 10270,
                         "kravchenko"           => 25630,
                         "krayzie"              => 20746,
                         "krazy"                => 17228,
                         "kreator"              => 24736,
                         "kreker"               => 27798,
                         "kremlin"              => 10853,
                         "krille"               => 26163,
                         "krillin"              => 22248,
                         "krimml"               => 24826,
                         "kringle"              => 18074,
                         "krishn"               => 21515,
                         "krishna"              => 1727,
                         "krist"                => 22299,
                         "kristall"             => 21115,
                         "kriste"               => 12541,
                         "kristen1"             => 6575,
                         "kristie1"             => 29914,
                         "kristin1"             => 6192,
                         "kristina1"            => 23490,
                         "kristinka"            => 13276,
                         "kristjan"             => 13252,
                         "kristo"               => 24089,
                         "kristof"              => 27337,
                         "krokodil"             => 5092,
                         "krokus"               => 18083,
                         "krolik"               => 4782,
                         "krondor"              => 20612,
                         "kronik"               => 25108,
                         "kronos"               => 5177,
                         "kroshka"              => 12979,
                         "kruemel"              => 22309,
                         "krusty"               => 3820,
                         "krypto"               => 7572,
                         "krypton"              => 4030,
                         "krypton1"             => 28074,
                         "kryptoni"             => 19986,
                         "kryten"               => 13072,
                         "ksenia"               => 4843,
                         "kseniya"              => 7521,
                         "kstate"               => 16855,
                         "ksusha"               => 4739,
                         "kswbdu"               => 11408,
                         "kswiss"               => 16784,
                         "ksyusha"              => 27741,
                         "kthjxrf"              => 8670,
                         "ktjybl"               => 12539,
                         "ktm250"               => 24645,
                         "ktnj2010"             => 18114,
                         "ktr1996"              => 17490,
                         "ktrcec"               => 17185,
                         "ktutylf"              => 16030,
                         "ktybyuhfl"            => 17025,
                         "ktyecbr"              => 18790,
                         "ktyjxrf"              => 2351,
                         "ktyxbr"               => 16186,
                         "kuai"                 => 3508,
                         "kuan"                 => 6308,
                         "kuang"                => 3825,
                         "kubrick"              => 6429,
                         "kucing"               => 18504,
                         "kudos4ever"           => 27878,
                         "kugm7b"               => 14690,
                         "kukareku"             => 19865,
                         "kukolka"              => 9829,
                         "kukuruza"             => 11217,
                         "kukushka"             => 11507,
                         "kuleshov"             => 13413,
                         "kulikov"              => 24189,
                         "kulikova"             => 29227,
                         "kumar1"               => 17995,
                         "kumar123"             => 23974,
                         "kumari"               => 20623,
                         "kume"                 => 2244,
                         "kumiko"               => 23156,
                         "kumquat"              => 13245,
                         "kungen"               => 22008,
                         "kungfu"               => 2471,
                         "kuolema"              => 27964,
                         "kurama"               => 29716,
                         "kurgan"               => 20008,
                         "kurosaki"             => 10721,
                         "kurosawa"             => 22982,
                         "kurtcobain"           => 22563,
                         "kurupt"               => 22762,
                         "kurwamac"             => 20320,
                         "kusanagi"             => 11102,
                         "kutter"               => 29247,
                         "kuzmich"              => 20615,
                         "kuzmina"              => 22567,
                         "kvartira"             => 26820,
                         "kwiatek"              => 18669,
                         "kwiatuszek"           => 26410,
                         "kwiettie"             => 22344,
                         "kyjelly"              => 25896,
                         "kyle1"                => 21910,
                         "kyle123"              => 28863,
                         "kylie1"               => 20534,
                         "kyliem"               => 20620,
                         "kyocera"              => 22550,
                         "kzinti"               => 22036,
                         "kzkmrf"               => 24160,
                         "kzktxrf"              => 21281,
                         "kzsfj874"             => 21486,
                         "kzueirf"              => 16291,
                         "l0nd0n"               => 28270,
                         "l0swf9gx"             => 22802,
                         "l12345"               => 28635,
                         "l123456"              => 23215,
                         "l1750sq"              => 27475,
                         "l2g7k3"               => 11249,
                         "l3tm31n"              => 7237,
                         "l58jkdjp!"            => 7737,
                         "l8g3bkde"             => 11971,
                         "l8v53x"               => 14837,
                         "labamba"              => 19460,
                         "labatt"               => 8899,
                         "labatts"              => 14236,
                         "labia"                => 6931,
                         "labrador"             => 1715,
                         "labrat"               => 14395,
                         "labtec"               => 1807,
                         "lacey1"               => 14072,
                         "lachesis"             => 27650,
                         "lacoste"              => 6895,
                         "lacrimos"             => 24597,
                         "lacrimosa"            => 6995,
                         "lacrosse"             => 427,
                         "lactate"              => 24145,
                         "ladder1"              => 28328,
                         "laddie"               => 5138,
                         "ladeda"               => 26052,
                         "ladles"               => 9275,
                         "lady12"               => 19409,
                         "ladybird"             => 7653,
                         "ladyboy"              => 6797,
                         "ladybu"               => 22984,
                         "ladybug"              => 1121,
                         "ladybug1"             => 11025,
                         "ladydi"               => 18879,
                         "ladydog"              => 11393,
                         "ladyffesta"           => 17038,
                         "ladygaga"             => 9522,
                         "ladygirl"             => 21627,
                         "ladylove"             => 26547,
                         "ladyluck"             => 14712,
                         "laetitia"             => 5464,
                         "lafayett"             => 19807,
                         "lagarto"              => 17225,
                         "lager"                => 10230,
                         "lagers"               => 18426,
                         "lagnaf"               => 5340,
                         "laguna"               => 1775,
                         "lagwagon"             => 8218,
                         "laika"                => 20903,
                         "lainth88"             => 28228,
                         "lajolla"              => 19154,
                         "lakeland"             => 12333,
                         "laker"                => 7142,
                         "lakers"               => 137,
                         "lakers08"             => 27360,
                         "lakers1"              => 4915,
                         "lakers12"             => 19869,
                         "lakers24"             => 8223,
                         "lakers32"             => 11607,
                         "lakers34"             => 15739,
                         "lakers8"              => 16354,
                         "lakeshow"             => 20948,
                         "lakeside"             => 4713,
                         "laketaho"             => 26843,
                         "lakewood"             => 4946,
                         "lakings"              => 9228,
                         "lakota"               => 3089,
                         "lakshmi"              => 7059,
                         "lala123"              => 20471,
                         "lalakers"             => 4803,
                         "lalal"                => 14754,
                         "lalala1"              => 20041,
                         "lalaland"             => 9099,
                         "lalit"                => 25902,
                         "laluna"               => 23815,
                         "lambada"              => 14824,
                         "lambchop"             => 7454,
                         "lambda"               => 4482,
                         "lambert1"             => 27028,
                         "lambo1"               => 22546,
                         "lamborghini"          => 6974,
                         "lamborgini"           => 19962,
                         "lambrett"             => 15315,
                         "lament"               => 14834,
                         "lamer"                => 4334,
                         "lamers"               => 17280,
                         "lamerz"               => 25550,
                         "lamesa"               => 11685,
                         "lammas"               => 20372,
                         "lampard"              => 8123,
                         "lampoon"              => 16743,
                         "lancaste"             => 8473,
                         "lance1"               => 8286,
                         "lancelot"             => 1924,
                         "lancer"               => 930,
                         "lancer1"              => 15809,
                         "lancers"              => 13108,
                         "lances"               => 23837,
                         "lancia"               => 6144,
                         "landrove"             => 7299,
                         "landrover"            => 11655,
                         "landscap"             => 9962,
                         "lanesra"              => 26552,
                         "lanfear"              => 24010,
                         "lanman"               => 11457,
                         "lansing"              => 2020,
                         "lantern"              => 3677,
                         "lanzarot"             => 21887,
                         "laotzu"               => 25366,
                         "lapdance"             => 10026,
                         "lapin"                => 21181,
                         "lapo4ka"              => 28221,
                         "lapochka"             => 6512,
                         "lapper"               => 15522,
                         "laptop"               => 1885,
                         "laptop1"              => 27011,
                         "laputaxx"             => 19328,
                         "laracrof"             => 10096,
                         "laracroft"            => 8083,
                         "laranja"              => 29659,
                         "laredo"               => 10125,
                         "larina"               => 25270,
                         "larinso"              => 14802,
                         "larionov"             => 24315,
                         "larisa"               => 971,
                         "larkspur"             => 25969,
                         "larousse"             => 25938,
                         "larry1"               => 3747,
                         "larry123"             => 10843,
                         "larry33"              => 13019,
                         "larryb"               => 14773,
                         "larrybir"             => 19352,
                         "larrys"               => 11371,
                         "larrywn"              => 18108,
                         "larsson"              => 8371,
                         "laser"                => 2910,
                         "laser1"               => 6007,
                         "laser123"             => 28128,
                         "laserjet"             => 5944,
                         "lasers"               => 7712,
                         "lasombra"             => 15031,
                         "lasse"                => 26077,
                         "lassie"               => 3283,
                         "lastochka"            => 12981,
                         "lastone"              => 15513,
                         "lasttime"             => 8154,
                         "lasvega"              => 4271,
                         "lasvegas"             => 380,
                         "latching"             => 27850,
                         "latenite"             => 26368,
                         "lateralu"             => 20928,
                         "lateralus"            => 21207,
                         "latex"                => 8791,
                         "latics"               => 20073,
                         "latin1"               => 29758,
                         "latinas"              => 3337,
                         "latino"               => 1429,
                         "latinus"              => 27564,
                         "latrell"              => 29059,
                         "laura1"               => 3808,
                         "laura123"             => 17929,
                         "laura2"               => 25978,
                         "laurab"               => 21669,
                         "lauras"               => 9204,
                         "lauren1"              => 5516,
                         "lauren12"             => 27085,
                         "laurenc"              => 25303,
                         "laurent"              => 3443,
                         "laurita"              => 29825,
                         "lavalamp"             => 6180,
                         "lavanda"              => 21350,
                         "laverda"              => 26167,
                         "lawdog"               => 10753,
                         "lawina"               => 24136,
                         "lawman"               => 6346,
                         "lawnboy"              => 16123,
                         "lawncare"             => 20871,
                         "lawnmowe"             => 24631,
                         "lawntrax"             => 19521,
                         "lawrun"               => 16544,
                         "laxman"               => 10628,
                         "layla1"               => 25152,
                         "laz2937"              => 24508,
                         "lazarev"              => 27739,
                         "lazarus"              => 3549,
                         "lazer"                => 13919,
                         "lazer1"               => 25089,
                         "lazyacres"            => 19788,
                         "lback"                => 5146,
                         "lbfyjxrf"             => 10649,
                         "lbhtrnjh"             => 13951,
                         "lbpfqyth"             => 19775,
                         "lbtest"               => 7755,
                         "lbvekmrf"             => 27301,
                         "lbvekz"               => 13153,
                         "lbvfcbr"              => 23225,
                         "lbvjxrf"              => 7612,
                         "lbyfhf"               => 16044,
                         "lbyfvj"               => 12437,
                         "le33px"               => 25474,
                         "leachim"              => 22443,
                         "leader1"              => 19181,
                         "leadfoot"             => 20142,
                         "leafs"                => 8173,
                         "leafs1"               => 17472,
                         "leahcim"              => 8740,
                         "leapfrog"             => 17244,
                         "learjet"              => 8336,
                         "leather"              => 712,
                         "leather1"             => 22135,
                         "leavemealone"         => 2903,
                         "lebedev"              => 22999,
                         "lebedeva"             => 13772,
                         "lebowski"             => 5848,
                         "lebron23"             => 7916,
                         "lechat"               => 29567,
                         "lechef"               => 24360,
                         "ledzep"               => 1474,
                         "ledzeppe"             => 19864,
                         "ledzeppelin"          => 12942,
                         "lee123"               => 17795,
                         "leecher"              => 29994,
                         "leeds1"               => 9080,
                         "leedsu"               => 28559,
                         "leedsuni"             => 24925,
                         "leedsutd"             => 4540,
                         "leeloo"               => 7295,
                         "leeroy"               => 8058,
                         "leetch"               => 17026,
                         "left4dead"            => 5769,
                         "left4dead2"           => 21054,
                         "lefthand"             => 16630,
                         "leftie"               => 28405,
                         "lefty"                => 5427,
                         "lefty1"               => 15714,
                         "legacy"               => 1830,
                         "legalize"             => 18759,
                         "legend"               => 314,
                         "legend1"              => 13385,
                         "legenda"              => 6897,
                         "legends1"             => 28767,
                         "leghorn"              => 25813,
                         "legion"               => 1208,
                         "legion1"              => 24351,
                         "legioner"             => 19634,
                         "leglover"             => 12462,
                         "legman"               => 6207,
                         "legola"               => 22411,
                         "legoland"             => 9353,
                         "legolas"              => 1287,
                         "legolas1"             => 21229,
                         "legoman"              => 22899,
                         "legos"                => 6022,
                         "legs11"               => 25167,
                         "legsex"               => 13648,
                         "legshow"              => 27747,
                         "lehjxrf"              => 6689,
                         "leica"                => 21592,
                         "leiceste"             => 10468,
                         "leigh1"               => 22376,
                         "leinad"               => 5611,
                         "lekbyxxx"             => 17125,
                         "lekker"               => 4982,
                         "lektor"               => 24072,
                         "lemans"               => 5778,
                         "lemmein"              => 4813,
                         "lemming"              => 9041,
                         "lemmings"             => 8302,
                         "lemon1"               => 8092,
                         "lemonade"             => 4184,
                         "lemond"               => 9912,
                         "len2ski1"             => 18099,
                         "lena12"               => 27074,
                         "lena123"              => 11309,
                         "lena1982"             => 22240,
                         "lena2010"             => 17004,
                         "lenchik"              => 23617,
                         "leng"                 => 3083,
                         "lenina"               => 29565,
                         "lennart"              => 22675,
                         "lennon"               => 802,
                         "lennon1"              => 24843,
                         "lenny1"               => 16523,
                         "leno4ka"              => 9047,
                         "lenochka"             => 5032,
                         "lenovo"               => 13522,
                         "lenusik"              => 14454,
                         "leo123"               => 11355,
                         "leolion"              => 27499,
                         "leonard1"             => 13647,
                         "leonardo1"            => 29584,
                         "leones"               => 29045,
                         "leonid"               => 2656,
                         "leonidas"             => 6684,
                         "leonov"               => 24312,
                         "leopard"              => 1783,
                         "leopold"              => 4800,
                         "leppard"              => 19670,
                         "lepton"               => 13440,
                         "lero4ka"              => 21447,
                         "lerochka"             => 14817,
                         "leroy1"               => 8309,
                         "lerxst"               => 17905,
                         "lesbain"              => 7012,
                         "lesbean"              => 7503,
                         "lesbens"              => 8518,
                         "lesbia"               => 19663,
                         "lesbian"              => 839,
                         "lesbian1"             => 16998,
                         "lesbians"             => 1731,
                         "lesbo"                => 10913,
                         "lesbos"               => 7498,
                         "leshka"               => 26557,
                         "leslie1"              => 13318,
                         "lesnik"               => 19293,
                         "lespaul"              => 1898,
                         "lespaul1"             => 22521,
                         "lestat"               => 878,
                         "lestat1"              => 28389,
                         "lester1"              => 20158,
                         "letici"               => 24468,
                         "letitbe"              => 11262,
                         "letitrid"             => 11489,
                         "letme1n"              => 6678,
                         "letmego"              => 23910,
                         "letmei"               => 4630,
                         "letmein"              => 16,
                         "letmein0"             => 14291,
                         "letmein1"             => 685,
                         "letmein2"             => 1120,
                         "letmein22"            => 9502,
                         "letmein3"             => 17414,
                         "letmein4"             => 21670,
                         "letmein5"             => 28957,
                         "letmein6"             => 12394,
                         "letmein7"             => 13119,
                         "letmein9"             => 14873,
                         "letmeinn"             => 7340,
                         "letmeinnow"           => 12182,
                         "letmeino"             => 23455,
                         "letmeon"              => 27411,
                         "letmesee"             => 6903,
                         "leto2010"             => 19296,
                         "letsdoit"             => 5651,
                         "letsfuck"             => 6656,
                         "letsgo"               => 1643,
                         "letsplay"             => 8486,
                         "letssee"              => 29328,
                         "letterma"             => 24987,
                         "levani"               => 10258,
                         "level1"               => 21590,
                         "level42"              => 9635,
                         "levelone"             => 15538,
                         "levent"               => 29832,
                         "lever"                => 7832,
                         "leviatha"             => 13620,
                         "leviathan"            => 16235,
                         "lewie622"             => 21475,
                         "lewis1"               => 12706,
                         "lexicon"              => 10055,
                         "lexingky"             => 8965,
                         "lexingto"             => 11504,
                         "lexmark"              => 1523,
                         "lexmark1"             => 23212,
                         "lexus"                => 2990,
                         "lexus1"               => 7098,
                         "lexus300"             => 26058,
                         "lexusis"              => 27565,
                         "lexxus"               => 25960,
                         "lfdbl11"              => 18428,
                         "lfhbyf"               => 9901,
                         "lfiekmrf"             => 26028,
                         "lfiekz"               => 11538,
                         "lfitymrf"             => 5381,
                         "lfplhfgthvf"          => 19061,
                         "lfybbk"               => 4650,
                         "lfybkf"               => 6500,
                         "lfybkjd"              => 27691,
                         "lfybkrf"              => 10130,
                         "lfytxrf"              => 23136,
                         "lg2wmgvr"             => 22221,
                         "lgkp500"              => 29712,
                         "lgnu9d"               => 25429,
                         "lhbjkjubz2957704"     => 16572,
                         "lhepmz"               => 12877,
                         "lhfrjy"               => 5106,
                         "lian"                 => 6214,
                         "liang"                => 3391,
                         "liao"                 => 3488,
                         "libby1"               => 11573,
                         "libero"               => 5898,
                         "libert"               => 17091,
                         "liberta"              => 11662,
                         "libertad"             => 6480,
                         "liberte"              => 14232,
                         "libertin"             => 27829,
                         "liberty"              => 503,
                         "liberty1"             => 5658,
                         "liberty2"             => 21336,
                         "liberty7"             => 24313,
                         "libido"               => 7120,
                         "libra"                => 7534,
                         "libra1"               => 28961,
                         "libras"               => 21395,
                         "libtech"              => 22479,
                         "lichking"             => 25889,
                         "lick"                 => 1743,
                         "lickem"               => 10526,
                         "licker"               => 1307,
                         "lickher"              => 14926,
                         "licking"              => 3529,
                         "lickit"               => 1983,
                         "lickme"               => 750,
                         "lickme2"              => 26849,
                         "lickme69"             => 20022,
                         "lickpussy"            => 28120,
                         "licorice"             => 9142,
                         "lidiya"               => 23872,
                         "liebe"                => 18644,
                         "lieben"               => 19926,
                         "liebherr"             => 21773,
                         "liebling"             => 19996,
                         "liefde"               => 18904,
                         "lietuva"              => 14510,
                         "lieve27"              => 21387,
                         "lifeguar"             => 20501,
                         "lifehack"             => 348,
                         "lifeisgood"           => 8659,
                         "lifeson"              => 17893,
                         "lifestyl"             => 25402,
                         "lifesuck"             => 13512,
                         "lifesucks"            => 14276,
                         "lifesux"              => 23473,
                         "lifetec"              => 19500,
                         "lifter"               => 12453,
                         "ligeti"               => 24629,
                         "light1"               => 6367,
                         "lightbul"             => 17792,
                         "lighter"              => 3135,
                         "lightfoo"             => 22773,
                         "lighthou"             => 6663,
                         "lightman"             => 22683,
                         "lightnin"             => 1641,
                         "lightning"            => 2881,
                         "lights"               => 824,
                         "lights1"              => 16852,
                         "lightsab"             => 13421,
                         "lightsaber"           => 16673,
                         "lightspe"             => 28286,
                         "likeit"               => 11803,
                         "likeme"               => 27464,
                         "likemike"             => 19357,
                         "likesdick"            => 29547,
                         "likesit"              => 24896,
                         "likewhoa"             => 19651,
                         "lilbit"               => 5845,
                         "lilcrowe"             => 29529,
                         "lildevil"             => 15934,
                         "liliput"              => 23880,
                         "liliya"               => 5894,
                         "liljoe"               => 25770,
                         "liljon"               => 18761,
                         "lilkim"               => 14185,
                         "lilleke"              => 15553,
                         "lillian1"             => 26228,
                         "lillo"                => 24103,
                         "lilly1"               => 11277,
                         "lilmama"              => 27507,
                         "lilman"               => 7161,
                         "lilmike"              => 25844,
                         "lilone"               => 25755,
                         "lilred"               => 13626,
                         "lilwayne"             => 6233,
                         "limabean"             => 13636,
                         "limaperu"             => 12122,
                         "limewire"             => 5063,
                         "limpbizk"             => 14182,
                         "limpbizkit"           => 9269,
                         "limpdick"             => 19368,
                         "limpone"              => 9262,
                         "limpopo"              => 9364,
                         "lincol"               => 29055,
                         "lincoln1"             => 6893,
                         "lincoln2"             => 29616,
                         "lincoln7"             => 28337,
                         "linda1"               => 3068,
                         "linda123"             => 17321,
                         "lindaa"               => 14066,
                         "lindac"               => 28332,
                         "lindalou"             => 29381,
                         "lindam"               => 27554,
                         "lindas"               => 12020,
                         "lindros"              => 3674,
                         "lindros8"             => 22453,
                         "lindsay1"             => 8212,
                         "lindsey1"             => 8721,
                         "lineage"              => 4110,
                         "lineage2"             => 2328,
                         "lineman"              => 9621,
                         "lingus"               => 22486,
                         "linkin"               => 5375,
                         "linkinpark"           => 24224,
                         "linksys"              => 21141,
                         "linus"                => 7660,
                         "linus1"               => 18923,
                         "lion"                 => 2252,
                         "lioness"              => 7155,
                         "lionhear"             => 6851,
                         "lionheart"            => 6738,
                         "lionking"             => 2133,
                         "lions1"               => 12132,
                         "lionsden"             => 23818,
                         "lipper"               => 18340,
                         "lipton"               => 6225,
                         "liquid"               => 1388,
                         "lisa01"               => 16057,
                         "lisa1"                => 18478,
                         "lisa12"               => 22777,
                         "lisa123"              => 13353,
                         "lisa1234"             => 23034,
                         "lisa69"               => 9975,
                         "lisaann"              => 26312,
                         "lisamari"             => 19100,
                         "lisboa"               => 9665,
                         "lisenok"              => 7273,
                         "lisica"               => 26326,
                         "lisichka"             => 20388,
                         "listopad"             => 20660,
                         "litebeer"             => 25184,
                         "liten"                => 27199,
                         "liteon"               => 14806,
                         "litespee"             => 28717,
                         "lithium"              => 4083,
                         "lithium1"             => 18070,
                         "litle"                => 7287,
                         "little1"              => 4716,
                         "littleb"              => 25812,
                         "littlebear"           => 24747,
                         "littlebi"             => 10282,
                         "littlebit"            => 17495,
                         "littlebitch"          => 22542,
                         "littlebo"             => 17697,
                         "littledo"             => 21606,
                         "littlee"              => 13556,
                         "littlefuck"           => 27121,
                         "littlegi"             => 24551,
                         "littlegirl"           => 25292,
                         "littleguy"            => 29871,
                         "littlejo"             => 18415,
                         "littlema"             => 8089,
                         "littleman"            => 12356,
                         "littleminge"          => 27117,
                         "littleon"             => 13321,
                         "littleone"            => 22286,
                         "littlewhore"          => 25300,
                         "liudmila"             => 26721,
                         "liveevil"             => 15804,
                         "livefree"             => 26914,
                         "livelife"             => 6756,
                         "liveoak"              => 24012,
                         "liverp00l"            => 17378,
                         "liverpoo"             => 217,
                         "liverpool"            => 240,
                         "liverpool1"           => 4864,
                         "liverpoolfc"          => 22014,
                         "liverune"             => 12924,
                         "livestrong"           => 21551,
                         "livewire"             => 6755,
                         "liza2000"             => 22375,
                         "liza2009"             => 25864,
                         "lizard"               => 484,
                         "lizard1"              => 8636,
                         "lizaveta"             => 9999,
                         "liziko"               => 26993,
                         "lizottes"             => 23079,
                         "lizzard"              => 6292,
                         "lizzie1"              => 27655,
                         "lizzy"                => 5959,
                         "lizzy1"               => 18722,
                         "ljb4dt7n"             => 20003,
                         "ljcneg"               => 19027,
                         "ljhjuf"               => 21900,
                         "ljrnjh"               => 10067,
                         "ljxtymrf"             => 5980,
                         "lkjhgfdsaz"           => 15674,
                         "lkjhgfdsazx"          => 27897,
                         "llabesab"             => 29426,
                         "llama"                => 7697,
                         "llama1"               => 24658,
                         "llbean"               => 27737,
                         "llcoolj"              => 18284,
                         "llebpmac"             => 28934,
                         "lllll1"               => 13149,
                         "llllll1"              => 21067,
                         "lllllll1"             => 29840,
                         "lllooottt"            => 26681,
                         "lloo999"              => 28624,
                         "lloyd1"               => 16638,
                         "lloyds"               => 19565,
                         "lmfao"                => 20716,
                         "loader"               => 6856,
                         "lobito"               => 14606,
                         "lobo"                 => 5220,
                         "lobster"              => 1314,
                         "lobster1"             => 16359,
                         "lobzik"               => 28725,
                         "lochness"             => 13924,
                         "lockdown"             => 5695,
                         "lockedup"             => 27576,
                         "lockerroom"           => 7114,
                         "lockout"              => 6605,
                         "locksley"             => 29713,
                         "locksmit"             => 16104,
                         "loco"                 => 2786,
                         "locoman0"             => 11811,
                         "locust"               => 6565,
                         "locutus"              => 6468,
                         "locutus1"             => 29538,
                         "lodoss"               => 18774,
                         "logan1"               => 2864,
                         "logan123"             => 19029,
                         "logan2"               => 23385,
                         "logan5"               => 10661,
                         "logans"               => 24789,
                         "logcabin"             => 23446,
                         "logger"               => 5975,
                         "logging7"             => 22627,
                         "logica"               => 23031,
                         "login1"               => 27293,
                         "loginova"             => 20217,
                         "logistic"             => 14956,
                         "logitec"              => 15749,
                         "logitech"             => 566,
                         "logitech1"            => 20213,
                         "logjam"               => 29008,
                         "loglatin"             => 8419,
                         "logoff"               => 28893,
                         "logout"               => 28024,
                         "lohotron"             => 26898,
                         "loislane"             => 14983,
                         "loki"                 => 4718,
                         "lokiju"               => 20665,
                         "lokit"                => 28256,
                         "lokomoti"             => 25568,
                         "lokomotiv"            => 2615,
                         "lol12"                => 11835,
                         "lol123"               => 420,
                         "lol123123"            => 19974,
                         "lol1234"              => 9082,
                         "lol12345"             => 5804,
                         "lol123456"            => 20374,
                         "lolipop"              => 2343,
                         "lolit"                => 10868,
                         "lolita1"              => 23751,
                         "lolitas"              => 12832,
                         "lolkin09"             => 27713,
                         "loller"               => 22937,
                         "lollie"               => 24198,
                         "lollipo"              => 19365,
                         "lollipop"             => 1225,
                         "lollo"                => 11114,
                         "lollol"               => 1026,
                         "lollol1"              => 10533,
                         "lollol12"             => 27635,
                         "lollol123"            => 26822,
                         "lollone"              => 13797,
                         "lolly"                => 12283,
                         "lollypop"             => 3664,
                         "lolnoob"              => 24261,
                         "lolol"                => 5200,
                         "lololol"              => 8301,
                         "lololyo123"           => 19971,
                         "lolopc"               => 24727,
                         "loloxx"               => 8534,
                         "lolpop"               => 18025,
                         "lolwut"               => 9788,
                         "lommerse"             => 27891,
                         "lomond"               => 25106,
                         "lomonosov"            => 20466,
                         "londo"                => 5746,
                         "london"               => 134,
                         "london01"             => 25177,
                         "london1"              => 3893,
                         "london11"             => 15499,
                         "london12"             => 11196,
                         "london123"            => 27508,
                         "london2"              => 19900,
                         "london20"             => 17779,
                         "london22"             => 13993,
                         "london99"             => 14294,
                         "lonely1"              => 14187,
                         "lonesome"             => 5321,
                         "lonestar"             => 1464,
                         "lonewolf"             => 857,
                         "longball"             => 16844,
                         "longbeac"             => 11052,
                         "longbeach"            => 17661,
                         "longboar"             => 23663,
                         "longboard"            => 25780,
                         "longbow"              => 3899,
                         "longcut"              => 14675,
                         "longdick"             => 9624,
                         "longdong"             => 4333,
                         "longhair"             => 5624,
                         "longhorn"             => 829,
                         "longhorns"            => 8438,
                         "longjohn"             => 3924,
                         "longjump"             => 29868,
                         "longlegs"             => 9217,
                         "longlife"             => 17934,
                         "longman"              => 28683,
                         "longone"              => 13936,
                         "longshot"             => 7327,
                         "longtong"             => 22922,
                         "longview"             => 15670,
                         "longwood"             => 13572,
                         "lonsdale"             => 13720,
                         "lookatme"             => 12576,
                         "looker"               => 1847,
                         "looking1"             => 26090,
                         "looking4"             => 25652,
                         "lookout"              => 4935,
                         "looksee"              => 18706,
                         "lookup"               => 7827,
                         "loosee123"            => 21456,
                         "looser"               => 2448,
                         "lopas"                => 9307,
                         "lopas123"             => 17962,
                         "lopata"               => 8586,
                         "lopesk"               => 28622,
                         "lopez1"               => 21417,
                         "loploprock"           => 25296,
                         "lopotok01"            => 29155,
                         "loppol"               => 29365,
                         "loqse"                => 15028,
                         "loquit"               => 29066,
                         "loranthos"            => 22000,
                         "lordik"               => 18909,
                         "lordsoth"             => 21159,
                         "loreal"               => 16054,
                         "loredana"             => 9737,
                         "loreli"               => 25706,
                         "lorenzo1"             => 16652,
                         "lorien"               => 7366,
                         "lorna1"               => 26786,
                         "losangel"             => 7641,
                         "losangeles"           => 6677,
                         "losbravo"             => 24566,
                         "losenord"             => 21206,
                         "loser"                => 1101,
                         "loser1"               => 4856,
                         "loser123"             => 14470,
                         "loser2"               => 21068,
                         "losers"               => 2630,
                         "losfix16"             => 25217,
                         "loshara"              => 18076,
                         "lost4815162342"       => 11586,
                         "lostboy"              => 19602,
                         "lostboys"             => 26303,
                         "lostlove"             => 15720,
                         "lostone"              => 11516,
                         "lostsoul"             => 9750,
                         "lothar"               => 7711,
                         "lotrfotr34"           => 23379,
                         "lotus"                => 3143,
                         "lotus1"               => 7057,
                         "lotus123"             => 8588,
                         "lotus7"               => 13573,
                         "lou1988"              => 23298,
                         "loudog"               => 8808,
                         "louie1"               => 11826,
                         "louis1"               => 9611,
                         "louis123"             => 29661,
                         "louise1"              => 9058,
                         "louisian"             => 23450,
                         "loulo"                => 11405,
                         "love"                 => 66,
                         "love007"              => 29020,
                         "love01"               => 19003,
                         "love1"                => 2796,
                         "love11"               => 7996,
                         "love12"               => 3282,
                         "love123"              => 2495,
                         "love1234"             => 6114,
                         "love13"               => 11079,
                         "love14"               => 16976,
                         "love143"              => 12763,
                         "love15"               => 25545,
                         "love2"                => 11340,
                         "love20"               => 24701,
                         "love2000"             => 16782,
                         "love2010"             => 23436,
                         "love2011"             => 14484,
                         "love21"               => 12676,
                         "love22"               => 10750,
                         "love23"               => 11162,
                         "love24"               => 22543,
                         "love269"              => 20495,
                         "love3"                => 28664,
                         "love33"               => 17672,
                         "love4eve"             => 28859,
                         "love4ever"            => 12855,
                         "love4u"               => 13221,
                         "love4you"             => 24758,
                         "love55"               => 27534,
                         "love5683"             => 27026,
                         "love69"               => 2349,
                         "love77"               => 15365,
                         "love777"              => 13976,
                         "love88"               => 24637,
                         "love98"               => 28299,
                         "love99"               => 21084,
                         "loveable"             => 15011,
                         "lovebaby"             => 29777,
                         "lovebird"             => 13479,
                         "loveboat"             => 13204,
                         "lovebu"               => 28072,
                         "lovebug"              => 3594,
                         "lovebugs"             => 23657,
                         "lovecock"             => 19777,
                         "lovecraf"             => 11785,
                         "lovedick"             => 28011,
                         "loveee"               => 17235,
                         "lovefeet"             => 9276,
                         "loveforever"          => 20923,
                         "lovegame"             => 28365,
                         "lovegirl"             => 13525,
                         "lovegod"              => 9101,
                         "lovegun"              => 10471,
                         "lovehate"             => 6559,
                         "loveher"              => 17311,
                         "lovehina"             => 24730,
                         "lovehurt"             => 28051,
                         "lovehurts"            => 16204,
                         "loveis"               => 6662,
                         "loveislife"           => 17329,
                         "loveit"               => 1804,
                         "lovejone"             => 27814,
                         "lovel"                => 7787,
                         "lovelife"             => 4080,
                         "loveline"             => 28076,
                         "lovelov"              => 19427,
                         "lovely"               => 413,
                         "lovely1"              => 7720,
                         "lovem"                => 7693,
                         "loveman"              => 20673,
                         "loveme"               => 359,
                         "loveme1"              => 9120,
                         "loveme2"              => 11218,
                         "loveme89"             => 8875,
                         "loveone"              => 20025,
                         "loveporn"             => 12905,
                         "lovepuss"             => 25693,
                         "lovepussy"            => 11395,
                         "lover"                => 356,
                         "lover1"               => 2795,
                         "lover123"             => 27428,
                         "lover2"               => 15564,
                         "lover69"              => 10835,
                         "loverbo"              => 20188,
                         "loverboy"             => 647,
                         "lovergir"             => 15276,
                         "lovergirl"            => 22748,
                         "loverman"             => 5852,
                         "loverr"               => 15562,
                         "lovers"               => 265,
                         "lovesex"              => 2787,
                         "lovesexy"             => 9640,
                         "lovesme"              => 9335,
                         "lovesong"             => 21183,
                         "lovespor"             => 22907,
                         "lovesporn"            => 15054,
                         "lovess"               => 24874,
                         "lovestory"            => 14406,
                         "lovesuck"             => 23779,
                         "lovesyou"             => 18966,
                         "lovethem"             => 24161,
                         "lovetits"             => 12340,
                         "loveu"                => 14419,
                         "loveu2"               => 12916,
                         "loveya"               => 4948,
                         "loveyo"               => 12900,
                         "loveyou"              => 518,
                         "loveyou1"             => 9104,
                         "loveyou2"             => 8776,
                         "lovezp1314"           => 25067,
                         "lovinit"              => 27416,
                         "lowboy"               => 17668,
                         "lowdown"              => 9638,
                         "lowkey"               => 22425,
                         "lowrider"             => 1475,
                         "loyola"               => 7075,
                         "lozinka"              => 26882,
                         "lp2568cskt"           => 20033,
                         "lsdlsd12"             => 16690,
                         "lsia9dnb9y"           => 17696,
                         "lsutiger"             => 12257,
                         "ltcnhjth"             => 21704,
                         "ltdjxrf"              => 9234,
                         "lth1108"              => 29104,
                         "lthgfhjkm"            => 12202,
                         "lthtdj"               => 12016,
                         "lthtdyz"              => 18873,
                         "ltkmaby"              => 6375,
                         "ltleirf"              => 15385,
                         "ltybcjdf"             => 22551,
                         "ltybcrf"              => 3308,
                         "ltymub"               => 7598,
                         "luan"                 => 3230,
                         "luansantana"          => 26463,
                         "lubimaya"             => 26339,
                         "lubimka"              => 25911,
                         "luca"                 => 4497,
                         "lucas1"               => 5592,
                         "lucas12"              => 23278,
                         "lucas123"             => 9560,
                         "lucent"               => 8216,
                         "lucian"               => 7444,
                         "lucidity"             => 29130,
                         "lucifer"              => 784,
                         "lucifer1"             => 12948,
                         "lucifer666"           => 20887,
                         "luckie"               => 8311,
                         "luckies"              => 21005,
                         "lucky"                => 282,
                         "lucky1"               => 470,
                         "lucky12"              => 17714,
                         "lucky123"             => 6388,
                         "lucky13"              => 2209,
                         "lucky2"               => 9725,
                         "lucky3"               => 13134,
                         "lucky4"               => 28518,
                         "lucky5"               => 14858,
                         "lucky6"               => 22774,
                         "lucky69"              => 19795,
                         "lucky7"               => 1389,
                         "lucky777"             => 9494,
                         "lucky8"               => 19908,
                         "lucky9"               => 21279,
                         "lucky99"              => 24169,
                         "luckyboy"             => 10636,
                         "luckycat"             => 16389,
                         "luckycharm"           => 19925,
                         "luckydog"             => 1852,
                         "luckyman"             => 9076,
                         "luckyme"              => 7020,
                         "luckyone"             => 5470,
                         "luckys"               => 7385,
                         "luckystr"             => 27450,
                         "luckyy"               => 28641,
                         "lucozade"             => 24581,
                         "lucy1"                => 26999,
                         "lucy11"               => 27271,
                         "lucycat"              => 24680,
                         "lucydog"              => 12444,
                         "lucylu"               => 17268,
                         "ludacris"             => 6899,
                         "ludic"                => 27825,
                         "ludmila"              => 2972,
                         "ludmilla"             => 22800,
                         "ludovic"              => 16806,
                         "luebri"               => 13309,
                         "luetdi"               => 20110,
                         "luft4"                => 12526,
                         "lugano"               => 8430,
                         "lugnut"               => 9425,
                         "luigi1"               => 23402,
                         "luis1"                => 22054,
                         "luisito"              => 14085,
                         "lukas1"               => 25299,
                         "lukas123"             => 28160,
                         "lukasz"               => 21455,
                         "luke1"                => 16214,
                         "lumber"               => 3890,
                         "lumina"               => 5537,
                         "lumpy"                => 9075,
                         "lumpy1"               => 18856,
                         "lunar2"               => 29601,
                         "lunchbox"             => 5895,
                         "luners"               => 23183,
                         "lunita"               => 15173,
                         "lunker"               => 16251,
                         "luntik"               => 15307,
                         "luojianhua"           => 14943,
                         "lupine"               => 18530,
                         "lurker"               => 18720,
                         "luscious"             => 8396,
                         "lust"                 => 3073,
                         "lustful"              => 11554,
                         "lusty"                => 9004,
                         "luthien"              => 16739,
                         "luton1"               => 26859,
                         "lutscher"             => 23092,
                         "luv269"               => 21136,
                         "luv2epus"             => 8840,
                         "luv2fuck"             => 15086,
                         "luvbekki"             => 25831,
                         "luvbug"               => 14438,
                         "luvfur"               => 12630,
                         "luvpussy"             => 16174,
                         "luvsex"               => 24755,
                         "lux2000"              => 7443,
                         "luxor"                => 20942,
                         "luzern"               => 11431,
                         "luzifer"              => 20976,
                         "lvbnhbq"              => 1293,
                         "lvbnhbq1"             => 15872,
                         "lvbnhbtdf"            => 28545,
                         "lvjdp383"             => 17756,
                         "lydia1"               => 29037,
                         "lysander"             => 15136,
                         "lytdybr"              => 23141,
                         "lytghjgtnhjdcr"       => 23912,
                         "lyubov"               => 19732,
                         "lyudmila"             => 12317,
                         "lzbs2twz"             => 13998,
                         "lzhan16889"           => 26030,
                         "lzlzdfcz"             => 29294,
                         "m0b1l3"               => 21152,
                         "m0nk3y"               => 8589,
                         "m0nkey"               => 7607,
                         "m0rn3"                => 16575,
                         "m12345"               => 7375,
                         "m123456"              => 5098,
                         "m1234567"             => 13878,
                         "m123456789"           => 29385,
                         "m1911a1"              => 16227,
                         "m1chael"              => 17439,
                         "m1garand"             => 18645,
                         "m1sf1t"               => 14884,
                         "m5wkqf"               => 12208,
                         "m69fg1w"              => 18056,
                         "m69fg2w"              => 15441,
                         "m6cjy69u35"           => 13765,
                         "m7hsqstm"             => 22612,
                         "m7n56xo"              => 27855,
                         "m_roesel"             => 29389,
                         "ma123123123"          => 28865,
                         "maandag"              => 24391,
                         "maarten"              => 18778,
                         "maasikas"             => 26417,
                         "mac123"               => 13967,
                         "macabre"              => 21072,
                         "macaco"               => 6929,
                         "macanudo"             => 17640,
                         "macarena"             => 12370,
                         "macaroni"             => 6092,
                         "macbeth"              => 4123,
                         "macbook"              => 27882,
                         "maccom"               => 29109,
                         "macdad"               => 28821,
                         "macdaddy"             => 1963,
                         "macdog"               => 29519,
                         "macdonal"             => 20823,
                         "macduff"              => 12909,
                         "macgyver"             => 6805,
                         "mach1"                => 15396,
                         "machina"              => 22754,
                         "machine"              => 819,
                         "machine1"             => 13379,
                         "machoman"             => 8517,
                         "maciek"               => 8354,
                         "macintos"             => 5873,
                         "macintosh"            => 8242,
                         "mack10"               => 10361,
                         "mackdad"              => 19059,
                         "mackdadd"             => 16363,
                         "mackdaddy"            => 21314,
                         "mackenzi"             => 7777,
                         "macker"               => 19829,
                         "macman"               => 4572,
                         "macondo"              => 28206,
                         "macros"               => 11204,
                         "macross"              => 2330,
                         "macross1"             => 27770,
                         "macross7"             => 25603,
                         "macsan26"             => 17051,
                         "madagaskar"           => 5850,
                         "madala11"             => 7086,
                         "madalena"             => 28066,
                         "madalina"             => 22070,
                         "madarchod"            => 27742,
                         "madball"              => 12914,
                         "madcap"               => 17546,
                         "madcat"               => 4247,
                         "madcow"               => 6137,
                         "maddawg"              => 24982,
                         "maddie"               => 892,
                         "maddie1"              => 14342,
                         "maddison"             => 8651,
                         "maddmaxx"             => 19713,
                         "maddo"                => 19835,
                         "maddog"               => 266,
                         "maddog01"             => 29231,
                         "maddog1"              => 11482,
                         "maddog69"             => 25245,
                         "maddy1"               => 14654,
                         "madeira"              => 12329,
                         "madelein"             => 15206,
                         "madhatte"             => 19485,
                         "madhatter"            => 25470,
                         "madhouse"             => 11858,
                         "madhu"                => 22209,
                         "madhuri"              => 17359,
                         "madina"               => 3110,
                         "madinina"             => 27537,
                         "madiso"               => 9274,
                         "madison"              => 197,
                         "madison0"             => 20766,
                         "madison1"             => 2545,
                         "madison2"             => 14240,
                         "madison3"             => 19942,
                         "madison9"             => 19573,
                         "madlen"               => 29948,
                         "madma"                => 22018,
                         "madman"               => 828,
                         "madman1"              => 28363,
                         "madmax"               => 675,
                         "madmax1"              => 24941,
                         "madmax11"             => 28163,
                         "madmike"              => 19497,
                         "madnes"               => 25999,
                         "madness"              => 1099,
                         "madness1"             => 21770,
                         "madoka"               => 10706,
                         "madona"               => 12584,
                         "madone"               => 18215,
                         "madonn"               => 11587,
                         "madonna"              => 575,
                         "madonna1"             => 6997,
                         "madri"                => 16439,
                         "maduro"               => 16465,
                         "madzia"               => 12818,
                         "maersk"               => 25042,
                         "maestro"              => 1336,
                         "maestro1"             => 25123,
                         "mafia"                => 5992,
                         "mafia1"               => 29593,
                         "mafioso"              => 22104,
                         "magadan"              => 7706,
                         "magal"                => 29786,
                         "maganda"              => 8018,
                         "magazin"              => 13329,
                         "magda1"               => 12614,
                         "magelan"              => 3923,
                         "magellan"             => 4858,
                         "magenta"              => 6577,
                         "maggi"                => 4240,
                         "maggie"               => 60,
                         "maggie1"              => 3356,
                         "maggie11"             => 13698,
                         "maggie12"             => 16294,
                         "maggie2"              => 13500,
                         "maggiema"             => 14982,
                         "maggot"               => 2749,
                         "maggy"                => 14771,
                         "magic"                => 326,
                         "magic1"               => 1171,
                         "magic123"             => 6540,
                         "magic2"               => 23838,
                         "magic32"              => 5102,
                         "magic69"              => 26891,
                         "magic7"               => 26107,
                         "magica"               => 14176,
                         "magical1"             => 28691,
                         "magical123"           => 22108,
                         "magichat"             => 28276,
                         "magician"             => 3560,
                         "magick"               => 2358,
                         "magicman"             => 2433,
                         "magicone"             => 29511,
                         "magics"               => 8390,
                         "magik"                => 29540,
                         "magister"             => 13423,
                         "magistr"              => 19588,
                         "magnat"               => 18905,
                         "magnavox"             => 9259,
                         "magnet"               => 3964,
                         "magneto"              => 4708,
                         "magnit"               => 24920,
                         "magnoli"              => 28921,
                         "magnu"                => 22063,
                         "magnum"               => 424,
                         "magnum1"              => 16672,
                         "magnus"               => 1630,
                         "magnus1"              => 21878,
                         "magomed"              => 15208,
                         "magoo"                => 7494,
                         "magoo1"               => 19329,
                         "magpie"               => 2651,
                         "magpies"              => 4781,
                         "magpies1"             => 19735,
                         "magritte"             => 29872,
                         "magyar"               => 10647,
                         "mahal"                => 9010,
                         "mahalkit"             => 13949,
                         "mahalkita"            => 8084,
                         "mahalko"              => 10752,
                         "mahalo"               => 7442,
                         "mahesh"               => 13549,
                         "mahina"               => 28696,
                         "maiden"               => 1006,
                         "maiden1"              => 14326,
                         "mailcreated5240"      => 1516,
                         "mailliw"              => 27483,
                         "mailman"              => 1970,
                         "mailman1"             => 20737,
                         "mailru"               => 6810,
                         "mailto"               => 12971,
                         "maine1"               => 14284,
                         "mainman"              => 13033,
                         "mainstre"             => 28335,
                         "maint"                => 27816,
                         "maison"               => 5900,
                         "maitai"               => 17422,
                         "maiyeuem"             => 21661,
                         "majere"               => 12885,
                         "majestic"             => 2307,
                         "majick"               => 21173,
                         "majik"                => 21984,
                         "majinbuu"             => 18069,
                         "major1"               => 8615,
                         "majortom"             => 18361,
                         "makaka"               => 5725,
                         "makalu"               => 29160,
                         "makarenko"            => 22997,
                         "makarov"              => 9472,
                         "makarova"             => 11134,
                         "makavel"              => 27936,
                         "makaveli"             => 1242,
                         "makayla"              => 5919,
                         "makeit"               => 24621,
                         "makeitso"             => 6474,
                         "makeksa11"            => 14969,
                         "makelove"             => 13555,
                         "makeme"               => 16581,
                         "makemone"             => 10940,
                         "makemoney"            => 10368,
                         "makenna"              => 27911,
                         "makenzie"             => 28251,
                         "makita"               => 13212,
                         "makoto"               => 9615,
                         "maks123"              => 23434,
                         "maks2010"             => 25528,
                         "maks5843"             => 29611,
                         "maksat"               => 23062,
                         "maksik"               => 12075,
                         "maksim"               => 666,
                         "maksimka"             => 3584,
                         "maksimus"             => 14691,
                         "maktub"               => 24957,
                         "malachi"              => 4376,
                         "malacon"              => 28783,
                         "malaga"               => 8750,
                         "malaika"              => 14784,
                         "malaka"               => 2272,
                         "malaka1"              => 29270,
                         "malakas"              => 8253,
                         "malaki"               => 29603,
                         "malamute"             => 12390,
                         "malboro"              => 20070,
                         "malcolm1"             => 9874,
                         "malcolmx"             => 24406,
                         "maldini"              => 11696,
                         "malibog"              => 14193,
                         "malibu"               => 849,
                         "malibu1"              => 15839,
                         "malice"               => 4505,
                         "malik1"               => 19405,
                         "malina"               => 2451,
                         "malinka"              => 6615,
                         "malinois"             => 22368,
                         "malish"               => 5776,
                         "malishka"             => 10860,
                         "malkav"               => 16967,
                         "mallard"              => 1567,
                         "mallard1"             => 15371,
                         "mallards"             => 27644,
                         "mallorca"             => 5504,
                         "mallrats"             => 6023,
                         "malvin"               => 22319,
                         "malyshka"             => 26358,
                         "mama11"               => 21418,
                         "mama12"               => 15277,
                         "mama123"              => 4069,
                         "mama1234"             => 12618,
                         "mama12345"            => 23959,
                         "mama1961"             => 24537,
                         "mama1963"             => 21129,
                         "mama1964"             => 26468,
                         "mama1970"             => 27950,
                         "mama2010"             => 20433,
                         "mama22"               => 29078,
                         "mama777"              => 26865,
                         "mamabear"             => 14339,
                         "mamacita"             => 5054,
                         "mamada"               => 26233,
                         "mamadou"              => 25316,
                         "mamaliga"             => 25980,
                         "mamamia"              => 4582,
                         "maman"                => 14472,
                         "mamapap"              => 25388,
                         "mamapapa"             => 2474,
                         "mamas"                => 5983,
                         "mamasboy"             => 26243,
                         "mamasita"             => 11673,
                         "mamatata"             => 28880,
                         "mambo"                => 10851,
                         "mamedov"              => 10650,
                         "mamit"                => 11099,
                         "mamita"               => 8962,
                         "mamiya"               => 27995,
                         "mamma1"               => 26258,
                         "mamma123"             => 25515,
                         "mammamia"             => 9391,
                         "mammoth"              => 6210,
                         "mammoth1"             => 20649,
                         "mammy"                => 23744,
                         "mamo4ka"              => 8148,
                         "mamochka"             => 6562,
                         "mamon"                => 20029,
                         "mamont"               => 8051,
                         "mamou"                => 29866,
                         "mamuka"               => 13127,
                         "mamula"               => 24764,
                         "mamulya"              => 14147,
                         "mamusia"              => 24271,
                         "man123"               => 10481,
                         "manageme"             => 26514,
                         "manager1"             => 7147,
                         "managua"              => 15345,
                         "manana"               => 9873,
                         "manara"               => 28789,
                         "manatee"              => 7782,
                         "manchest"             => 1966,
                         "mancheste"            => 13655,
                         "manchester"           => 987,
                         "manchester1"          => 25995,
                         "manchild"             => 21416,
                         "mancity"              => 3288,
                         "mancity1"             => 19031,
                         "mancow"               => 18952,
                         "mandarin"             => 3172,
                         "mandarinka"           => 24918,
                         "mander"               => 15249,
                         "manders"              => 7937,
                         "mandingo"             => 1869,
                         "mandog"               => 29195,
                         "mandolin"             => 8812,
                         "mandragora"           => 19275,
                         "mandrake"             => 4912,
                         "mandreki"             => 22382,
                         "mandy1"               => 3794,
                         "mandy123"             => 17392,
                         "mandys"               => 19375,
                         "manfred"              => 4470,
                         "mang"                 => 3980,
                         "manga1"               => 19487,
                         "mangas"               => 16557,
                         "mango"                => 3193,
                         "mango1"               => 8292,
                         "mangoes"              => 23047,
                         "mangos"               => 5985,
                         "mangust6403"          => 18620,
                         "manhatta"             => 7467,
                         "mania"                => 10108,
                         "maniac"               => 1245,
                         "maniak"               => 14810,
                         "manics"               => 17880,
                         "maniek"               => 24862,
                         "manimal"              => 23242,
                         "manish"               => 10362,
                         "manisha"              => 13458,
                         "manitou"              => 10755,
                         "mankind"              => 3917,
                         "mankind1"             => 27197,
                         "mannheim"             => 7146,
                         "manni"                => 18100,
                         "mannie"               => 14932,
                         "manning1"             => 17113,
                         "manning18"            => 27550,
                         "mannn"                => 8978,
                         "manny1"               => 13958,
                         "manol"                => 19508,
                         "manolito"             => 18986,
                         "manolo"               => 4021,
                         "manoman"              => 21359,
                         "manon"                => 17769,
                         "manowar"              => 3051,
                         "mansfiel"             => 24175,
                         "mansikka"             => 25647,
                         "manso"                => 17470,
                         "manson"               => 945,
                         "manstein"             => 19342,
                         "mansur"               => 10119,
                         "manta"                => 13285,
                         "mantaray"             => 25857,
                         "mantas"               => 19171,
                         "manteca"              => 28607,
                         "mantis"               => 3264,
                         "mantle"               => 5888,
                         "mantle7"              => 21509,
                         "mantra"               => 6538,
                         "manu"                 => 6423,
                         "manuals"              => 8076,
                         "manue"                => 7886,
                         "manuel1"              => 18205,
                         "manunite"             => 11584,
                         "manunited"            => 6362,
                         "manut"                => 28672,
                         "manutd"               => 637,
                         "manutd1"              => 26974,
                         "manwhore"             => 11743,
                         "manyak"               => 16553,
                         "manzana"              => 11660,
                         "mapet123456"          => 9175,
                         "maplelea"             => 12835,
                         "mapleleafs"           => 21697,
                         "mapper"               => 21459,
                         "maprchem56458"        => 24914,
                         "maraca"               => 27076,
                         "maradon"              => 18578,
                         "maradona"             => 2089,
                         "marajade"             => 7499,
                         "marakesh"             => 20526,
                         "maral"                => 20668,
                         "maranell"             => 21806,
                         "maranello"            => 21996,
                         "marantz"              => 27152,
                         "marat"                => 8451,
                         "marathon"             => 984,
                         "maratik"              => 20791,
                         "marauder"             => 6127,
                         "marbella"             => 11222,
                         "marbles"              => 5619,
                         "marcelin"             => 28319,
                         "marcelit"             => 23886,
                         "marcello"             => 3657,
                         "march1"               => 13137,
                         "march11"              => 24249,
                         "march13"              => 9211,
                         "march14"              => 29027,
                         "march15"              => 24264,
                         "march17"              => 25007,
                         "march2"               => 21879,
                         "march23"              => 27659,
                         "marchenko"            => 21120,
                         "marcia1"              => 24860,
                         "marcin"               => 5910,
                         "marcin1"              => 24327,
                         "marcio"               => 14411,
                         "marcius2"             => 4929,
                         "marco1"               => 8771,
                         "marco123"             => 28044,
                         "marcopol"             => 12093,
                         "marcopolo"            => 14407,
                         "marcos1"              => 26338,
                         "marcu"                => 19458,
                         "marcus1"              => 9340,
                         "marcus12"             => 23653,
                         "marcus2"              => 24536,
                         "mardigra"             => 19124,
                         "marduk"               => 10013,
                         "maremma"              => 25448,
                         "margare"              => 20123,
                         "margaret1"            => 23633,
                         "margarit"             => 4478,
                         "margaux"              => 8918,
                         "marge1"               => 26298,
                         "margera"              => 23718,
                         "margo1"               => 17195,
                         "margosha"             => 9664,
                         "marhaba"              => 29757,
                         "maria1"               => 2917,
                         "maria12"              => 24339,
                         "maria123"             => 10934,
                         "maria2"               => 18024,
                         "maria3"               => 27057,
                         "maria6"               => 12470,
                         "mariachi"             => 14961,
                         "mariajos"             => 15679,
                         "marial"               => 26934,
                         "mariami"              => 25164,
                         "mariana1"             => 25456,
                         "marias"               => 13096,
                         "maribe"               => 11443,
                         "maricon"              => 10875,
                         "marie1"               => 4939,
                         "marie123"             => 19805,
                         "marie2"               => 20957,
                         "maries"               => 19838,
                         "marigold"             => 9081,
                         "marihuana"            => 22340,
                         "marija"               => 15750,
                         "marijuan"             => 5074,
                         "marijuana"            => 4681,
                         "marika"               => 3161,
                         "marilena"             => 20561,
                         "marillio"             => 11244,
                         "marillion"            => 27861,
                         "marilyn1"             => 15761,
                         "marimar"              => 28814,
                         "marimba"              => 11339,
                         "marina"               => 122,
                         "marina1"              => 8080,
                         "marina123"            => 17802,
                         "marine"               => 173,
                         "marine1"              => 3149,
                         "marine21"             => 29834,
                         "mariner"              => 5331,
                         "mariner1"             => 19396,
                         "mariners"             => 1605,
                         "marines"              => 553,
                         "marines1"             => 4254,
                         "marinka"              => 7950,
                         "marino"               => 966,
                         "marino1"              => 25699,
                         "marino13"             => 2462,
                         "marinus"              => 27764,
                         "mario1"               => 4512,
                         "mario12"              => 24676,
                         "mario123"             => 17720,
                         "mario5"               => 22814,
                         "mario64"              => 23857,
                         "mario66"              => 6275,
                         "marion1"              => 29218,
                         "marios"               => 12278,
                         "maripos"              => 8374,
                         "mariposa"             => 3644,
                         "marishka"             => 7546,
                         "mariska"              => 22941,
                         "mariso"               => 12552,
                         "marissa1"             => 11684,
                         "marit"                => 15143,
                         "mariupol"             => 24897,
                         "marius"               => 2607,
                         "mariusz"              => 18381,
                         "mariya"               => 4848,
                         "marjan"               => 11260,
                         "mark01"               => 21061,
                         "mark1"                => 6542,
                         "mark11"               => 22033,
                         "mark12"               => 13146,
                         "mark123"              => 7917,
                         "mark1234"             => 12217,
                         "mark13"               => 25994,
                         "mark22"               => 12290,
                         "mark3434"             => 25887,
                         "mark69"               => 15001,
                         "marker"               => 3401,
                         "marketin"             => 8202,
                         "markhegarty"          => 19211,
                         "markie"               => 4974,
                         "markis"               => 29951,
                         "markiz"               => 4204,
                         "markiza"              => 8045,
                         "markos"               => 14483,
                         "markova"              => 17339,
                         "markp"                => 24246,
                         "markus1"              => 22442,
                         "marky"                => 11479,
                         "marky1"               => 28558,
                         "marlbor"              => 17409,
                         "marlboro"             => 176,
                         "marlboro1"            => 20218,
                         "marle"                => 16405,
                         "marley"               => 509,
                         "marley1"              => 7438,
                         "marley12"             => 24497,
                         "marlin1"              => 18689,
                         "marlins"              => 7338,
                         "marlins1"             => 25173,
                         "marma"                => 10010,
                         "marmalad"             => 24465,
                         "marmaris"             => 27506,
                         "marmelad"             => 14209,
                         "marmite"              => 7992,
                         "marmot"               => 13240,
                         "marocas"              => 28507,
                         "maroon"               => 9534,
                         "maroon5"              => 20847,
                         "marquise"             => 24298,
                         "married1"             => 20672,
                         "marryher"             => 19403,
                         "marryme"              => 22314,
                         "marsbar"              => 17627,
                         "marseill"             => 4857,
                         "marseille"            => 4382,
                         "marsel"               => 7571,
                         "marshal1"             => 23879,
                         "marsik"               => 9536,
                         "marta1"               => 12251,
                         "martesana"            => 18028,
                         "martha1"              => 22846,
                         "marthe"               => 23294,
                         "martian"              => 6498,
                         "martie"               => 20784,
                         "martijn"              => 27494,
                         "martin01"             => 27785,
                         "martin1"              => 2633,
                         "martin11"             => 18037,
                         "martin12"             => 12997,
                         "martin2"              => 15468,
                         "martin6"              => 8924,
                         "martin7"              => 16591,
                         "martina1"             => 14139,
                         "martinet"             => 28151,
                         "martini"              => 1237,
                         "martini1"             => 11303,
                         "martusia"             => 21193,
                         "marty1"               => 6675,
                         "martyn"               => 12466,
                         "martyna"              => 17368,
                         "maruni"               => 22306,
                         "marusa"               => 19791,
                         "marusia"              => 12806,
                         "marusya"              => 8761,
                         "marvi"                => 18630,
                         "marvin1"              => 8350,
                         "marwan"               => 19626,
                         "mary1"                => 24725,
                         "mary69"               => 25651,
                         "maryann1"             => 23937,
                         "maryjan"              => 28351,
                         "maryjane"             => 462,
                         "maryjoy"              => 17194,
                         "marykate"             => 22450,
                         "marykay"              => 9021,
                         "marysia"              => 15443,
                         "marzena"              => 20569,
                         "masahiro"             => 14049,
                         "masaki"               => 12475,
                         "masami"               => 20166,
                         "masamune"             => 3641,
                         "mascha"               => 24202,
                         "maserati"             => 5166,
                         "mash4077"             => 5123,
                         "masha"                => 8208,
                         "masha1"               => 22630,
                         "masha123"             => 15141,
                         "masha1998"            => 21526,
                         "mashamasha"           => 24856,
                         "mashenka"             => 17956,
                         "masher"               => 15426,
                         "mashina"              => 10021,
                         "mashka"               => 6414,
                         "mashoutq"             => 23587,
                         "masiania"             => 26728,
                         "maslova"              => 28287,
                         "mason1"               => 3579,
                         "mason123"             => 17052,
                         "masons"               => 14129,
                         "massim"               => 29631,
                         "massimiliano"         => 19939,
                         "massive"              => 1639,
                         "massive1"             => 26745,
                         "maste"                => 2793,
                         "master"               => 18,
                         "master0"              => 24063,
                         "master00"             => 20044,
                         "master01"             => 9164,
                         "master1"              => 958,
                         "master10"             => 17110,
                         "master11"             => 9409,
                         "master12"             => 3662,
                         "master123"            => 7684,
                         "master13"             => 20956,
                         "master2"              => 11915,
                         "master21"             => 22367,
                         "master22"             => 14172,
                         "master23"             => 16505,
                         "master3"              => 13900,
                         "master4"              => 29286,
                         "master5"              => 17701,
                         "master55"             => 22958,
                         "master69"             => 14421,
                         "master7"              => 19096,
                         "master77"             => 19752,
                         "master99"             => 12100,
                         "masterb"              => 18438,
                         "masterb8"             => 18592,
                         "masterba"             => 25202,
                         "masterbaiting"        => 7842,
                         "masterbate"           => 5344,
                         "masterbating"         => 5921,
                         "masterca"             => 14243,
                         "mastercard"           => 17299,
                         "masterch"             => 13922,
                         "masterchief"          => 15483,
                         "masterkey"            => 8736,
                         "masterlo"             => 13734,
                         "masterma"             => 23157,
                         "mastermi"             => 7642,
                         "mastermind"           => 6323,
                         "masterof"             => 16105,
                         "masterp"              => 5532,
                         "masters1"             => 16171,
                         "mastiff"              => 14130,
                         "masturba"             => 15661,
                         "masturbation"         => 7289,
                         "masyanya"             => 13794,
                         "matador"              => 2348,
                         "matahari"             => 14432,
                         "matchbox"             => 5925,
                         "matchbox20"           => 25394,
                         "matematica"           => 21739,
                         "matematika"           => 12716,
                         "materia"              => 22845,
                         "mateus"               => 16381,
                         "mateusz"              => 9387,
                         "matheus"              => 20252,
                         "mathew1"              => 16293,
                         "matia"                => 18097,
                         "matild"               => 18010,
                         "matilda1"             => 18577,
                         "matisse"              => 5979,
                         "matkhau"              => 21188,
                         "matman"               => 12344,
                         "matri"                => 6403,
                         "matrim"               => 27667,
                         "matrix"               => 73,
                         "matrix01"             => 22074,
                         "matrix1"              => 4805,
                         "matrix12"             => 17200,
                         "matrix123"            => 26422,
                         "matrix13"             => 20339,
                         "matrix19"             => 29677,
                         "matrix2"              => 12809,
                         "matrix3"              => 15742,
                         "matrix69"             => 19379,
                         "matrix7"              => 21779,
                         "matrix99"             => 24544,
                         "matrixx"              => 26279,
                         "matrixxx"             => 28032,
                         "matros"               => 8193,
                         "matt01"               => 24404,
                         "matt1"                => 9896,
                         "matt11"               => 14281,
                         "matt12"               => 18224,
                         "matt123"              => 14566,
                         "matt1234"             => 16385,
                         "matt21"               => 28307,
                         "matt23"               => 29362,
                         "matteo"               => 3495,
                         "matthe"               => 4443,
                         "matthe1"              => 17920,
                         "matthew0"             => 26324,
                         "matthew1"             => 1080,
                         "matthew2"             => 9277,
                         "matthew3"             => 21553,
                         "matthew4"             => 29302,
                         "matthew5"             => 25015,
                         "matthew6"             => 27105,
                         "matthew7"             => 10798,
                         "matthew8"             => 15324,
                         "matthew9"             => 16043,
                         "matthewd"             => 29586,
                         "matthias"             => 4387,
                         "matthieu"             => 16778,
                         "mattias"              => 24378,
                         "mattingl"             => 8974,
                         "mattman"              => 11465,
                         "matty"                => 5637,
                         "matty1"               => 18888,
                         "mattylad10"           => 27147,
                         "matulino"             => 23039,
                         "mature"               => 1376,
                         "matveev"              => 25984,
                         "matveeva"             => 19633,
                         "matvei"               => 9983,
                         "matvey"               => 8818,
                         "maulwurf"             => 23624,
                         "maureen1"             => 19249,
                         "mauric"               => 28071,
                         "maurice1"             => 16040,
                         "maurici"              => 6809,
                         "maurizio"             => 6787,
                         "maurolarastefy"       => 8122,
                         "mauser"               => 11601,
                         "mausi"                => 15845,
                         "maveric"              => 4891,
                         "maverick"             => 97,
                         "maverick1"            => 10249,
                         "mavericks"            => 9626,
                         "maverik"              => 13461,
                         "mavrick"              => 11201,
                         "mavrik"               => 16734,
                         "max007"               => 22679,
                         "max123"               => 2991,
                         "max1234"              => 29751,
                         "max1998"              => 26650,
                         "max2000"              => 17241,
                         "max2010"              => 26935,
                         "max333"               => 5242,
                         "max33484"             => 20445,
                         "max777"               => 18294,
                         "maxcat"               => 26467,
                         "maxdog"               => 5379,
                         "maxell"               => 2253,
                         "maxfli"               => 9377,
                         "maxi"                 => 6154,
                         "maxie1"               => 28476,
                         "maxim"                => 2940,
                         "maxim1"               => 11445,
                         "maxim1935"            => 15096,
                         "maxima"               => 817,
                         "maximal"              => 11381,
                         "maxime"               => 3604,
                         "maximili"             => 15442,
                         "maximilian"           => 7489,
                         "maximka"              => 5998,
                         "maximu"               => 25272,
                         "maximus"              => 411,
                         "maximus1"             => 7463,
                         "maximus2"             => 22957,
                         "maxine1"              => 22713,
                         "maxman"               => 10199,
                         "maxmotives"           => 29711,
                         "maxpayne"             => 7580,
                         "maxpower"             => 6522,
                         "maxsam"               => 29445,
                         "maxsim"               => 26231,
                         "maxthedo"             => 23351,
                         "maxtor"               => 12707,
                         "maxwel"               => 14087,
                         "maxwell"              => 262,
                         "maxwell1"             => 3514,
                         "maxwell2"             => 22707,
                         "maxwell7"             => 22297,
                         "maxx"                 => 2472,
                         "maxxam"               => 29859,
                         "maxxx"                => 17442,
                         "maxxxx"               => 3505,
                         "mayday"               => 2015,
                         "mayfair"              => 8385,
                         "mayflowe"             => 24305,
                         "mayfly"               => 17990,
                         "mayhem"               => 2070,
                         "maynard1"             => 14210,
                         "maytag"               => 19956,
                         "maywood"              => 24601,
                         "mazafaka"             => 2733,
                         "mazahaka"             => 16725,
                         "mazda"                => 3361,
                         "mazda1"               => 8594,
                         "mazda3"               => 5855,
                         "mazda323"             => 6607,
                         "mazda6"               => 4413,
                         "mazda626"             => 3628,
                         "mazdamx5"             => 28229,
                         "mazdarx"              => 27044,
                         "mazdarx7"             => 4073,
                         "mazdarx8"             => 11709,
                         "mazepa"               => 25869,
                         "mazinger"             => 10094,
                         "mbkugegs"             => 24059,
                         "mccool24"             => 25628,
                         "mcdonalds"            => 13848,
                         "mcgwire"              => 10933,
                         "mcitra"               => 29135,
                         "mclaren"              => 3423,
                         "mclaren1"             => 23786,
                         "mclarenf1"            => 23381,
                         "md2020"               => 16516,
                         "mdmaiwa3"             => 24201,
                         "mdmgatew"             => 28252,
                         "mdogg"                => 7495,
                         "me1234"               => 15003,
                         "me2you"               => 27383,
                         "meadow"               => 5468,
                         "meagain"              => 18571,
                         "meandyou"             => 8469,
                         "meanone"              => 17615,
                         "meatball"             => 1969,
                         "meathead"             => 2734,
                         "meatloaf"             => 2099,
                         "meatman"              => 11870,
                         "meatwad"              => 26446,
                         "mechanic"             => 2291,
                         "mechta"               => 13760,
                         "media1"               => 17341,
                         "medias"               => 25467,
                         "medic"                => 4070,
                         "medic1"               => 6033,
                         "medical1"             => 24459,
                         "medicin"              => 18961,
                         "medicina"             => 10445,
                         "medicus"              => 25329,
                         "medin"                => 28633,
                         "medion"               => 4019,
                         "meditate"             => 16350,
                         "medman"               => 20992,
                         "medtech"              => 25238,
                         "medusa"               => 2973,
                         "meduza"               => 26039,
                         "medved"               => 4480,
                         "medvedev"             => 15746,
                         "medvedeva"            => 21353,
                         "meeeee"               => 21463,
                         "meeko"                => 25158,
                         "meesha"               => 29539,
                         "meetme"               => 29765,
                         "meetoo"               => 27802,
                         "megabyte"             => 13855,
                         "megadeth"             => 1269,
                         "megafon"              => 9696,
                         "megama"               => 29047,
                         "megaman"              => 1471,
                         "megaman1"             => 21143,
                         "megamanx"             => 12420,
                         "megamon"              => 29460,
                         "megan1"               => 3971,
                         "megan123"             => 27623,
                         "megan2"               => 27022,
                         "megane"               => 4566,
                         "megans"               => 19999,
                         "megapass"             => 2403,
                         "megapolis"            => 17596,
                         "megastar"             => 19274,
                         "megat"                => 16710,
                         "megatron"             => 2889,
                         "meggie"               => 6585,
                         "megha"                => 23853,
                         "megiddo"              => 22694,
                         "megryan"              => 18419,
                         "megumi"               => 17695,
                         "mehmet"               => 12785,
                         "meiling"              => 28809,
                         "meister"              => 2947,
                         "meister1"             => 28425,
                         "melange"              => 15278,
                         "melanie1"             => 5487,
                         "melanie2"             => 22122,
                         "melbourn"             => 10480,
                         "melena"               => 20941,
                         "melinda1"             => 18283,
                         "melis"                => 23272,
                         "meliss"               => 5397,
                         "melissa1"             => 1920,
                         "melissa2"             => 11608,
                         "melissa3"             => 22817,
                         "melissa6"             => 18452,
                         "melissa7"             => 19937,
                         "melkor"               => 13312,
                         "mello1"               => 27423,
                         "mellon"               => 2077,
                         "mellons"              => 11512,
                         "mellow"               => 2790,
                         "melly"                => 28255,
                         "melmac"               => 17164,
                         "melnik"               => 12951,
                         "melnikova"            => 25002,
                         "melon"                => 9418,
                         "melon1"               => 23127,
                         "melons"               => 5571,
                         "melrose"              => 5556,
                         "melvin1"              => 24389,
                         "melvins"              => 20117,
                         "member1"              => 12535,
                         "memem"                => 26800,
                         "memento"              => 11307,
                         "memnoch"              => 9098,
                         "memorex"              => 2147,
                         "memphis"              => 1205,
                         "memphis1"             => 12792,
                         "memyself"             => 11319,
                         "menace"               => 2907,
                         "menards"              => 26743,
                         "mendoz"               => 27844,
                         "meng"                 => 3364,
                         "mensch"               => 8404,
                         "mensuck"              => 22325,
                         "menthol"              => 5954,
                         "mentor"               => 4455,
                         "mentos"               => 8553,
                         "menudo"               => 21230,
                         "meoff"                => 19570,
                         "meonly"               => 7185,
                         "meowmeow"             => 2774,
                         "meowmix"              => 8610,
                         "mephisto"             => 3474,
                         "mercator"             => 22009,
                         "mercede"              => 5400,
                         "mercede1"             => 29996,
                         "mercedes"             => 107,
                         "mercedes1"            => 16757,
                         "mercenar"             => 20512,
                         "merckx"               => 22121,
                         "mercur"               => 13103,
                         "mercury"              => 502,
                         "mercury1"             => 5916,
                         "mercury2"             => 29664,
                         "mercury7"             => 14341,
                         "mercutio"             => 19815,
                         "merda"                => 16229,
                         "merengue"             => 24082,
                         "merete"               => 22614,
                         "merhaba"              => 12085,
                         "meridian"             => 1466,
                         "merkin"               => 13227,
                         "merkur"               => 13248,
                         "merl1n"               => 22629,
                         "merli"                => 10449,
                         "merlin"               => 80,
                         "merlin01"             => 18118,
                         "merlin1"              => 3695,
                         "merlin11"             => 24625,
                         "merlin12"             => 17307,
                         "merlin21"             => 25948,
                         "merlin69"             => 17539,
                         "merlin99"             => 20511,
                         "merlot"               => 3343,
                         "mermaid"              => 3034,
                         "mermaid1"             => 23393,
                         "mermaids"             => 18166,
                         "merrill1"             => 19271,
                         "merry1"               => 27671,
                         "mersedes"             => 1562,
                         "merson"               => 18872,
                         "mesohorny"            => 25682,
                         "mesquite"             => 17664,
                         "messenge"             => 22573,
                         "messi"                => 21524,
                         "messi10"              => 9242,
                         "messiah"              => 4341,
                         "messiah1"             => 24120,
                         "mester"               => 20221,
                         "met2002"              => 5783,
                         "metal1"               => 6078,
                         "metal123"             => 28510,
                         "metal666"             => 9984,
                         "metal69"              => 29699,
                         "metalgea"             => 21780,
                         "metalgear"            => 9341,
                         "metalhead"            => 25376,
                         "metalica"             => 9421,
                         "metall"               => 5329,
                         "metallic"             => 269,
                         "metallica"            => 415,
                         "metallica1"           => 6111,
                         "metalman"             => 10482,
                         "metart"               => 18455,
                         "metatron"             => 19454,
                         "meteora"              => 15135,
                         "meteoro"              => 29701,
                         "method1"              => 20109,
                         "method7"              => 25461,
                         "methodma"             => 26315,
                         "methodman"            => 13534,
                         "methos"               => 6823,
                         "metlife"              => 27446,
                         "metoo"                => 6435,
                         "metoyou"              => 25010,
                         "metro1"               => 10751,
                         "metro2033"            => 15350,
                         "metroid"              => 5243,
                         "metropol"             => 9568,
                         "metros"               => 14476,
                         "mets"                 => 3377,
                         "mets1986"             => 23068,
                         "mets69"               => 21252,
                         "mets86"               => 11842,
                         "mettss"               => 9747,
                         "mevefalkcakk"         => 15550,
                         "mewtwo"               => 10035,
                         "mexic"                => 9150,
                         "mexicali"             => 25438,
                         "mexican1"             => 29591,
                         "mexicano"             => 13651,
                         "mexico"               => 404,
                         "mexico1"              => 11001,
                         "mgoblue"              => 11611,
                         "mhorgan"              => 17724,
                         "miami"                => 1397,
                         "miami1"               => 6413,
                         "miami305"             => 23534,
                         "miamo"                => 7981,
                         "miamor"               => 8031,
                         "mian"                 => 2958,
                         "miao"                 => 3158,
                         "miasma"               => 29773,
                         "miata"                => 14864,
                         "miata1"               => 18941,
                         "miatamx5"             => 29401,
                         "micael"               => 29179,
                         "micasa"               => 17513,
                         "michae"               => 2997,
                         "michae1"              => 14435,
                         "michael0"             => 13295,
                         "michael1"             => 519,
                         "michael12"            => 21801,
                         "michael123"           => 27285,
                         "michael2"             => 3670,
                         "michael3"             => 9172,
                         "michael4"             => 14039,
                         "michael5"             => 14141,
                         "michael6"             => 12767,
                         "michael7"             => 10252,
                         "michael8"             => 9860,
                         "michael9"             => 9380,
                         "michaelb"             => 22913,
                         "michaelc"             => 14224,
                         "michaeld"             => 14436,
                         "michaelj"             => 12310,
                         "michaeljackson"       => 27292,
                         "michaell"             => 24929,
                         "michaelm"             => 28079,
                         "michail"              => 21116,
                         "michal1"              => 28452,
                         "miche"                => 16357,
                         "michel1"              => 18658,
                         "michela"              => 20755,
                         "michele1"             => 7346,
                         "michelin"             => 12126,
                         "michell1"             => 27573,
                         "michelle1"            => 7211,
                         "michelob"             => 17636,
                         "michi"                => 9948,
                         "michigan"             => 396,
                         "michou"               => 25322,
                         "mick"                 => 3735,
                         "mick7278"             => 14913,
                         "mickael"              => 27763,
                         "micke"                => 9847,
                         "mickey"               => 100,
                         "mickey01"             => 21030,
                         "mickey1"              => 3316,
                         "mickey11"             => 22610,
                         "mickey12"             => 17849,
                         "mickey2"              => 25581,
                         "mickey22"             => 23181,
                         "mickey69"             => 28182,
                         "mickey7"              => 22726,
                         "mickeymo"             => 21372,
                         "mickeymouse"          => 11018,
                         "mickeys"              => 27940,
                         "micky"                => 8131,
                         "micky1"               => 24374,
                         "micmac"               => 24278,
                         "micro"                => 3996,
                         "micro1"               => 14042,
                         "microlab"             => 1999,
                         "microlab1"            => 22991,
                         "micron"               => 2694,
                         "microphone"           => 3450,
                         "micros"               => 11343,
                         "microsof"             => 1998,
                         "microsoft"            => 835,
                         "microwav"             => 19899,
                         "midas"                => 17635,
                         "midcon"               => 16362,
                         "middleto"             => 27077,
                         "midgard"              => 18467,
                         "midget"               => 2251,
                         "midian"               => 12361,
                         "midiland"             => 28797,
                         "midnigh"              => 14849,
                         "midnight"             => 162,
                         "midnight1"            => 14642,
                         "midnite"              => 4967,
                         "midori"               => 7138,
                         "midway"               => 2902,
                         "mierd"                => 13065,
                         "mierda"               => 6124,
                         "mifune"               => 14843,
                         "mighty"               => 1964,
                         "mighty1"              => 14968,
                         "mightymo"             => 18249,
                         "migue"                => 5908,
                         "miguelit"             => 21557,
                         "mihaela"              => 13165,
                         "mihail"               => 3751,
                         "mika00"               => 18321,
                         "mikado"               => 7007,
                         "mikael"               => 5187,
                         "mikasa"               => 22023,
                         "mikayla"              => 7594,
                         "mike00"               => 18023,
                         "mike007"              => 28346,
                         "mike01"               => 8885,
                         "mike1"                => 4111,
                         "mike11"               => 9583,
                         "mike12"               => 7625,
                         "mike123"              => 4072,
                         "mike1234"             => 6518,
                         "mike12345"            => 25271,
                         "mike13"               => 12502,
                         "mike18"               => 17616,
                         "mike1969"             => 28403,
                         "mike2"                => 15863,
                         "mike2000"             => 27862,
                         "mike21"               => 18463,
                         "mike22"               => 14109,
                         "mike23"               => 6926,
                         "mike24"               => 18304,
                         "mike25"               => 20651,
                         "mike26"               => 21452,
                         "mike31"               => 27095,
                         "mike34"               => 23939,
                         "mike44"               => 20862,
                         "mike69"               => 7361,
                         "mike77"               => 13912,
                         "mike99"               => 25675,
                         "miked"                => 17752,
                         "mikeee"               => 24777,
                         "mikehunt"             => 22246,
                         "mikejone"             => 28291,
                         "mikes"                => 18196,
                         "mikey"                => 1588,
                         "mikey1"               => 3388,
                         "mikey123"             => 13771,
                         "mikey2"               => 27992,
                         "mikeyb"               => 22052,
                         "mikeyg"               => 21154,
                         "mikeys"               => 12758,
                         "mikie"                => 28882,
                         "mikkel"               => 6705,
                         "mikola"               => 15376,
                         "milamber"             => 6900,
                         "milan1"               => 21386,
                         "milana"               => 2169,
                         "milano"               => 1413,
                         "milano1"              => 22873,
                         "milashka"             => 9761,
                         "miledi"               => 24779,
                         "milehigh"             => 16262,
                         "milen"                => 13821,
                         "milena"               => 2242,
                         "milenium"             => 9244,
                         "milenko"              => 20223,
                         "miles1"               => 7316,
                         "milesd"               => 11137,
                         "milfhunter"           => 28864,
                         "milfnew"              => 7603,
                         "milhouse"             => 7840,
                         "milion"               => 19821,
                         "militar"              => 27615,
                         "milka"                => 23739,
                         "milkbone"             => 13264,
                         "milkdud"              => 19107,
                         "milker"               => 29082,
                         "milkmaid"             => 26224,
                         "milkman"              => 3126,
                         "milkman1"             => 20536,
                         "milkshak"             => 16164,
                         "milkyway"             => 7439,
                         "milla"                => 20563,
                         "mille"                => 8563,
                         "millenia"             => 18531,
                         "milleniu"             => 12374,
                         "millenium"            => 4889,
                         "millenni"             => 14540,
                         "miller01"             => 27066,
                         "miller1"              => 3960,
                         "miller12"             => 27407,
                         "miller2"              => 20437,
                         "miller31"             => 17760,
                         "millerli"             => 10671,
                         "millerlite"           => 22644,
                         "millers"              => 14526,
                         "millerti"             => 22888,
                         "millertime"           => 19682,
                         "milli"                => 12972,
                         "millie1"              => 17323,
                         "million1"             => 9914,
                         "milliona"             => 26372,
                         "millwall"             => 3344,
                         "milo17"               => 24372,
                         "milosc"               => 15877,
                         "milwauke"             => 12429,
                         "mimi92139"            => 14387,
                         "mimosa"               => 6953,
                         "mimoza"               => 15490,
                         "minako"               => 10728,
                         "minami"               => 18724,
                         "minchia"              => 18376,
                         "minddoc"              => 23226,
                         "mindgame"             => 20504,
                         "mindy1"               => 12166,
                         "mine1"                => 22750,
                         "mine11"               => 25012,
                         "mine12"               => 14693,
                         "mine2306"             => 12501,
                         "mine69"               => 26136,
                         "minecraft"            => 410,
                         "minecraft123"         => 17746,
                         "mineonly"             => 23486,
                         "minette"              => 15223,
                         "minfd"                => 27634,
                         "mingus"               => 4556,
                         "minhasenha"           => 19513,
                         "mini14"               => 23792,
                         "miniclip"             => 26715,
                         "minicoop"             => 17528,
                         "minicooper"           => 27170,
                         "minidisc"             => 11301,
                         "minim"                => 25346,
                         "minimax"              => 19658,
                         "minime"               => 2507,
                         "minimoni"             => 5285,
                         "minion"               => 10138,
                         "miniskir"             => 20424,
                         "minka"                => 17481,
                         "minkey"               => 29051,
                         "minnesot"             => 6206,
                         "minnesota_hp"         => 28517,
                         "minnette"             => 19191,
                         "minni"                => 12347,
                         "minnie1"              => 16428,
                         "minnow"               => 12342,
                         "minolta"              => 18359,
                         "minotaur"             => 9590,
                         "minotavr"             => 28724,
                         "minou"                => 14948,
                         "minouche"             => 19894,
                         "minstrel"             => 15066,
                         "minty"                => 21119,
                         "miracle1"             => 23736,
                         "mirage"               => 1356,
                         "miramar"              => 12776,
                         "mirand"               => 28849,
                         "miranda1"             => 8911,
                         "mircea"               => 17310,
                         "mirela"               => 15017,
                         "miria"                => 11647,
                         "mirjam"               => 15302,
                         "mirko"                => 24692,
                         "mironova"             => 13542,
                         "miroslav"             => 10643,
                         "miroslava"            => 20596,
                         "mirror1"              => 22638,
                         "miruvor79"            => 29394,
                         "misato"               => 13594,
                         "misawa"               => 18035,
                         "mischa"               => 8562,
                         "mischief"             => 4618,
                         "misfit"               => 2459,
                         "misfit99"             => 3873,
                         "misfits"              => 3521,
                         "misfits1"             => 23803,
                         "misha1"               => 12559,
                         "misha1111"            => 26828,
                         "misha123"             => 24247,
                         "mishanya"             => 17492,
                         "mishel"               => 20514,
                         "mishima"              => 18567,
                         "mishka"               => 2842,
                         "mishmash"             => 28441,
                         "mishutka"             => 20222,
                         "misiaczek"            => 8220,
                         "misiek"               => 5906,
                         "misiek1"              => 27805,
                         "missey"               => 18710,
                         "missie"               => 6008,
                         "mission1"             => 14625,
                         "mississi"             => 6485,
                         "misskitt"             => 12519,
                         "misskitty"            => 18090,
                         "missle"               => 21471,
                         "missy1"               => 2996,
                         "missy123"             => 21660,
                         "missy2"               => 18758,
                         "missyou"              => 24373,
                         "missys"               => 24900,
                         "mister"               => 980,
                         "mister2"              => 27149,
                         "misterio"             => 18540,
                         "misterme"             => 25235,
                         "mistery"              => 22069,
                         "mistic"               => 22024,
                         "mistral"              => 8098,
                         "mistral1"             => 21609,
                         "mistress"             => 894,
                         "misty1"               => 3038,
                         "misty123"             => 12926,
                         "misty2"               => 22397,
                         "mistydog"             => 16730,
                         "mistys"               => 23755,
                         "mitch1"               => 11775,
                         "mithrand"             => 18839,
                         "mithril"              => 15251,
                         "mitsou"               => 27079,
                         "mitsu"                => 19584,
                         "mitsubis"             => 14626,
                         "mitten"               => 11398,
                         "mittens"              => 2712,
                         "mittens1"             => 14006,
                         "mitzi1"               => 25981,
                         "mixail"               => 13464,
                         "miyuki"               => 26259,
                         "miyvarxar"            => 25973,
                         "mizredhe"             => 16829,
                         "mizuno"               => 6438,
                         "mizzou"               => 5172,
                         "mjollnir"             => 22089,
                         "mjolnir"              => 7163,
                         "mjordan"              => 14441,
                         "mjujuj"               => 21586,
                         "mko09ijn"             => 28493,
                         "mkonji"               => 23664,
                         "mkvdari"              => 24412,
                         "mlesp31"              => 21927,
                         "mm111qm"              => 20443,
                         "mm259up"              => 22465,
                         "mmcm19"               => 23368,
                         "mmm666"               => 17434,
                         "mmmmm1"               => 13163,
                         "mmmmmm1"              => 18768,
                         "mmmmmmm1"             => 24944,
                         "mmmnnn"               => 24700,
                         "mmouse"               => 14110,
                         "mmxxmm"               => 27689,
                         "mnbvcxz"              => 550,
                         "mnbvcxz1"             => 9671,
                         "mo5kva"               => 21122,
                         "mobbdeep"             => 9040,
                         "mobil"                => 10030,
                         "mobil1"               => 11686,
                         "mobila"               => 25034,
                         "mobile1"              => 26883,
                         "mobius"               => 12296,
                         "mobydick"             => 3721,
                         "mocha1"               => 13084,
                         "mochaj"               => 19542,
                         "mockba"               => 24875,
                         "modaddy"              => 29464,
                         "modano"               => 13315,
                         "model1"               => 22392,
                         "modelsne"             => 5192,
                         "modem"                => 8900,
                         "modem1"               => 25646,
                         "modems"               => 15690,
                         "modena"               => 3199,
                         "moderato"             => 29870,
                         "modles"               => 8239,
                         "moebius"              => 21185,
                         "mof6681"              => 12999,
                         "mogli"                => 26831,
                         "moguls"               => 18611,
                         "mogwai"               => 6013,
                         "mohamma"              => 28984,
                         "mohawk"               => 5213,
                         "mohican"              => 18929,
                         "moikka"               => 21555,
                         "moimeme"              => 20810,
                         "mojave"               => 8347,
                         "mojo"                 => 2087,
                         "mojo69"               => 17385,
                         "mojojojo"             => 7218,
                         "mojoman"              => 18278,
                         "moldir"               => 17457,
                         "moleman"              => 14313,
                         "molley"               => 22322,
                         "molly1"               => 1196,
                         "molly12"              => 19959,
                         "molly123"             => 6863,
                         "molly2"               => 22065,
                         "mollyb"               => 22452,
                         "mollycat"             => 15869,
                         "mollydog"             => 3213,
                         "mollymoo"             => 23077,
                         "mollys"               => 10426,
                         "molodec"              => 25932,
                         "molokai"              => 21565,
                         "moloko"               => 1849,
                         "molotok"              => 8090,
                         "molotov"              => 12564,
                         "molson"               => 1549,
                         "mom123"               => 14188,
                         "mom4u4mm"             => 13625,
                         "momanddad"            => 27588,
                         "momdad"               => 5833,
                         "mommie"               => 9347,
                         "mommy1"               => 5824,
                         "mommy123"             => 21042,
                         "mommy2"               => 28005,
                         "mommys"               => 23152,
                         "momoney"              => 1907,
                         "momoney1"             => 25132,
                         "momsanaladventure"    => 8341,
                         "momsuck"              => 7604,
                         "monaco"               => 2457,
                         "monalis"              => 29842,
                         "monalisa"             => 2724,
                         "monaliza"             => 15334,
                         "monami"               => 15373,
                         "monamour"             => 16952,
                         "monarch"              => 3386,
                         "monaro"               => 12734,
                         "monday"               => 559,
                         "monday1"              => 7560,
                         "monday12"             => 17068,
                         "monday2"              => 24269,
                         "mondeo"               => 2525,
                         "mondo"                => 14587,
                         "mone"                 => 5458,
                         "monet1"               => 17656,
                         "money"                => 142,
                         "money01"              => 15830,
                         "money1"               => 498,
                         "money100"             => 27215,
                         "money111"             => 19674,
                         "money12"              => 4918,
                         "money123"             => 4640,
                         "money1234"            => 27421,
                         "money2"               => 7378,
                         "money21"              => 27254,
                         "money23"              => 23501,
                         "money3"               => 28794,
                         "money4"               => 19466,
                         "money4me"             => 14265,
                         "money5"               => 22148,
                         "money69"              => 23365,
                         "money7"               => 16188,
                         "money77"              => 28062,
                         "money777"             => 21036,
                         "money8"               => 26684,
                         "money99"              => 23819,
                         "moneybag"             => 9770,
                         "moneymak"             => 16315,
                         "moneymaker"           => 11886,
                         "moneyman"             => 2505,
                         "moneymon"             => 18894,
                         "moneys"               => 1867,
                         "moneyy"               => 10698,
                         "mongini"              => 27364,
                         "mongo"                => 6376,
                         "mongo1"               => 12289,
                         "mongoose"             => 1144,
                         "monic"                => 5126,
                         "monica01"             => 27578,
                         "monica1"              => 6937,
                         "monica12"             => 19679,
                         "monica2"              => 10978,
                         "monica69"             => 16653,
                         "monies"               => 7296,
                         "monika1"              => 21706,
                         "monique1"             => 8945,
                         "monito"               => 17059,
                         "monitor"              => 1172,
                         "monitor1"             => 21605,
                         "monitor2"             => 25602,
                         "monk3y"               => 27000,
                         "monke"                => 2807,
                         "monkee"               => 11315,
                         "monker"               => 14589,
                         "monkey"               => 15,
                         "monkey00"             => 22284,
                         "monkey01"             => 15388,
                         "monkey1"              => 859,
                         "monkey10"             => 13401,
                         "monkey11"             => 8707,
                         "monkey12"             => 3451,
                         "monkey123"            => 7751,
                         "monkey13"             => 12910,
                         "monkey14"             => 28705,
                         "monkey2"              => 7410,
                         "monkey20"             => 21694,
                         "monkey21"             => 19234,
                         "monkey22"             => 14853,
                         "monkey23"             => 19648,
                         "monkey24"             => 21575,
                         "monkey3"              => 15397,
                         "monkey4"              => 24079,
                         "monkey5"              => 18255,
                         "monkey6"              => 20680,
                         "monkey66"             => 22487,
                         "monkey69"             => 6881,
                         "monkey7"              => 11933,
                         "monkey77"             => 14151,
                         "monkey9"              => 25836,
                         "monkey99"             => 13493,
                         "monkeybo"             => 3993,
                         "monkeyboy"            => 6332,
                         "monkeybu"             => 23110,
                         "monkeybutt"           => 24803,
                         "monkeyma"             => 8368,
                         "monkeyman"            => 7639,
                         "monkeys"              => 1586,
                         "monkeys1"             => 18866,
                         "monkfish"             => 17599,
                         "monkies"              => 19172,
                         "monolit"              => 16168,
                         "monolith"             => 7235,
                         "mononoke"             => 27939,
                         "monopoli"             => 19960,
                         "monopoly"             => 1738,
                         "monsoon"              => 7768,
                         "monsta"               => 19918,
                         "monste"               => 6537,
                         "monster"              => 128,
                         "monster1"             => 2792,
                         "monster2"             => 13916,
                         "monster7"             => 24052,
                         "monster9"             => 25099,
                         "monstr"               => 12574,
                         "montag"               => 5231,
                         "montagne"             => 11729,
                         "montan"               => 12312,
                         "montana"              => 408,
                         "montana1"             => 5111,
                         "montauk"              => 10665,
                         "montblanc"            => 27559,
                         "monte1"               => 18167,
                         "montecar"             => 5633,
                         "montecarlo"           => 7592,
                         "montego"              => 12953,
                         "montella"             => 29271,
                         "monterey"             => 6200,
                         "monterre"             => 17763,
                         "montesa"              => 23593,
                         "montess"              => 13917,
                         "montgom240"           => 2848,
                         "montgome"             => 18185,
                         "montreal"             => 904,
                         "montrose"             => 5683,
                         "montse"               => 25027,
                         "monty1"               => 4350,
                         "monty123"             => 12907,
                         "moo123"               => 28471,
                         "moochie"              => 7388,
                         "moocow"               => 1911,
                         "moody1"               => 26814,
                         "moogie"               => 21650,
                         "moogle"               => 13635,
                         "mookey"               => 19217,
                         "mooki"                => 20529,
                         "mookie"               => 633,
                         "mookie1"              => 11808,
                         "mookie12"             => 16481,
                         "moom4242"             => 21423,
                         "moom4261"             => 23295,
                         "mooman"               => 29217,
                         "moomin"               => 15325,
                         "moomoo"               => 1236,
                         "moomoo1"              => 21383,
                         "moon1"                => 21319,
                         "moon123"              => 19218,
                         "moon69"               => 26255,
                         "moonbeam"             => 3671,
                         "moondog"              => 4020,
                         "moondog1"             => 25162,
                         "mooner"               => 8213,
                         "moonglow"             => 15429,
                         "moonie"               => 11346,
                         "moonligh"             => 4772,
                         "moonlight"            => 2921,
                         "moonlite"             => 21331,
                         "moonman"              => 6502,
                         "moonpie"              => 10358,
                         "moonrake"             => 24424,
                         "moonshin"             => 4908,
                         "moonshine"            => 8898,
                         "moonshot"             => 28423,
                         "moonstafa"            => 25442,
                         "moonstar"             => 8979,
                         "moonunit"             => 19136,
                         "moonwalk"             => 29663,
                         "mooooo"               => 21075,
                         "mooose"               => 29861,
                         "moore1"               => 11055,
                         "moorea"               => 27977,
                         "moose"                => 899,
                         "moose1"               => 2345,
                         "moose123"             => 17609,
                         "moose69"              => 25019,
                         "moosehea"             => 14609,
                         "moosejaw"             => 17673,
                         "mooseman"             => 12248,
                         "mooser"               => 28070,
                         "mooses"               => 5583,
                         "moosey"               => 10796,
                         "moosie"               => 15833,
                         "mopar"                => 4802,
                         "mopar1"               => 10257,
                         "mopar440"             => 29992,
                         "moparman"             => 26271,
                         "mopars"               => 15738,
                         "moppel"               => 18594,
                         "morbius"              => 18746,
                         "mordor"               => 3616,
                         "mordred"              => 19536,
                         "morebeer"             => 16274,
                         "morefun"              => 25430,
                         "morelia"              => 25519,
                         "moremone"             => 14162,
                         "moremoney"            => 17415,
                         "moren"                => 12259,
                         "morena"               => 6825,
                         "moresex"              => 19661,
                         "morga"                => 8691,
                         "morgaine"             => 24417,
                         "morgan01"             => 20124,
                         "morgan1"              => 3183,
                         "morgan12"             => 18240,
                         "morgan2"              => 16931,
                         "morgana"              => 6536,
                         "morgane"              => 17846,
                         "morgans"              => 29005,
                         "morganstanley"        => 25140,
                         "morgen"               => 9936,
                         "morgoth"              => 6410,
                         "moritz"               => 3297,
                         "morkovka"             => 10564,
                         "morlii"               => 9483,
                         "moroni"               => 14532,
                         "morozov"              => 9093,
                         "morozova"             => 7501,
                         "morpheus"             => 1031,
                         "morphius"             => 25334,
                         "morri"                => 24472,
                         "morrigan"             => 10678,
                         "morris1"              => 14105,
                         "morrisse"             => 10593,
                         "morrowin"             => 26074,
                         "morrowind"            => 5253,
                         "mortalkombat"         => 28114,
                         "morten"               => 5835,
                         "mortgage"             => 2932,
                         "morticia"             => 7324,
                         "mortimer"             => 2974,
                         "mortis"               => 6101,
                         "moscow"               => 1374,
                         "moscow1"              => 28670,
                         "mosdef"               => 12872,
                         "moses1"               => 10686,
                         "mosias98"             => 29554,
                         "moskva"               => 4149,
                         "moskwa"               => 26621,
                         "moss84"               => 11613,
                         "mossad"               => 20075,
                         "mossberg"             => 23798,
                         "mossimo"              => 16248,
                         "mossyoak"             => 29935,
                         "mostwanted"           => 8996,
                         "motaro"               => 27596,
                         "motdepas"             => 18492,
                         "motdepass"            => 26215,
                         "motdepasse"           => 7394,
                         "mothe"                => 9742,
                         "mother"               => 153,
                         "mother1"              => 3944,
                         "mother12"             => 25726,
                         "mother2"              => 22441,
                         "motherfu"             => 7483,
                         "motherfuck"           => 17347,
                         "motherlode"           => 2590,
                         "mothra"               => 8631,
                         "moto"                 => 6242,
                         "motocros"             => 5694,
                         "motocross"            => 6975,
                         "motoguzz"             => 23571,
                         "motoko"               => 15361,
                         "motoman"              => 21532,
                         "motorbik"             => 20593,
                         "motorbike"            => 20879,
                         "motorcyc"             => 8039,
                         "motorhea"             => 16012,
                         "motorhead"            => 17411,
                         "motorman"             => 22574,
                         "motorol"              => 17876,
                         "motorola"             => 572,
                         "motorolla"            => 20927,
                         "motorrad"             => 21197,
                         "motown"               => 6095,
                         "motox"                => 24098,
                         "motoxxx"              => 25021,
                         "motzart"              => 28036,
                         "mouche"               => 14539,
                         "moulin"               => 17619,
                         "mounta1n"             => 10032,
                         "mountai1"             => 29447,
                         "mountain"             => 272,
                         "mouse"                => 803,
                         "mouse1"               => 2603,
                         "mouse123"             => 18734,
                         "mouse2"               => 26403,
                         "mouseman"             => 19737,
                         "mousepad"             => 9417,
                         "mouser"               => 5827,
                         "mouses"               => 6334,
                         "mousey"               => 6659,
                         "mousie"               => 22461,
                         "movado"               => 19534,
                         "moveon"               => 13697,
                         "movie1"               => 20567,
                         "moviebuf"             => 27980,
                         "movieman"             => 21678,
                         "movies23"             => 28647,
                         "mowerman"             => 14670,
                         "mowgli"               => 8170,
                         "moxie"                => 16080,
                         "mozar"                => 21038,
                         "mozart"               => 479,
                         "mozart1"              => 14485,
                         "mozilla"              => 11856,
                         "mozzer"               => 11178,
                         "mp8o6d"               => 11155,
                         "mpegs"                => 6795,
                         "mpetroff"             => 19844,
                         "mpower"               => 12566,
                         "mrbean"               => 15628,
                         "mrbig"                => 23981,
                         "mrbill"               => 8056,
                         "mrblonde"             => 22213,
                         "mrbrown"              => 13978,
                         "mrbrownx"             => 11670,
                         "mrbrownxx"            => 11181,
                         "mrbungle"             => 15697,
                         "mrclean"              => 14253,
                         "mrgreen"              => 19132,
                         "mrhappy"              => 11480,
                         "mrjones"              => 16898,
                         "mrkitty"              => 20538,
                         "mrlover"              => 19474,
                         "mrmagoo"              => 24048,
                         "mrmike"               => 28679,
                         "mrmojo"               => 28132,
                         "mrpibb"               => 23781,
                         "mrpink"               => 12483,
                         "mrskin"               => 16755,
                         "mrsmith"              => 19302,
                         "mrspock"              => 18668,
                         "mrwhite"              => 29912,
                         "ms6nud"               => 15079,
                         "msconfig"             => 23213,
                         "msinfo"               => 24116,
                         "msnxbi"               => 15394,
                         "msorcloledbr"         => 26807,
                         "msouthwa"             => 23672,
                         "mst3000"              => 19247,
                         "msvcr71"              => 26876,
                         "mtgox"                => 24689,
                         "mtndew"               => 14819,
                         "mtnman"               => 22972,
                         "mtwapa1a"             => 21588,
                         "mty3rh"               => 15178,
                         "muaddib"              => 10455,
                         "muaythai"             => 10732,
                         "muchacha"             => 27469,
                         "mucker"               => 22539,
                         "mudbone"              => 25965,
                         "mudbug"               => 26815,
                         "mudcat"               => 17729,
                         "mudder"               => 13824,
                         "mudhen"               => 29795,
                         "mudhoney"             => 15207,
                         "mudman"               => 18583,
                         "mudshark"             => 20155,
                         "mudslide"             => 24358,
                         "mudvayne"             => 3972,
                         "muenchen"             => 10420,
                         "muerte"               => 16117,
                         "mufasa"               => 5866,
                         "muffdive"             => 7983,
                         "muffdiver"            => 19018,
                         "muffer"               => 24612,
                         "muffi"                => 11048,
                         "muffie"               => 13725,
                         "muffin"               => 216,
                         "muffin1"              => 5960,
                         "muffin11"             => 26923,
                         "muffin12"             => 19406,
                         "muffinman"            => 27865,
                         "muffy"                => 6347,
                         "muffy1"               => 18865,
                         "mugen"                => 25223,
                         "muggins"              => 23138,
                         "muggsy"               => 13410,
                         "mugsy"                => 12631,
                         "mugwump"              => 9783,
                         "muhtar"               => 14046,
                         "mujeres"              => 12479,
                         "mukesh"               => 19758,
                         "mulberry"             => 10677,
                         "mulch"                => 17306,
                         "mulder"               => 1159,
                         "mulder1"              => 15068,
                         "muledeer"             => 22385,
                         "muleman"              => 24618,
                         "mullet"               => 3246,
                         "multik"               => 18691,
                         "multimed"             => 17078,
                         "multipas"             => 24017,
                         "multiplelo"           => 2588,
                         "multiplelog"          => 21191,
                         "multiscan"            => 25811,
                         "multisyn"             => 9790,
                         "multisync"            => 11171,
                         "mumbles"              => 14408,
                         "mumdad"               => 19938,
                         "mummy1"               => 16886,
                         "munch"                => 5046,
                         "muncher"              => 10268,
                         "munchie"              => 10375,
                         "munchkin"             => 1425,
                         "muncho"               => 25595,
                         "munchy"               => 25088,
                         "muneca"               => 28212,
                         "munkee"               => 25551,
                         "munkey"               => 13447,
                         "munson15"             => 27128,
                         "muppet"               => 1821,
                         "muppet1"              => 27895,
                         "muppets"              => 14797,
                         "murat"                => 9932,
                         "murciela"             => 28543,
                         "murcielago"           => 21231,
                         "murder1"              => 15339,
                         "murena"               => 27477,
                         "murmansk"             => 17942,
                         "murph"                => 7369,
                         "murphy01"             => 20775,
                         "murphy1"              => 5608,
                         "murphy11"             => 29032,
                         "murphydo"             => 29344,
                         "murphys"              => 21685,
                         "murzik"               => 4944,
                         "murzilka"             => 12445,
                         "musashi"              => 3163,
                         "muschi"               => 6869,
                         "muscle"               => 1325,
                         "muscle1"              => 21788,
                         "muscles"              => 3974,
                         "muselman"             => 23067,
                         "mushin"               => 22684,
                         "mushka"               => 24616,
                         "mushroom"             => 1393,
                         "music1"               => 2073,
                         "music101"             => 26473,
                         "music11"              => 29523,
                         "music123"             => 8249,
                         "music2"               => 23775,
                         "musica"               => 2562,
                         "musical1"             => 29363,
                         "musiclover"           => 27826,
                         "musicman"             => 1264,
                         "musics"               => 15224,
                         "muskan"               => 23287,
                         "muskie"               => 9046,
                         "muskrat"              => 8868,
                         "mustafa"              => 3091,
                         "mustaine"             => 25428,
                         "mustan"               => 6384,
                         "mustang"              => 20,
                         "mustang0"             => 9193,
                         "mustang1"             => 754,
                         "mustang2"             => 5413,
                         "mustang3"             => 9357,
                         "mustang4"             => 14322,
                         "mustang5"             => 6085,
                         "mustang6"             => 4238,
                         "mustang67"            => 26350,
                         "mustang69"            => 21388,
                         "mustang7"             => 10958,
                         "mustang8"             => 8570,
                         "mustang9"             => 8342,
                         "mustangg"             => 9625,
                         "mustanggt"            => 17583,
                         "mustangs"             => 1540,
                         "mustard"              => 2770,
                         "mustard1"             => 17650,
                         "mustdie"              => 12237,
                         "mustek"               => 28806,
                         "mutabor"              => 9981,
                         "mutant"               => 5395,
                         "mutley"               => 6592,
                         "mutter"               => 7019,
                         "muttley"              => 8323,
                         "muttly"               => 23459,
                         "mutton"               => 12822,
                         "mvtnr765"             => 23693,
                         "mwq6qlzo"             => 14060,
                         "mwss474"              => 21323,
                         "mxaigtg5"             => 18368,
                         "mxyzptlk"             => 21542,
                         "my2girls"             => 17825,
                         "my2kids"              => 16949,
                         "my3girls"             => 16529,
                         "my3kids"              => 12092,
                         "my3sons"              => 7277,
                         "myangel"              => 9595,
                         "myass"                => 12507,
                         "mybabe"               => 27906,
                         "mybaby"               => 2527,
                         "myballs"              => 16606,
                         "mybitch"              => 12793,
                         "myboys"               => 8583,
                         "mybuddy"              => 14719,
                         "mybutt"               => 17709,
                         "mycats"               => 21941,
                         "mycock"               => 9619,
                         "mycroft"              => 16049,
                         "mydaddy"              => 21146,
                         "mydick"               => 4141,
                         "mydog"                => 17953,
                         "mydogs"               => 19434,
                         "mydream"              => 15046,
                         "myemail"              => 29879,
                         "myfamily"             => 12254,
                         "myfriend"             => 7187,
                         "mygal"                => 28195,
                         "mygirl"               => 3848,
                         "mygirls"              => 6874,
                         "myheart"              => 22597,
                         "myhero"               => 23961,
                         "myhome"               => 11676,
                         "myhoney"              => 24858,
                         "myhouse"              => 9044,
                         "mykids"               => 4121,
                         "mykiss"               => 24244,
                         "mykitty"              => 26922,
                         "mylady"               => 20999,
                         "mylene"               => 10946,
                         "mylife"               => 2671,
                         "mylord"               => 11269,
                         "mylov"                => 15459,
                         "mylove"               => 949,
                         "mylove1"              => 17148,
                         "mylover"              => 28499,
                         "mymail"               => 21864,
                         "mymoney"              => 10709,
                         "mymoney1"             => 23646,
                         "mymother"             => 9381,
                         "mymusic"              => 14855,
                         "myname"               => 3374,
                         "mynameis"             => 5612,
                         "mynewbots"            => 24939,
                         "mynewpas"             => 14319,
                         "mynuts"               => 19905,
                         "myopia"               => 16281,
                         "mypass"               => 1659,
                         "mypass1"              => 24155,
                         "mypasswo"             => 7490,
                         "mypassword"           => 3859,
                         "myporn"               => 6341,
                         "mypuppy"              => 28910,
                         "mypussy"              => 8560,
                         "mysecret"             => 8450,
                         "myshit"               => 14514,
                         "mysite"               => 22779,
                         "myspace"              => 7424,
                         "myspace1"             => 6342,
                         "mystere"              => 16267,
                         "mysterio"             => 10348,
                         "mystery1"             => 20684,
                         "mystic"               => 1872,
                         "mystic1"              => 24062,
                         "mystikal"             => 18812,
                         "mystuff"              => 8386,
                         "myszka"               => 9672,
                         "mythos"               => 11778,
                         "mytime"               => 6240,
                         "mytruck"              => 19323,
                         "myturn"               => 27172,
                         "mywife"               => 9139,
                         "myword"               => 17098,
                         "myworld"              => 6302,
                         "myxworld"             => 5193,
                         "myxworld4"            => 14475,
                         "mzepab"               => 11004,
                         "n.kmgfy"              => 20496,
                         "n0th1ng"              => 27289,
                         "n12345"               => 18503,
                         "n123456"              => 16658,
                         "n7td4bjl"             => 25305,
                         "n8skfswa"             => 24032,
                         "nabeel"               => 13400,
                         "nabila"               => 29113,
                         "nabisco"              => 27413,
                         "nabokov"              => 16682,
                         "nacho"                => 12086,
                         "nacho1"               => 28979,
                         "nachos"               => 6407,
                         "naciona"              => 12468,
                         "nacked"               => 8363,
                         "nadano"               => 25317,
                         "nadegda"              => 9191,
                         "nadege"               => 21391,
                         "nadejda"              => 6970,
                         "nadezda"              => 15824,
                         "nadezhda"             => 8522,
                         "nadia1"               => 17856,
                         "nadin"                => 12938,
                         "nadine1"              => 29775,
                         "nadroj"               => 16892,
                         "nadya"                => 28505,
                         "nafanya"              => 20576,
                         "nafets"               => 11157,
                         "nagrom"               => 10542,
                         "nagual"               => 17426,
                         "nahlik"               => 29435,
                         "nailer"               => 12994,
                         "nairda"               => 23529,
                         "naked"                => 1122,
                         "naked1"               => 10530,
                         "nalgas"               => 12391,
                         "nalgene"              => 29255,
                         "nalini"               => 24331,
                         "nallepuh"             => 21587,
                         "namaste"              => 3846,
                         "namron"               => 18055,
                         "namtab"               => 19488,
                         "nancy1"               => 4420,
                         "nancy123"             => 6665,
                         "nando"                => 16988,
                         "nang"                 => 3732,
                         "nanook"               => 3527,
                         "nanotech"             => 19615,
                         "nantucke"             => 25614,
                         "naomi1"               => 21124,
                         "napalm"               => 5727,
                         "napass"               => 1815,
                         "napol"                => 20440,
                         "napolean"             => 20202,
                         "napoleo"              => 17382,
                         "napoli"               => 3411,
                         "napster"              => 2892,
                         "napster1"             => 23613,
                         "naresh"               => 11861,
                         "nargiza"              => 26739,
                         "nariman"              => 12009,
                         "narkoman"             => 20199,
                         "narnia"               => 5412,
                         "narut"                => 7540,
                         "naruto"               => 501,
                         "naruto1"              => 8623,
                         "naruto12"             => 12282,
                         "naruto123"            => 12815,
                         "nascar"               => 123,
                         "nascar03"             => 19882,
                         "nascar1"              => 6303,
                         "nascar2"              => 15470,
                         "nascar20"             => 15558,
                         "nascar24"             => 4137,
                         "nascar3"              => 9735,
                         "nascar8"              => 20503,
                         "nascar88"             => 13791,
                         "nascar99"             => 17055,
                         "nasdaq"               => 10145,
                         "nashua"               => 18351,
                         "nashvill"             => 11960,
                         "nastena"              => 6854,
                         "nastenka"             => 7158,
                         "nastia"               => 5131,
                         "nastik"               => 23198,
                         "nastja"               => 14682,
                         "nasty"                => 1249,
                         "nasty1"               => 3020,
                         "nastya"               => 741,
                         "nastya123"            => 27839,
                         "nastya1995"           => 21825,
                         "nastya1996"           => 26749,
                         "nastya2010"           => 25449,
                         "nastyboy"             => 12498,
                         "nastyman"             => 17536,
                         "nata123"              => 23085,
                         "nata1980"             => 28023,
                         "nataha"               => 6913,
                         "natala"               => 22826,
                         "natali"               => 767,
                         "natalia1"             => 16532,
                         "natalie1"             => 5109,
                         "natalie2"             => 28871,
                         "nataliya"             => 12021,
                         "natalka"              => 9539,
                         "nataly"               => 5232,
                         "natas"                => 11095,
                         "natas666"             => 16991,
                         "natasa"               => 18243,
                         "natascha"             => 7370,
                         "natash"               => 11428,
                         "natasha"              => 172,
                         "natasha1"             => 5015,
                         "natasha123"           => 26016,
                         "natasha2"             => 17773,
                         "natashka"             => 10966,
                         "nataxa"               => 26967,
                         "natchez"              => 6237,
                         "natedawg"             => 16696,
                         "natedog"              => 8059,
                         "natedogg"             => 5947,
                         "natha"                => 9210,
                         "nathalia"             => 28438,
                         "nathan0"              => 19632,
                         "nathan01"             => 23163,
                         "nathan1"              => 4114,
                         "nathan12"             => 16230,
                         "nathanie"             => 6555,
                         "natura"               => 17624,
                         "natural1"             => 22181,
                         "naturals"             => 23554,
                         "naturist"             => 24140,
                         "natusik"              => 14156,
                         "natwest"              => 18314,
                         "naught"               => 7943,
                         "naughty"              => 601,
                         "naughty1"             => 5856,
                         "naughtyboy"           => 16037,
                         "naumenko"             => 27182,
                         "naumov"               => 27202,
                         "naumova"              => 28520,
                         "nausicaa"             => 24318,
                         "nautica"              => 5467,
                         "nautica1"             => 29770,
                         "nautilus"             => 4315,
                         "nautique"             => 17811,
                         "navajo"               => 5665,
                         "naveed"               => 19037,
                         "naveen"               => 12772,
                         "navidad"              => 18396,
                         "navigato"             => 7873,
                         "navigator"            => 4930,
                         "navyblue"             => 16566,
                         "navyman"              => 26555,
                         "navyseal"             => 5342,
                         "nazarenko"            => 23963,
                         "nazaret"              => 26692,
                         "nazareth"             => 11852,
                         "nazarova"             => 22075,
                         "nazgul"               => 4845,
                         "nazira"               => 15898,
                         "nbhtqa"               => 27933,
                         "nbibyf"               => 24375,
                         "nbnfybr"              => 12061,
                         "nbu3cd"               => 18617,
                         "nbuhbwf"              => 22043,
                         "nbuhtyjr"             => 8869,
                         "nbvcxw"               => 11302,
                         "nbvfnb"               => 19354,
                         "nbvibt"               => 16587,
                         "nbvjatq"              => 4841,
                         "nbvjif"               => 9321,
                         "nbvjirf"              => 13856,
                         "ncc170"               => 19232,
                         "ncc1701"              => 144,
                         "ncc1701a"             => 1808,
                         "ncc1701d"             => 604,
                         "ncc1701e"             => 1076,
                         "ncc1864"              => 22993,
                         "ncc74656"             => 5290,
                         "nccpl25282"           => 21662,
                         "ncstate"              => 22943,
                         "ndaswf"               => 15481,
                         "ndeyl5"               => 14022,
                         "ndirish"              => 9710,
                         "ndshnx4s"             => 21296,
                         "ne1469"               => 2339,
                         "nebraska"             => 1838,
                         "nebula"               => 7398,
                         "nec3520"              => 11806,
                         "necro"                => 19260,
                         "necroman"             => 19782,
                         "necromancer"          => 15639,
                         "necron"               => 14328,
                         "nectarin"             => 22541,
                         "ned467"               => 24762,
                         "nederland"            => 14945,
                         "nedkelly"             => 24741,
                         "nedved"               => 20228,
                         "need4speed"           => 29619,
                         "needajob"             => 28850,
                         "needforspeed"         => 7529,
                         "needit"               => 8995,
                         "needsex"              => 18456,
                         "needsome"             => 19965,
                         "neel21"               => 24805,
                         "neelam"               => 24521,
                         "neener"               => 16550,
                         "neeraj"               => 24333,
                         "nefertit"             => 29693,
                         "nefertiti"            => 17047,
                         "negra"                => 23050,
                         "negras"               => 12946,
                         "negril"               => 17719,
                         "negrit"               => 10545,
                         "negrita"              => 26042,
                         "negrito"              => 21815,
                         "nekkid"               => 18510,
                         "nelli"                => 16197,
                         "nelly1"               => 25199,
                         "nels0n"               => 26639,
                         "nelso"                => 9853,
                         "nelson1"              => 9978,
                         "nemesi"               => 14003,
                         "nemesis"              => 626,
                         "nemesis1"             => 7557,
                         "nemesis2"             => 29013,
                         "nemezida"             => 20943,
                         "nemiroff"             => 29876,
                         "nemisis"              => 14909,
                         "nemrac"               => 18220,
                         "nemrac58"             => 6113,
                         "nemvxyheqdd5oqxyxyzi" => 19528,
                         "neng"                 => 3157,
                         "nenit"                => 20614,
                         "neo123"               => 24681,
                         "neogeo"               => 11094,
                         "neon"                 => 5557,
                         "neopets"              => 20506,
                         "neophyte"             => 21144,
                         "nepenthe"             => 25396,
                         "nephilim"             => 19881,
                         "neptun"               => 10826,
                         "neptune"              => 1323,
                         "neptune1"             => 19473,
                         "nermal"               => 6778,
                         "nermin"               => 24438,
                         "neruda"               => 15836,
                         "nescafe"              => 17027,
                         "nessie"               => 9033,
                         "nesta"                => 24383,
                         "nestea"               => 22959,
                         "nesterov"             => 18272,
                         "nesterova"            => 28567,
                         "nestle"               => 6355,
                         "netcom"               => 18760,
                         "netgear"              => 16537,
                         "netman"               => 21505,
                         "netnwlnk"             => 24867,
                         "netpass"              => 28260,
                         "netscape"             => 3437,
                         "netsnip"              => 24849,
                         "netvideo"             => 17211,
                         "netware"              => 14423,
                         "netware1"             => 29264,
                         "network1"             => 9622,
                         "network2"             => 27807,
                         "networkingpe"         => 16791,
                         "netzwerk"             => 13042,
                         "neuken"               => 11274,
                         "neuron"               => 11546,
                         "neuspeed"             => 18609,
                         "neutrino"             => 15568,
                         "neutron"              => 6488,
                         "nevada"               => 1866,
                         "nevaeh"               => 16590,
                         "never1"               => 8412,
                         "neveraga"             => 26808,
                         "neveragain"           => 11820,
                         "neverdie"             => 17144,
                         "nevergiveup"          => 25264,
                         "neverland"            => 16957,
                         "neverman"             => 27269,
                         "nevermin"             => 6252,
                         "nevermind"            => 3731,
                         "nevermor"             => 8923,
                         "nevermore"            => 5266,
                         "neverwinter"          => 23435,
                         "nevets"               => 5026,
                         "new123"               => 11627,
                         "newage"               => 10148,
                         "newark"               => 5434,
                         "newbaby"              => 21960,
                         "newbie"               => 2628,
                         "newblood"             => 27226,
                         "newburgh"             => 20233,
                         "newcar"               => 20958,
                         "newcastl"             => 2556,
                         "newday"               => 8000,
                         "newdelhi"             => 18532,
                         "newera"               => 21894,
                         "newfie"               => 14217,
                         "newguy"               => 11629,
                         "newhaven"             => 15532,
                         "newhome"              => 19820,
                         "newhope"              => 19279,
                         "newjerse"             => 16641,
                         "newjersey"            => 15460,
                         "newjob"               => 8571,
                         "newlife"              => 1341,
                         "newlife1"             => 10980,
                         "newlife2"             => 28383,
                         "newlove"              => 23466,
                         "newman1"              => 14989,
                         "newmedia"             => 29325,
                         "newmexic"             => 19681,
                         "newmexico"            => 29313,
                         "newmoney"             => 27007,
                         "newmoon"              => 11599,
                         "newness"              => 6880,
                         "newone"               => 7239,
                         "neworder"             => 7207,
                         "neworlea"             => 19933,
                         "neworleans"           => 19242,
                         "newpass"              => 1403,
                         "newpass1"             => 7685,
                         "newpass3"             => 23788,
                         "newpass6"             => 3111,
                         "newpassw"             => 28646,
                         "newpassword"          => 15033,
                         "newpoint"             => 15113,
                         "newport"              => 670,
                         "newport1"             => 7789,
                         "newports"             => 11639,
                         "newproject2004"       => 7450,
                         "newshoes"             => 19304,
                         "newspape"             => 28038,
                         "newstart"             => 7263,
                         "newstyle"             => 10292,
                         "newto"                => 28528,
                         "newton1"              => 15255,
                         "newuser"              => 6600,
                         "newworld"             => 10129,
                         "newyear"              => 5358,
                         "newyor"               => 13238,
                         "newyork"              => 234,
                         "newyork1"             => 2654,
                         "newyork2"             => 28289,
                         "newyorke"             => 25870,
                         "newzeala"             => 24431,
                         "newzealand"           => 16720,
                         "nextdoor"             => 24259,
                         "nextel"               => 3679,
                         "nexus"                => 8109,
                         "nexus1"               => 22887,
                         "nexus6"               => 6960,
                         "nezabudka"            => 15400,
                         "nfbcbz"               => 13686,
                         "nfhfrfy"              => 6867,
                         "nfhtkrf"              => 27032,
                         "nfkbcvfy"             => 27334,
                         "nfnfhby"              => 15950,
                         "nfnmzyf"              => 813,
                         "nfnmzyrf"             => 24884,
                         "nfqcjy"               => 22263,
                         "nfvfhf"               => 9478,
                         "nfvthkfy"             => 14839,
                         "nfy.irf"              => 8064,
                         "nfymrf"               => 21109,
                         "nfyrbcn"              => 24445,
                         "nfytxrf"              => 4285,
                         "nfyufh"               => 13455,
                         "nfyz123"              => 23543,
                         "ngc4565"              => 23337,
                         "nhecsyfujkjdt"        => 24462,
                         "nhfdvfnjkju123"       => 20200,
                         "nhfkbdfkb"            => 25937,
                         "nhfkzkz"              => 29380,
                         "nhfnfnf"              => 23024,
                         "nhfrnjh"              => 8266,
                         "nhfrnjhbcn"           => 29010,
                         "nhfycajhvths"         => 26722,
                         "niagra"               => 26532,
                         "niang"                => 3635,
                         "niao"                 => 3378,
                         "nibbles"              => 9979,
                         "nibiru"               => 25971,
                         "niblick"              => 21163,
                         "niceass"              => 3938,
                         "niceday"              => 9198,
                         "nicegirl"             => 22576,
                         "niceguy"              => 3909,
                         "niceone"              => 11987,
                         "nicerack"             => 21382,
                         "nicetits"             => 6335,
                         "nicetry"              => 24504,
                         "nichol1"              => 18101,
                         "nichola"              => 8432,
                         "nicholas1"            => 10071,
                         "nick01"               => 22191,
                         "nick11"               => 23897,
                         "nick12"               => 12833,
                         "nick123"              => 12898,
                         "nick1234"             => 14096,
                         "nickel"               => 2772,
                         "nickers"              => 27465,
                         "nicklaus"             => 16231,
                         "nickle"               => 9325,
                         "nicksfun"             => 24570,
                         "nicky1"               => 8149,
                         "nicnac"               => 29929,
                         "nico"                 => 5753,
                         "nicola"               => 1078,
                         "nicola1"              => 18385,
                         "nicolas1"             => 16042,
                         "nicolas2"             => 25229,
                         "nicole0"              => 29149,
                         "nicole01"             => 27797,
                         "nicole1"              => 2414,
                         "nicole11"             => 19496,
                         "nicole12"             => 20539,
                         "nicole123"            => 29267,
                         "nicole18"             => 23929,
                         "nicole2"              => 12422,
                         "nicole23"             => 22253,
                         "nicole3"              => 25732,
                         "nicolett"             => 20554,
                         "nicosnn"              => 19166,
                         "nietzsch"             => 11458,
                         "niewiem"              => 26679,
                         "nigel1"               => 19941,
                         "nigga"                => 3901,
                         "nigga1"               => 11565,
                         "niggas"               => 8866,
                         "niggaz"               => 7781,
                         "nigge"                => 21964,
                         "nigger"               => 562,
                         "nigger1"              => 7406,
                         "nigger123"            => 25841,
                         "niggers"              => 6860,
                         "night1"               => 14942,
                         "nightcrawler"         => 21521,
                         "nightfal"             => 25000,
                         "nighthaw"             => 9474,
                         "nighthawk"            => 14770,
                         "nightime"             => 21539,
                         "nightman"             => 15076,
                         "nightmar"             => 5461,
                         "nightowl"             => 6247,
                         "nightshade"           => 29578,
                         "nightwin"             => 6417,
                         "nightwing"            => 17815,
                         "nightwis"             => 25579,
                         "nightwish"            => 5014,
                         "nightwolf"            => 15061,
                         "nihao123"             => 16130,
                         "nihaoma"              => 24549,
                         "nihongo"              => 10159,
                         "nike"                 => 2586,
                         "nike1234"             => 22343,
                         "nike23"               => 22733,
                         "nikeair"              => 17463,
                         "nikhil"               => 19524,
                         "nikifor"              => 29311,
                         "nikit"                => 10120,
                         "nikita"               => 151,
                         "nikita1"              => 8019,
                         "nikita123"            => 10416,
                         "nikita1998"           => 23417,
                         "nikita2000"           => 21064,
                         "nikita95"             => 23089,
                         "nikita99"             => 26930,
                         "nikitin"              => 9690,
                         "nikitina"             => 10489,
                         "nikitka"              => 12713,
                         "nikitos"              => 3503,
                         "nikki1"               => 3958,
                         "nikki123"             => 23052,
                         "nikki2"               => 16378,
                         "nikki69"              => 29151,
                         "nikkie"               => 12685,
                         "nikkii"               => 15707,
                         "nikkis"               => 24308,
                         "nikkita"              => 28281,
                         "nikko"                => 9588,
                         "nikko1"               => 29289,
                         "niklas"               => 8013,
                         "nikola"               => 2257,
                         "nikolaev"             => 12198,
                         "nikolaeva"            => 12163,
                         "nikolaevna"           => 26395,
                         "nikolai"              => 4520,
                         "nikolaj"              => 16401,
                         "nikolaus"             => 10573,
                         "nikolay"              => 2854,
                         "nikolay9"             => 27245,
                         "nikon"                => 6813,
                         "nikon1"               => 17379,
                         "nikusha"              => 14220,
                         "nilknarf"             => 20370,
                         "nilrem"               => 15266,
                         "nimbus"               => 3108,
                         "nimda"                => 21444,
                         "nimda2k"              => 12512,
                         "nimitz"               => 6134,
                         "nimrod"               => 1400,
                         "nimrod1"              => 27339,
                         "nina1"                => 29709,
                         "nina123"              => 21527,
                         "nine09"               => 27241,
                         "nineball"             => 6046,
                         "nineinch"             => 5077,
                         "niners"               => 1219,
                         "ning"                 => 3400,
                         "ninguna"              => 9147,
                         "ninja"                => 1311,
                         "ninja1"               => 3534,
                         "ninja123"             => 27854,
                         "ninja9"               => 24369,
                         "ninjaman"             => 17675,
                         "ninjas"               => 3174,
                         "ninjutsu"             => 25655,
                         "nintend"              => 23254,
                         "nintendo"             => 366,
                         "nintendo1"            => 19074,
                         "nintendo64"           => 18829,
                         "nipper"               => 2508,
                         "nipple"               => 1068,
                         "nipples"              => 818,
                         "nipples1"             => 28620,
                         "nippon"               => 9299,
                         "nirmal"               => 18606,
                         "nirmala"              => 19290,
                         "nirvan"               => 7988,
                         "nirvana"              => 268,
                         "nirvana1"             => 4276,
                         "nirvana9"             => 28718,
                         "nissa"                => 15682,
                         "nissan"               => 303,
                         "nissan1"              => 6812,
                         "nissan350z"           => 19797,
                         "nisse"                => 15402,
                         "nitehawk"             => 16255,
                         "nitemare"             => 22692,
                         "nitram"               => 2677,
                         "nitro"                => 4339,
                         "nitro1"               => 13367,
                         "nitros"               => 28283,
                         "nitrous"              => 9525,
                         "nitrox"               => 9174,
                         "nitsua"               => 26184,
                         "nitsuj"               => 15554,
                         "nittany"              => 5185,
                         "niunia"               => 11083,
                         "nivek"                => 17674,
                         "nivram"               => 17171,
                         "njdevils"             => 9940,
                         "njhvjp"               => 25335,
                         "njhyflj"              => 23737,
                         "nji90okm"             => 29324,
                         "njkcnsq"              => 12170,
                         "njkmrjz"              => 27098,
                         "njnets"               => 13751,
                         "njqcw4"               => 13793,
                         "nn527hp"              => 26222,
                         "nnagqx"               => 13511,
                         "nnmaster"             => 23274,
                         "nnnnn1"               => 14055,
                         "nnnnnn1"              => 24514,
                         "nnnnnnn1"             => 24945,
                         "nnssnn"               => 17067,
                         "noaccess"             => 17079,
                         "nobby"                => 15942,
                         "nobody1"              => 29900,
                         "nobull"               => 29589,
                         "nochance"             => 13150,
                         "noclue"               => 20377,
                         "nocode"               => 15166,
                         "nocturne"             => 7203,
                         "noddy"                => 21257,
                         "nodnarb"              => 26980,
                         "nodoubt"              => 10351,
                         "nodrog"               => 10990,
                         "noentry"              => 20795,
                         "nofags"               => 21489,
                         "nofate"               => 20659,
                         "nofear"               => 1906,
                         "nogard"               => 7960,
                         "noggin"               => 14818,
                         "nogood"               => 13945,
                         "nohack04"             => 14323,
                         "noidea"               => 16869,
                         "noisette"             => 19095,
                         "nokia"                => 1803,
                         "nokia1"               => 5328,
                         "nokia123"             => 6184,
                         "nokia2700"            => 22967,
                         "nokia3110"            => 18103,
                         "nokia3230"            => 15759,
                         "nokia3250"            => 9367,
                         "nokia3310"            => 10506,
                         "nokia5130"            => 7153,
                         "nokia5200"            => 25962,
                         "nokia5228"            => 16818,
                         "nokia5230"            => 7709,
                         "nokia5300"            => 10233,
                         "nokia5310"            => 11621,
                         "nokia5320"            => 19484,
                         "nokia5530"            => 6624,
                         "nokia5610"            => 29221,
                         "nokia5800"            => 6016,
                         "nokia6120"            => 14478,
                         "nokia6131"            => 26397,
                         "nokia6230"            => 17456,
                         "nokia6230i"           => 21289,
                         "nokia6233"            => 4331,
                         "nokia6300"            => 2818,
                         "nokia6303"            => 11823,
                         "nokia6500"            => 26428,
                         "nokia6630"            => 19483,
                         "nokia7070"            => 25926,
                         "nokia7610"            => 13749,
                         "nokia8800"            => 13160,
                         "nokiaa"               => 24376,
                         "nokiadermo"           => 25339,
                         "nokiae51"             => 28442,
                         "nokian"               => 23448,
                         "nokian70"             => 9506,
                         "nokian73"             => 4722,
                         "nokian95"             => 13391,
                         "nokias"               => 14583,
                         "nokiax2"              => 24791,
                         "nokids"               => 12323,
                         "nolan1"               => 18641,
                         "noles1"               => 6199,
                         "nolife"               => 20759,
                         "nolimit"              => 1180,
                         "nolimit5"             => 15881,
                         "nolimit8"             => 11970,
                         "nolimit9"             => 12759,
                         "nolimits"             => 9300,
                         "nollie"               => 29811,
                         "nolove"               => 11017,
                         "nomad"                => 4766,
                         "nomad1"               => 12041,
                         "nomads"               => 9503,
                         "nomames"              => 23355,
                         "nomar"                => 22840,
                         "nomar5"               => 9267,
                         "nomarg"               => 20900,
                         "nomercy"              => 12886,
                         "nomis"                => 24744,
                         "nomoney"              => 22503,
                         "nomore"               => 3366,
                         "noname"               => 4892,
                         "noname123"            => 4689,
                         "noncapa0"             => 16404,
                         "nondriversig"         => 28634,
                         "none1"                => 28446,
                         "noneya"               => 20131,
                         "nong"                 => 3165,
                         "nonmembe"             => 8012,
                         "nonrev"               => 22269,
                         "nonrev67"             => 10015,
                         "nonstop"              => 7271,
                         "noodle"               => 1933,
                         "noodle1"              => 26089,
                         "noodles"              => 1615,
                         "noodles1"             => 20947,
                         "nookie"               => 1419,
                         "nooner"               => 17527,
                         "noonie"               => 21794,
                         "nopasaran"            => 27614,
                         "nopass"               => 1632,
                         "nopasswo"             => 16212,
                         "nopassword"           => 6234,
                         "norcal"               => 16312,
                         "noreaga"              => 20236,
                         "noremac"              => 26265,
                         "norma1"               => 19578,
                         "norman1"              => 18749,
                         "normandy"             => 5512,
                         "norseman"             => 22856,
                         "nortel"               => 13607,
                         "north1"               => 14966,
                         "northsta"             => 10898,
                         "northstar"            => 18554,
                         "northwes"             => 17584,
                         "norton1"              => 19332,
                         "norwegen"             => 21677,
                         "norwest"              => 29101,
                         "norwich"              => 4046,
                         "nosaints"             => 23825,
                         "nosaj"                => 13521,
                         "nosferat"             => 9543,
                         "nosferatu"            => 6305,
                         "nosgoth"              => 20962,
                         "noshit"               => 14264,
                         "noskcaj"              => 26879,
                         "nosliw"               => 27987,
                         "nosmas"               => 27498,
                         "nospam"               => 23247,
                         "nosredna"             => 27759,
                         "nostra"               => 18805,
                         "nostromo"             => 4181,
                         "not4u2c"              => 28122,
                         "not4u2no"             => 28447,
                         "not4you"              => 7734,
                         "notagain"             => 11745,
                         "note1234"             => 12902,
                         "notebook"             => 4881,
                         "notgood"              => 27060,
                         "nothanks"             => 25933,
                         "nothere"              => 28088,
                         "nothing0"             => 24709,
                         "nothing1"             => 6477,
                         "notime"               => 16836,
                         "notlob"               => 22884,
                         "notme"                => 24546,
                         "notmine"              => 24184,
                         "notnow"               => 6301,
                         "notoriou"             => 14973,
                         "notredam"             => 5655,
                         "notredame"            => 9910,
                         "nottingh"             => 16530,
                         "nottoday"             => 23866,
                         "notused"              => 4705,
                         "notyou"               => 16122,
                         "notyours"             => 18684,
                         "nougat"               => 15924,
                         "nounour"              => 27674,
                         "nounours"             => 5520,
                         "novartis"             => 13702,
                         "novass"               => 19614,
                         "novastar"             => 21414,
                         "novell"               => 3064,
                         "novembe"              => 14069,
                         "novembre"             => 16704,
                         "novifarm"             => 8882,
                         "novikov"              => 10109,
                         "novikova"             => 8070,
                         "noway"                => 4986,
                         "noway1"               => 19384,
                         "nowayman"             => 23125,
                         "nowayout"             => 15701,
                         "nowwowtg"             => 16573,
                         "npyxr5"               => 14677,
                         "nqdgxz"               => 18374,
                         "nremtp"               => 17974,
                         "nsync"                => 28263,
                         "nt5d27"               => 15107,
                         "nthtvjr"              => 28810,
                         "nthvbyfnjh"           => 5555,
                         "ntktajy"              => 3373,
                         "ntktdbpjh"            => 6503,
                         "ntktgepbr"            => 29164,
                         "nuaddn9561"           => 25370,
                         "nuan"                 => 3456,
                         "nubian"               => 9724,
                         "nude"                 => 3171,
                         "nudegirl"             => 28116,
                         "nudelamb"             => 19476,
                         "nudes"                => 4364,
                         "nudist"               => 2484,
                         "nudity"               => 7071,
                         "nugget"               => 1088,
                         "nugget1"              => 16617,
                         "nuggets"              => 3262,
                         "nuggets1"             => 26176,
                         "nuggett"              => 29646,
                         "nujbhc"               => 16849,
                         "nukem"                => 22236,
                         "numark"               => 11925,
                         "number1"              => 2074,
                         "number2"              => 11527,
                         "number20"             => 20542,
                         "number3"              => 21469,
                         "number5"              => 14615,
                         "number6"              => 9561,
                         "number7"              => 14621,
                         "number8"              => 26321,
                         "number9"              => 9241,
                         "numberon"             => 17860,
                         "numbnuts"             => 11391,
                         "numlock"              => 8991,
                         "numpty"               => 24748,
                         "nunya"                => 28933,
                         "nunzio"               => 12362,
                         "nurbek"               => 10917,
                         "nurbol"               => 16651,
                         "nurgle"               => 15340,
                         "nurich"               => 26996,
                         "nurik"                => 16585,
                         "nurjan"               => 24311,
                         "nurlan"               => 6587,
                         "nurse1"               => 11892,
                         "nursultan"            => 20794,
                         "nusrat"               => 29509,
                         "nutella"              => 7923,
                         "nutmeg"               => 3853,
                         "nutsac"               => 29068,
                         "nutsack"              => 9941,
                         "nuttertools"          => 1575,
                         "nvidia"               => 9870,
                         "nwo4life"             => 2340,
                         "nx74205"              => 12158,
                         "nygiants"             => 3982,
                         "nyjets"               => 2282,
                         "nyknicks"             => 10745,
                         "nylon"                => 13235,
                         "nylons"               => 1207,
                         "nymets"               => 1391,
                         "nymets1"              => 28149,
                         "nympho"               => 5806,
                         "nyranger"             => 29242,
                         "nytimes"              => 26975,
                         "nyyankee"             => 8867,
                         "nyyankees"            => 28443,
                         "nyyanks"              => 21874,
                         "o123456"              => 27275,
                         "o236nq"               => 18995,
                         "o4izdmxu"             => 19818,
                         "oakland"              => 1460,
                         "oakland1"             => 15002,
                         "oakridge"             => 16140,
                         "oaktown"              => 26593,
                         "oaktree"              => 6481,
                         "oakwood"              => 12002,
                         "oasis"                => 2880,
                         "oasis1"               => 7962,
                         "oatmeal"              => 3947,
                         "obafgkm"              => 27505,
                         "obelisk"              => 12049,
                         "obelix"               => 3543,
                         "oberon"               => 4972,
                         "obiwan"               => 1332,
                         "oblivion"             => 1548,
                         "obsessio"             => 22371,
                         "obsidian"             => 4696,
                         "obvious1"             => 25627,
                         "oc247ngucz"           => 10369,
                         "ocarina"              => 9890,
                         "ocean1"               => 8871,
                         "ocean11"              => 13628,
                         "oceane"               => 17529,
                         "oceano"               => 20711,
                         "oceans"               => 3334,
                         "oceans11"             => 10262,
                         "ocelot"               => 6457,
                         "octagon"              => 12473,
                         "octane"               => 16940,
                         "octavian"             => 10729,
                         "octobe"               => 18077,
                         "october1"             => 8453,
                         "october2"             => 9310,
                         "october3"             => 21358,
                         "october6"             => 22463,
                         "october7"             => 24196,
                         "october8"             => 19995,
                         "octopus"              => 5678,
                         "octopuss"             => 14511,
                         "oddball"              => 19799,
                         "oddjob"               => 10986,
                         "oddworld"             => 19036,
                         "odelay"               => 22093,
                         "odense"               => 14197,
                         "odgez8j3"             => 28242,
                         "odin"                 => 6815,
                         "odinthor"             => 24878,
                         "odt4p6sv8"            => 25644,
                         "odysseus"             => 10322,
                         "odyssey"              => 5076,
                         "oedipus"              => 7659,
                         "oemdlg"               => 10844,
                         "ofclr278"             => 25611,
                         "ofcourse"             => 26366,
                         "office1"              => 19287,
                         "offroad"              => 7143,
                         "offsprin"             => 13478,
                         "oglala"               => 27617,
                         "ogoshi"               => 26787,
                         "ohbaby"               => 8719,
                         "ohboy"                => 21544,
                         "ohiostat"             => 12159,
                         "ohiostate"            => 12823,
                         "ohlala"               => 25592,
                         "ohmygod"              => 6443,
                         "ohotnik"              => 28247,
                         "ohshit"               => 4214,
                         "ohwell"               => 17543,
                         "ohyeah"               => 1624,
                         "ohyeah1"              => 19537,
                         "ohyes"                => 29111,
                         "oi812"                => 29521,
                         "oicu812"              => 918,
                         "oilers"               => 1910,
                         "oilman"               => 9287,
                         "oinker"               => 24636,
                         "oiseau"               => 21478,
                         "ojp123456"            => 26805,
                         "okaykk"               => 27185,
                         "okidoki"              => 13182,
                         "oklick"               => 12145,
                         "okmijn"               => 8179,
                         "oksana"               => 558,
                         "oktober"              => 10079,
                         "oktober7"             => 18246,
                         "ola123"               => 21683,
                         "olamide"              => 13501,
                         "olcrackmaster"        => 18868,
                         "olddog"               => 13598,
                         "oldfart"              => 7281,
                         "oldguy"               => 18665,
                         "oldman"               => 1326,
                         "oldmans"              => 29533,
                         "oldnavy"              => 10161,
                         "oldno7"               => 26869,
                         "oldone"               => 9263,
                         "oldpussy"             => 26130,
                         "olds442"              => 9851,
                         "oldschoo"             => 16309,
                         "oldschool"            => 9351,
                         "oldskool"             => 27523,
                         "oldsmobi"             => 13530,
                         "oldsmobile"           => 16201,
                         "oldspice"             => 15406,
                         "oldtimer"             => 15866,
                         "ole4ka"               => 17787,
                         "oleander"             => 19076,
                         "olechka"              => 10011,
                         "oleg"                 => 2329,
                         "oleg123"              => 23991,
                         "oleg1994"             => 24668,
                         "oleg1995"             => 19643,
                         "oleg1996"             => 26792,
                         "olegnaruto"           => 17097,
                         "olemiss"              => 6150,
                         "olemiss1"             => 28456,
                         "olenka"               => 5581,
                         "olesia"               => 17334,
                         "olesica"              => 27898,
                         "olesja"               => 28042,
                         "olesya"               => 4152,
                         "olga123"              => 12687,
                         "olga1976"             => 24870,
                         "oligarh"              => 28813,
                         "olive1"               => 15515,
                         "oliveoil"             => 13646,
                         "oliver"               => 158,
                         "oliver1"              => 3120,
                         "oliver2"              => 26273,
                         "olivetti"             => 10521,
                         "olivi"                => 10992,
                         "olivia1"              => 9527,
                         "olivier"              => 2541,
                         "olivier1"             => 28919,
                         "ollie1"               => 12234,
                         "ollieb"               => 27996,
                         "ololo"                => 17131,
                         "ololo123"             => 20937,
                         "olorin"               => 13316,
                         "olympus"              => 4896,
                         "omanko"               => 9430,
                         "omar10"               => 12435,
                         "omega"                => 1082,
                         "omega1"               => 1790,
                         "omega123"             => 13363,
                         "omega13"              => 20555,
                         "omega2"               => 10664,
                         "omega3"               => 10725,
                         "omega5"               => 14020,
                         "omega7"               => 13827,
                         "omega9"               => 18950,
                         "omegaman"             => 15530,
                         "omegared"             => 7736,
                         "omegas"               => 12711,
                         "omerta"               => 8395,
                         "omg123"               => 21271,
                         "omgkremidia"          => 19330,
                         "omgwtf"               => 20806,
                         "omgwtfbbq"            => 20841,
                         "omicron"              => 8020,
                         "omnislash"            => 28349,
                         "omsairam"             => 9222,
                         "onclick"              => 11051,
                         "one2one"              => 26217,
                         "one4all"              => 14971,
                         "oneday"               => 15817,
                         "oneeye"               => 12219,
                         "onelov"               => 27246,
                         "onelove"              => 1129,
                         "onelove1"             => 12492,
                         "oneluv"               => 18469,
                         "oneman"               => 13104,
                         "onemore"              => 21731,
                         "onepiece"             => 8555,
                         "oneputt"              => 25097,
                         "onering"              => 17789,
                         "oneshot"              => 10778,
                         "onetime"              => 3112,
                         "oneton"               => 10085,
                         "onetwo"               => 3804,
                         "onetwo12"             => 26804,
                         "onetwo34"             => 29342,
                         "onetwothree"          => 29690,
                         "oneway"               => 13051,
                         "onfire"               => 14600,
                         "onion"                => 4895,
                         "onions"               => 5857,
                         "onizuka"              => 25588,
                         "onkelz"               => 12246,
                         "onlin"                => 28728,
                         "online"               => 345,
                         "online1"              => 9831,
                         "only4me"              => 13871,
                         "onlyme"               => 2390,
                         "onlyone"              => 6262,
                         "onlyone1"             => 26120,
                         "onlyone4"             => 16790,
                         "onlyyou"              => 15708,
                         "ontheoutside"         => 29660,
                         "ontheroc"             => 16974,
                         "ontherocks"           => 18994,
                         "ontime"               => 16919,
                         "oohrah"               => 22290,
                         "ooicu812"             => 27168,
                         "oompah"               => 26085,
                         "ooooo1"               => 13278,
                         "oooooo1"              => 22905,
                         "oooooo99"             => 22427,
                         "ooooooo1"             => 29841,
                         "oooppp"               => 21897,
                         "oou812"               => 21967,
                         "opelagila"            => 28168,
                         "opelastra"            => 16610,
                         "opelgt"               => 27567,
                         "open1"                => 20386,
                         "open12"               => 28804,
                         "open123"              => 8841,
                         "open1234"             => 8819,
                         "open321"              => 29170,
                         "open4me"              => 11646,
                         "opendoor"             => 4937,
                         "openit"               => 6554,
                         "openme"               => 7135,
                         "opennow"              => 5313,
                         "opensesa"             => 11723,
                         "opensesame"           => 9187,
                         "openup"               => 865,
                         "openwide"             => 17429,
                         "operatio"             => 14528,
                         "operator"             => 2293,
                         "opiate"               => 6706,
                         "opopop11"             => 17239,
                         "optima"               => 7070,
                         "optimist"             => 5010,
                         "optimus"              => 2922,
                         "optimus1"             => 25171,
                         "optiplex"             => 7666,
                         "optiquest"            => 23862,
                         "opus"                 => 6448,
                         "opusone"              => 28645,
                         "oqglh565"             => 15144,
                         "oracle"               => 1573,
                         "oralsex"              => 8677,
                         "orang"                => 6988,
                         "orange"               => 94,
                         "orange01"             => 29766,
                         "orange1"              => 2711,
                         "orange10"             => 23843,
                         "orange11"             => 26208,
                         "orange12"             => 9592,
                         "orange2"              => 16864,
                         "orange22"             => 29031,
                         "orange3"              => 18301,
                         "orange44"             => 12088,
                         "orange6"              => 28799,
                         "orange77"             => 13847,
                         "orange8"              => 10956,
                         "orange88"             => 27139,
                         "orange99"             => 21583,
                         "oranges"              => 2055,
                         "oranges1"             => 15486,
                         "orbita"               => 16508,
                         "orchard"              => 5433,
                         "orchid"               => 2924,
                         "orenburg"             => 20898,
                         "oreo"                 => 4955,
                         "orgasm"               => 2150,
                         "orgasmic"             => 21090,
                         "orgasms"              => 7284,
                         "orgy"                 => 6348,
                         "oriana"               => 27046,
                         "orient"               => 3580,
                         "oriflame"             => 9782,
                         "origami"              => 14585,
                         "oriole"               => 10894,
                         "orioles"              => 2036,
                         "orioles1"             => 19021,
                         "orion"                => 1216,
                         "orion1"               => 3370,
                         "orion123"             => 26840,
                         "orion2"               => 12779,
                         "orion3"               => 27256,
                         "orion7"               => 28186,
                         "orions"               => 14584,
                         "orkiox."              => 10350,
                         "orland"               => 10042,
                         "orlando1"             => 9448,
                         "orlova"               => 11061,
                         "ornw6d"               => 13654,
                         "orochimaru"           => 29638,
                         "orosie1"              => 28802,
                         "orpheus"              => 6802,
                         "ortezza"              => 25107,
                         "orwell"               => 7480,
                         "osama"                => 8160,
                         "osasuna"              => 27922,
                         "oscar1"               => 1785,
                         "oscar123"             => 9462,
                         "oscar2"               => 14570,
                         "oscardog"             => 16218,
                         "oscarr"               => 18830,
                         "oscars"               => 6873,
                         "oshkosh"              => 16840,
                         "osipov"               => 23433,
                         "osiris"               => 1458,
                         "osito"                => 26874,
                         "osprey"               => 6620,
                         "ostrov"               => 16515,
                         "ostsee"               => 25122,
                         "oswego"               => 15298,
                         "otello"               => 17286,
                         "othello"              => 3220,
                         "other1"               => 20881,
                         "otherside"            => 28265,
                         "otter"                => 7583,
                         "otter1"               => 23142,
                         "otters"               => 9756,
                         "ottom"                => 24888,
                         "ou812"                => 428,
                         "ou8122"               => 2736,
                         "ou8123"               => 4984,
                         "ou81234"              => 28994,
                         "ou812345"             => 23721,
                         "ou8124me"             => 16264,
                         "ou81269"              => 23707,
                         "ou812a"               => 23988,
                         "ou812ic"              => 10929,
                         "ousooner"             => 27771,
                         "oussama"              => 29474,
                         "out3xf"               => 10391,
                         "outback"              => 5262,
                         "outkast"              => 2632,
                         "outlaw"               => 737,
                         "outlaw1"              => 23778,
                         "outlaws"              => 7613,
                         "outlawz"              => 12844,
                         "outside1"             => 27349,
                         "outsider"             => 6169,
                         "ov3ajy"               => 15410,
                         "ovation"              => 8232,
                         "overdriv"             => 21871,
                         "overkill"             => 2845,
                         "overlord"             => 1054,
                         "ow8jtcs8t"            => 28837,
                         "owen10"               => 21535,
                         "owen11"               => 29025,
                         "ownage"               => 6416,
                         "ownage123"            => 24585,
                         "ownsu"                => 13997,
                         "ownzyou"              => 13888,
                         "ox3ford"              => 26658,
                         "oxcart"               => 20456,
                         "oxford"               => 1263,
                         "oxnard"               => 16282,
                         "oxymoron"             => 18358,
                         "oyster"               => 6091,
                         "ozlq6qwm"             => 13680,
                         "ozzie"                => 7989,
                         "ozzie1"               => 11563,
                         "ozzman"               => 14717,
                         "ozzmosis"             => 29674,
                         "ozzy"                 => 3658,
                         "ozzy666"              => 24641,
                         "p0015123"             => 2413,
                         "p00kie"               => 13015,
                         "p030710p\$e4o"        => 20822,
                         "p0o9i8"               => 6878,
                         "p0o9i8u7"             => 5238,
                         "p0o9i8u7y6"           => 24781,
                         "p12345"               => 13259,
                         "p123456"              => 17453,
                         "p1234567"             => 19721,
                         "p2ssw0rd"             => 21328,
                         "p3e85tr"              => 15151,
                         "p3nnywiz"             => 22436,
                         "p3orion"              => 24648,
                         "p3wqaw"               => 13269,
                         "p455w0rd"             => 8445,
                         "p4ssw0rd"             => 4987,
                         "p4ssword"             => 15730,
                         "p\@ssw0rd"            => 4795,
                         "pa\$\$w0rd"           => 23325,
                         "pa437tu"              => 28780,
                         "pa55w0rd"             => 1826,
                         "pa55wd"               => 28524,
                         "pa55word"             => 1593,
                         "pablit"               => 26556,
                         "pablito"              => 10038,
                         "pablo1"               => 9916,
                         "pablo123"             => 27143,
                         "pablos"               => 17202,
                         "pacers"               => 3001,
                         "pachanga"             => 25410,
                         "pacific1"             => 13861,
                         "pacifica"             => 10824,
                         "pacino"               => 5407,
                         "packard"              => 781,
                         "packard1"             => 8357,
                         "packer"               => 2125,
                         "packer1"              => 16896,
                         "packers"              => 253,
                         "packers1"             => 2275,
                         "packers2"             => 27439,
                         "packers4"             => 11286,
                         "packman"              => 11294,
                         "packrat"              => 12678,
                         "pacman"               => 1724,
                         "paco"                 => 4685,
                         "padawan"              => 25679,
                         "paddle"               => 3755,
                         "paddy"                => 7445,
                         "paddy1"               => 17319,
                         "padres"               => 2703,
                         "padrino"              => 27253,
                         "paganini"             => 14364,
                         "pagedown"             => 22064,
                         "paige1"               => 10267,
                         "paigow"               => 28572,
                         "pain4me"              => 14229,
                         "painkill"             => 24646,
                         "painkiller"           => 11518,
                         "paint1"               => 19398,
                         "paintbal"             => 2612,
                         "paintball"            => 2701,
                         "paintball1"           => 22377,
                         "painter1"             => 17975,
                         "paisley"              => 6534,
                         "paiste"               => 17910,
                         "pajaro"               => 14576,
                         "pajero"               => 5788,
                         "pakalolo"             => 25246,
                         "pakista"              => 6649,
                         "pakistan"             => 369,
                         "pakistan1"            => 28162,
                         "palace1"              => 24538,
                         "palace22"             => 28117,
                         "paladin"              => 985,
                         "paladin1"             => 5892,
                         "paladine"             => 21935,
                         "palantir"             => 21457,
                         "paleale"              => 12212,
                         "palenque"             => 20895,
                         "palermo1"             => 27367,
                         "palevo"               => 27189,
                         "palladin"             => 28585,
                         "pallas"               => 13157,
                         "pallet"               => 28564,
                         "pallina"              => 26572,
                         "pallino"              => 13373,
                         "pallmall"             => 4022,
                         "palmeira"             => 22160,
                         "palmeiras"            => 20493,
                         "palmer1"              => 26003,
                         "palmetto"             => 10265,
                         "palmtree"             => 4365,
                         "paloalto"             => 13977,
                         "palom"                => 14146,
                         "paloma"               => 3239,
                         "palpatin"             => 23777,
                         "pamel"                => 7785,
                         "pamela1"              => 9052,
                         "pammy"                => 22175,
                         "pampers"              => 11118,
                         "panacea"              => 10891,
                         "panache"              => 7533,
                         "panam"                => 21744,
                         "panama"               => 1140,
                         "panama1"              => 15672,
                         "panasoni"             => 2528,
                         "panasonic"            => 1365,
                         "panasonik"            => 24775,
                         "panatha"              => 29732,
                         "pancake"              => 5125,
                         "pancake1"             => 19916,
                         "panchito"             => 10436,
                         "pancho"               => 1726,
                         "panda"                => 1884,
                         "panda1"               => 5311,
                         "panda123"             => 21177,
                         "pandabear"            => 21322,
                         "pandas"               => 5550,
                         "pandemonium"          => 26893,
                         "pander"               => 21848,
                         "pandor"               => 18880,
                         "pandora"              => 696,
                         "pandora1"             => 8519,
                         "pandora2"             => 21760,
                         "pandoras"             => 23951,
                         "pang"                 => 3576,
                         "pangaea"              => 23762,
                         "panget"               => 21481,
                         "pangit"               => 28105,
                         "pangolin"             => 29756,
                         "panhead"              => 5763,
                         "panic1"               => 17427,
                         "pankaj"               => 14336,
                         "panman"               => 22725,
                         "panocha"              => 13331,
                         "panorama"             => 7265,
                         "panter"               => 5641,
                         "pantera"              => 401,
                         "pantera1"             => 4363,
                         "pantera6"             => 26524,
                         "panthe"               => 19664,
                         "panther"              => 199,
                         "panther1"             => 2648,
                         "panther2"             => 16176,
                         "panther5"             => 21826,
                         "panther6"             => 25406,
                         "panther8"             => 26959,
                         "panther9"             => 28907,
                         "panthers"             => 623,
                         "panthers1"            => 22373,
                         "pantie"               => 8810,
                         "panties"              => 184,
                         "panties1"             => 8455,
                         "panties2"             => 20192,
                         "pants1"               => 21212,
                         "pantss"               => 22471,
                         "panty"                => 11661,
                         "pantyhos"             => 2010,
                         "pantyhose"            => 8764,
                         "pantyman"             => 25881,
                         "panzer"               => 735,
                         "panzer1"              => 23583,
                         "paolit"               => 28334,
                         "paolo"                => 4296,
                         "paolo1"               => 25797,
                         "papabear"             => 7225,
                         "papageno"             => 24131,
                         "papamama"             => 5828,
                         "paparoach"            => 17759,
                         "papasmur"             => 29901,
                         "papasmurf"            => 24642,
                         "papaya"               => 9128,
                         "paper1"               => 10116,
                         "paperboy"             => 11889,
                         "papercli"             => 13184,
                         "paperclip"            => 19833,
                         "papercut"             => 10954,
                         "paperino"             => 6504,
                         "papero"               => 14756,
                         "papichul"             => 9765,
                         "papillon"             => 4592,
                         "papirus"              => 28551,
                         "papit"                => 7844,
                         "papito"               => 4445,
                         "pappa"                => 15834,
                         "pappnase"             => 23807,
                         "pappy"                => 8211,
                         "paprika"              => 12149,
                         "paquito"              => 21428,
                         "parabola"             => 13733,
                         "parachut"             => 16480,
                         "paradigm"             => 4218,
                         "paradise"             => 421,
                         "paradoks"             => 29642,
                         "paradox"              => 1481,
                         "paradoxx"             => 14516,
                         "paragon"              => 5404,
                         "paraiso"              => 26026,
                         "paraklast1974"        => 28494,
                         "parallax"             => 14613,
                         "paramedi"             => 4758,
                         "paramedic"            => 11734,
                         "paramore"             => 7434,
                         "paramoun"             => 29727,
                         "paranoya"             => 26310,
                         "parasha"              => 29039,
                         "paravoz"              => 21186,
                         "parazit"              => 19382,
                         "parcells"             => 20418,
                         "parfilev"             => 21548,
                         "pargolf"              => 15344,
                         "paris1"               => 4588,
                         "paris123"             => 15737,
                         "pariss"               => 21863,
                         "parkave"              => 19804,
                         "parker01"             => 27530,
                         "parker1"              => 8255,
                         "parker12"             => 17931,
                         "parkhead"             => 28625,
                         "parkour"              => 6039,
                         "parkside"             => 18172,
                         "parkview"             => 17806,
                         "parlament"            => 5928,
                         "parliame"             => 26257,
                         "parol"                => 4607,
                         "parol1"               => 12013,
                         "parol123"             => 16873,
                         "parol999"             => 15768,
                         "parola"               => 1617,
                         "parolamea"            => 21998,
                         "paroli"               => 11257,
                         "paroll"               => 8699,
                         "parolparol"           => 10623,
                         "parool"               => 16955,
                         "parovoz"              => 20209,
                         "parrot"               => 1447,
                         "parrothe"             => 19437,
                         "parsifal"             => 8014,
                         "partagas"             => 20410,
                         "partizan"             => 7893,
                         "partner1"             => 25951,
                         "partridg"             => 28610,
                         "party1"               => 9564,
                         "partyboy"             => 19196,
                         "partyman"             => 25912,
                         "partyon"              => 20460,
                         "partys"               => 19596,
                         "partytim"             => 16286,
                         "parviz"               => 22407,
                         "pasadena"             => 4483,
                         "pasca"                => 18836,
                         "pascal"               => 1033,
                         "pascha"               => 15455,
                         "pasha1"               => 26390,
                         "pasha123"             => 18022,
                         "pashka"               => 15268,
                         "paska"                => 14962,
                         "pasport"              => 9763,
                         "pass"                 => 61,
                         "pass01"               => 10198,
                         "pass1"                => 5079,
                         "pass10"               => 22677,
                         "pass11"               => 14261,
                         "pass111"              => 27915,
                         "pass12"               => 7689,
                         "pass123"              => 1454,
                         "pass1234"             => 2117,
                         "pass1wor"             => 26332,
                         "pass1word"            => 13332,
                         "pass2"                => 16909,
                         "pass22"               => 21376,
                         "pass69"               => 18000,
                         "pass88"               => 24577,
                         "pass99"               => 9412,
                         "pass999"              => 21834,
                         "passat"               => 1162,
                         "passat99"             => 26747,
                         "passcode"             => 7050,
                         "passe"                => 10470,
                         "passer"               => 13154,
                         "passfan"              => 7030,
                         "passfind"             => 9461,
                         "passio"               => 16643,
                         "passion"              => 524,
                         "passion1"             => 9717,
                         "passions"             => 9000,
                         "passit"               => 27206,
                         "passking"             => 24732,
                         "passmast"             => 6419,
                         "passmaster"           => 12991,
                         "passme"               => 2518,
                         "passord"              => 6350,
                         "passout"              => 28618,
                         "passpage"             => 26929,
                         "passport"             => 530,
                         "passss"               => 12865,
                         "passssap"             => 27130,
                         "passsword"            => 26084,
                         "passthie"             => 8244,
                         "passthief"            => 24469,
                         "passw"                => 24105,
                         "passw0r"              => 9511,
                         "passw0rd"             => 220,
                         "passw0rd1"            => 15897,
                         "passward"             => 17500,
                         "passwd"               => 3023,
                         "passwd1"              => 26525,
                         "passwerd"             => 8850,
                         "passwo"               => 19202,
                         "passwo1"              => 20924,
                         "passwor"              => 1005,
                         "passwor1"             => 2029,
                         "password"             => 2,
                         "password!"            => 26433,
                         "password0"            => 11168,
                         "password00"           => 16623,
                         "password01"           => 5652,
                         "password1"            => 189,
                         "password10"           => 16856,
                         "password11"           => 6883,
                         "password12"           => 3897,
                         "password123"          => 595,
                         "password1234"         => 11383,
                         "password13"           => 14854,
                         "password2"            => 2985,
                         "password21"           => 21366,
                         "password22"           => 27103,
                         "password23"           => 16944,
                         "password3"            => 8855,
                         "password4"            => 10760,
                         "password5"            => 12499,
                         "password6"            => 12012,
                         "password69"           => 11020,
                         "password7"            => 12528,
                         "password8"            => 18209,
                         "password9"            => 5188,
                         "password99"           => 5800,
                         "passwords"            => 2320,
                         "passwordstandard"     => 24813,
                         "passwort"             => 1927,
                         "passwrd"              => 18886,
                         "pasta1"               => 15233,
                         "pastas"               => 18318,
                         "pastel"               => 15322,
                         "paswoord"             => 24922,
                         "pasword"              => 3565,
                         "pasword1"             => 29007,
                         "patagoni"             => 17725,
                         "patat"                => 28522,
                         "patata"               => 8496,
                         "patate"               => 8977,
                         "patatina"             => 27190,
                         "patch1"               => 12249,
                         "patch123"             => 27410,
                         "patche"               => 19178,
                         "patches"              => 520,
                         "patches1"             => 5019,
                         "patchy"               => 14828,
                         "path13"               => 21571,
                         "pathfind"             => 5186,
                         "pathfinder"           => 8128,
                         "patit"                => 9849,
                         "patito"               => 27832,
                         "patric"               => 3515,
                         "patric1"              => 18953,
                         "patrici"              => 5073,
                         "patricio"             => 10897,
                         "patrick0"             => 20530,
                         "patrick1"             => 1570,
                         "patrick2"             => 10158,
                         "patrick3"             => 19538,
                         "patrick5"             => 29238,
                         "patrick7"             => 13559,
                         "patrick8"             => 14051,
                         "patrick9"             => 11129,
                         "patrik"               => 6186,
                         "patriot"              => 1247,
                         "patriot1"             => 11128,
                         "patriots"             => 573,
                         "patriots1"            => 25673,
                         "patrizia"             => 7955,
                         "patrycja"             => 14296,
                         "patryk"               => 9905,
                         "pattaya"              => 9106,
                         "patter"               => 9143,
                         "patterso"             => 8621,
                         "patti1"               => 27093,
                         "patty1"               => 17116,
                         "paul01"               => 20805,
                         "paul1"                => 11098,
                         "paul11"               => 27330,
                         "paul12"               => 12353,
                         "paul123"              => 10401,
                         "paul1234"             => 14727,
                         "paul99"               => 28925,
                         "paula1"               => 10106,
                         "paula123"             => 20332,
                         "paulaner"             => 18054,
                         "paulchen"             => 12416,
                         "paule"                => 25719,
                         "paulie"               => 4017,
                         "paulina1"             => 15664,
                         "paulinka"             => 24830,
                         "paully"               => 23720,
                         "pavel"                => 4013,
                         "pavel1"               => 15637,
                         "pavell"               => 15301,
                         "pavement"             => 5545,
                         "pavilion"             => 759,
                         "pavlenko"             => 19425,
                         "pavlik"               => 6761,
                         "pavlin"               => 21375,
                         "pavlov"               => 3567,
                         "pavlova"              => 7823,
                         "pavlusha"             => 17745,
                         "pawel1"               => 22459,
                         "payday"               => 5448,
                         "paypal"               => 12594,
                         "payton34"             => 8426,
                         "pazzword"             => 19243,
                         "pbyfblf"              => 23993,
                         "pchealth"             => 24848,
                         "pcitra"               => 24329,
                         "pdiddy"               => 7382,
                         "pdtplf"               => 3406,
                         "pdtpljxrf"            => 16472,
                         "peace1"               => 4999,
                         "peace123"             => 21494,
                         "peaceout"             => 8315,
                         "peaces"               => 13569,
                         "peach"                => 2931,
                         "peach1"               => 19315,
                         "peache"               => 12551,
                         "peaches"              => 255,
                         "peaches1"             => 4190,
                         "peaches2"             => 10360,
                         "peachfuz"             => 29272,
                         "peachy"               => 4811,
                         "peacock1"             => 21089,
                         "peanu"                => 7801,
                         "peanut"               => 108,
                         "peanut1"              => 5222,
                         "peanut11"             => 24974,
                         "peanut12"             => 19702,
                         "peanutbutter"         => 18159,
                         "peanuts"              => 1306,
                         "peanuts1"             => 17644,
                         "peapod"               => 17984,
                         "pearl1"               => 6125,
                         "pearljam"             => 609,
                         "pearls"               => 5696,
                         "peartree"             => 14458,
                         "peavey"               => 6456,
                         "pebble"               => 4521,
                         "pebbles"              => 1055,
                         "pebbles1"             => 13448,
                         "pecker"               => 3743,
                         "pecos"                => 23955,
                         "peddler"              => 6793,
                         "pedigree"             => 13189,
                         "pedrito"              => 25058,
                         "pedro1"               => 10766,
                         "pedro123"             => 16038,
                         "pedros"               => 10604,
                         "peedee"               => 16055,
                         "peejay"               => 20141,
                         "peekab00"             => 17249,
                         "peekaboo"             => 628,
                         "peeker"               => 13286,
                         "peeper"               => 5097,
                         "peepers"              => 8643,
                         "peepshow"             => 22749,
                         "peewee"               => 864,
                         "peewee1"              => 16380,
                         "peewee51"             => 28761,
                         "pegas"                => 25571,
                         "pegaso"               => 12497,
                         "pegasus"              => 827,
                         "pegasus1"             => 7599,
                         "peggy1"               => 18875,
                         "peggy12"              => 22699,
                         "peggys"               => 29792,
                         "peggysue"             => 24753,
                         "pegleg"               => 14870,
                         "pele10"               => 25082,
                         "pelican"              => 3989,
                         "pelican1"             => 29335,
                         "pelikan"              => 9792,
                         "pelle"                => 18590,
                         "pelmen"               => 20363,
                         "pelota"               => 18067,
                         "peluche"              => 13587,
                         "peludo"               => 24557,
                         "pelus"                => 19051,
                         "pelusa"               => 18197,
                         "penchair"             => 26156,
                         "pencil"               => 1012,
                         "pencil1"              => 15997,
                         "pendejo"              => 7698,
                         "pendrago"             => 9804,
                         "pendragon"            => 13820,
                         "penelopa"             => 20510,
                         "penetrating"          => 8235,
                         "penetration"          => 5445,
                         "penfloor"             => 26013,
                         "penfold"              => 8832,
                         "peng"                 => 3155,
                         "pengui"               => 25403,
                         "penguin"              => 523,
                         "penguin1"             => 4343,
                         "penguin8"             => 27443,
                         "penguins"             => 1524,
                         "penhorse"             => 28261,
                         "penis"                => 624,
                         "penis1"               => 5962,
                         "penis123"             => 16772,
                         "peniss"               => 14249,
                         "penmouse"             => 18113,
                         "pennst"               => 10544,
                         "pennstat"             => 7559,
                         "pennstate"            => 9382,
                         "penny1"               => 2860,
                         "penny123"             => 20174,
                         "penny2"               => 29536,
                         "pennydog"             => 26124,
                         "pennys"               => 13682,
                         "pennywis"             => 7066,
                         "pennywise"            => 12696,
                         "penpal"               => 24572,
                         "penquin"              => 23943,
                         "pens66"               => 24222,
                         "pensacol"             => 26201,
                         "penske"               => 22228,
                         "pentable"             => 27886,
                         "pentax"               => 12596,
                         "penthous"             => 2512,
                         "pentium"              => 1211,
                         "pentium1"             => 12662,
                         "pentium2"             => 16310,
                         "pentium3"             => 15621,
                         "pentium4"             => 9173,
                         "peopl"                => 22635,
                         "people1"              => 11316,
                         "peoria"               => 11885,
                         "pepino"               => 11732,
                         "pepit"                => 10991,
                         "pepita"               => 14841,
                         "pepito"               => 3809,
                         "pepluv"               => 24418,
                         "pepote"               => 24090,
                         "peppe"                => 4951,
                         "pepper"               => 54,
                         "pepper01"             => 16454,
                         "pepper1"              => 2158,
                         "pepper11"             => 20652,
                         "pepper12"             => 10699,
                         "pepper123"            => 16047,
                         "pepper14"             => 29450,
                         "pepper2"              => 20426,
                         "pepper76"             => 17507,
                         "peppino"              => 28056,
                         "pepsi"                => 916,
                         "pepsi1"               => 1412,
                         "pepsi12"              => 29226,
                         "pepsi123"             => 8848,
                         "pepsi2"               => 17597,
                         "pepsico"              => 17887,
                         "pepsicol"             => 12739,
                         "pepsicola"            => 10642,
                         "pepsiman"             => 23854,
                         "pepsimax"             => 12111,
                         "pepsione"             => 11649,
                         "pepsis"               => 11454,
                         "percy1"               => 17386,
                         "peregrin"             => 8072,
                         "peresvet"             => 28985,
                         "perfect1"             => 4835,
                         "perfecto"             => 12022,
                         "performa"             => 15748,
                         "pericles"             => 13937,
                         "perico"               => 11580,
                         "perils"               => 10382,
                         "perkele"              => 8121,
                         "perkman"              => 20720,
                         "pernille"             => 14167,
                         "perrit"               => 23119,
                         "perrito"              => 21017,
                         "perro"                => 9118,
                         "perros"               => 12599,
                         "perry1"               => 15607,
                         "persepho"             => 24520,
                         "perseus"              => 20067,
                         "pershing"             => 11972,
                         "persik"               => 3453,
                         "persona"              => 5265,
                         "persona1"             => 25818,
                         "pertinant"            => 6182,
                         "peruan"               => 28503,
                         "pervasive"            => 10577,
                         "pervert"              => 815,
                         "pervert1"             => 13014,
                         "pescado"              => 16692,
                         "pescator"             => 10557,
                         "peter01"              => 8770,
                         "peter1"               => 1986,
                         "peter12"              => 19324,
                         "peter123"             => 10202,
                         "peter2"               => 22169,
                         "peter22"              => 24677,
                         "peter69"              => 23511,
                         "peter7"               => 28208,
                         "petera"               => 25386,
                         "peterb"               => 19322,
                         "peterbil"             => 5346,
                         "peterbilt"            => 11329,
                         "peterburg"            => 25490,
                         "peterc"               => 20226,
                         "peterg"               => 20909,
                         "peterj"               => 14092,
                         "peterk"               => 23495,
                         "peterm"               => 26195,
                         "peternor"             => 16292,
                         "peternorth"           => 8698,
                         "peterose"             => 10213,
                         "peterp"               => 18334,
                         "peterpan"             => 1587,
                         "petert"               => 26636,
                         "petey1"               => 16545,
                         "petite"               => 7319,
                         "petra1"               => 9754,
                         "petros"               => 16555,
                         "petrov"               => 3209,
                         "petrova"              => 4828,
                         "petrovich"            => 6711,
                         "petrovna"             => 18128,
                         "petrus"               => 7741,
                         "petshop"              => 26394,
                         "petter"               => 9481,
                         "petticoa"             => 29125,
                         "petty43"              => 28496,
                         "petunia"              => 5273,
                         "peugeo"               => 28419,
                         "peugeot"              => 1767,
                         "peugeot406"           => 27198,
                         "peyote"               => 24142,
                         "peyton18"             => 28719,
                         "pfchfytw"             => 12636,
                         "pfhbyf"               => 26171,
                         "pfhfnecnhf"           => 28975,
                         "pfhfpf"               => 17996,
                         "pfkegf"               => 8489,
                         "pflhjn"               => 19053,
                         "pfloyd"               => 8057,
                         "pflybwf"              => 11905,
                         "pfqxbr"               => 8448,
                         "pfqxjyjr"             => 19401,
                         "pfqxtyjr"             => 28710,
                         "pfuflrf"              => 28605,
                         "pgszt6md"             => 22700,
                         "phaedra"              => 23371,
                         "phaedrus"             => 8250,
                         "phantasm"             => 11037,
                         "phantasy"             => 18978,
                         "phanto"               => 20309,
                         "phantom"              => 329,
                         "phantom1"             => 6159,
                         "phantom2"             => 14227,
                         "phantom3"             => 28158,
                         "phantom7"             => 29077,
                         "phantoms"             => 11738,
                         "pharao"               => 5955,
                         "pharmacy"             => 3601,
                         "pharoh"               => 15270,
                         "phase1"               => 16394,
                         "phase2"               => 28477,
                         "phaser"               => 11890,
                         "phat"                 => 5815,
                         "phatass"              => 14463,
                         "phatboy"              => 22951,
                         "phatfarm"             => 22717,
                         "phatty"               => 10397,
                         "pheasant"             => 10225,
                         "phelge"               => 27853,
                         "phenix"               => 10703,
                         "phenmarr"             => 26773,
                         "phenom"               => 13535,
                         "pheonix"              => 3217,
                         "pheonix1"             => 26059,
                         "phezc419hv"           => 25400,
                         "phialpha"             => 5488,
                         "phidelt"              => 13054,
                         "phikap"               => 18221,
                         "phil413"              => 20394,
                         "philbert"             => 24742,
                         "phili"                => 24664,
                         "philip1"              => 22964,
                         "philipp"              => 6650,
                         "philippe"             => 2646,
                         "philips"              => 1087,
                         "philips1"             => 17096,
                         "phillesh"             => 15727,
                         "philli"               => 29012,
                         "phillies"             => 1825,
                         "phillip1"             => 9179,
                         "philly"               => 1222,
                         "philly1"              => 14730,
                         "philmont"             => 15578,
                         "philos"               => 29806,
                         "philou"               => 27238,
                         "phinupi"              => 22935,
                         "phipsi"               => 11394,
                         "phish"                => 2826,
                         "phish1"               => 5607,
                         "phish123"             => 21519,
                         "phish420"             => 15776,
                         "phishin"              => 21969,
                         "phishing"             => 22842,
                         "phishy"               => 7794,
                         "phisig"               => 16192,
                         "phitau"               => 17992,
                         "phobos"               => 14473,
                         "phoebus"              => 20048,
                         "phoeni"               => 3363,
                         "phoenix"              => 99,
                         "phoenix0"             => 27099,
                         "phoenix1"             => 1762,
                         "phoenix2"             => 8452,
                         "phoenix3"             => 22592,
                         "phoenix5"             => 27080,
                         "phoenix7"             => 18051,
                         "phoenix8"             => 20509,
                         "phoenix9"             => 24994,
                         "phone1"               => 11937,
                         "phoneman"             => 19875,
                         "photo1"               => 6782,
                         "photoes"              => 10184,
                         "photog"               => 8327,
                         "photogra"             => 24644,
                         "photoman"             => 13389,
                         "photon"               => 6088,
                         "photos"               => 1417,
                         "photosho"             => 21570,
                         "photowiz"             => 28041,
                         "phpbb"                => 724,
                         "phreak"               => 7015,
                         "phred"                => 12523,
                         "phuket"               => 10736,
                         "phunky"               => 18129,
                         "phydeaux"             => 12258,
                         "pi3141"               => 12074,
                         "pi31415"              => 21431,
                         "pi314159"             => 9679,
                         "pian"                 => 3390,
                         "piano1"               => 11591,
                         "pianoman"             => 2760,
                         "pianos"               => 6798,
                         "piao"                 => 3166,
                         "piazza31"             => 10985,
                         "pic\\'s"              => 6523,
                         "picard"               => 644,
                         "picard1"              => 10376,
                         "picass"               => 19186,
                         "picasso"              => 1436,
                         "picasso1"             => 13044,
                         "piccolo"              => 2083,
                         "piccolo1"             => 23712,
                         "picher"               => 7121,
                         "picker"               => 9643,
                         "pickle"               => 709,
                         "pickle1"              => 15051,
                         "pickles"              => 1187,
                         "pickles1"             => 12235,
                         "pickup"               => 3238,
                         "pickwick"             => 29062,
                         "picolo"               => 12490,
                         "pics"                 => 1789,
                         "pictere"              => 7089,
                         "pictuers"             => 7152,
                         "picture1"             => 26661,
                         "picturs"              => 4032,
                         "pidaras"              => 12067,
                         "pidoras"              => 26754,
                         "pie123"               => 24659,
                         "piehonkii"            => 16875,
                         "pieman"               => 9466,
                         "piercing"             => 5868,
                         "pierr"                => 14201,
                         "pierre1"              => 24818,
                         "pierrot"              => 17774,
                         "piesek"               => 23925,
                         "pietro"               => 6983,
                         "pigboy"               => 19742,
                         "pigdog"               => 10153,
                         "pigeon"               => 4142,
                         "piggie"               => 17454,
                         "piggies"              => 6799,
                         "piggy"                => 4257,
                         "piggy1"               => 12640,
                         "piggys"               => 14582,
                         "piglet"               => 901,
                         "piglet1"              => 21237,
                         "piglets"              => 11576,
                         "piglett"              => 19766,
                         "pigman"               => 15467,
                         "pigpen"               => 5103,
                         "pikach"               => 23618,
                         "pikachu"              => 1305,
                         "pikachu1"             => 13472,
                         "pikapp"               => 15693,
                         "piknik"               => 18084,
                         "pilatus"              => 17419,
                         "piligrim"             => 16013,
                         "pillow"               => 2205,
                         "pillow1"              => 20906,
                         "pilot1"               => 7068,
                         "pilot123"             => 14762,
                         "pilote"               => 29042,
                         "piloto"               => 20420,
                         "pilsbury"             => 25691,
                         "pilsner"              => 8587,
                         "pilsung"              => 29794,
                         "pimaou"               => 27787,
                         "pimmel"               => 15077,
                         "pimp"                 => 797,
                         "pimp1"                => 27909,
                         "pimp13"               => 29707,
                         "pimp69"               => 11663,
                         "pimpdad"              => 18619,
                         "pimpdadd"             => 5142,
                         "pimpdaddy"            => 6141,
                         "pimpdady"             => 29332,
                         "pimper"               => 26151,
                         "pimphard"             => 26479,
                         "pimpi"                => 16203,
                         "pimpin"               => 433,
                         "pimpin1"              => 14695,
                         "pimpin69"             => 27008,
                         "pimping"              => 5371,
                         "pimpjuic"             => 28820,
                         "pimpjuice"            => 20868,
                         "pimpman"              => 27276,
                         "pimpshit"             => 15318,
                         "pimpsta"              => 23909,
                         "pimpster"             => 8669,
                         "pinarell"             => 24475,
                         "pinball"              => 3891,
                         "pinche"               => 18323,
                         "pincher"              => 26476,
                         "pineappl"             => 1730,
                         "pineapple"            => 3845,
                         "pineapple1"           => 28490,
                         "pinecone"             => 12106,
                         "pinetree"             => 5699,
                         "pinewood"             => 9906,
                         "ping"                 => 1467,
                         "pinga"                => 16020,
                         "pinggolf"             => 14764,
                         "pingpong"             => 2292,
                         "pingu"                => 22256,
                         "pinguin"              => 8151,
                         "pinguino"             => 23033,
                         "pingvin"              => 7708,
                         "pingzing"             => 19079,
                         "pinhead"              => 2844,
                         "pink"                 => 1451,
                         "pink1"                => 22485,
                         "pink123"              => 15879,
                         "pinkerto"             => 24081,
                         "pinkey"               => 24031,
                         "pinkfl"               => 25705,
                         "pinkfloy"             => 1848,
                         "pinkfloyd"            => 3538,
                         "pinkpant"             => 19428,
                         "pinkpuss"             => 15218,
                         "pinkpussy"            => 23532,
                         "pinky"                => 3182,
                         "pinky1"               => 4454,
                         "pinky123"             => 25688,
                         "pinky2"               => 28999,
                         "pinnacle"             => 5378,
                         "pinokio"              => 23391,
                         "pinoy"                => 24688,
                         "pinoyako"             => 24559,
                         "pintail"              => 8271,
                         "pinto1"               => 18877,
                         "piolin"               => 19408,
                         "pionee"               => 10889,
                         "pioneer"              => 1027,
                         "pioneer1"             => 9317,
                         "pioner"               => 7561,
                         "pionex"               => 16059,
                         "piotrek"              => 11687,
                         "pipeline"             => 4130,
                         "pipeman"              => 26493,
                         "piper1"               => 7354,
                         "piper2"               => 26472,
                         "pipers"               => 9127,
                         "pipetka"              => 17479,
                         "pipeutvj"             => 25557,
                         "pipiska"              => 9423,
                         "pippa"                => 23143,
                         "pippa1"               => 21106,
                         "pippen"               => 2398,
                         "pippen33"             => 6657,
                         "pipper"               => 14269,
                         "pippo"                => 3806,
                         "pippo1"               => 27830,
                         "pippolo"              => 28467,
                         "pippone"              => 29223,
                         "piramid"              => 17320,
                         "piramida"             => 3469,
                         "piramide"             => 10169,
                         "piranha"              => 10133,
                         "pirat"                => 15516,
                         "pirata"               => 10837,
                         "pirate"               => 614,
                         "pirate1"              => 11986,
                         "pirates"              => 1223,
                         "pirates1"             => 17387,
                         "piroca"               => 24230,
                         "pirrello"             => 17251,
                         "pisces"               => 2580,
                         "pissant"              => 10255,
                         "pisser"               => 6573,
                         "pissing"              => 2952,
                         "pissoff"              => 3138,
                         "pissword"             => 27434,
                         "pistache"             => 18876,
                         "pistol"               => 1854,
                         "pistol1"              => 22770,
                         "pistola"              => 25785,
                         "piston"               => 6737,
                         "pistons"              => 3910,
                         "pistons1"             => 15638,
                         "pitboss"              => 28663,
                         "pitbul"               => 15545,
                         "pitbull"              => 1046,
                         "pitbull1"             => 16172,
                         "pitbulls"             => 18033,
                         "pitcher1"             => 27343,
                         "pitchers"             => 6288,
                         "piter"                => 17458,
                         "pitstop"              => 13326,
                         "pittbull"             => 10655,
                         "pittsbur"             => 14043,
                         "pitufo"               => 16614,
                         "pitures"              => 8106,
                         "pivkoo"               => 28019,
                         "pixie"                => 8219,
                         "pixie1"               => 16676,
                         "pixies"               => 3933,
                         "pizda"                => 8052,
                         "pizdec"               => 4660,
                         "pizdets"              => 19566,
                         "pizza"                => 1017,
                         "pizza1"               => 4256,
                         "pizza123"             => 13337,
                         "pizzaboy"             => 18874,
                         "pizzahut"             => 6451,
                         "pizzaman"             => 5736,
                         "pizzapie"             => 10260,
                         "pizzas"               => 2982,
                         "pizzle"               => 28762,
                         "pjcgujrat"            => 18216,
                         "pjflkork"             => 16796,
                         "pjkeirf"              => 25244,
                         "pjkjnj"               => 6370,
                         "pktmxr"               => 14662,
                         "pkunzip"              => 23832,
                         "pkxe62"               => 11442,
                         "placebo"              => 3688,
                         "placid"               => 6147,
                         "planet"               => 1175,
                         "planet1"              => 13693,
                         "planeta"              => 7953,
                         "planetx"              => 11758,
                         "plankton"             => 18729,
                         "planner"              => 7292,
                         "planot"               => 12028,
                         "plant1"               => 24482,
                         "plasma"               => 3516,
                         "plastic"              => 1164,
                         "plastic1"             => 12573,
                         "plastics"             => 5258,
                         "plastik"              => 27466,
                         "plat1num"             => 23234,
                         "platin"               => 18849,
                         "platina"              => 26148,
                         "platini"              => 26660,
                         "platinu"              => 26561,
                         "platinum"             => 336,
                         "plato"                => 5634,
                         "plato1"               => 12816,
                         "platon"               => 5002,
                         "platypus"             => 3888,
                         "play2win"             => 27676,
                         "playa"                => 4490,
                         "playa1"               => 17248,
                         "playas"               => 12777,
                         "playaz"               => 15099,
                         "playball"             => 5523,
                         "playbo"               => 10842,
                         "playboy"              => 358,
                         "playboy1"             => 3548,
                         "playboy2"             => 5690,
                         "playboy6"             => 28519,
                         "playboys"             => 9779,
                         "playe"                => 11653,
                         "player"               => 159,
                         "player1"              => 4450,
                         "player69"             => 10033,
                         "playful"              => 9944,
                         "playgirl"             => 14014,
                         "playgolf"             => 20701,
                         "playgrou"             => 25093,
                         "playhard"             => 18176,
                         "playmate"             => 5726,
                         "playme"               => 23071,
                         "playstat"             => 3983,
                         "playstation"          => 3096,
                         "playstation2"         => 21155,
                         "playstation3"         => 15561,
                         "playtime"             => 1375,
                         "plazma"               => 14599,
                         "please1"              => 5790,
                         "pleaseme"             => 9400,
                         "pleaser"              => 18089,
                         "pleomax"              => 20883,
                         "plhy6hql"             => 26788,
                         "plmokn"               => 19072,
                         "plokij"               => 7343,
                         "plokiju"              => 29071,
                         "plokijuh"             => 14116,
                         "plonker"              => 17487,
                         "ploppy"               => 5597,
                         "plover"               => 10606,
                         "plowboy"              => 28946,
                         "plucky"               => 16890,
                         "plugger"              => 29604,
                         "plumber"              => 1772,
                         "plumber1"             => 15449,
                         "plumper"              => 13106,
                         "plumpy"               => 29729,
                         "pluto"                => 3611,
                         "pluto1"               => 8285,
                         "pluton"               => 9057,
                         "plymouth"             => 1621,
                         "pmdmscts"             => 15534,
                         "pmdmsctsk"            => 20481,
                         "pmtgjnbl"             => 29477,
                         "pn5jvw"               => 13795,
                         "pngfilt"              => 24847,
                         "pnp0c08"              => 16599,
                         "pobeda"               => 2918,
                         "pochta"               => 9190,
                         "podaria"              => 12797,
                         "podarok"              => 29033,
                         "poekie"               => 28400,
                         "pogiako"              => 20389,
                         "pogoda"               => 24545,
                         "poi098"               => 8231,
                         "poi123"               => 14501,
                         "poidog"               => 22565,
                         "poilkj"               => 12511,
                         "point1"               => 27437,
                         "pointman"             => 23367,
                         "poison"               => 1067,
                         "poiu0987"             => 12719,
                         "poiu123"              => 15510,
                         "poiu1234"             => 14831,
                         "poiulkjh"             => 22566,
                         "poiuyt"               => 1146,
                         "poiuyt1"              => 27178,
                         "poiuytrewq"           => 2078,
                         "pokemo"               => 5949,
                         "pokemon"              => 222,
                         "pokemon00"            => 27479,
                         "pokemon1"             => 1937,
                         "pokemon12"            => 12840,
                         "pokemon123"           => 8272,
                         "pokemon2"             => 18011,
                         "pokemons"             => 22117,
                         "poker0"               => 24640,
                         "poker1"               => 5237,
                         "poker123"             => 20944,
                         "poker2"               => 25814,
                         "pokerface"            => 17559,
                         "pokerman"             => 26708,
                         "pokers"               => 19551,
                         "pokesmot"             => 16542,
                         "pokey"                => 6948,
                         "pokey1"               => 9969,
                         "polarbea"             => 9059,
                         "polarbear"            => 14967,
                         "polaris"              => 902,
                         "polaris1"             => 12036,
                         "polaroid"             => 8474,
                         "polecat"              => 12931,
                         "polgara"              => 9960,
                         "polic"                => 17826,
                         "police"               => 344,
                         "police1"              => 8758,
                         "police22"             => 10548,
                         "policema"             => 19056,
                         "poligon"              => 15777,
                         "polina"               => 662,
                         "polinka"              => 8759,
                         "politic"              => 22678,
                         "polizei"              => 19891,
                         "polka"                => 10520,
                         "polkadot"             => 25141,
                         "polkaudi"             => 22981,
                         "polkaudio"            => 24532,
                         "polkilo"              => 27894,
                         "polkmn"               => 10797,
                         "polla"                => 29528,
                         "pollit"               => 16543,
                         "pollito"              => 11776,
                         "pollo"                => 14404,
                         "pollux"               => 6082,
                         "polly1"               => 8217,
                         "polly123"             => 26319,
                         "polniypizdec0211"     => 2174,
                         "polniypizdec110211"   => 14974,
                         "polo"                 => 1612,
                         "polo12"               => 21721,
                         "polo1234"             => 17165,
                         "polock"               => 24771,
                         "pololo"               => 20285,
                         "polopo"               => 29504,
                         "polopol"              => 20553,
                         "polopolo09"           => 22489,
                         "polska"               => 2007,
                         "polska1"              => 10123,
                         "poltava"              => 22986,
                         "pomidor"              => 8504,
                         "pommes"               => 6733,
                         "pompano"              => 18187,
                         "pompey"               => 2322,
                         "pompier"              => 11483,
                         "pompon"               => 22527,
                         "pon32029"             => 19630,
                         "ponchik"              => 15053,
                         "poncho"               => 1953,
                         "pondscum"             => 18939,
                         "pondus"               => 27965,
                         "pong"                 => 5970,
                         "pongo"                => 12892,
                         "pongo1"               => 26170,
                         "pontiac"              => 733,
                         "pontiac1"             => 7855,
                         "pontoon"              => 15919,
                         "pony"                 => 2885,
                         "ponyboy"              => 8557,
                         "poobear"              => 7682,
                         "pooch"                => 9797,
                         "poochie"              => 2824,
                         "poochie1"             => 20836,
                         "poochy"               => 19733,
                         "pooder"               => 19659,
                         "poodle"               => 2136,
                         "pooh"                 => 1658,
                         "poohbea"              => 9987,
                         "poohbear"             => 437,
                         "poohbear1"            => 22495,
                         "pooka"                => 17572,
                         "pooker"               => 13397,
                         "pookey"               => 5390,
                         "pooki"                => 13947,
                         "pookie"               => 254,
                         "pookie1"              => 8633,
                         "pookie11"             => 28756,
                         "pookster"             => 26221,
                         "pooky"                => 5961,
                         "pooky1"               => 24593,
                         "pool6123"             => 4253,
                         "poolman"              => 18988,
                         "poonam"               => 13764,
                         "poontang"             => 2126,
                         "poop"                 => 607,
                         "poop1"                => 18248,
                         "poop12"               => 14471,
                         "poop123"              => 6467,
                         "poopee"               => 22413,
                         "pooper"               => 1563,
                         "poopers"              => 16308,
                         "poopface"             => 15082,
                         "poophead"             => 6197,
                         "poopi"                => 24435,
                         "poopie"               => 1426,
                         "poopies"              => 14169,
                         "poopo"                => 27837,
                         "poopoo"               => 447,
                         "poopoo1"              => 23899,
                         "poopsie"              => 9180,
                         "poopy"                => 3762,
                         "poopy1"               => 9891,
                         "poopypan"             => 26132,
                         "poorboy"              => 16798,
                         "pooter"               => 2331,
                         "pootie"               => 11419,
                         "pop123"               => 14517,
                         "popart"               => 28449,
                         "popcor"               => 27556,
                         "popcorn"              => 507,
                         "popcorn1"             => 5803,
                         "popey"                => 29931,
                         "popeye"               => 783,
                         "popeye1"              => 20938,
                         "popimp"               => 15743,
                         "popkorn"              => 19975,
                         "popmart"              => 16466,
                         "popol"                => 16406,
                         "popolo"               => 13903,
                         "popov"                => 16776,
                         "popova"               => 4704,
                         "poppen"               => 15008,
                         "popper"               => 3773,
                         "poppet"               => 10627,
                         "poppi"                => 25352,
                         "poppie"               => 7927,
                         "poppies"              => 14929,
                         "poppin"               => 12408,
                         "poppy"                => 2558,
                         "poppy1"               => 6188,
                         "poppy123"             => 18850,
                         "poppydog"             => 24576,
                         "poppys"               => 16918,
                         "popstar"              => 16252,
                         "poptart"              => 5927,
                         "poptarts"             => 21712,
                         "porche"               => 12335,
                         "porkchop"             => 1662,
                         "porker"               => 11308,
                         "porkpie"              => 26569,
                         "porky"                => 9008,
                         "porkypig"             => 22007,
                         "porn"                 => 281,
                         "porn1"                => 11555,
                         "porn11"               => 23668,
                         "porn123"              => 8689,
                         "porn1234"             => 21716,
                         "porn4life"            => 10311,
                         "porn4me"              => 7859,
                         "porn69"               => 9071,
                         "pornclub"             => 27184,
                         "pornking"             => 5317,
                         "pornlo"               => 24893,
                         "pornlove"             => 17909,
                         "pornlover"            => 20573,
                         "pornman"              => 19606,
                         "porno"                => 495,
                         "porno1"               => 3640,
                         "porno123"             => 17291,
                         "porno2"               => 27497,
                         "porno69"              => 11742,
                         "pornog"               => 28900,
                         "pornogra"             => 15089,
                         "pornografia"          => 15627,
                         "pornographic"         => 7387,
                         "pornoman"             => 15057,
                         "pornos"               => 2405,
                         "pornosta"             => 23203,
                         "pornostar"            => 24558,
                         "pornpass"             => 8859,
                         "pornsite"             => 12963,
                         "pornstar"             => 1009,
                         "porol777"             => 27354,
                         "porosenok"            => 27625,
                         "porpoise"             => 20329,
                         "porsch"               => 12524,
                         "porsche"              => 127,
                         "porsche1"             => 3365,
                         "porsche2"             => 27817,
                         "porsche9"             => 1781,
                         "porsche911"           => 7404,
                         "porsches"             => 19445,
                         "porshe"               => 7973,
                         "porthos"              => 14753,
                         "portishead"           => 26610,
                         "portland"             => 1367,
                         "portman"              => 10996,
                         "portos"               => 14656,
                         "portsmou"             => 15632,
                         "portuga"              => 12070,
                         "portugal"             => 1094,
                         "portvale"             => 22522,
                         "poseidon"             => 2554,
                         "positano"             => 28931,
                         "positiv"              => 21483,
                         "positivo"             => 11720,
                         "possum"               => 1908,
                         "postal"               => 1448,
                         "postal1"              => 20835,
                         "postbank"             => 21681,
                         "postie"               => 25069,
                         "postit"               => 14178,
                         "postman"              => 3799,
                         "postov10"             => 12150,
                         "postov1000"           => 9349,
                         "posture"              => 9673,
                         "pot420"               => 16999,
                         "potapov"              => 28201,
                         "potapova"             => 25925,
                         "potato"               => 1363,
                         "potatoe"              => 16484,
                         "pothead"              => 3151,
                         "potsmoke"             => 26972,
                         "potte"                => 28112,
                         "potter1"              => 19608,
                         "poulet"               => 19814,
                         "poulette"             => 23784,
                         "pouncer"              => 20640,
                         "pounded"              => 7504,
                         "pourquoi"             => 16237,
                         "poussin"              => 21886,
                         "poutine"              => 22741,
                         "powder"               => 1405,
                         "power1"               => 1684,
                         "power123"             => 5083,
                         "power2"               => 11397,
                         "power5"               => 28300,
                         "power666"             => 25483,
                         "power7"               => 19478,
                         "power9"               => 20517,
                         "powerade"             => 9428,
                         "powerboo"             => 11549,
                         "powerhou"             => 23585,
                         "powermac"             => 11550,
                         "powerman"             => 6313,
                         "powerpc"              => 10392,
                         "powerpla"             => 24447,
                         "powerr"               => 23170,
                         "powerstr"             => 23336,
                         "powerup"              => 11865,
                         "pozitiv"              => 16298,
                         "ppppp1"               => 10469,
                         "pppppp1"              => 19747,
                         "ppppppp1"             => 24936,
                         "ppspankp"             => 11511,
                         "pqnr67w5"             => 28241,
                         "pr1ncess"             => 25363,
                         "pradeep"              => 16582,
                         "prakash"              => 10274,
                         "praline"              => 28740,
                         "prancer"              => 8495,
                         "prapor"               => 17796,
                         "prashant"             => 9375,
                         "pravda"               => 14529,
                         "praveen"              => 23944,
                         "praxis"               => 7446,
                         "preacher"             => 3092,
                         "precios"              => 16677,
                         "preciosa"             => 18394,
                         "preciou"              => 20756,
                         "precious"             => 779,
                         "precious1"            => 12612,
                         "precisio"             => 23580,
                         "predator"             => 618,
                         "preeti"               => 24102,
                         "preggo"               => 24770,
                         "prelude"              => 846,
                         "prelude1"             => 7334,
                         "prelude9"             => 28295,
                         "premier1"             => 18713,
                         "premium"              => 3625,
                         "premiumcash"          => 23112,
                         "presari"              => 19543,
                         "presario"             => 790,
                         "presiden"             => 3759,
                         "prestigio"            => 20441,
                         "presto"               => 2294,
                         "preston1"             => 12052,
                         "preteen"              => 22211,
                         "pretende"             => 22796,
                         "prett"                => 18927,
                         "pretty1"              => 14005,
                         "prettybo"             => 14634,
                         "prettyboy"            => 15409,
                         "prettygirl"           => 10287,
                         "pretzel"              => 6353,
                         "prevert"              => 26709,
                         "price1"               => 22030,
                         "pride1"               => 29057,
                         "pridurok"             => 14993,
                         "prikol"               => 10491,
                         "prima"                => 8238,
                         "primal"               => 8177,
                         "primas"               => 26873,
                         "primaver"             => 15328,
                         "primavera"            => 13633,
                         "primax"               => 15663,
                         "prime1"               => 9061,
                         "primer"               => 12632,
                         "primetim"             => 10434,
                         "primetime21"          => 14230,
                         "primo"                => 10761,
                         "primo1"               => 20447,
                         "primrose"             => 11143,
                         "primus"               => 1697,
                         "primus1"              => 25013,
                         "princ"                => 7776,
                         "prince"               => 178,
                         "prince1"              => 5012,
                         "prince11"             => 25143,
                         "prince12"             => 18783,
                         "prince2"              => 26311,
                         "princes"              => 1348,
                         "princesa"             => 5994,
                         "princesit"            => 28357,
                         "princess"             => 59,
                         "princess1"            => 6318,
                         "princessa"            => 8906,
                         "princesse"            => 23060,
                         "princeto"             => 7513,
                         "princip"              => 29116,
                         "principa"             => 18177,
                         "principe"             => 12880,
                         "pringles"             => 3531,
                         "printer"              => 1585,
                         "printer1"             => 15910,
                         "priora"               => 18595,
                         "prisca"               => 25776,
                         "priscill"             => 8821,
                         "prisma"               => 26309,
                         "prisonbreak"          => 22966,
                         "prissy"               => 2709,
                         "privado"              => 27669,
                         "privat"               => 7248,
                         "private"              => 376,
                         "private1"             => 4401,
                         "private5"             => 23505,
                         "prive"                => 28001,
                         "privet"               => 1283,
                         "privet123"            => 28827,
                         "priyanka"             => 7044,
                         "prizrak"              => 11050,
                         "pro100"               => 6068,
                         "prober"               => 18511,
                         "probes"               => 6049,
                         "problemas"            => 29105,
                         "process1"             => 28673,
                         "prodigy"              => 1537,
                         "prodigy1"             => 15316,
                         "prodojo"              => 28689,
                         "producti"             => 18175,
                         "profesor"             => 15034,
                         "professo"             => 13172,
                         "profil"               => 27840,
                         "proghouse"            => 28269,
                         "programm"             => 16750,
                         "prohor"               => 29322,
                         "project1"             => 19772,
                         "prokuror"             => 28938,
                         "proline"              => 14493,
                         "promethe"             => 11759,
                         "promo1"               => 29778,
                         "promopas"             => 24463,
                         "prong"                => 20899,
                         "pronger"              => 17930,
                         "pronin"               => 28960,
                         "prono1"               => 16510,
                         "prophet"              => 2777,
                         "prophet1"             => 24343,
                         "prorok"               => 27280,
                         "prosper"              => 5530,
                         "prospero"             => 9003,
                         "prosto"               => 7381,
                         "prostock"             => 15764,
                         "prostreet"            => 28502,
                         "proton"               => 5025,
                         "protools"             => 20282,
                         "protos"               => 19038,
                         "protoss"              => 8343,
                         "prototyp"             => 24393,
                         "protozoa"             => 29553,
                         "proust"               => 14533,
                         "proverbs"             => 10915,
                         "providen"             => 18031,
                         "providian"            => 27668,
                         "proview"              => 5337,
                         "provista"             => 21004,
                         "prowler"              => 3860,
                         "proxima"              => 20415,
                         "proxy"                => 2852,
                         "prozac"               => 4745,
                         "prozak"               => 29034,
                         "prufrock"             => 14782,
                         "ps253535"             => 23681,
                         "psalm23"              => 14851,
                         "psalm69"              => 20715,
                         "psalms"               => 12380,
                         "psswrd"               => 14363,
                         "psw333333"            => 21679,
                         "psych0"               => 24226,
                         "psychnau"             => 9569,
                         "psychnaut1"           => 10476,
                         "psycho"               => 631,
                         "psycho1"              => 10379,
                         "psycholo"             => 19816,
                         "psylocke"             => 15504,
                         "ptbdhw"               => 16501,
                         "ptfe3xxp"             => 12920,
                         "pthrfkj"              => 14795,
                         "ptichka"              => 25597,
                         "ptktysq"              => 15119,
                         "ptybnxtvgbjy"         => 15087,
                         "pub113"               => 23694,
                         "pucara"               => 12348,
                         "puccini"              => 16533,
                         "puck"                 => 5819,
                         "pudder"               => 28602,
                         "puddin"               => 3019,
                         "pudding"              => 2655,
                         "pudding1"             => 27449,
                         "puddles"              => 7144,
                         "pudge"                => 13941,
                         "pudge1"               => 22480,
                         "puertori"             => 27350,
                         "puertorico"           => 14796,
                         "puffdadd"             => 29317,
                         "puffer"               => 6686,
                         "puffin"               => 3956,
                         "puffy"                => 3605,
                         "puffy1"               => 24187,
                         "pufunga7782"          => 4882,
                         "pugdog"               => 24276,
                         "pugsley"              => 5905,
                         "pugsly"               => 18194,
                         "pugwash"              => 19650,
                         "puissant"             => 29560,
                         "pujols"               => 28795,
                         "pukimak"              => 27527,
                         "pulamea"              => 10528,
                         "puller"               => 11767,
                         "pullings"             => 12677,
                         "pullup"               => 20706,
                         "pulsar"               => 3413,
                         "pumba"                => 28302,
                         "pumkin"               => 8074,
                         "pumper"               => 5279,
                         "pumpk1n"              => 28292,
                         "pumpki"               => 19848,
                         "pumpkin"              => 370,
                         "pumpkin1"             => 3798,
                         "pumpkin2"             => 23635,
                         "pumpkins"             => 3723,
                         "punani"               => 7115,
                         "pundai"               => 27502,
                         "puneet"               => 20799,
                         "punheta"              => 19338,
                         "punisher"             => 1316,
                         "punkass"              => 6790,
                         "punker"               => 5195,
                         "punkie"               => 13274,
                         "punkin"               => 1735,
                         "punkrawk"             => 22783,
                         "punkrock"             => 1256,
                         "punksnotdead"         => 21132,
                         "punky"                => 14852,
                         "punt0it"              => 21304,
                         "puntang"              => 18324,
                         "punter"               => 8409,
                         "punter12"             => 26887,
                         "punto"                => 25056,
                         "pupkin"               => 7200,
                         "pupper"               => 14140,
                         "puppie"               => 17254,
                         "puppies"              => 1870,
                         "puppy"                => 1860,
                         "puppy1"               => 5716,
                         "puppydog"             => 5455,
                         "puppys"               => 8800,
                         "pupsik"               => 2344,
                         "pupuce"               => 13533,
                         "puravida"             => 10993,
                         "purdue"               => 2817,
                         "pureevil"             => 26976,
                         "purgator"             => 26969,
                         "purgen"               => 10594,
                         "purina"               => 29069,
                         "purpl"                => 5190,
                         "purple"               => 135,
                         "purple01"             => 22205,
                         "purple1"              => 4555,
                         "purple11"             => 24164,
                         "purple12"             => 14372,
                         "purple13"             => 24480,
                         "purple2"              => 23809,
                         "purple3"              => 29655,
                         "purple69"             => 26244,
                         "purzel"               => 15421,
                         "puschel"              => 15121,
                         "pusher"               => 10073,
                         "pushistik"            => 23387,
                         "pushit"               => 18992,
                         "pushkin"              => 5426,
                         "pushok"               => 7159,
                         "puss"                 => 3782,
                         "pusser"               => 16024,
                         "pussey"               => 3245,
                         "pussie"               => 2355,
                         "pussies"              => 855,
                         "pusssy"               => 6680,
                         "pussy"                => 25,
                         "pussy1"               => 576,
                         "pussy101"             => 20595,
                         "pussy11"              => 20132,
                         "pussy12"              => 23347,
                         "pussy123"             => 3803,
                         "pussy2"               => 7165,
                         "pussy21"              => 18516,
                         "pussy3"               => 15364,
                         "pussy4"               => 25168,
                         "pussy4me"             => 7427,
                         "pussy5"               => 24911,
                         "pussy6"               => 25231,
                         "pussy69"              => 1564,
                         "pussy7"               => 14918,
                         "pussy9"               => 29181,
                         "pussybitch"           => 22547,
                         "pussyboy"             => 19139,
                         "pussyca"              => 19753,
                         "pussycat"             => 708,
                         "pussyeat"             => 7897,
                         "pussyeater"           => 10406,
                         "pussyfuck"            => 16603,
                         "pussygal"             => 28941,
                         "pussykat"             => 25619,
                         "pussylic"             => 14346,
                         "pussylick"            => 17784,
                         "pussylicker"          => 9051,
                         "pussylip"             => 16393,
                         "pussylov"             => 9289,
                         "pussylover"           => 7180,
                         "pussyman"             => 3278,
                         "pussys"               => 1073,
                         "pussyy"               => 14547,
                         "pusyy"                => 6399,
                         "puszek"               => 21019,
                         "putain"               => 20352,
                         "putamadre"            => 18900,
                         "putang"               => 15007,
                         "putangina"            => 25562,
                         "putaria"              => 18364,
                         "putas"                => 16664,
                         "puttana"              => 23344,
                         "putter"               => 1637,
                         "pvjegu"               => 20108,
                         "pwnage"               => 20683,
                         "pwxd5x"               => 11622,
                         "pxx3eftp"             => 12301,
                         "pyf8ah"               => 16507,
                         "pynchon"              => 12982,
                         "pyon"                 => 6243,
                         "pypsik"               => 21622,
                         "pyramid"              => 768,
                         "pyramid1"             => 7912,
                         "pyramid7"             => 25783,
                         "pyramide"             => 16737,
                         "pyramids"             => 8158,
                         "python"               => 1354,
                         "python1"              => 24746,
                         "pzaiu8"               => 13576,
                         "q11111"               => 4853,
                         "q111111"              => 15209,
                         "q123123"              => 28916,
                         "q12345"               => 1074,
                         "q123456"              => 2534,
                         "q1234567"             => 5149,
                         "q12345678"            => 12974,
                         "q123456789"           => 5286,
                         "q1234567890"          => 9700,
                         "q123456q"             => 17894,
                         "q12345q"              => 20855,
                         "q1234q"               => 28004,
                         "q12we3"               => 28832,
                         "q1a1z1"               => 25488,
                         "q1a2z3"               => 11370,
                         "q1q2q3"               => 3737,
                         "q1q2q3q4"             => 7376,
                         "q1q2q3q4q5"           => 6520,
                         "q1w1e1"               => 22163,
                         "q1w2e"                => 15326,
                         "q1w2e3"               => 285,
                         "q1w2e3r"              => 5593,
                         "q1w2e3r4"             => 147,
                         "q1w2e3r4t"            => 11010,
                         "q1w2e3r4t5"           => 96,
                         "q1w2e3r4t5y6"         => 1100,
                         "q1w2e3r4t5y6u7"       => 14256,
                         "q1w2e3r4t5y6u7i8"     => 16029,
                         "q1w2e3r4t5y6u7i8o9p0" => 24800,
                         "q22222"               => 23192,
                         "q2w3e4"               => 5045,
                         "q2w3e4r"              => 20197,
                         "q2w3e4r5"             => 3497,
                         "q55555"               => 12275,
                         "q8zo8wzq"             => 11176,
                         "q9umoz"               => 13128,
                         "qagsud"               => 22996,
                         "qantas"               => 20664,
                         "qapmoc"               => 13450,
                         "qaswed"               => 15210,
                         "qawsed"               => 1148,
                         "qawsed123"            => 19199,
                         "qawsedr"              => 19499,
                         "qawsedrf"             => 1766,
                         "qawsedrftg"           => 7350,
                         "qawsedrftgyh"         => 19280,
                         "qaywsx"               => 6852,
                         "qaz12"                => 21392,
                         "qaz123"               => 717,
                         "qaz1234"              => 20946,
                         "qaz12345"             => 8181,
                         "qaz123456"            => 16880,
                         "qaz123wsx"            => 6581,
                         "qaz123wsx456"         => 27546,
                         "qaz12wsx"             => 19769,
                         "qaz1wsx2"             => 16098,
                         "qaz321"               => 29131,
                         "qaz741"               => 7915,
                         "qazedc"               => 9926,
                         "qazedctgb"            => 15819,
                         "qazokm"               => 19715,
                         "qazplm"               => 8608,
                         "qazqaz"               => 843,
                         "qazqaz123"            => 27398,
                         "qazqwe"               => 22266,
                         "qazsedcft"            => 19303,
                         "qazsew"               => 27613,
                         "qazws"                => 4290,
                         "qazwsx"               => 31,
                         "qazwsx1"              => 3014,
                         "qazwsx11"             => 25043,
                         "qazwsx12"             => 2480,
                         "qazwsx123"            => 834,
                         "qazwsx1234"           => 21833,
                         "qazwsx12345"          => 23661,
                         "qazwsxc"              => 27058,
                         "qazwsxe"              => 18991,
                         "qazwsxed"             => 1297,
                         "qazwsxedc"            => 238,
                         "qazwsxedc1"           => 7379,
                         "qazwsxedc12"          => 16848,
                         "qazwsxedc123"         => 3598,
                         "qazwsxedcrfv"         => 1671,
                         "qazwsxedcrfvtgb"      => 8609,
                         "qazxcdew"             => 25941,
                         "qazxcdews"            => 19712,
                         "qazxcv"               => 4994,
                         "qazxcvbn"             => 14214,
                         "qazxcvbnm"            => 19983,
                         "qazxdr"               => 21736,
                         "qazxs"                => 13115,
                         "qazxsw"               => 225,
                         "qazxsw1"              => 15439,
                         "qazxsw12"             => 8724,
                         "qazxsw123"            => 6886,
                         "qazxsw2"              => 19863,
                         "qazxsw21"             => 11376,
                         "qazxswe"              => 25112,
                         "qazxswed"             => 10563,
                         "qazxswedc"            => 1128,
                         "qazxswedc123"         => 25487,
                         "qazxswedcvfr"         => 10023,
                         "qazzaq"               => 3042,
                         "qbert"                => 21453,
                         "qbg26i"               => 11534,
                         "qcactw"               => 14298,
                         "qcfmtz"               => 12805,
                         "qcmfd454"             => 16562,
                         "qcxdw8ry"             => 29478,
                         "qdarcv"               => 14708,
                         "qguvyt"               => 15425,
                         "qhxbij"               => 14934,
                         "qian"                 => 6601,
                         "qiang"                => 3436,
                         "qiao"                 => 3200,
                         "qing"                 => 3102,
                         "qiong"                => 3306,
                         "qmezrxg4"             => 23292,
                         "qmpq39zr"             => 20078,
                         "qn632o"               => 14306,
                         "qpalzm"               => 6887,
                         "qpful542"             => 17663,
                         "qpwoei"               => 14882,
                         "qpwoeiruty"           => 11387,
                         "qq123123"             => 29496,
                         "qq12345"              => 20584,
                         "qq123456"             => 6754,
                         "qq123456789"          => 13267,
                         "qqaazz"               => 12699,
                         "qqh92r"               => 12738,
                         "qqq111"               => 716,
                         "qqq123"               => 14459,
                         "qqq777"               => 29733,
                         "qqqaaa"               => 26012,
                         "qqqq1"                => 23037,
                         "qqqq1111"             => 10016,
                         "qqqqq1"               => 3830,
                         "qqqqqq1"              => 10000,
                         "qqqqqqq1"             => 12671,
                         "qqqqqqw"              => 29432,
                         "qqqqwwww"             => 27522,
                         "qqqwww"               => 5118,
                         "qqqwwweee"            => 14382,
                         "qqwwee"               => 6320,
                         "qqwweerr"             => 19625,
                         "qr5mx7"               => 19903,
                         "qrhmis"               => 16451,
                         "qsawbbs"              => 17289,
                         "qscesz"               => 28530,
                         "qscwdv"               => 25768,
                         "qsdfgh"               => 11990,
                         "qsefth"               => 14805,
                         "quacker"              => 24626,
                         "quackers"             => 28249,
                         "quadra"               => 28333,
                         "quagmire"             => 15916,
                         "quake"                => 6508,
                         "quake1"               => 13261,
                         "quake2"               => 13340,
                         "quake3"               => 7061,
                         "quaker"               => 7274,
                         "quality1"             => 11665,
                         "quan"                 => 3013,
                         "quant4307"            => 17817,
                         "quant4307s"           => 6871,
                         "quantex"              => 23235,
                         "quantum"              => 2579,
                         "quantum1"             => 15618,
                         "quaresma"             => 23270,
                         "quark"                => 11524,
                         "quartz"               => 2695,
                         "quartz1"              => 27874,
                         "quasar"               => 4485,
                         "quatro"               => 20431,
                         "quattro"              => 2409,
                         "quattro6"             => 18142,
                         "queball"              => 26330,
                         "queen1"               => 6647,
                         "queenas8151"          => 25659,
                         "queenb"               => 21601,
                         "queenbee"             => 13775,
                         "queens"               => 2714,
                         "queens1"              => 24872,
                         "queeny"               => 19924,
                         "queequeg"             => 27045,
                         "quest"                => 3189,
                         "quest1"               => 7658,
                         "questor"              => 28058,
                         "quetzal"              => 11385,
                         "quick1"               => 11769,
                         "quicken"              => 14804,
                         "quicksan"             => 15156,
                         "quicksil"             => 14596,
                         "quicksilver"          => 12412,
                         "quiet1"               => 21018,
                         "quietkey"             => 24077,
                         "quiksilv"             => 28102,
                         "quiksilver"           => 19265,
                         "quincunx"             => 23028,
                         "quinta"               => 23082,
                         "quintain"             => 27908,
                         "quique"               => 29280,
                         "quixote"              => 10004,
                         "quixotic"             => 28090,
                         "quixtar"              => 12381,
                         "quovadis"             => 18738,
                         "qvw6n2"               => 17986,
                         "qw1234"               => 11840,
                         "qw12345"              => 25865,
                         "qw123456"             => 6660,
                         "qw12er34"             => 12681,
                         "qw12qw"               => 18080,
                         "qwaser"               => 28990,
                         "qwasz"                => 14960,
                         "qwaszx"               => 228,
                         "qwaszx1"              => 18317,
                         "qwaszx11"             => 28233,
                         "qwaszx12"             => 7963,
                         "qwaszx123"            => 10611,
                         "qwaszxedc"            => 26823,
                         "qwaszxerdfcv"         => 24498,
                         "qwaszxqw"             => 21071,
                         "qwe123"               => 500,
                         "qwe1234"              => 25774,
                         "qwe123456"            => 19033,
                         "qwe1234567"           => 22914,
                         "qwe123asd"            => 11531,
                         "qwe123qwe"            => 4074,
                         "qwe123rty"            => 15395,
                         "qwe321"               => 5377,
                         "qwe456"               => 23342,
                         "qwe789"               => 10057,
                         "qweas"                => 15016,
                         "qweasd"               => 516,
                         "qweasd1"              => 24528,
                         "qweasd12"             => 15563,
                         "qweasd123"            => 3202,
                         "qweasdqwe"            => 19035,
                         "qweasdzx"             => 6317,
                         "qweasdzxc"            => 441,
                         "qweasdzxc1"           => 12446,
                         "qweasdzxc123"         => 6077,
                         "qwedcxzas"            => 12917,
                         "qwedsa"               => 4789,
                         "qwedsazxc"            => 7189,
                         "qweewq"               => 8408,
                         "qwepoi"               => 14033,
                         "qweqaz"               => 19599,
                         "qweqw"                => 29453,
                         "qweqwe"               => 337,
                         "qweqwe12"             => 23855,
                         "qweqwe123"            => 9787,
                         "qwer11"               => 27268,
                         "qwer12"               => 3986,
                         "qwer1209"             => 25513,
                         "qwer123"              => 2387,
                         "qwer1234"             => 139,
                         "qwer12345"            => 13398,
                         "qwer4321"             => 10595,
                         "qweras"               => 28429,
                         "qwerasd"              => 19629,
                         "qwerasdf"             => 1514,
                         "qwerasdfzxcv"         => 6019,
                         "qwerfdsa"             => 10162,
                         "qwert"                => 324,
                         "qwert1"               => 2333,
                         "qwert12"              => 9135,
                         "qwert123"             => 1664,
                         "qwert1234"            => 18057,
                         "qwert12345"           => 3904,
                         "qwert40"              => 5009,
                         "qwert54321"           => 18153,
                         "qwerta"               => 17016,
                         "qwertasd"             => 27856,
                         "qwertasdfg"           => 10196,
                         "qwertasdfgzxcvb"      => 29855,
                         "qwertgfdsa"           => 25791,
                         "qwerttrewq"           => 23507,
                         "qwerty"               => 4,
                         "qwerty00"             => 10741,
                         "qwerty01"             => 22261,
                         "qwerty02"             => 17832,
                         "qwerty09"             => 26186,
                         "qwerty1"              => 386,
                         "qwerty10"             => 15929,
                         "qwerty100"            => 27818,
                         "qwerty11"             => 3838,
                         "qwerty111"            => 18257,
                         "qwerty12"             => 491,
                         "qwerty123"            => 219,
                         "qwerty1234"           => 2494,
                         "qwerty12345"          => 1255,
                         "qwerty123456"         => 1850,
                         "qwerty123456789"      => 12590,
                         "qwerty13"             => 6368,
                         "qwerty2"              => 8312,
                         "qwerty2010"           => 16486,
                         "qwerty21"             => 11570,
                         "qwerty22"             => 10443,
                         "qwerty23"             => 19017,
                         "qwerty3"              => 17318,
                         "qwerty32"             => 26580,
                         "qwerty321"            => 15602,
                         "qwerty33"             => 18798,
                         "qwerty4"              => 28657,
                         "qwerty5"              => 13062,
                         "qwerty6"              => 12179,
                         "qwerty66"             => 12545,
                         "qwerty666"            => 16970,
                         "qwerty69"             => 18810,
                         "qwerty7"              => 4209,
                         "qwerty77"             => 8925,
                         "qwerty777"            => 8884,
                         "qwerty78"             => 7615,
                         "qwerty789"            => 26300,
                         "qwerty8"              => 27560,
                         "qwerty88"             => 15590,
                         "qwerty89"             => 16707,
                         "qwerty99"             => 7911,
                         "qwerty999"            => 28317,
                         "qwertyas"             => 20734,
                         "qwertyasd"            => 18386,
                         "qwertyasdfgh"         => 10110,
                         "qwertyu"              => 431,
                         "qwertyu1"             => 12174,
                         "qwertyu123"           => 27125,
                         "qwertyu8"             => 12336,
                         "qwertyui"             => 263,
                         "qwertyuio"            => 1840,
                         "qwertyuiop"           => 22,
                         "qwertyuiop1"          => 14641,
                         "qwertyuiop10"         => 25398,
                         "qwertyuiop12"         => 29640,
                         "qwertyuiop123"        => 14013,
                         "qwertyuiop12345"      => 26714,
                         "qwertyy"              => 24525,
                         "qwertyytrewq"         => 13271,
                         "qwertyz"              => 24111,
                         "qwertz"               => 1532,
                         "qwertzu"              => 23984,
                         "qwertzui"             => 9359,
                         "qwertzuiop"           => 24792,
                         "qwerzxcv"             => 11921,
                         "qwest123"             => 24651,
                         "qweszxc"              => 15592,
                         "qwezxc"               => 9373,
                         "qwsazx"               => 25211,
                         "qzwxec"               => 16400,
                         "qzwxecrv"             => 19269,
                         "r12345"               => 10982,
                         "r123456"              => 14207,
                         "r1234567"             => 23357,
                         "r1chard"              => 17502,
                         "r29hqq"               => 13935,
                         "r2d2"                 => 5841,
                         "r2d2c3p0"             => 8799,
                         "r2d2c3po"             => 2374,
                         "r3ady41t"             => 13485,
                         "r3vi3wpass"           => 18581,
                         "r4e3w2q1"             => 8303,
                         "r4zpm3"               => 24066,
                         "r7112s"               => 23066,
                         "rabbit"               => 171,
                         "rabbit1"              => 5950,
                         "rabbit66"             => 25110,
                         "rabbit69"             => 29115,
                         "rabbits"              => 5499,
                         "rabbitt"              => 15408,
                         "rabota"               => 2722,
                         "raccoon"              => 10343,
                         "racecar"              => 1059,
                         "racecar02"            => 26965,
                         "racecar1"             => 22504,
                         "racecars"             => 16330,
                         "racefan"              => 22797,
                         "racer"                => 2622,
                         "racer1"               => 6690,
                         "racer2"               => 27297,
                         "racers"               => 6550,
                         "racerx"               => 1480,
                         "racerx1"              => 25608,
                         "rachael1"             => 22204,
                         "rache"                => 10515,
                         "rachel1"              => 2908,
                         "rachel69"             => 22577,
                         "rachid"               => 20121,
                         "racin"                => 24501,
                         "racing"               => 442,
                         "racing1"              => 17522,
                         "racoon"               => 8785,
                         "radagast"             => 14333,
                         "radar1"               => 7249,
                         "radeon"               => 5689,
                         "radial9"              => 18844,
                         "radiance"             => 9952,
                         "radiatio"             => 21982,
                         "radical1"             => 20341,
                         "radio1"               => 7995,
                         "radio123"             => 28803,
                         "radiohea"             => 3511,
                         "radiohead"            => 3900,
                         "radioman"             => 12005,
                         "radish"               => 12659,
                         "radman"               => 14740,
                         "radmir"               => 21468,
                         "radost"               => 16276,
                         "raduga"               => 5951,
                         "rafae"                => 10437,
                         "rafale"               => 24511,
                         "raffael"              => 23794,
                         "raffaele"             => 12197,
                         "raffaello"            => 20459,
                         "raffles"              => 9608,
                         "rafiki"               => 14290,
                         "ragdoll"              => 14710,
                         "ragman"               => 8880,
                         "ragnar"               => 8194,
                         "ragnarok"             => 1526,
                         "ragtop"               => 15014,
                         "rahasia"              => 11186,
                         "raide"                => 29666,
                         "raiden"               => 6966,
                         "raider"               => 531,
                         "raider1"              => 10128,
                         "raider12"             => 29456,
                         "raiders"              => 177,
                         "raiders1"             => 1651,
                         "raiders2"             => 20818,
                         "rainbo"               => 11085,
                         "rainbow"              => 231,
                         "rainbow1"             => 4186,
                         "rainbow2"             => 16261,
                         "rainbow6"             => 3442,
                         "rainbow7"             => 18846,
                         "rainbows"             => 5420,
                         "raindog"              => 27062,
                         "raindrop"             => 7997,
                         "rainger"              => 15594,
                         "rainier"              => 9231,
                         "rainmake"             => 19631,
                         "rainmaker"            => 21342,
                         "rainman"              => 2814,
                         "rainman1"             => 21370,
                         "raintree"             => 15093,
                         "rainyday"             => 5406,
                         "raisin"               => 9601,
                         "raissa"               => 24199,
                         "raistlin"             => 1254,
                         "rajeev"               => 16133,
                         "rajesh"               => 9877,
                         "rakas"                => 25063,
                         "rakesh"               => 9591,
                         "raketa"               => 8263,
                         "rakkaus"              => 9115,
                         "rakker"               => 19467,
                         "raleigh1"             => 29566,
                         "ralliart"             => 28571,
                         "rallye"               => 23158,
                         "ralph1"               => 6807,
                         "ralphie"              => 6669,
                         "ralphy"               => 9066,
                         "ram123"               => 26638,
                         "ram1500"              => 8330,
                         "ram2500"              => 23055,
                         "ramada"               => 7065,
                         "ramair"               => 10762,
                         "ramana"               => 23397,
                         "ramazan"              => 9928,
                         "rambler"              => 2269,
                         "rambler1"             => 22099,
                         "rambo"                => 2803,
                         "rambo1"               => 5812,
                         "rambo123"             => 16332,
                         "rambo2"               => 25395,
                         "rambone"              => 17641,
                         "rambos"               => 25055,
                         "ramesh"               => 13914,
                         "ramil"                => 23118,
                         "ramin"                => 29718,
                         "ramina"               => 28034,
                         "ramir"                => 28235,
                         "ramire"               => 27282,
                         "ramjet"               => 5880,
                         "ramman"               => 26288,
                         "rammer"               => 12513,
                         "rammstei"             => 7451,
                         "rammstein"            => 1421,
                         "rammstein1"           => 18811,
                         "ramone"               => 10419,
                         "ramones"              => 3395,
                         "rampage"              => 4394,
                         "ramrod"               => 3629,
                         "ramses"               => 2308,
                         "ramstein"             => 7554,
                         "ramzes"               => 7197,
                         "ranchero"             => 9714,
                         "rancid"               => 3050,
                         "randers"              => 20300,
                         "randie"               => 24684,
                         "random"               => 881,
                         "random1"              => 8809,
                         "random123"            => 18993,
                         "randy1"               => 4926,
                         "randy2"               => 20525,
                         "ranetka"              => 22157,
                         "ranetki"              => 6783,
                         "rang"                 => 3789,
                         "ranger"               => 49,
                         "ranger01"             => 12178,
                         "ranger02"             => 20717,
                         "ranger1"              => 1462,
                         "ranger11"             => 14669,
                         "ranger12"             => 17748,
                         "ranger2"              => 13037,
                         "ranger21"             => 12878,
                         "ranger3"              => 29016,
                         "ranger5"              => 19133,
                         "ranger6"              => 22423,
                         "ranger69"             => 21589,
                         "ranger7"              => 21911,
                         "ranger75"             => 21623,
                         "ranger9"              => 28770,
                         "ranger98"             => 23312,
                         "ranger99"             => 11932,
                         "rangerover"           => 28983,
                         "rangers"              => 161,
                         "rangers1"             => 1965,
                         "rangers2"             => 23804,
                         "rangers9"             => 16358,
                         "ranita"               => 23416,
                         "ranjan"               => 17466,
                         "ranma"                => 15726,
                         "ranma12"              => 22094,
                         "ranman"               => 21033,
                         "rapala"               => 17711,
                         "rapeme"               => 24973,
                         "rapid1"               => 21961,
                         "rapide"               => 28173,
                         "rapido"               => 21482,
                         "rapier"               => 6925,
                         "raptor"               => 667,
                         "raptor1"              => 21645,
                         "raptor22"             => 25277,
                         "raptors"              => 8279,
                         "rapture"              => 6972,
                         "rapunzel"             => 7576,
                         "raque"                => 26150,
                         "rascal"               => 515,
                         "rascal1"              => 15048,
                         "rasdzv3"              => 627,
                         "rasengan"             => 11305,
                         "rashmi"               => 14769,
                         "rasmus"               => 4957,
                         "raspberr"             => 14427,
                         "rasputin"             => 2296,
                         "rassvet"              => 17906,
                         "rasta"                => 2856,
                         "rasta1"               => 9772,
                         "rasta220"             => 12542,
                         "rasta69"              => 7861,
                         "rastafar"             => 19837,
                         "rastafari"            => 16417,
                         "rastaman"             => 2276,
                         "rastas"               => 18145,
                         "raster"               => 8970,
                         "rastus"               => 8839,
                         "rataros"              => 24889,
                         "ratbag"               => 12674,
                         "ratboy"               => 5750,
                         "ratchet"              => 10981,
                         "ratdog"               => 9208,
                         "ratface"              => 20160,
                         "ratfink"              => 9748,
                         "ratiug"               => 27986,
                         "ratman"               => 4831,
                         "ratpack"              => 12268,
                         "ratrace"              => 15849,
                         "ratten"               => 21872,
                         "rattler"              => 8602,
                         "rattlers"             => 26007,
                         "rattlesn"             => 19677,
                         "rattolo58"            => 16011,
                         "rattrace"             => 27401,
                         "rattrap"              => 28118,
                         "rauchen"              => 28222,
                         "raunchy"              => 27981,
                         "ravage"               => 10963,
                         "raven"                => 788,
                         "raven1"               => 1934,
                         "raven11"              => 28831,
                         "raven123"             => 16792,
                         "raven13"              => 28069,
                         "raven3"               => 21665,
                         "raven69"              => 18421,
                         "ravens"               => 1268,
                         "ravens1"              => 16897,
                         "ravers"               => 24853,
                         "ravshan"              => 25037,
                         "rawdog"               => 16759,
                         "rawhide"              => 7774,
                         "rawiswar"             => 14578,
                         "rawks"                => 15201,
                         "ray123"               => 25862,
                         "rayden"               => 12112,
                         "raygun"               => 14383,
                         "rayman"               => 8075,
                         "raymond1"             => 6526,
                         "razdvatri"            => 11437,
                         "razer"                => 26262,
                         "raziel"               => 9157,
                         "razor"                => 4369,
                         "razor1"               => 12113,
                         "razorbac"             => 10983,
                         "razors"               => 15675,
                         "razvan"               => 24195,
                         "razz"                 => 233,
                         "razzle"               => 9721,
                         "rb26dett"             => 7807,
                         "rbcekz"               => 7631,
                         "rbgtkjd"              => 28312,
                         "rbhbkk"               => 1776,
                         "rbhgbx"               => 21523,
                         "rbhjxrf"              => 26242,
                         "rccola"               => 19167,
                         "rcfhlfc"              => 28232,
                         "rclaki"               => 15514,
                         "rctybz"               => 2286,
                         "rdfhnbhf"             => 7526,
                         "rdgpl3ds"             => 22437,
                         "reader"               => 2941,
                         "readme"               => 13603,
                         "ready1"               => 10508,
                         "ready2go"             => 12224,
                         "realdeal"             => 11323,
                         "realgood"             => 17441,
                         "realmadr"             => 22881,
                         "realmadri"            => 17563,
                         "realmadrid"           => 2912,
                         "realman"              => 20721,
                         "realsex"              => 25195,
                         "realtime"             => 12863,
                         "realtor"              => 7668,
                         "realty"               => 15573,
                         "reanimator"           => 17512,
                         "reape"                => 23590,
                         "reaper"               => 947,
                         "reaper1"              => 10590,
                         "reaver"               => 8329,
                         "rebbyt34"             => 8580,
                         "rebecc"               => 11132,
                         "rebecca1"             => 2858,
                         "rebecca2"             => 22852,
                         "rebel"                => 1932,
                         "rebel1"               => 3491,
                         "rebel12"              => 29368,
                         "rebel2"               => 18962,
                         "rebeld"               => 24434,
                         "rebelde"              => 10899,
                         "rebell"               => 12623,
                         "rebellio"             => 20406,
                         "rebels"               => 1521,
                         "rebelz"               => 6993,
                         "rebenok"              => 23430,
                         "rebirth"              => 10575,
                         "rebon"                => 29999,
                         "reboot"               => 6818,
                         "reborn"               => 7956,
                         "rebrov"               => 14050,
                         "reccos"               => 14487,
                         "reckless"             => 3574,
                         "recoba"               => 23575,
                         "recoil"               => 12419,
                         "recon"                => 6742,
                         "recon1"               => 12928,
                         "recon7"               => 26135,
                         "rectum"               => 15484,
                         "recycle"              => 11642,
                         "red007"               => 20740,
                         "red100"               => 25654,
                         "red111"               => 22582,
                         "red12"                => 17778,
                         "red123"               => 294,
                         "red1234"              => 10878,
                         "red12345"             => 9450,
                         "red222"               => 25215,
                         "red321"               => 11318,
                         "red333"               => 25584,
                         "red456"               => 13712,
                         "red666"               => 28209,
                         "red911"               => 21733,
                         "redalert"             => 1653,
                         "redapple"             => 18983,
                         "redarmy"              => 24553,
                         "redbarch"             => 14536,
                         "redbaron"             => 4119,
                         "redbeard"             => 9617,
                         "redbird"              => 3504,
                         "redbirds"             => 11130,
                         "redblue"              => 12694,
                         "redbone"              => 5204,
                         "redboy"               => 18883,
                         "redbud"               => 20965,
                         "redbull"              => 1784,
                         "redbull1"             => 19022,
                         "redcar"               => 5053,
                         "redcar27"             => 26619,
                         "redcard"              => 24018,
                         "redcat"               => 12377,
                         "redcloud"             => 15894,
                         "redcross"             => 17217,
                         "reddawg"              => 17782,
                         "redder"               => 23472,
                         "reddevil"             => 3729,
                         "reddevils"            => 29205,
                         "reddog"               => 482,
                         "reddog1"              => 7636,
                         "reddrago"             => 11757,
                         "reddragon"            => 10916,
                         "reddwarf"             => 3922,
                         "redeemed"             => 13802,
                         "redeemer"             => 16202,
                         "redeye"               => 4347,
                         "redfire"              => 17537,
                         "redfish"              => 2674,
                         "redfish1"             => 21922,
                         "redfive"              => 9704,
                         "redfox"               => 4109,
                         "redfred"              => 16195,
                         "redgreen"             => 12769,
                         "redhair"              => 20184,
                         "redhat"               => 4886,
                         "redhawk"              => 11236,
                         "redhawks"             => 25863,
                         "redhead"              => 738,
                         "redhead1"             => 9215,
                         "redheads"             => 6129,
                         "redhed"               => 29719,
                         "redhill"              => 24768,
                         "redhook"              => 14748,
                         "redhorse"             => 23632,
                         "redhot"               => 1997,
                         "redhouse"             => 13025,
                         "rediska"              => 10836,
                         "redknapp"             => 15946,
                         "redlands"             => 22702,
                         "redleg"               => 6776,
                         "redlegs"              => 18484,
                         "redlight"             => 6185,
                         "redline"              => 3072,
                         "redlion"              => 22730,
                         "redman"               => 1004,
                         "redman1"              => 18392,
                         "redmoon"              => 16522,
                         "redneck"              => 936,
                         "redneck1"             => 8941,
                         "redoak"               => 21199,
                         "redone"               => 6442,
                         "redrider"             => 13477,
                         "redriver"             => 13872,
                         "redrobin"             => 29436,
                         "redrock"              => 9097,
                         "redrocke"             => 19714,
                         "redrose"              => 4140,
                         "redroses"             => 16072,
                         "redrover"             => 13532,
                         "redrum"               => 548,
                         "redrum1"              => 16456,
                         "redryder"             => 29351,
                         "reds"                 => 3405,
                         "redsand"              => 25378,
                         "redsea"               => 18147,
                         "redshift"             => 9108,
                         "redshoes"             => 18943,
                         "redskin"              => 4961,
                         "redskin1"             => 15718,
                         "redskins"             => 235,
                         "redskins1"            => 20564,
                         "redsky"               => 15656,
                         "redso"                => 17649,
                         "redsox"               => 165,
                         "redsox04"             => 11115,
                         "redsox1"              => 3870,
                         "redsox11"             => 24348,
                         "redsox12"             => 28439,
                         "redsox19"             => 28029,
                         "redsox20"             => 26520,
                         "redsox24"             => 29789,
                         "redsox3"              => 29480,
                         "redsox99"             => 28379,
                         "redstar"              => 5785,
                         "redstone"             => 16426,
                         "redstorm"             => 7433,
                         "redtail"              => 14668,
                         "redtruck"             => 10695,
                         "redvette"             => 21250,
                         "redwall"              => 7652,
                         "redwhite"             => 24399,
                         "redwin"               => 26810,
                         "redwine"              => 6042,
                         "redwing"              => 2828,
                         "redwing1"             => 8975,
                         "redwings"             => 373,
                         "redwings1"            => 19444,
                         "redwolf"              => 8351,
                         "redwood"              => 2827,
                         "redwood1"             => 17631,
                         "reebok"               => 2111,
                         "reefer"               => 2780,
                         "reeper"               => 26597,
                         "reese1"               => 16879,
                         "reeses"               => 7397,
                         "refinnej"             => 25930,
                         "reflex"               => 4313,
                         "regal"                => 9316,
                         "regal1"               => 26502,
                         "regedit"              => 23691,
                         "reggae"               => 5088,
                         "reggi"                => 21449,
                         "reggie1"              => 10821,
                         "reggie31"             => 28431,
                         "reggin"               => 19771,
                         "regin"                => 20169,
                         "regis1"               => 22042,
                         "registr"              => 21994,
                         "reglisse"             => 28872,
                         "rehbwf"               => 6674,
                         "rehjgfnrf"            => 20687,
                         "rehnrf"               => 20840,
                         "reisen"               => 28754,
                         "rekbrjdf"             => 18925,
                         "reklama"              => 10688,
                         "reksio"               => 11543,
                         "relayer"              => 22520,
                         "reliant"              => 8910,
                         "relisys"              => 12540,
                         "rellik"               => 11523,
                         "reload"               => 3814,
                         "reloaded"             => 6143,
                         "rembrand"             => 18408,
                         "remembe"              => 19356,
                         "remingto"             => 4559,
                         "remmah"               => 29430,
                         "remmus"               => 27385,
                         "renat"                => 8784,
                         "renault"              => 2395,
                         "renee1"               => 7714,
                         "reneee"               => 20115,
                         "renegade"             => 943,
                         "renfield"             => 21767,
                         "reng"                 => 3293,
                         "renob"                => 29197,
                         "renrut"               => 29024,
                         "renton"               => 16457,
                         "renwod"               => 18968,
                         "repmvbx"              => 26333,
                         "repmvbyf"             => 27291,
                         "repmvf"               => 13396,
                         "repoman"              => 8410,
                         "reppep"               => 27873,
                         "reptile"              => 4378,
                         "repvtyrj"             => 20675,
                         "repytwjd"             => 10100,
                         "repytwjdf"            => 9649,
                         "repytxbr"             => 20880,
                         "requiem"              => 5865,
                         "requin"               => 19083,
                         "rerecz"               => 13045,
                         "rerehepf"             => 9365,
                         "rereirf"              => 2178,
                         "rerfhfxf"             => 9424,
                         "rerfhtre"             => 8136,
                         "rerjkrf"              => 11341,
                         "rescue"               => 1552,
                         "rescue1"              => 12765,
                         "reset1"               => 26501,
                         "reshma"               => 13433,
                         "residentevil"         => 19221,
                         "resipsa"              => 29260,
                         "resolute"             => 21759,
                         "respekt"              => 10928,
                         "respublika"           => 22198,
                         "restart"              => 5715,
                         "restaura"             => 24094,
                         "retard"               => 2046,
                         "retep"                => 10805,
                         "retired1"             => 23541,
                         "retlaw"               => 14320,
                         "retnuh"               => 21787,
                         "retrac"               => 26538,
                         "retsam"               => 8967,
                         "retsub"               => 23220,
                         "retype"               => 28829,
                         "rev2000"              => 21074,
                         "revelati"             => 23528,
                         "revenant"             => 20054,
                         "reverb"               => 10036,
                         "review69"             => 12328,
                         "reviewpa"             => 11604,
                         "reviewpass"           => 24761,
                         "revilo"               => 12366,
                         "revival47"            => 7551,
                         "revoluti"             => 5811,
                         "revolver"             => 4244,
                         "rewster"              => 24773,
                         "rexdog"               => 19695,
                         "rexona"               => 12026,
                         "rey619"               => 19883,
                         "reynald"              => 26475,
                         "rezeda"               => 17077,
                         "reznor"               => 7010,
                         "rf6666"               => 25590,
                         "rfcgth"               => 16240,
                         "rfcgthcrbq"           => 28093,
                         "rfgbnfy"              => 11136,
                         "rfgbnjirf"            => 6836,
                         "rfgecnf"              => 5751,
                         "rfgecnfcerf"          => 23790,
                         "rfghbp"               => 14520,
                         "rfghjy"               => 24277,
                         "rfgtkmrf"             => 18350,
                         "rfhbyf"               => 2110,
                         "rfhbyjxrf"            => 16520,
                         "rfhbyrf"              => 23882,
                         "rfhectkm"             => 15622,
                         "rfhfcm"               => 13306,
                         "rfhfdfy"              => 29455,
                         "rfhfgep"              => 8708,
                         "rfhfnt"               => 27509,
                         "rfhfntkm"             => 13663,
                         "rfhfrfnbwf"           => 18974,
                         "rfhfufylf"            => 12570,
                         "rfhfvtkm"             => 15040,
                         "rfhfvtkmrf"           => 5885,
                         "rfhfylfi"             => 6145,
                         "rfhfynby"             => 18282,
                         "rfhjkbyf"             => 11440,
                         "rfhkcjy"              => 20522,
                         "rfhlbyfk"             => 7305,
                         "rfhnbyf"              => 21085,
                         "rfhnjirf"             => 5181,
                         "rfj422"               => 17106,
                         "rfkbybyf"             => 19692,
                         "rfkbyf"               => 9875,
                         "rfkmrekznjh"          => 14938,
                         "rfktylfhm"            => 20086,
                         "rfn.irf"              => 13237,
                         "rfnfcnhjaf"           => 13230,
                         "rfnfgekmnf"           => 14631,
                         "rfnfhbyf"             => 23487,
                         "rfnhby"               => 12575,
                         "rfnmrf"               => 18148,
                         "rfnthbyf"             => 1897,
                         "rfnthbyf1988"         => 26686,
                         "rfnthbyrf"            => 11747,
                         "rfntyf"               => 28101,
                         "rfntyjr"              => 10044,
                         "rfntymrf"             => 5093,
                         "rfnz90"               => 18514,
                         "rfpfyjdf"             => 26870,
                         "rfpfym"               => 16908,
                         "rfpfynbg"             => 11233,
                         "rfpzdrf"              => 19950,
                         "rfrfirf"              => 1328,
                         "rfrltkf"              => 12209,
                         "rfrnec"               => 2215,
                         "rfvbkf"               => 27351,
                         "rfvbkkf"              => 16828,
                         "rfvbkm"               => 28094,
                         "rfvbrflpt"            => 13005,
                         "rfvfcenhf"            => 4577,
                         "rfvtgb"               => 12424,
                         "rfvtgbyhn"            => 22067,
                         "rfvtym"               => 29724,
                         "rfvxfnrf"             => 19684,
                         "rfybreks"             => 28947,
                         "rfycthdf"             => 23968,
                         "rfyfgkz"              => 22287,
                         "rhapsody"             => 10340,
                         "rhbcnb"               => 29315,
                         "rhbcnbyf"             => 1127,
                         "rhbcnbyjxrf"          => 12307,
                         "rhenjq"               => 18851,
                         "rhett32"              => 19161,
                         "rhfcbdfz"             => 23666,
                         "rhfcfdbwf"            => 5912,
                         "rhfcfdxbr"            => 9270,
                         "rhfcjnf"              => 6767,
                         "rhfcjnrf"             => 2847,
                         "rhfcyjlfh"            => 21096,
                         "rhfcyjzhcr"           => 27584,
                         "rhfcysq"              => 12826,
                         "rhfdxtyrj"            => 15795,
                         "rhfvfnjhcr"           => 27566,
                         "rhianna"              => 20838,
                         "rhind101"             => 22564,
                         "rhino"                => 3299,
                         "rhino1"               => 6772,
                         "rhinos"               => 5914,
                         "rhjirf"               => 16340,
                         "rhjkbr"               => 6622,
                         "rhjrjlbk"             => 3631,
                         "rhodan"               => 16943,
                         "rhonda1"              => 28084,
                         "rhtdtlrj"             => 3122,
                         "rhtfnbd"              => 19188,
                         "rhtyltkm"             => 28659,
                         "rhubarb"              => 5836,
                         "ribbit"               => 6888,
                         "ribeye"               => 20559,
                         "ricard"               => 4898,
                         "ricardo1"             => 11406,
                         "riccardo"             => 5174,
                         "rice80"               => 9577,
                         "ricflair"             => 13013,
                         "rich123"              => 22502,
                         "richar"               => 5021,
                         "richar1"              => 24712,
                         "richard0"             => 23844,
                         "richard1"             => 1477,
                         "richard2"             => 10244,
                         "richard3"             => 18568,
                         "richard4"             => 26305,
                         "richard7"             => 16763,
                         "richard8"             => 26301,
                         "richard9"             => 25489,
                         "riches"               => 9837,
                         "richi"                => 24816,
                         "richy"                => 23865,
                         "rick1"                => 24334,
                         "rickster"             => 8027,
                         "ricky1"               => 7176,
                         "ricochet"             => 9112,
                         "riddler"              => 7134,
                         "rideme"               => 27332,
                         "rider1"               => 11375,
                         "ridered"              => 28835,
                         "riesling"             => 18296,
                         "riffraff"             => 5724,
                         "rifleman"             => 17015,
                         "rifraf"               => 25649,
                         "rigger"               => 8370,
                         "right1"               => 16959,
                         "rightnow"             => 2095,
                         "righton"              => 9031,
                         "riker1"               => 11836,
                         "rikimaru"             => 16645,
                         "riley1"               => 6157,
                         "rileydog"             => 16387,
                         "rimjob"               => 15025,
                         "rimshot"              => 12471,
                         "rincewin"             => 18005,
                         "rincewind"            => 15713,
                         "ringding"             => 29680,
                         "ringo"                => 5115,
                         "ringo1"               => 13169,
                         "ringo123"             => 29200,
                         "riobravo"             => 22978,
                         "riogrand"             => 27809,
                         "ripazha"              => 19505,
                         "ripcord"              => 19348,
                         "ripcurl"              => 13199,
                         "ripken"               => 2875,
                         "ripken8"              => 15660,
                         "ripley1"              => 26704,
                         "ripoff"               => 16150,
                         "ripper"               => 1176,
                         "ripper1"              => 19525,
                         "ripple"               => 2835,
                         "riptide"              => 7957,
                         "riptide1"             => 25086,
                         "risky1"               => 28892,
                         "rivaldo"              => 16429,
                         "riven"                => 19636,
                         "river1"               => 7976,
                         "river123"             => 25480,
                         "riverat"              => 29159,
                         "riverplate"           => 22815,
                         "riverrat"             => 6211,
                         "riversid"             => 5896,
                         "rizwan"               => 13558,
                         "rjcnbr"               => 10701,
                         "rjcntyrj"             => 13780,
                         "rjcnzy"               => 21111,
                         "rjcvjc"               => 6976,
                         "rjdfkmxer"            => 22752,
                         "rjdfktdf"             => 29406,
                         "rjdfktyrj"            => 12732,
                         "rjhjdf"               => 6912,
                         "rjhjkm"               => 5915,
                         "rjhjkmbien"           => 17357,
                         "rjhjktdf"             => 3767,
                         "rjirf"                => 25321,
                         "rjirfrgbde"           => 2093,
                         "rjitxrf"              => 7574,
                         "rjktcj"               => 15754,
                         "rjnjatq"              => 26499,
                         "rjnjgtc"              => 13650,
                         "rjntyjr"              => 1473,
                         "rjntyjxtr"            => 13550,
                         "rjnzhf"               => 8373,
                         "rjpthju"              => 17094,
                         "rjpzdrf"              => 15902,
                         "rjrfrjkf"             => 20335,
                         "rjvgm.nth"            => 19823,
                         "rjw7x4"               => 11799,
                         "rjyatnf"              => 22491,
                         "rjyatnrf"             => 9945,
                         "rjycnbnewbz"          => 23623,
                         "rjycnfynby"           => 2637,
                         "rjyjgkz"              => 9734,
                         "rjynfrn"              => 11802,
                         "rkbvtyrj"             => 24285,
                         "rkelly"               => 25297,
                         "rkfdbfnehf"           => 12936,
                         "rktjgfnhf"            => 7656,
                         "rlzwp503"             => 17857,
                         "rmfidd"               => 27161,
                         "rmracing"             => 27203,
                         "roach1"               => 26576,
                         "roaddog"              => 15975,
                         "roaddogg"             => 14106,
                         "roadhog"              => 22590,
                         "roadie"               => 17614,
                         "roadkill"             => 2262,
                         "roadking"             => 2895,
                         "roadrage"             => 27562,
                         "roadrash"             => 24494,
                         "roadrunn"             => 2976,
                         "roadrunner"           => 4998,
                         "roadstar"             => 15870,
                         "roadster"             => 4092,
                         "roadtrip"             => 18663,
                         "roadway"              => 6855,
                         "roamer"               => 28998,
                         "rob123"               => 9793,
                         "robbie1"              => 11519,
                         "robbob"               => 25214,
                         "rober"                => 4187,
                         "robert01"             => 21031,
                         "robert1"              => 1437,
                         "robert11"             => 21175,
                         "robert12"             => 10994,
                         "robert123"            => 22348,
                         "robert19"             => 29029,
                         "robert2"              => 9018,
                         "robert22"             => 24255,
                         "robert23"             => 28896,
                         "robert3"              => 15548,
                         "robert4"              => 29240,
                         "robert8"              => 26910,
                         "robert99"             => 22794,
                         "roberta1"             => 16635,
                         "roberto1"             => 9998,
                         "robertr"              => 28877,
                         "roberts1"             => 16103,
                         "robertso"             => 19504,
                         "robin1"               => 5322,
                         "robin123"             => 24705,
                         "robin2"               => 26943,
                         "robinh"               => 21988,
                         "robinho"              => 24148,
                         "robinhoo"             => 10144,
                         "robinhood"            => 8515,
                         "robinso"              => 21362,
                         "robocop"              => 4741,
                         "robot"                => 3874,
                         "robot1"               => 27221,
                         "robotec"              => 23629,
                         "robotech"             => 2284,
                         "robotics"             => 3718,
                         "roboto"               => 23443,
                         "robroy"               => 12402,
                         "robyn1"               => 12679,
                         "rocawear"             => 19601,
                         "rocco1"               => 10234,
                         "rochard"              => 7247,
                         "rocheste"             => 10637,
                         "rock1"                => 11105,
                         "rock12"               => 21001,
                         "rock123"              => 15018,
                         "rock22"               => 29003,
                         "rock69"               => 27207,
                         "rockandr"             => 24722,
                         "rockbott"             => 13738,
                         "rockbottom"           => 25182,
                         "rockcity"             => 24172,
                         "rocke"                => 17552,
                         "rocker"               => 1151,
                         "rocker1"              => 26263,
                         "rocket"               => 247,
                         "rocket1"              => 6589,
                         "rocket21"             => 23903,
                         "rocket69"             => 22364,
                         "rocket88"             => 16099,
                         "rocketma"             => 9802,
                         "rocketman"            => 9675,
                         "rockets"              => 2001,
                         "rockets1"             => 24706,
                         "rockey"               => 7027,
                         "rockfish"             => 16518,
                         "rockford"             => 2806,
                         "rockhard"             => 2208,
                         "rockhead"             => 18174,
                         "rockhopper"           => 27375,
                         "rockie"               => 4674,
                         "rockies"              => 4206,
                         "rockin"               => 5256,
                         "rockit"               => 12288,
                         "rockman"              => 8186,
                         "rockme"               => 22277,
                         "rocknrol"             => 5196,
                         "rocknroll"            => 5526,
                         "rocko"                => 15519,
                         "rockon"               => 1535,
                         "rockport"             => 11674,
                         "rockroll"             => 9370,
                         "rocks"                => 822,
                         "rocks1"               => 9582,
                         "rockshox"             => 24367,
                         "rockss"               => 16136,
                         "rocksta"              => 26361,
                         "rockstar"             => 792,
                         "rockstar1"            => 28098,
                         "rocky1"               => 879,
                         "rocky123"             => 7130,
                         "rocky13"              => 18287,
                         "rocky2"               => 6453,
                         "rocky3"               => 16241,
                         "rocky4"               => 22928,
                         "rocky5"               => 20911,
                         "rocky6"               => 14653,
                         "rockyboy"             => 16889,
                         "rockydog"             => 9828,
                         "rockys"               => 13347,
                         "rockytop"             => 25709,
                         "rockyy"               => 24634,
                         "rockz"                => 15569,
                         "rodder"               => 26592,
                         "rodders"              => 22298,
                         "rodent"               => 7591,
                         "rodeo"                => 5182,
                         "rodeo1"               => 11857,
                         "rodeos"               => 26550,
                         "rodina"               => 8713,
                         "rodion"               => 9880,
                         "rodman"               => 2682,
                         "rodman91"             => 24209,
                         "rodney1"              => 18117,
                         "rodrig"               => 10773,
                         "roenick"              => 29241,
                         "roflcopter"           => 15725,
                         "roflmao"              => 15274,
                         "roger1"               => 4680,
                         "roger123"             => 16244,
                         "roger2"               => 19341,
                         "rogue"                => 4581,
                         "rogue1"               => 7423,
                         "rogue2"               => 16193,
                         "rogues"               => 15042,
                         "roisin"               => 23639,
                         "roksana"              => 16022,
                         "rolan"                => 12493,
                         "roland1"              => 9088,
                         "roleplay"             => 28686,
                         "rolex"                => 5829,
                         "rolex1"               => 13897,
                         "roller"               => 1661,
                         "roller1"              => 21912,
                         "rollie"               => 11675,
                         "rollin"               => 5728,
                         "rollout"              => 19845,
                         "rollover"             => 24670,
                         "rollrock"             => 27768,
                         "rolltide"             => 629,
                         "rolltide1"            => 26600,
                         "rolodex"              => 21809,
                         "rolsen"               => 19711,
                         "rolyat"               => 28655,
                         "roma123"              => 10600,
                         "roma1990"             => 26775,
                         "roma1993"             => 23016,
                         "roma1995"             => 29327,
                         "romai"                => 21369,
                         "roman1"               => 7149,
                         "roman123"             => 12350,
                         "roman222"             => 16588,
                         "roman777"             => 23398,
                         "romance1"             => 26365,
                         "romanenko"            => 23305,
                         "romann"               => 25196,
                         "romanov"              => 7824,
                         "romanova"             => 8499,
                         "romans"               => 3970,
                         "romanson"             => 25377,
                         "romantik"             => 14041,
                         "romantika"            => 25401,
                         "romario"              => 6956,
                         "romashka"             => 1740,
                         "romawka"              => 20704,
                         "romeo1"               => 5361,
                         "romeo123"             => 14270,
                         "romeos"               => 16536,
                         "romina"               => 11787,
                         "rommel"               => 1079,
                         "romuald"              => 16349,
                         "romulus"              => 8723,
                         "ronal"                => 12101,
                         "ronald1"              => 7487,
                         "ronaldinho"           => 5917,
                         "ronaldo"              => 684,
                         "ronaldo1"             => 10652,
                         "ronaldo7"             => 9343,
                         "ronaldo9"             => 10359,
                         "ronaldo99"            => 29165,
                         "rong"                 => 3375,
                         "ronin"                => 16441,
                         "ronjon"               => 22831,
                         "ronnie1"              => 16180,
                         "roodypoo"             => 10502,
                         "roofer"               => 4873,
                         "roofing"              => 12947,
                         "roofus"               => 23917,
                         "rookie"               => 1886,
                         "rookie1"              => 18884,
                         "room112"              => 17530,
                         "rooney1"              => 29790,
                         "rooney10"             => 27561,
                         "roosevel"             => 22650,
                         "rooster"              => 657,
                         "rooster1"             => 9265,
                         "roosters"             => 6757,
                         "rootbeer"             => 1610,
                         "rootedit"             => 8738,
                         "rooter"               => 8344,
                         "rosari"               => 15431,
                         "rosco1"               => 21410,
                         "roscoe1"              => 15603,
                         "rose1"                => 23650,
                         "rose12"               => 16958,
                         "rose123"              => 17308,
                         "rosebowl"             => 12663,
                         "rosebu"               => 21585,
                         "rosebud"              => 271,
                         "rosebud1"             => 6642,
                         "rosebud7"             => 28875,
                         "rosebudd"             => 25578,
                         "rosebuds"             => 16546,
                         "rosedale"             => 22665,
                         "rosehill"             => 24915,
                         "rosemari"             => 14946,
                         "rosenrot"             => 26918,
                         "rosewood"             => 6278,
                         "rosey"                => 12683,
                         "roshan"               => 16092,
                         "rosie1"               => 7181,
                         "rosies"               => 22103,
                         "rosit"                => 18853,
                         "rossco"               => 23098,
                         "rossella"             => 20212,
                         "rossi46"              => 13661,
                         "rossia"               => 12019,
                         "rossigno"             => 26173,
                         "rostik"               => 10259,
                         "rostislav"            => 18200,
                         "rostov"               => 8161,
                         "roswell"              => 4710,
                         "rotary"               => 6719,
                         "rotciv"               => 20790,
                         "rothmans"             => 22832,
                         "rotten"               => 2056,
                         "rotterda"             => 10862,
                         "rottie"               => 13205,
                         "rottweil"             => 11598,
                         "rouges"               => 25249,
                         "rounders"             => 17881,
                         "route66"              => 2310,
                         "router"               => 8637,
                         "rover"                => 2619,
                         "rover1"               => 8120,
                         "rovers"               => 2101,
                         "rovnogod"             => 18999,
                         "rowdy"                => 7671,
                         "rowdy1"               => 15623,
                         "roxan"                => 11498,
                         "roxanne1"             => 21970,
                         "roxette"              => 14619,
                         "roxie1"               => 24356,
                         "roxydog"              => 17924,
                         "roy123"               => 26327,
                         "royal1"               => 13609,
                         "royale"               => 10135,
                         "royals"               => 2486,
                         "royboy"               => 7715,
                         "roygbiv"              => 9587,
                         "roykeane"             => 28878,
                         "rrpass1"              => 6340,
                         "rrrrr1"               => 15374,
                         "rrrrrr1"              => 21367,
                         "rrrrrrr1"             => 21811,
                         "rsalinas"             => 8436,
                         "rse2540"              => 22079,
                         "rstlne"               => 24879,
                         "rsturbo"              => 29293,
                         "rt6ytere"             => 7817,
                         "rtynfdh"              => 16207,
                         "rtyuehe"              => 2690,
                         "ruan"                 => 3168,
                         "rubber"               => 1193,
                         "rubberdu"             => 22038,
                         "rubble"               => 4323,
                         "ruben1"               => 29150,
                         "rubicon"              => 6241,
                         "rubies"               => 12514,
                         "rubina"               => 19012,
                         "rubyred"              => 15422,
                         "rubyrose"             => 29576,
                         "rudeboy"              => 5893,
                         "rudedog"              => 12228,
                         "rudenko"              => 23107,
                         "rudiger"              => 24178,
                         "ruffian"              => 20234,
                         "ruffles"              => 8838,
                         "ruffneck"             => 20284,
                         "ruffryde"             => 13273,
                         "ruffus"               => 28315,
                         "rufus1"               => 5886,
                         "rufus2"               => 27404,
                         "rufuss"               => 23374,
                         "rugburn"              => 22599,
                         "rugby1"               => 5525,
                         "rugby123"             => 28568,
                         "rugby2"               => 22876,
                         "rugby8"               => 26287,
                         "rugbyman"             => 24971,
                         "ruger"                => 9808,
                         "ruger1"               => 14916,
                         "rugger"               => 5659,
                         "rugrat"               => 6938,
                         "rugrats"              => 7268,
                         "rul3z"                => 23592,
                         "rules1"               => 11361,
                         "rulesyou"             => 16265,
                         "rulez"                => 769,
                         "rulez1"               => 22202,
                         "rulezz"               => 16159,
                         "rulezzz"              => 2933,
                         "rumble"               => 5732,
                         "rumple"               => 10536,
                         "rumpole"              => 23884,
                         "run4fun"              => 25496,
                         "runaway"              => 4463,
                         "rundmc"               => 8798,
                         "runescape"            => 2870,
                         "runescape1"           => 18081,
                         "runfast"              => 24898,
                         "runne"                => 26997,
                         "runner"               => 377,
                         "runner1"              => 10535,
                         "running1"             => 17504,
                         "runvs"                => 23457,
                         "rupert1"              => 22040,
                         "rusalka"              => 13214,
                         "rush211"              => 27141,
                         "rush2112"             => 287,
                         "rushfan"              => 22142,
                         "rushman"              => 25008,
                         "rushmore"             => 6992,
                         "ruslan"               => 487,
                         "ruslan123"            => 20813,
                         "ruslana"              => 13052,
                         "rusrap"               => 14556,
                         "russ120"              => 20998,
                         "russel1"              => 21814,
                         "russell1"             => 7936,
                         "russell2"             => 22448,
                         "russia"               => 521,
                         "russia1"              => 15044,
                         "russian7"             => 7970,
                         "russland"             => 14649,
                         "rustam"               => 2042,
                         "rustem"               => 13562,
                         "rustler"              => 21491,
                         "rusty1"               => 1669,
                         "rusty123"             => 13544,
                         "rusty2"               => 4679,
                         "rusty21"              => 29973,
                         "rusty5"               => 24061,
                         "rustyboy"             => 26225,
                         "rustydog"             => 5702,
                         "rustys"               => 17732,
                         "rutabega"             => 21594,
                         "rvd420"               => 15980,
                         "rvgmw2gl"             => 24112,
                         "rxmtkp"               => 13995,
                         "ryan01"               => 23876,
                         "ryan1"                => 12658,
                         "ryan11"               => 16050,
                         "ryan123"              => 19415,
                         "ryan22"               => 21881,
                         "ryder1"               => 23222,
                         "ryjgjxrf"             => 18401,
                         "ryjgrf"               => 9422,
                         "rynner"               => 28678,
                         "ryno23"               => 15719,
                         "ryslan"               => 23766,
                         "rz93qpmq"             => 23289,
                         "s0ccer"               => 25634,
                         "s1107d"               => 12478,
                         "s12345"               => 7257,
                         "s123456"              => 5424,
                         "s1234567"             => 20034,
                         "s12345678"            => 27433,
                         "s123456789"           => 22445,
                         "s1lver"               => 18947,
                         "s1s2s3s4"             => 27712,
                         "s4114d"               => 17499,
                         "s456123789"           => 15535,
                         "s5r8ed67s"            => 22908,
                         "s62i93"               => 22226,
                         "s7fhs127"             => 18726,
                         "s9te949f"             => 29856,
                         "saab900"              => 7913,
                         "saab9000"             => 8524,
                         "saab93"               => 14905,
                         "saab95"               => 15543,
                         "sabaka"               => 7977,
                         "sabbat"               => 14010,
                         "sabbath"              => 1836,
                         "sabbath1"             => 16119,
                         "sabbeth"              => 23477,
                         "saber"                => 10693,
                         "saber1"               => 19103,
                         "sabian"               => 9253,
                         "sabine"               => 1352,
                         "sable"                => 6444,
                         "sable1"               => 9757,
                         "sabre"                => 6840,
                         "sabre1"               => 16663,
                         "sabres"               => 2504,
                         "sabrin"               => 8786,
                         "sabrina1"             => 4897,
                         "sachas"               => 16756,
                         "sachem"               => 15254,
                         "sachin"               => 7511,
                         "sacramen"             => 14998,
                         "sacrific"             => 25538,
                         "sactown"              => 26370,
                         "sad123"               => 21707,
                         "saddie"               => 17983,
                         "sadie1"               => 2552,
                         "sadiedog"             => 16374,
                         "sadies"               => 20712,
                         "sadman"               => 27249,
                         "sadomaso"             => 28125,
                         "safado"               => 25635,
                         "safari"               => 2447,
                         "safety1"              => 20761,
                         "safeu851"             => 22920,
                         "safeway"              => 6572,
                         "saffron"              => 6568,
                         "safina"               => 17944,
                         "safrane"              => 24433,
                         "sagitari"             => 14247,
                         "sahalin"              => 25880,
                         "sahar"                => 27728,
                         "sahara"               => 3510,
                         "saibaba"              => 7219,
                         "saigon"               => 4990,
                         "sailaway"             => 22151,
                         "sailboat"             => 1817,
                         "sailfish"             => 9156,
                         "sailing"              => 1188,
                         "sailing1"             => 11981,
                         "sailor"               => 811,
                         "sailor1"              => 9579,
                         "sailormo"             => 24787,
                         "sailormoon"           => 10294,
                         "saint1"               => 11292,
                         "saints"               => 591,
                         "saints1"              => 12482,
                         "sairam"               => 4038,
                         "saisg002"             => 23824,
                         "saisha"               => 23470,
                         "saitek"               => 13120,
                         "saiyan"               => 4068,
                         "sakic"                => 27724,
                         "sakic19"              => 15462,
                         "sakur"                => 22938,
                         "sakura"               => 1069,
                         "salam"                => 14418,
                         "salama"               => 15822,
                         "salamand"             => 11166,
                         "salamander"           => 2830,
                         "salamandra"           => 9937,
                         "salamat"              => 11594,
                         "salami"               => 5367,
                         "salasana"             => 3472,
                         "salavat"              => 13426,
                         "saleen"               => 2934,
                         "salem1"               => 12193,
                         "sales1"               => 14422,
                         "salguod"              => 20722,
                         "salima"               => 24328,
                         "salinger"             => 19301,
                         "salisbur"             => 18936,
                         "sallad"               => 12286,
                         "sallas"               => 9659,
                         "sally1"               => 3006,
                         "sally123"             => 18064,
                         "sallys"               => 20148,
                         "salma"                => 14016,
                         "salman"               => 5771,
                         "salmon"               => 1246,
                         "salmon1"              => 20601,
                         "salom"                => 28753,
                         "salomon"              => 2946,
                         "salope"               => 4760,
                         "salsa1"               => 27014,
                         "salsero"              => 3065,
                         "salt55"               => 15335,
                         "saltanat"             => 11825,
                         "saltlake"             => 15170,
                         "salty1"               => 20261,
                         "saltydog"             => 7601,
                         "saluki"               => 17362,
                         "salut"                => 13545,
                         "salvado"              => 22784,
                         "salvatio"             => 12639,
                         "salvator"             => 7178,
                         "sam123"               => 3596,
                         "sam138989"            => 18779,
                         "sam2000"              => 20119,
                         "samadams"             => 7740,
                         "samadhi"              => 22412,
                         "samael"               => 10117,
                         "samant"               => 27322,
                         "samanta"              => 8388,
                         "samanth"              => 5731,
                         "samanth1"             => 21604,
                         "samantha"             => 90,
                         "samantha1"            => 8939,
                         "samapi"               => 14170,
                         "samarkand"            => 19065,
                         "samat"                => 24760,
                         "samatron"             => 25620,
                         "samba"                => 8801,
                         "samba1"               => 27389,
                         "sambo"                => 5428,
                         "sambo1"               => 27938,
                         "sambora"              => 26449,
                         "samboy"               => 24652,
                         "sambuca"              => 14521,
                         "sambuka"              => 24786,
                         "samcat"               => 29728,
                         "samdog"               => 7390,
                         "sameas"               => 21597,
                         "samedi"               => 18337,
                         "sameer"               => 10299,
                         "samfox"               => 28480,
                         "samhain"              => 9683,
                         "samia"                => 28866,
                         "samiam"               => 2210,
                         "samir"                => 6987,
                         "samm"                 => 5227,
                         "sammi"                => 8118,
                         "sammie1"              => 17452,
                         "sammmy"               => 21966,
                         "sammy1"               => 1084,
                         "sammy11"              => 25181,
                         "sammy12"              => 13144,
                         "sammy123"             => 5117,
                         "sammy2"               => 13761,
                         "sammy69"              => 23750,
                         "sammy7"               => 24428,
                         "sammyboy"             => 10941,
                         "sammycat"             => 20523,
                         "sammydog"             => 7731,
                         "sammys"               => 6406,
                         "sammyy"               => 21659,
                         "samoht"               => 5217,
                         "samolet"              => 10507,
                         "sampras"              => 13145,
                         "sampson1"             => 9562,
                         "samsam1"              => 27145,
                         "samsara"              => 11683,
                         "samso"                => 20589,
                         "samson"               => 284,
                         "samson1"              => 8141,
                         "samsun"               => 3652,
                         "samsung"              => 114,
                         "samsung1"             => 2199,
                         "samsung123"           => 14953,
                         "samsung2"             => 11810,
                         "samsung9"             => 26693,
                         "samtron"              => 3204,
                         "samue"                => 7032,
                         "samuel1"              => 5396,
                         "samuel12"             => 22140,
                         "samurai"              => 889,
                         "samurai1"             => 11005,
                         "samuraix"             => 28818,
                         "samuri"               => 18450,
                         "samvel"               => 19282,
                         "samwise"              => 10084,
                         "san123"               => 28285,
                         "sanan"                => 19955,
                         "sanandreas"           => 16067,
                         "sanane"               => 8605,
                         "sananton"             => 25642,
                         "sanche"               => 17044,
                         "sanchez1"             => 20742,
                         "sanchin"              => 27089,
                         "sancho"               => 2971,
                         "sanctuar"             => 19819,
                         "sandal"               => 14318,
                         "sandan"               => 23641,
                         "sandeep"              => 9935,
                         "sanders1"             => 23004,
                         "sanders2"             => 28178,
                         "sandhya"              => 17710,
                         "sandia"               => 23570,
                         "sandiego"             => 1366,
                         "sandman"              => 529,
                         "sandman1"             => 6643,
                         "sandmann"             => 14460,
                         "sandokan"             => 16019,
                         "sandr"                => 5081,
                         "sandra1"              => 5229,
                         "sandrin"              => 16352,
                         "sandrine"             => 4395,
                         "sandro"               => 2090,
                         "sandrock"             => 11719,
                         "sandy1"               => 2124,
                         "sandy123"             => 10976,
                         "sandy2"               => 22281,
                         "sandy69"              => 20558,
                         "sandydog"             => 9620,
                         "sandys"               => 9206,
                         "sane4ek"              => 26517,
                         "sanek"                => 23906,
                         "sanek94"              => 17517,
                         "sanfran"              => 3223,
                         "sanfrancisco"         => 23503,
                         "sangeeta"             => 16412,
                         "sanibel"              => 12932,
                         "sanity"               => 4221,
                         "sanity72"             => 7890,
                         "sanity729"            => 13729,
                         "sanja"                => 28792,
                         "sanjar"               => 19489,
                         "sanjay"               => 7054,
                         "sanjeev"              => 12620,
                         "sanjos"               => 26348,
                         "sanjose"              => 7399,
                         "sanjuan"              => 10524,
                         "sanman"               => 23095,
                         "sanna"                => 25741,
                         "sanpedro"             => 15867,
                         "santa1"               => 13769,
                         "santa234"             => 28424,
                         "santacla"             => 19901,
                         "santacru"             => 7670,
                         "santafe"              => 3912,
                         "santan"               => 28451,
                         "santana1"             => 28703,
                         "santana5"             => 27471,
                         "santeria"             => 18926,
                         "santiag"              => 6933,
                         "santino"              => 8987,
                         "santorin"             => 24251,
                         "santosh"              => 13017,
                         "sanya"                => 16485,
                         "sanyco"               => 25207,
                         "saopaulo"             => 9086,
                         "sapato"               => 29829,
                         "saphir"               => 19992,
                         "saphire"              => 9286,
                         "sapito"               => 29106,
                         "sapper"               => 2618,
                         "sapphic"              => 6105,
                         "sapphire"             => 1663,
                         "sappho"               => 17264,
                         "saqartvelo"           => 24996,
                         "sara123"              => 27555,
                         "saraann"              => 26492,
                         "saracen"              => 12729,
                         "sarah1"               => 1507,
                         "sarah123"             => 10065,
                         "sarah2"               => 17524,
                         "sarah69"              => 23515,
                         "sarah7"               => 27261,
                         "saraha"               => 28323,
                         "sarahb"               => 13928,
                         "sarahc"               => 17852,
                         "sarahh"               => 26506,
                         "sarahm"               => 19162,
                         "sarahs"               => 10335,
                         "saraht"               => 28527,
                         "sarajane"             => 17601,
                         "sarajevo"             => 6832,
                         "saralee"              => 25795,
                         "sarang"               => 17935,
                         "saransk"              => 26836,
                         "sarasota"             => 11561,
                         "saratoga"             => 2062,
                         "saratov"              => 8203,
                         "sardor"               => 15131,
                         "sarenna"              => 17201,
                         "saretta"              => 29685,
                         "sarge1"               => 14053,
                         "sargon"               => 13923,
                         "sargsyan"             => 26006,
                         "sarit"                => 15222,
                         "sarita2"              => 29846,
                         "sarmat"               => 27034,
                         "sartre"               => 12753,
                         "saruman"              => 12096,
                         "sarvar"               => 28765,
                         "sasa123"              => 18656,
                         "sasafras"             => 23561,
                         "sasami"               => 20288,
                         "sascha"               => 2676,
                         "sascha1"              => 25773,
                         "sasha1"               => 1702,
                         "sasha11"              => 23173,
                         "sasha12"              => 14965,
                         "sasha123"             => 5365,
                         "sasha1234"            => 16422,
                         "sasha12345"           => 20338,
                         "sasha13"              => 28949,
                         "sasha1988"            => 20347,
                         "sasha1992"            => 22041,
                         "sasha1993"            => 28177,
                         "sasha1994"            => 28420,
                         "sasha1995"            => 14004,
                         "sasha1996"            => 12985,
                         "sasha1997"            => 22850,
                         "sasha2"               => 14242,
                         "sasha2000"            => 22662,
                         "sasha2010"            => 14059,
                         "sasha2011"            => 28352,
                         "sasha777"             => 26565,
                         "sasha_007"            => 4624,
                         "sashaa"               => 16127,
                         "sashadog"             => 19245,
                         "sashas"               => 15994,
                         "sashenka"             => 22765,
                         "sashimi"              => 13862,
                         "sashka"               => 6136,
                         "sashok"               => 10428,
                         "saskatoo"             => 23771,
                         "saskia"               => 5809,
                         "sasquatc"             => 19954,
                         "sassie"               => 9733,
                         "sassy"                => 1958,
                         "sassy1"               => 3522,
                         "sassy123"             => 24738,
                         "sassy2"               => 25669,
                         "sassycat"             => 27579,
                         "sassydog"             => 23889,
                         "sassys"               => 26741,
                         "sasuke"               => 2598,
                         "sat321321"            => 24316,
                         "satan"                => 1705,
                         "satan1"               => 9453,
                         "satan6"               => 18838,
                         "satan66"              => 14721,
                         "satan666"             => 1244,
                         "satana"               => 3015,
                         "satana666"            => 12306,
                         "satanas"              => 8973,
                         "satanic"              => 11278,
                         "sataniv1993"          => 28416,
                         "satans"               => 17765,
                         "satchel"              => 9576,
                         "satchel1"             => 28606,
                         "satchmo"              => 6044,
                         "satcom"               => 28390,
                         "satelite"             => 20632,
                         "satellit"             => 8607,
                         "sathya"               => 23291,
                         "sativa"               => 7314,
                         "satnam"               => 18775,
                         "satori"               => 8294,
                         "satoshi"              => 17588,
                         "satriani"             => 9800,
                         "satsuma"              => 14565,
                         "satur"                => 25855,
                         "saturn"               => 367,
                         "saturn1"              => 9094,
                         "saturn5"              => 10062,
                         "saturne"              => 21461,
                         "saturno"              => 12427,
                         "satyam"               => 26105,
                         "sauber"               => 14800,
                         "saudade"              => 24565,
                         "saudan"               => 20250,
                         "saun"                 => 2027,
                         "saun24865709"         => 14136,
                         "sauron"               => 2778,
                         "saurus"               => 21690,
                         "sausage"              => 2181,
                         "sausage1"             => 16337,
                         "sausages"             => 3715,
                         "savag"                => 19896,
                         "savage1"              => 13372,
                         "savana"               => 11995,
                         "savanah"              => 28883,
                         "savannah1"            => 27476,
                         "savant"               => 11392,
                         "savatage"             => 13444,
                         "savchenko"            => 26676,
                         "save13tx"             => 10504,
                         "saveliy"              => 24807,
                         "saveme"               => 13079,
                         "savina"               => 24838,
                         "saviola"              => 22987,
                         "savior"               => 5051,
                         "sawadee"              => 27214,
                         "sawdust"              => 9830,
                         "saxman"               => 7101,
                         "saxophon"             => 6850,
                         "sayaka"               => 28393,
                         "sayan"                => 24714,
                         "sayana"               => 14266,
                         "sayang"               => 2116,
                         "sayangku"             => 12056,
                         "sayuri"               => 23982,
                         "saywhat"              => 11708,
                         "sb211st"              => 27574,
                         "sc00by"               => 14881,
                         "sc00ter"              => 10092,
                         "sc0tland"             => 15962,
                         "scabby"               => 23027,
                         "scale1"               => 16904,
                         "scammer"              => 17963,
                         "scamp"                => 11735,
                         "scamp1"               => 29658,
                         "scamper"              => 5497,
                         "scampi"               => 14369,
                         "scania"               => 2488,
                         "scanman"              => 25408,
                         "scanner"              => 2621,
                         "scanner1"             => 25919,
                         "scarab"               => 7507,
                         "scarecro"             => 12421,
                         "scarfac"              => 20875,
                         "scarface"             => 490,
                         "scarface1"            => 12787,
                         "scarlet"              => 1508,
                         "scarlet1"             => 15091,
                         "scarlets"             => 26175,
                         "scatman"              => 14307,
                         "scc1975"              => 26159,
                         "sceptre"              => 9202,
                         "schaap"               => 17766,
                         "schach"               => 19394,
                         "schalke"              => 3757,
                         "schalke0"             => 19800,
                         "schalke04"            => 25279,
                         "schastie"             => 9114,
                         "schatzi"              => 8822,
                         "scheiss"              => 24091,
                         "scheisse"             => 5163,
                         "schlampe"             => 11317,
                         "schlange"             => 23860,
                         "schlong"              => 10870,
                         "schlumpf"             => 17947,
                         "schmidt1"             => 20826,
                         "schmoe"               => 16773,
                         "schmoo"               => 17805,
                         "schnecke"             => 15312,
                         "schnee"               => 11666,
                         "schneide"             => 13032,
                         "schnuff"              => 27552,
                         "schnuffi"             => 8306,
                         "schoo"                => 10046,
                         "school1"              => 6923,
                         "school12"             => 23692,
                         "schoolgirlie"         => 23922,
                         "schorsch"             => 13658,
                         "schreibe"             => 27305,
                         "schroede"             => 24022,
                         "schuey"               => 23231,
                         "schule"               => 9517,
                         "schumach"             => 15506,
                         "schumi"               => 6282,
                         "schwanz"              => 9500,
                         "schweden"             => 29479,
                         "schwein"              => 13268,
                         "schweiz"              => 10353,
                         "schwinn"              => 9986,
                         "science1"             => 26651,
                         "scimitar"             => 10556,
                         "scirocco"             => 6990,
                         "scitra"               => 29891,
                         "scoob"                => 10385,
                         "scooba"               => 20062,
                         "scoobie"              => 7301,
                         "scooby"               => 149,
                         "scooby1"              => 5354,
                         "scooby11"             => 25596,
                         "scooby12"             => 11146,
                         "scooby2"              => 10088,
                         "scoobydo"             => 1547,
                         "scoobydoo"            => 4161,
                         "scoop1"               => 22953,
                         "scooper"              => 25570,
                         "scoopy"               => 23799,
                         "scoote"               => 8163,
                         "scooter"              => 92,
                         "scooter1"             => 1613,
                         "scooter2"             => 11076,
                         "scooter5"             => 29187,
                         "scooter6"             => 22703,
                         "scooter7"             => 20295,
                         "scooters"             => 10460,
                         "scoots"               => 18061,
                         "scorch"               => 15650,
                         "score1"               => 14542,
                         "scorelan"             => 16929,
                         "scoreland"            => 19272,
                         "scorpi"               => 8429,
                         "scorpian"             => 23313,
                         "scorpio"              => 283,
                         "scorpio1"             => 3266,
                         "scorpio2"             => 19828,
                         "scorpio6"             => 23898,
                         "scorpio7"             => 16234,
                         "scorpion"             => 227,
                         "scorpions"            => 6922,
                         "scorpius"             => 26534,
                         "scotch"               => 2022,
                         "scotlan"              => 25992,
                         "scotland"             => 510,
                         "scotsman"             => 14878,
                         "scott1"               => 2629,
                         "scott11"              => 28134,
                         "scott12"              => 23207,
                         "scott123"             => 10510,
                         "scott2"               => 14648,
                         "scott3"               => 29437,
                         "scottb"               => 26080,
                         "scottie1"             => 19967,
                         "scottm"               => 24275,
                         "scotts"               => 7569,
                         "scottsda"             => 25371,
                         "scottt"               => 9457,
                         "scotty"               => 432,
                         "scotty1"              => 10653,
                         "scoubidou"            => 15482,
                         "scoubidou2"           => 21441,
                         "scoubidou6"           => 22950,
                         "scouse"               => 18473,
                         "scouser"              => 19049,
                         "scout"                => 2647,
                         "scout1"               => 7244,
                         "scout2"               => 20771,
                         "scouter"              => 16767,
                         "scrabble"             => 3620,
                         "scrapland"            => 25433,
                         "scrapp"               => 25518,
                         "scrapper"             => 5283,
                         "scrappy"              => 1714,
                         "scrappy1"             => 20120,
                         "scrapy"               => 28512,
                         "scratch1"             => 25522,
                         "scream"               => 1681,
                         "screamer"             => 4649,
                         "screwbal"             => 14164,
                         "screwme"              => 22146,
                         "screwu"               => 28454,
                         "screwy"               => 6059,
                         "screwyou"             => 6425,
                         "scribble"             => 11245,
                         "scribe"               => 11268,
                         "scripto"              => 17498,
                         "scrooge"              => 8055,
                         "scrotum"              => 6661,
                         "scruff"               => 14919,
                         "scruffy"              => 1424,
                         "scruffy1"             => 9609,
                         "scrumpy"              => 18855,
                         "scsa316"              => 23582,
                         "scuba"                => 2766,
                         "scuba1"               => 4788,
                         "scuba10"              => 27551,
                         "scubad"               => 21952,
                         "scubadiv"             => 12195,
                         "scubaman"             => 29314,
                         "scubapro"             => 15260,
                         "scubas"               => 24997,
                         "scuderia"             => 19367,
                         "scully"               => 907,
                         "scully1"              => 27451,
                         "scxakv"               => 12284,
                         "scylla"               => 22004,
                         "scythe"               => 14904,
                         "sd3lpgdr"             => 18281,
                         "sd3utre7"             => 25678,
                         "sdbaker"              => 24118,
                         "sdpass"               => 21822,
                         "sdsadee23"            => 14191,
                         "seabass"              => 7939,
                         "seabass1"             => 24505,
                         "seabee"               => 4402,
                         "seadog"               => 6557,
                         "seadoo"               => 3597,
                         "seagate"              => 10553,
                         "seagrams"             => 13140,
                         "seagrave"             => 11680,
                         "seagull"              => 4176,
                         "seagulls"             => 11567,
                         "seahawk"              => 9236,
                         "seahawks"             => 2959,
                         "seahorse"             => 7622,
                         "seaking"              => 16814,
                         "sealteam"             => 6336,
                         "seamus"               => 2342,
                         "seanjohn"             => 17918,
                         "searay"               => 2698,
                         "searcher"             => 9232,
                         "searchin"             => 20391,
                         "searock"              => 25443,
                         "searock6"             => 15264,
                         "seashell"             => 21743,
                         "seashore"             => 18315,
                         "seaside"              => 6276,
                         "seatleon"             => 27274,
                         "seattle"              => 842,
                         "seattle1"             => 8214,
                         "seattle2"             => 23965,
                         "seau55"               => 23727,
                         "seaways"              => 14268,
                         "seaweed"              => 8401,
                         "seawolf"              => 6796,
                         "sebast"               => 21715,
                         "sebastia"             => 1209,
                         "sebastian1"           => 16196,
                         "sebastie"             => 8649,
                         "sebastien"            => 11362,
                         "sebora"               => 6770,
                         "sebora64"             => 19590,
                         "sebring"              => 5514,
                         "sebring1"             => 23649,
                         "secre"                => 8703,
                         "secret"               => 81,
                         "secret1"              => 2347,
                         "secret12"             => 12487,
                         "secret123"            => 14216,
                         "secret2"              => 22444,
                         "secreta"              => 29497,
                         "secretar"             => 20345,
                         "secreto"              => 12302,
                         "section8"             => 16325,
                         "secure1"              => 23493,
                         "securit"              => 20340,
                         "security"             => 472,
                         "security1"            => 16862,
                         "sedona"               => 5362,
                         "seductive"            => 6430,
                         "seeker"               => 2369,
                         "seemann"              => 27629,
                         "seeme"                => 22593,
                         "seemee"               => 25147,
                         "seemnemaailm"         => 24262,
                         "seemore"              => 18687,
                         "seesaw"               => 19313,
                         "seether"              => 20091,
                         "seeyou"               => 18377,
                         "segblue2"             => 5632,
                         "segredo"              => 21360,
                         "segreto"              => 8192,
                         "seifer"               => 18857,
                         "seiko"                => 16360,
                         "seinfeld"             => 1265,
                         "sekirarr"             => 26839,
                         "sekret"               => 4286,
                         "sektor"               => 21958,
                         "select"               => 1858,
                         "select1"              => 28272,
                         "selecta"              => 26232,
                         "selen"                => 11251,
                         "selfok2013"           => 22536,
                         "selhurst"             => 28478,
                         "sellout"              => 13664,
                         "selmer"               => 7469,
                         "selrahc"              => 23950,
                         "selur"                => 27872,
                         "semaj"                => 10418,
                         "semaj1"               => 25606,
                         "semenov"              => 13835,
                         "semenova"             => 15430,
                         "seminole"             => 1111,
                         "seminoles"            => 16283,
                         "semper"               => 5792,
                         "semperf1"             => 24408,
                         "semperfi"             => 505,
                         "semprini"             => 13082,
                         "senators"             => 3722,
                         "seneca"               => 4866,
                         "seng"                 => 3247,
                         "senha"                => 12293,
                         "senha123"             => 12783,
                         "senna"                => 5408,
                         "senna1"               => 11726,
                         "sensatio"             => 10247,
                         "sensei"               => 4132,
                         "sentinal"             => 19554,
                         "sentinel"             => 1979,
                         "sentra"               => 7464,
                         "sentry"               => 6479,
                         "sephan"               => 20448,
                         "sephirot"             => 6598,
                         "sephiroth"            => 5585,
                         "seppel"               => 22275,
                         "septembe"             => 1410,
                         "septembr"             => 16811,
                         "septiembr"            => 28903,
                         "sepultur"             => 16366,
                         "sepultura"            => 10910,
                         "sequoia"              => 16184,
                         "ser123"               => 21534,
                         "serafim"              => 14119,
                         "serafima"             => 27753,
                         "seraph"               => 11089,
                         "seraphim"             => 8929,
                         "serdar"               => 12386,
                         "serdce"               => 20934,
                         "serebro"              => 10780,
                         "sereda"               => 19317,
                         "serega"               => 651,
                         "serega123"            => 18256,
                         "seren"                => 9882,
                         "serena1"              => 29650,
                         "serenada"             => 22799,
                         "serendip"             => 12389,
                         "serendipity"          => 20604,
                         "serenit"              => 19945,
                         "serenity"             => 747,
                         "sergant"              => 21287,
                         "sergbest"             => 5756,
                         "serge"                => 7329,
                         "sergeev"              => 12644,
                         "sergeeva"             => 20470,
                         "sergeevna"            => 13593,
                         "sergei"               => 1493,
                         "sergei1"              => 25645,
                         "sergej"               => 9034,
                         "sergey"               => 372,
                         "sergey1"              => 13109,
                         "sergey123"            => 17336,
                         "sergi"                => 3046,
                         "sergik"               => 16583,
                         "sergio1"              => 24322,
                         "serious1"             => 28018,
                         "serjik"               => 28250,
                         "serkan"               => 18168,
                         "serpent"              => 4834,
                         "serpico"              => 15124,
                         "sersolution"          => 2849,
                         "serval"               => 14563,
                         "server"               => 1544,
                         "server1"              => 26889,
                         "servette"             => 29808,
                         "service01"            => 17899,
                         "service1"             => 7006,
                         "service321"           => 26664,
                         "servis"               => 24828,
                         "servo"                => 21104,
                         "servus"               => 13883,
                         "sesam"                => 13088,
                         "sesame"               => 1280,
                         "sesamo"               => 18895,
                         "sestra"               => 7788,
                         "setter"               => 13509,
                         "sevastopol"           => 15875,
                         "seven1"               => 13357,
                         "seven11"              => 10965,
                         "seven7"               => 1321,
                         "seven77"              => 9988,
                         "seven777"             => 10882,
                         "sevendus"             => 17119,
                         "sevenn"               => 29515,
                         "sevenof9"             => 7522,
                         "sevens"               => 4706,
                         "seventee"             => 13579,
                         "seventy7"             => 16097,
                         "sevenup"              => 12120,
                         "severin"              => 4044,
                         "severine"             => 17684,
                         "severus"              => 16189,
                         "sevilia1"             => 13445,
                         "seville"              => 7109,
                         "sevisgur"             => 23012,
                         "seviyi"               => 8831,
                         "sewanee"              => 24983,
                         "sex123"               => 2397,
                         "sex1234"              => 14108,
                         "sex12345"             => 15547,
                         "sex2000"              => 20446,
                         "sex4free"             => 29202,
                         "sex4me"               => 1155,
                         "sex666"               => 12165,
                         "sex69"                => 5646,
                         "sex6969"              => 10744,
                         "sex777"               => 24258,
                         "sexaddict"            => 29374,
                         "sexbomb"              => 10663,
                         "sexboy"               => 10788,
                         "sexdog"               => 15006,
                         "sexdrive"             => 19073,
                         "sexfiend"             => 22469,
                         "sexfreak"             => 25252,
                         "sexfun"               => 20057,
                         "sexgod"               => 4860,
                         "sexiness"             => 27880,
                         "sexisfun"             => 15645,
                         "sexisgood"            => 18951,
                         "sexking"              => 29673,
                         "sexkitte"             => 19866,
                         "sexkitten"            => 29853,
                         "sexlover"             => 12431,
                         "sexmachine"           => 11984,
                         "sexmad"               => 29776,
                         "sexman"               => 5582,
                         "sexmania"             => 23015,
                         "sexme"                => 11562,
                         "sexmeup"              => 13596,
                         "sexnow"               => 14166,
                         "sexo"                 => 5270,
                         "sexpics"              => 26915,
                         "sexpistols"           => 22962,
                         "sexpot"               => 7037,
                         "sexse"                => 13623,
                         "sexsells"             => 22558,
                         "sexsex"               => 201,
                         "sexsex1"              => 21657,
                         "sexsexse"             => 8196,
                         "sexsite"              => 17801,
                         "sexslave"             => 10737,
                         "sexstuff"             => 28095,
                         "sextime"              => 25227,
                         "sextoy"               => 5904,
                         "sexual"               => 1109,
                         "sexual1"              => 27482,
                         "sexx"                 => 2023,
                         "sexxes"               => 16945,
                         "sexxx"                => 4854,
                         "sexxxx"               => 2557,
                         "sexxxxxx"             => 22673,
                         "sexxxy"               => 3714,
                         "sexxy"                => 4794,
                         "sexxy1"               => 15584,
                         "sexxybj"              => 28305,
                         "sexy"                 => 113,
                         "sexy01"               => 27327,
                         "sexy1"                => 2731,
                         "sexy11"               => 17188,
                         "sexy12"               => 8883,
                         "sexy123"              => 7137,
                         "sexy1234"             => 12065,
                         "sexy21"               => 26246,
                         "sexy22"               => 25676,
                         "sexy4me"              => 26733,
                         "sexy69"               => 2624,
                         "sexyass"              => 8500,
                         "sexybabe"             => 5540,
                         "sexybaby"             => 10222,
                         "sexybeas"             => 26699,
                         "sexybeast"            => 15751,
                         "sexybitc"             => 22819,
                         "sexybitch"            => 5389,
                         "sexybo"               => 26748,
                         "sexyboy"              => 3428,
                         "sexyfeet"             => 12943,
                         "sexygirl"             => 1993,
                         "sexygirls"            => 24194,
                         "sexyguy"              => 10531,
                         "sexylady"             => 4656,
                         "sexylegs"             => 15971,
                         "sexylove"             => 17651,
                         "sexymama"             => 7208,
                         "sexyman"              => 2768,
                         "sexyme"               => 7676,
                         "sexyone"              => 5578,
                         "sexyred"              => 8790,
                         "sexyred1"             => 29405,
                         "sexysex"              => 21114,
                         "sexytime"             => 25071,
                         "sexywife"             => 18553,
                         "seymur"               => 25826,
                         "sf161pn"              => 24478,
                         "sf49ers"              => 4481,
                         "sfgiants"             => 7232,
                         "sh4d0w3d"             => 17989,
                         "shabba"               => 9207,
                         "shack1"               => 19281,
                         "shad0w"               => 16017,
                         "shaddy"               => 19334,
                         "shado"                => 2300,
                         "shadow"               => 17,
                         "shadow00"             => 29296,
                         "shadow01"             => 8153,
                         "shadow1"              => 1034,
                         "shadow10"             => 26299,
                         "shadow11"             => 9435,
                         "shadow12"             => 4988,
                         "shadow1212"           => 16318,
                         "shadow123"            => 11057,
                         "shadow13"             => 9950,
                         "shadow14"             => 25988,
                         "shadow2"              => 9616,
                         "shadow22"             => 19655,
                         "shadow23"             => 29147,
                         "shadow3"              => 19847,
                         "shadow69"             => 11510,
                         "shadow7"              => 15525,
                         "shadow88"             => 26064,
                         "shadow99"             => 13798,
                         "shadowfa"             => 12911,
                         "shadowfax"            => 25564,
                         "shadowma"             => 14455,
                         "shadowman"            => 24887,
                         "shadowru"             => 20570,
                         "shadows1"             => 13320,
                         "shady"                => 6031,
                         "shady1"               => 9411,
                         "shaft1"               => 20710,
                         "shag"                 => 5035,
                         "shagg"                => 28271,
                         "shagger"              => 12393,
                         "shaggy"               => 710,
                         "shaggy1"              => 13701,
                         "shagme"               => 19552,
                         "shaheen"              => 16801,
                         "shahid"               => 12084,
                         "shahrukh"             => 23675,
                         "shai"                 => 2942,
                         "shaitan"              => 17149,
                         "shaka"                => 11695,
                         "shakal"               => 21612,
                         "shaker"               => 6907,
                         "shakespe"             => 19727,
                         "shakey"               => 11612,
                         "shakir"               => 14143,
                         "shakti"               => 10164,
                         "shakur"               => 6020,
                         "shalimar"             => 19642,
                         "shalini"              => 19740,
                         "shalo"                => 25380,
                         "shalom"               => 1210,
                         "sham69"               => 21989,
                         "shama"                => 19067,
                         "shamal"               => 28978,
                         "shaman"               => 1561,
                         "shamanking"           => 20407,
                         "shameles"             => 26546,
                         "shamen"               => 22494,
                         "shami"                => 18106,
                         "shamil"               => 8976,
                         "shammy"               => 15789,
                         "shampoo"              => 5918,
                         "shampoo1"             => 26583,
                         "shamrock"             => 932,
                         "shamus"               => 4428,
                         "shana1"               => 23958,
                         "shandy"               => 8274,
                         "shane1"               => 6246,
                         "shane123"             => 17772,
                         "shaney14"             => 1456,
                         "shang"                => 3016,
                         "shania"               => 2172,
                         "shania1"              => 22995,
                         "shannara"             => 10950,
                         "shanno"               => 6777,
                         "shannon1"             => 2416,
                         "shannon2"             => 26833,
                         "shanny"               => 9087,
                         "shant"                => 27887,
                         "shanty"               => 16933,
                         "shao"                 => 3519,
                         "shaolin"              => 1618,
                         "shaolin1"             => 17109,
                         "shaq34"               => 28482,
                         "sharik"               => 11475,
                         "sharingan"            => 16304,
                         "sharipov"             => 26793,
                         "shark"                => 1343,
                         "shark01"              => 22383,
                         "shark1"               => 5807,
                         "sharkie"              => 21246,
                         "sharkman"             => 13383,
                         "sharks"               => 1272,
                         "sharks1"              => 16438,
                         "sharky"               => 2464,
                         "sharky7"              => 22171,
                         "sharo"                => 10822,
                         "sharon1"              => 8054,
                         "sharon69"             => 24070,
                         "sharona"              => 23676,
                         "sharp1"               => 14386,
                         "sharpie"              => 7508,
                         "sharps"               => 13999,
                         "shash"                => 24607,
                         "shashank"             => 29248,
                         "shashi"               => 21855,
                         "shasta"               => 1250,
                         "shasta1"              => 17747,
                         "shaun1"               => 18614,
                         "shaved"               => 1252,
                         "shaven"               => 13557,
                         "shavkat"              => 25718,
                         "shawn1"               => 7365,
                         "shawn41"              => 21757,
                         "shawshan"             => 19438,
                         "shazaam"              => 28758,
                         "shazam"               => 1510,
                         "shazam1"              => 23154,
                         "shazbot"              => 20732,
                         "shazza"               => 29038,
                         "shdwlnds"             => 23106,
                         "shearer9"             => 14696,
                         "sheba1"               => 4165,
                         "shecky"               => 19268,
                         "shedevil"             => 22460,
                         "sheeba"               => 5274,
                         "sheela"               => 21479,
                         "sheena1"              => 21837,
                         "sheep1"               => 22805,
                         "sheepdog"             => 5101,
                         "sheeps"               => 22474,
                         "sheffiel"             => 14394,
                         "shei"                 => 3328,
                         "sheila1"              => 16504,
                         "shelb"                => 16169,
                         "shelby"               => 327,
                         "shelby1"              => 7001,
                         "shelby2"              => 29004,
                         "sheldon1"             => 26928,
                         "shell1"               => 14196,
                         "shellac"              => 24739,
                         "shelley1"             => 13354,
                         "shelly1"              => 13589,
                         "sheltie"              => 9656,
                         "shemale"              => 1579,
                         "shemales"             => 11950,
                         "shemp"                => 27118,
                         "shen"                 => 5542,
                         "sheng"                => 3523,
                         "shenlong"             => 22073,
                         "shenmue"              => 24924,
                         "sherbert"             => 13939,
                         "shergar"              => 29199,
                         "sherif"               => 14135,
                         "sherlock"             => 1013,
                         "sherman1"             => 11917,
                         "sherpa"               => 11221,
                         "sherry1"              => 15347,
                         "sherzod"              => 17447,
                         "shevchenko"           => 7562,
                         "shibainu"             => 26760,
                         "shibby"               => 4403,
                         "shibumi"              => 8596,
                         "shifter"              => 11934,
                         "shifty"               => 8661,
                         "shihan"               => 25001,
                         "shilo"                => 14720,
                         "shiloh"               => 1490,
                         "shilpa"               => 16914,
                         "shimano"              => 7447,
                         "shimmer"              => 7133,
                         "shimmy"               => 13059,
                         "shinchan"             => 26236,
                         "shineon"              => 29974,
                         "shiner"               => 3420,
                         "shiney"               => 19767,
                         "shingo"               => 11721,
                         "shinigam"             => 19359,
                         "shinigami"            => 7201,
                         "shinji"               => 7351,
                         "shinobi"              => 4266,
                         "shinobu"              => 16190,
                         "shipmate"             => 23445,
                         "shippo"               => 28913,
                         "shirak"               => 13429,
                         "shiraz"               => 8763,
                         "shirin"               => 13568,
                         "shirle"               => 29323,
                         "shirley1"             => 14703,
                         "shit1"                => 27680,
                         "shit12"               => 26296,
                         "shit123"              => 19319,
                         "shitass"              => 16033,
                         "shitbag"              => 21041,
                         "shitball"             => 17820,
                         "shitbird"             => 13425,
                         "shitface"             => 3506,
                         "shitfuck"             => 7968,
                         "shithappens"          => 24523,
                         "shithead"             => 264,
                         "shithead1"            => 22185,
                         "shithole"             => 14031,
                         "shitter"              => 7321,
                         "shitty"               => 1689,
                         "shitty1"              => 22829,
                         "shiva1"               => 20061,
                         "shivan"               => 14874,
                         "shivani"              => 20735,
                         "shiznit"              => 8788,
                         "shizzle"              => 11492,
                         "shkola"               => 20404,
                         "shlomo"               => 16239,
                         "shlong"               => 12940,
                         "shmuck"               => 23348,
                         "shock123"             => 15238,
                         "shock5"               => 11144,
                         "shocker"              => 4052,
                         "shocker1"             => 29153,
                         "shockers"             => 22120,
                         "shockwav"             => 27951,
                         "shodan"               => 5357,
                         "shoeman"              => 24691,
                         "shogun"               => 1318,
                         "shojou"               => 5995,
                         "shokolad"             => 19944,
                         "shonuf"               => 5446,
                         "shonuff"              => 18472,
                         "shooby"               => 17451,
                         "shooter"              => 840,
                         "shooter1"             => 9470,
                         "shootme"              => 12903,
                         "shopper"              => 6087,
                         "shoppin"              => 18924,
                         "shopping1"            => 26251,
                         "short1"               => 24127,
                         "shortdog"             => 20892,
                         "shortie"              => 14601,
                         "shortman"             => 29408,
                         "shortsto"             => 15159,
                         "shorty"               => 476,
                         "shorty1"              => 10132,
                         "shortys"              => 18911,
                         "shotgun"              => 870,
                         "shotgun1"             => 10819,
                         "shotokan"             => 7620,
                         "shou"                 => 2820,
                         "showboat"             => 9386,
                         "showit"               => 29552,
                         "showme"               => 1330,
                         "showtime"             => 1324,
                         "shredder"             => 6949,
                         "shrike"               => 9667,
                         "shrike01"             => 17676,
                         "shroom"               => 9237,
                         "shrooms"              => 14616,
                         "shuai"                => 3540,
                         "shuan"                => 7959,
                         "shuang"               => 3418,
                         "shui"                 => 3736,
                         "shumaher"             => 18388,
                         "shun"                 => 2878,
                         "shuo"                 => 3431,
                         "shurik"               => 6466,
                         "shuriken"             => 24540,
                         "shutup"               => 3500,
                         "shweta"               => 20786,
                         "shwing"               => 26925,
                         "shyanne"              => 21470,
                         "shygirl1"             => 14414,
                         "shyguy"               => 8992,
                         "shyster"              => 19284,
                         "si711ne"              => 26652,
                         "sibelius"             => 17768,
                         "sicilia"              => 16388,
                         "sickan"               => 13302,
                         "sickboy"              => 6269,
                         "sicnarf"              => 15989,
                         "sid123"               => 19176,
                         "siddis"               => 24855,
                         "sidekick"             => 4278,
                         "sideout"              => 15446,
                         "sideshow"             => 11469,
                         "sidewind"             => 8550,
                         "sidewinder"           => 16881,
                         "sidney1"              => 17115,
                         "sidorov"              => 13874,
                         "sidorova"             => 19471,
                         "siegheil"             => 24268,
                         "siemen"               => 12477,
                         "siemens"              => 939,
                         "siemens1"             => 11344,
                         "siempre"              => 13083,
                         "sienna"               => 8029,
                         "sierr"                => 25439,
                         "sierra"               => 242,
                         "sierra01"             => 24654,
                         "sierra1"              => 6266,
                         "siesta"               => 22177,
                         "siffredi"             => 25575,
                         "sig229"               => 28723,
                         "sigge1"               => 26701,
                         "sigma"                => 4216,
                         "sigma1"               => 8024,
                         "sigma2"               => 27870,
                         "sigmachi"             => 5168,
                         "sigmanu"              => 13092,
                         "sigmapi"              => 23502,
                         "sigmar"               => 7088,
                         "signatur"             => 24217,
                         "signin"               => 25165,
                         "signon"               => 20932,
                         "signup"               => 17009,
                         "sigsauer"             => 15027,
                         "sigtau"               => 17587,
                         "sikici"               => 18735,
                         "silence1"             => 28408,
                         "silencer"             => 15214,
                         "silenthill"           => 20399,
                         "silicone"             => 11724,
                         "silkcut"              => 22303,
                         "silke"                => 21576,
                         "silkeborg"            => 26193,
                         "silkie"               => 29816,
                         "silky1"               => 17037,
                         "silly1"               => 8509,
                         "sillyboy"             => 15153,
                         "sillyme"              => 21954,
                         "silmaril"             => 24749,
                         "silvan"               => 29084,
                         "silve"                => 8304,
                         "silver"               => 87,
                         "silver01"             => 27786,
                         "silver1"              => 2831,
                         "silver11"             => 18277,
                         "silver12"             => 10277,
                         "silver2"              => 20380,
                         "silver22"             => 27575,
                         "silver33"             => 23820,
                         "silver69"             => 29955,
                         "silver7"              => 14759,
                         "silver77"             => 27378,
                         "silver99"             => 23659,
                         "silverad"             => 3116,
                         "silverado"            => 6934,
                         "silverch"             => 28714,
                         "silverfi"             => 23740,
                         "silverfo"             => 11291,
                         "silverfox"            => 20439,
                         "silverma"             => 23998,
                         "silversi"             => 20416,
                         "silverst"             => 15595,
                         "silvestr"             => 19069,
                         "silvi"                => 7313,
                         "silvia1"              => 20921,
                         "silvio"               => 12959,
                         "simba"                => 1712,
                         "simba1"               => 4299,
                         "simba123"             => 18152,
                         "simba2"               => 22276,
                         "simbacat"             => 25772,
                         "simbas"               => 12873,
                         "simcity"              => 8964,
                         "simeon"               => 10619,
                         "simferopol"           => 28662,
                         "simhrq"               => 13893,
                         "simon1"               => 2707,
                         "simon123"             => 12579,
                         "simone1"              => 18019,
                         "simonsay"             => 14763,
                         "simpl"                => 23230,
                         "simple"               => 453,
                         "simple1"              => 5973,
                         "simpleplan"           => 21263,
                         "simpso"               => 19785,
                         "simpson1"             => 9732,
                         "simpsons"             => 514,
                         "simran"               => 12484,
                         "sinatra"              => 1971,
                         "sinatra1"             => 23989,
                         "sinbad"               => 2529,
                         "sincity"              => 8467,
                         "sindhu"               => 27078,
                         "sinead"               => 14579,
                         "sinfonia"             => 11828,
                         "sinful"               => 7332,
                         "singapor"             => 5330,
                         "singapur"             => 25993,
                         "singe11"              => 24429,
                         "singer1"              => 23621,
                         "single1"              => 9171,
                         "sinister"             => 3061,
                         "sinjin"               => 9866,
                         "sinned"               => 4099,
                         "sinner"               => 1498,
                         "sinnet"               => 19404,
                         "sinnfein"             => 28143,
                         "sintesi07"            => 19878,
                         "sintra"               => 18160,
                         "siouxsie"             => 16992,
                         "sirene"               => 18864,
                         "sirius"               => 1487,
                         "sirius1"              => 27336,
                         "sirocco"              => 22932,
                         "sissi"                => 25383,
                         "sissie"               => 21664,
                         "sissinit"             => 29390,
                         "sissy"                => 4258,
                         "sissy1"               => 11846,
                         "sissyboy"             => 21286,
                         "sistem"               => 27073,
                         "sistema"              => 11508,
                         "sister1"              => 11426,
                         "sisyphus"             => 21247,
                         "sitges"               => 21624,
                         "sithlord"             => 1542,
                         "sitruc"               => 10297,
                         "sivart"               => 15479,
                         "sixer3"               => 24998,
                         "sixers"               => 2065,
                         "sixflags"             => 28623,
                         "sixgun"               => 18042,
                         "sixnine"              => 13746,
                         "sixpack"              => 4899,
                         "sixsix6"              => 20671,
                         "sixty9"               => 5567,
                         "sixtynin"             => 8393,
                         "sixtynine"            => 9518,
                         "sizzle"               => 7047,
                         "sk2000"               => 17638,
                         "sk84life"             => 10602,
                         "sk8board"             => 16165,
                         "sk8ordie"             => 7542,
                         "sk8ter"               => 9913,
                         "skagen"               => 29297,
                         "skate"                => 3153,
                         "skate1"               => 12015,
                         "skate123"             => 19557,
                         "skateboa"             => 9449,
                         "skateboard"           => 5251,
                         "skater"               => 988,
                         "skater1"              => 13723,
                         "skaven"               => 14495,
                         "skazka"               => 9548,
                         "skeet"                => 13622,
                         "skeeter"              => 957,
                         "skeeter1"             => 6978,
                         "skeets"               => 17603,
                         "skeletor"             => 10581,
                         "skelter"              => 11016,
                         "skibum"               => 4465,
                         "skidmark"             => 22669,
                         "skidoo"               => 2520,
                         "skidrow"              => 24662,
                         "skiing"               => 1857,
                         "skiller"              => 26863,
                         "skillet"              => 4548,
                         "skillz"               => 8290,
                         "skiman"               => 15362,
                         "skimmer"              => 17216,
                         "skinhead"             => 5629,
                         "skinnass"             => 26696,
                         "skinner1"             => 23032,
                         "skinny"               => 1941,
                         "skinny1"              => 25882,
                         "skins"                => 7870,
                         "skins1"               => 20088,
                         "skipjack"             => 12996,
                         "skipp"                => 16601,
                         "skippe"               => 19259,
                         "skipper"              => 625,
                         "skipper1"             => 5565,
                         "skippy"               => 321,
                         "skippy1"              => 8291,
                         "skittle"              => 10182,
                         "skittles"             => 1333,
                         "sklave"               => 23722,
                         "skoal"                => 11073,
                         "skoal1"               => 16631,
                         "skolko"               => 6421,
                         "skooter"              => 12200,
                         "skorpio"              => 18327,
                         "skorpion"             => 2214,
                         "skorpion39"           => 15381,
                         "skripka"              => 24068,
                         "skulls"               => 8030,
                         "skully"               => 13469,
                         "skunk"                => 6730,
                         "skunk1"               => 20521,
                         "skunks"               => 19305,
                         "skunky"               => 12425,
                         "sky123"               => 16005,
                         "skyblue"              => 11354,
                         "skyblue1"             => 28993,
                         "skyblues"             => 21223,
                         "skyclad"              => 28611,
                         "skydive"              => 2367,
                         "skydive1"             => 26141,
                         "skydiver"             => 6610,
                         "skydog"               => 14297,
                         "skyeseth"             => 26485,
                         "skyfir"               => 25816,
                         "skyhawk"              => 4327,
                         "skyhigh"              => 16305,
                         "skyhook"              => 19501,
                         "skyking"              => 12582,
                         "skylane"              => 19931,
                         "skylar"               => 3121,
                         "skylark"              => 5588,
                         "skyler"               => 3284,
                         "skylin"               => 17179,
                         "skyline"              => 606,
                         "skyline1"             => 9294,
                         "skyman"               => 27792,
                         "skynet"               => 7716,
                         "skynyrd"              => 17964,
                         "skypilot"             => 10293,
                         "skytommy"             => 11939,
                         "skywalk"              => 20832,
                         "skywalk1"             => 22825,
                         "skywalke"             => 1277,
                         "skywalker"            => 2190,
                         "sl1200"               => 23971,
                         "slacker"              => 2219,
                         "slacker1"             => 21157,
                         "slacking"             => 10812,
                         "slage33"              => 17049,
                         "slagelse"             => 29086,
                         "slainte"              => 8781,
                         "slamdunk"             => 3932,
                         "slammer"              => 4956,
                         "slapnuts"             => 6640,
                         "slapper"              => 3357,
                         "slappy"               => 1688,
                         "slapshot"             => 1409,
                         "slash1"               => 13093,
                         "slasher"              => 7224,
                         "slava"                => 6848,
                         "slava1"               => 15891,
                         "slava123"             => 22896,
                         "slava2"               => 26188,
                         "slave"                => 2335,
                         "slave1"               => 3260,
                         "slaveboy"             => 12592,
                         "slavik"               => 3530,
                         "slavko"               => 26424,
                         "slaye"                => 17853,
                         "slayer"               => 170,
                         "slayer1"              => 4298,
                         "slayer66"             => 10345,
                         "slayer666"            => 9634,
                         "slayer69"             => 17855,
                         "slayers1"             => 25036,
                         "sleddog"              => 25583,
                         "sleeper"              => 3553,
                         "sleepers"             => 13418,
                         "sleepy"               => 1580,
                         "sleepy1"              => 15736,
                         "sleipnir"             => 19592,
                         "sleuth"               => 12976,
                         "slicer"               => 8405,
                         "slick"                => 1349,
                         "slick1"               => 3952,
                         "slick123"             => 22785,
                         "slick50"              => 14245,
                         "slicker"              => 16912,
                         "slicko"               => 21088,
                         "slickone"             => 28258,
                         "slickric"             => 16494,
                         "slicks"               => 16598,
                         "slicky"               => 19943,
                         "slider"               => 2260,
                         "sliders"              => 20186,
                         "slim"                 => 3265,
                         "slimed123"            => 10497,
                         "slimer"               => 10290,
                         "slimjim"              => 6726,
                         "slimshad"             => 5291,
                         "slimshady"            => 4730,
                         "slinger"              => 11189,
                         "slinky"               => 2840,
                         "slipkno"              => 7669,
                         "slipknot"             => 224,
                         "slipknot1"            => 10463,
                         "slipknot666"          => 12040,
                         "slipper"              => 6655,
                         "slipper1"             => 29067,
                         "slippery"             => 3201,
                         "slippy"               => 8635,
                         "sliver"               => 5692,
                         "slk230"               => 15351,
                         "slobber"              => 22127,
                         "sloboda"              => 29215,
                         "sloeber"              => 25771,
                         "sloneczko"            => 18349,
                         "slonik"               => 5822,
                         "slonko"               => 24567,
                         "sloopy"               => 15291,
                         "slot2009"             => 22462,
                         "slowhand"             => 4171,
                         "slowpoke"             => 16853,
                         "slowride"             => 13727,
                         "sludge"               => 10408,
                         "slugger"              => 4668,
                         "sluggo"               => 4423,
                         "sluggy"               => 27681,
                         "slurp"                => 18745,
                         "slurpee"              => 14177,
                         "slurpy"               => 29970,
                         "slurred"              => 10383,
                         "slut"                 => 599,
                         "slut1"                => 13491,
                         "slut543"              => 20637,
                         "slut69"               => 9857,
                         "slutfuck"             => 25119,
                         "sluts"                => 1182,
                         "sluts1"               => 13215,
                         "sluttey"              => 6673,
                         "slutty"               => 2327,
                         "slutty3"              => 19874,
                         "slutwife"             => 13494,
                         "slydog"               => 10558,
                         "slyfox"               => 12438,
                         "sm9934"               => 18267,
                         "smackdow"             => 4768,
                         "smackdown"            => 5549,
                         "smacker"              => 17348,
                         "smacky"               => 23908,
                         "small1"               => 24122,
                         "smalldog"             => 25191,
                         "smallfry"             => 17979,
                         "smalltit"             => 24569,
                         "smallvil"             => 13314,
                         "smallvill"            => 27091,
                         "smallville"           => 9959,
                         "smart1"               => 5422,
                         "smartass"             => 6299,
                         "smartie"              => 17275,
                         "smarties"             => 10716,
                         "smarty"               => 7901,
                         "smasher"              => 14897,
                         "smashing"             => 3487,
                         "smeagol"              => 20240,
                         "smeghead"             => 2799,
                         "smegma"               => 2519,
                         "smeller"              => 7673,
                         "smelly"               => 2574,
                         "smelly1"              => 22242,
                         "smellyfe"             => 29895,
                         "smile1"               => 6218,
                         "smile123"             => 11659,
                         "smile2"               => 27904,
                         "smile4me"             => 21006,
                         "smile4u"              => 26694,
                         "smiler"               => 12157,
                         "smiles"               => 1138,
                         "smiley"               => 884,
                         "smiley1"              => 12751,
                         "smirnoff"             => 4144,
                         "smirnov"              => 5761,
                         "smirnova"             => 6780,
                         "smith1"               => 5209,
                         "smith123"             => 12789,
                         "smith22"              => 24047,
                         "smiths"               => 3018,
                         "smithy"               => 7267,
                         "smitty"               => 968,
                         "smitty1"              => 13374,
                         "smk7366"              => 17345,
                         "smoke"                => 961,
                         "smoke1"               => 4205,
                         "smoke20"              => 26829,
                         "smoke420"             => 7167,
                         "smokedog"             => 8222,
                         "smokee"               => 23711,
                         "smokeit"              => 19708,
                         "smokeone"             => 20366,
                         "smokepot"             => 21430,
                         "smoker"               => 1543,
                         "smokes"               => 2680,
                         "smokewee"             => 26738,
                         "smokeweed"            => 11736,
                         "smokey"               => 116,
                         "smokey01"             => 20800,
                         "smokey1"              => 3811,
                         "smokey12"             => 21028,
                         "smokey2"              => 21083,
                         "smokie"               => 3380,
                         "smokin"               => 1657,
                         "smolensk"             => 16779,
                         "smooch"               => 6817,
                         "smooches"             => 21560,
                         "smoochie"             => 15512,
                         "smooth"               => 582,
                         "smooth1"              => 9255,
                         "smoothe"              => 29056,
                         "smoothie"             => 5240,
                         "smoothy"              => 13233,
                         "smoove"               => 19309,
                         "smother"              => 6168,
                         "smudge"               => 1713,
                         "smudger"              => 13984,
                         "smuggles"             => 9512,
                         "smurf"                => 5993,
                         "smurf1"               => 15848,
                         "smurfs"               => 10137,
                         "smurfy"               => 15163,
                         "smurph"               => 23764,
                         "smut"                 => 2021,
                         "smutty"               => 8853,
                         "sn00py"               => 13203,
                         "snafu"                => 7905,
                         "snafu2"               => 29606,
                         "snaggle"              => 25351,
                         "snaiper"              => 18049,
                         "snake"                => 886,
                         "snake1"               => 2319,
                         "snake123"             => 19089,
                         "snake2"               => 23671,
                         "snakebit"             => 27278,
                         "snakeeye"             => 14107,
                         "snakeeyes"            => 21339,
                         "snakeman"             => 8444,
                         "snaker"               => 16721,
                         "snakes"               => 1152,
                         "snakey"               => 17567,
                         "snapon"               => 2759,
                         "snapper"              => 1243,
                         "snapper1"             => 14401,
                         "snapple"              => 2523,
                         "snappy"               => 3821,
                         "snappy1"              => 25848,
                         "snapshot"             => 7038,
                         "snarf"                => 29257,
                         "snatch"               => 1147,
                         "snatch1"              => 28600,
                         "sneaker"              => 9715,
                         "sneakers"             => 2533,
                         "sneaky"               => 4282,
                         "snicker"              => 5626,
                         "snickers"             => 417,
                         "snickers1"            => 15882,
                         "sniffer"              => 7914,
                         "sniffy"               => 22963,
                         "snikers"              => 9744,
                         "sniper"               => 351,
                         "sniper01"             => 23683,
                         "sniper1"              => 6653,
                         "sniper12"             => 18688,
                         "snooch"               => 28397,
                         "snoogans"             => 9452,
                         "snoogins"             => 14552,
                         "snooker"              => 3492,
                         "snookie"              => 8182,
                         "snooks"               => 10310,
                         "snooky"               => 14345,
                         "snoop"                => 2609,
                         "snoop1"               => 17087,
                         "snoopdog"             => 2376,
                         "snoopdogg"            => 7687,
                         "snooper"              => 14988,
                         "snoops"               => 14620,
                         "snoopy"               => 102,
                         "snoopy1"              => 3713,
                         "snoopy12"             => 17043,
                         "snoopy2"              => 19665,
                         "snoopy69"             => 26128,
                         "snoppy"               => 22201,
                         "snorkel"              => 17160,
                         "snow123"              => 27059,
                         "snowbal"              => 28599,
                         "snowball"             => 357,
                         "snowball1"            => 20767,
                         "snowbird"             => 5320,
                         "snowboar"             => 2503,
                         "snowboard"            => 3703,
                         "snowcat"              => 24972,
                         "snowdog"              => 8010,
                         "snowdon"              => 23051,
                         "snowdrop"             => 16777,
                         "snowey"               => 22031,
                         "snowflak"             => 3978,
                         "snowflake"            => 7829,
                         "snowhite"             => 25250,
                         "snowie"               => 21377,
                         "snowman"              => 726,
                         "snowman1"             => 7701,
                         "snowmass"             => 21432,
                         "snowshoe"             => 20369,
                         "snowstor"             => 26203,
                         "snowwhit"             => 19472,
                         "snowwhite"            => 21798,
                         "snowy"                => 7904,
                         "snowy1"               => 11528,
                         "snuffles"             => 22310,
                         "snuffy"               => 3351,
                         "snuggle"              => 8728,
                         "snuggles"             => 1750,
                         "snuggles1"            => 29581,
                         "snusmumrik"           => 20600,
                         "soapy"                => 22251,
                         "soarer"               => 26040,
                         "sobaka"               => 1495,
                         "sobeit"               => 15841,
                         "sober1"               => 8619,
                         "sobolev"              => 20474,
                         "soboleva"             => 22111,
                         "sobriety"             => 9991,
                         "socal"                => 22906,
                         "socball"              => 17226,
                         "socce"                => 6138,
                         "soccer"               => 43,
                         "soccer09"             => 24294,
                         "soccer1"              => 1499,
                         "soccer10"             => 4431,
                         "soccer11"             => 6122,
                         "soccer12"             => 4172,
                         "soccer123"            => 19947,
                         "soccer13"             => 8551,
                         "soccer14"             => 11322,
                         "soccer15"             => 11023,
                         "soccer16"             => 17128,
                         "soccer17"             => 12455,
                         "soccer18"             => 18332,
                         "soccer19"             => 25830,
                         "soccer2"              => 9716,
                         "soccer20"             => 17174,
                         "soccer21"             => 16249,
                         "soccer22"             => 12324,
                         "soccer3"              => 14024,
                         "soccer33"             => 20955,
                         "soccer4"              => 17938,
                         "soccer5"              => 19044,
                         "soccer6"              => 28553,
                         "soccer69"             => 20646,
                         "soccer7"              => 11432,
                         "soccer77"             => 29467,
                         "soccer9"              => 14121,
                         "soccer99"             => 16004,
                         "sochi2014"            => 12082,
                         "sociald"              => 16960,
                         "socken"               => 29917,
                         "socks1"               => 20319,
                         "socool"               => 27657,
                         "socrate"              => 9344,
                         "socrates"             => 1502,
                         "sodapop"              => 7482,
                         "sodoff"               => 23530,
                         "sofaking"             => 26408,
                         "sofia1"               => 22027,
                         "sofiko"               => 24503,
                         "sofiya"               => 8389,
                         "softail"              => 3858,
                         "softbal"              => 17890,
                         "softball"             => 546,
                         "softball1"            => 25450,
                         "softcore"             => 26018,
                         "softtail"             => 6295,
                         "software"             => 861,
                         "sofun"                => 23670,
                         "sogood"               => 11525,
                         "sojdlg123aljg"        => 2278,
                         "sokada"               => 23011,
                         "sokolov"              => 8503,
                         "sokolova"             => 6609,
                         "sokrates"             => 12697,
                         "solace"               => 6461,
                         "solana"               => 26825,
                         "solar1"               => 15294,
                         "solara"               => 16833,
                         "solaris"              => 5024,
                         "soldat"               => 6311,
                         "solder"               => 21092,
                         "soldier"              => 1105,
                         "soldier1"             => 11011,
                         "soleda"               => 8360,
                         "solei"                => 14202,
                         "soleil"               => 1918,
                         "solid1"               => 26423,
                         "solidsna"             => 22162,
                         "solidsnake"           => 9368,
                         "solidus"              => 20834,
                         "solitair"             => 22188,
                         "solitari"             => 12443,
                         "solitude"             => 4201,
                         "solnce"               => 2341,
                         "solnishko"            => 7798,
                         "solnyshko"            => 21189,
                         "solnze"               => 13667,
                         "soloma"               => 24885,
                         "solomon1"             => 18893,
                         "solovey"              => 21672,
                         "soloy"                => 27265,
                         "soloyo"               => 20241,
                         "solrac"               => 9165,
                         "solstice"             => 15074,
                         "solus"                => 26388,
                         "sombra"               => 20850,
                         "something1"           => 24798,
                         "sommar"               => 23907,
                         "sommer"               => 1512,
                         "sommer1"              => 24345,
                         "sonali"               => 13338,
                         "sonata"               => 4353,
                         "sone4ka"              => 25711,
                         "sonechka"             => 11455,
                         "songbird"             => 7941,
                         "songline"             => 26729,
                         "songohan"             => 20772,
                         "songoku"              => 7527,
                         "sonia1"               => 14308,
                         "sonic"                => 1995,
                         "sonic1"               => 5759,
                         "sonic123"             => 15230,
                         "sonic2"               => 13386,
                         "sonics"               => 2920,
                         "sonicx"               => 16745,
                         "sonja1"               => 26881,
                         "sonne"                => 8257,
                         "sonnen"               => 14163,
                         "sonnenschein"         => 29783,
                         "sonnet"               => 11158,
                         "sonnie"               => 20248,
                         "sonny1"               => 7491,
                         "sonnyboy"             => 10715,
                         "sonofgod"             => 19422,
                         "sonofsam"             => 24476,
                         "sonoio"               => 27735,
                         "sonoma"               => 3318,
                         "sonora"               => 6525,
                         "sonshine"             => 21901,
                         "sony"                 => 2019,
                         "sony1"                => 27158,
                         "sony12"               => 26010,
                         "sony123"              => 14098,
                         "sony1234"             => 16025,
                         "sonyericsson"         => 4356,
                         "sonyfuck"             => 4911,
                         "sonyvaio"             => 8383,
                         "sooner1"              => 22046,
                         "sooners"              => 1370,
                         "sooners1"             => 6916,
                         "sooty"                => 18190,
                         "sooty1"               => 28152,
                         "sophi"                => 3462,
                         "sophia1"              => 18480,
                         "sophie"               => 205,
                         "sophie01"             => 29534,
                         "sophie1"              => 5147,
                         "sophie12"             => 17085,
                         "sophie2"              => 21754,
                         "sophieh6"             => 25800,
                         "soprano"              => 3793,
                         "sopranos"             => 5952,
                         "sorcerer"             => 10776,
                         "sordfish"             => 20657,
                         "soreilly"             => 21723,
                         "sorento"              => 23852,
                         "soroka"               => 15680,
                         "sorokin"              => 28706,
                         "sorokina"             => 19450,
                         "sorrento"             => 13483,
                         "sosa21"               => 12404,
                         "sosexy"               => 26509,
                         "sosiska"              => 7558,
                         "soso123aljg"          => 893,
                         "sou812"               => 27406,
                         "soulfly"              => 6613,
                         "soulman"              => 12580,
                         "soulmate"             => 3422,
                         "sound1"               => 8993,
                         "soundman"             => 21501,
                         "soundwav"             => 29772,
                         "souppp"               => 24137,
                         "souris"               => 12993,
                         "souschef"             => 29154,
                         "south1"               => 15448,
                         "southbay"             => 19830,
                         "southpar"             => 3169,
                         "southpark"            => 2718,
                         "southpaw"             => 4865,
                         "souths"               => 27901,
                         "southsid"             => 9846,
                         "southside"            => 8102,
                         "southwes"             => 25179,
                         "sovereig"             => 24669,
                         "sowhat"               => 3786,
                         "soxfan"               => 23542,
                         "soylent"              => 29595,
                         "sp00ky"               => 18144,
                         "sp1der"               => 20058,
                         "space1"               => 7553,
                         "space199"             => 28014,
                         "spacebal"             => 26735,
                         "spacebar"             => 17399,
                         "spaceboy"             => 17961,
                         "spacejam"             => 29503,
                         "spaceman"             => 2861,
                         "spacer"               => 14259,
                         "spacey"               => 12160,
                         "spade1"               => 8817,
                         "spagetti"             => 20196,
                         "spaghett"             => 21563,
                         "spain1"               => 18418,
                         "spam"                 => 4146,
                         "spam69"               => 27031,
                         "spam967888"           => 21713,
                         "spammer"              => 18178,
                         "spammm"               => 28290,
                         "spammy"               => 13987,
                         "spandau"              => 27315,
                         "spaniel"              => 8470,
                         "spanis"               => 17557,
                         "spank"                => 2297,
                         "spank1"               => 16656,
                         "spanked"              => 14481,
                         "spanker"              => 4778,
                         "spankey"              => 16411,
                         "spanking"             => 1463,
                         "spankit"              => 15262,
                         "spankme"              => 1710,
                         "spankme1"             => 23257,
                         "spanks"               => 10329,
                         "spanky"               => 203,
                         "spanky1"              => 7509,
                         "spanner"              => 4807,
                         "spanner1"             => 23045,
                         "spanners"             => 27043,
                         "sparco"               => 11213,
                         "sparda"               => 26329,
                         "sparhawk"             => 6954,
                         "sparkey"              => 8298,
                         "sparkie"              => 11636,
                         "sparkle"              => 2206,
                         "sparkle1"             => 26662,
                         "sparkles"             => 5589,
                         "sparkplu"             => 29571,
                         "sparky"               => 98,
                         "sparky01"             => 25825,
                         "sparky1"              => 3058,
                         "sparky11"             => 20811,
                         "sparky12"             => 14941,
                         "sparky99"             => 24745,
                         "sparrow1"             => 20827,
                         "sparta"               => 2069,
                         "spartacu"             => 9759,
                         "spartak"              => 1043,
                         "spartak1922"          => 24628,
                         "spartan"              => 973,
                         "spartan1"             => 4511,
                         "spartan11"            => 26939,
                         "spartan117"           => 8073,
                         "spartans"             => 1747,
                         "sparticu"             => 15827,
                         "sparty"               => 7294,
                         "spawn"                => 2571,
                         "spawn1"               => 10279,
                         "spawn2"               => 14037,
                         "spawn666"             => 18743,
                         "spawn7"               => 25944,
                         "spawns"               => 24487,
                         "speaker"              => 1791,
                         "speaker1"             => 14980,
                         "spears1"              => 29212,
                         "specboot"             => 24394,
                         "special1"             => 5649,
                         "speciali"             => 20458,
                         "specialinsta"         => 27224,
                         "specialk"             => 3468,
                         "specops"              => 15778,
                         "spectre"              => 3289,
                         "spectre1"             => 29346,
                         "spectrum"             => 1698,
                         "speculum"             => 20006,
                         "speed1"               => 7096,
                         "speed2"               => 22729,
                         "speeder"              => 15762,
                         "speedie"              => 21832,
                         "speedo"               => 3339,
                         "speedrac"             => 14008,
                         "speedster"            => 28525,
                         "speedy"               => 418,
                         "speedy1"              => 9285,
                         "speedy2"              => 26456,
                         "spencer1"             => 3480,
                         "spencer2"             => 19716,
                         "spencer5"             => 29520,
                         "sperma"               => 5385,
                         "sperme"               => 27296,
                         "sphinx"               => 3589,
                         "spice"                => 3298,
                         "spice1"               => 8613,
                         "spicey"               => 11961,
                         "spide"                => 8434,
                         "spider"               => 129,
                         "spider1"              => 3551,
                         "spider10"             => 26005,
                         "spider12"             => 13982,
                         "spider7"              => 27386,
                         "spiderma"             => 600,
                         "spiderman"            => 688,
                         "spiderman1"           => 6567,
                         "spiderman3"           => 25413,
                         "spidey"               => 1640,
                         "spieng"               => 26783,
                         "spiff"                => 20575,
                         "spiffy"               => 6486,
                         "spike"                => 796,
                         "spike1"               => 2727,
                         "spike123"             => 18236,
                         "spike2"               => 24811,
                         "spike69"              => 27036,
                         "spiker"               => 3667,
                         "spikes"               => 3852,
                         "spikey"               => 4352,
                         "spinnake"             => 28616,
                         "spinne"               => 27812,
                         "spinner"              => 3300,
                         "spinoza"              => 22666,
                         "spiral"               => 5038,
                         "spiri"                => 23834,
                         "spirit"               => 497,
                         "spirit1"              => 11770,
                         "spirou"               => 19327,
                         "spitfire"             => 460,
                         "spjfet"               => 14602,
                         "spk666"               => 18151,
                         "splash"               => 1915,
                         "splatt"               => 26249,
                         "splatter"             => 8634,
                         "spleen"               => 6029,
                         "splicer"              => 29459,
                         "spliff"               => 5391,
                         "splinter"             => 2381,
                         "splitter"             => 18045,
                         "splodge"              => 18043,
                         "splooge"              => 17523,
                         "splunge"              => 14225,
                         "splurge"              => 9492,
                         "spock"                => 3711,
                         "spock1"               => 6110,
                         "sponge"               => 3041,
                         "spongebo"             => 3903,
                         "spongebob"            => 2730,
                         "spooge"               => 5613,
                         "spook"                => 6174,
                         "spook1"               => 27877,
                         "spooker"              => 20457,
                         "spookie"              => 22738,
                         "spooks"               => 14512,
                         "spooky"               => 508,
                         "spooky1"              => 10828,
                         "spoon1"               => 11979,
                         "spoonman"             => 11238,
                         "spoons"               => 5047,
                         "spoony"               => 18002,
                         "spooty"               => 24174,
                         "sport1"               => 8687,
                         "sport123"             => 28369,
                         "sportage"             => 25074,
                         "sportin"              => 20246,
                         "sports1"              => 8005,
                         "sportste"             => 10378,
                         "sportster"            => 19150,
                         "sporty"               => 3676,
                         "spotligh"             => 27106,
                         "spots3"               => 16007,
                         "spotter"              => 16559,
                         "spotty"               => 4223,
                         "sprewell"             => 15020,
                         "sprin"                => 20624,
                         "spring"               => 673,
                         "spring00"             => 25475,
                         "spring1"              => 14461,
                         "spring12"             => 23742,
                         "spring99"             => 16418,
                         "springst"             => 11698,
                         "sprint"               => 1505,
                         "sprint1"              => 20667,
                         "sprinter"             => 4400,
                         "sprite"               => 1221,
                         "sprocket"             => 6462,
                         "sprout"               => 5482,
                         "spud"                 => 4698,
                         "spuddy"               => 26430,
                         "spudman"              => 18719,
                         "spuds"                => 17740,
                         "spuds1"               => 27122,
                         "spunk"                => 6539,
                         "spunky"               => 1170,
                         "spunky1"              => 22408,
                         "spurs"                => 2325,
                         "spurs1"               => 3326,
                         "spurs123"             => 21422,
                         "spurss"               => 24940,
                         "sputnik"              => 2833,
                         "sputnik1"             => 23323,
                         "spycam"               => 20776,
                         "spycams"              => 15733,
                         "spyder"               => 1178,
                         "spyglass"             => 12710,
                         "sqdwfe"               => 5887,
                         "sqrunch"              => 12273,
                         "squad51"              => 27230,
                         "squall"               => 3142,
                         "squash"               => 2894,
                         "squeak"               => 4468,
                         "squeaker"             => 13307,
                         "squealer"             => 21492,
                         "squeek"               => 16245,
                         "squeeky"              => 24335,
                         "squerting"            => 6872,
                         "squid"                => 6849,
                         "squid1"               => 13621,
                         "squidly"              => 28027,
                         "squids"               => 12315,
                         "squiggy"              => 10546,
                         "squirrel"             => 1282,
                         "squirt"               => 938,
                         "squirter"             => 15198,
                         "squirtle"             => 28929,
                         "squirts"              => 6718,
                         "squish"               => 10331,
                         "squishy"              => 11497,
                         "squonk"               => 11205,
                         "sr20det"              => 13068,
                         "sr20dett"             => 20082,
                         "srilanka"             => 11957,
                         "srinivas"             => 867,
                         "ssbt8ae2"             => 26286,
                         "ssecca"               => 21161,
                         "sseexx"               => 15427,
                         "ssgoku"               => 22351,
                         "sslazio"              => 27495,
                         "ssnake"               => 29824,
                         "ssptx452"             => 14254,
                         "sss123"               => 26022,
                         "sssss1"               => 10926,
                         "ssssss1"              => 12718,
                         "sssssss1"             => 17166,
                         "ssvegeta"             => 21889,
                         "st0n3"                => 9917,
                         "st1100"               => 20609,
                         "st123st"              => 28898,
                         "stabbin"              => 26539,
                         "stabilo"              => 14502,
                         "stacey1"              => 12945,
                         "stacy1"               => 11429,
                         "staind"               => 8305,
                         "stairway"             => 11164,
                         "stakan"               => 20046,
                         "stalin"               => 2978,
                         "stalingrad"           => 14396,
                         "stalke"               => 23563,
                         "stalker"              => 414,
                         "stalker1"             => 11110,
                         "stalker123"           => 19502,
                         "stalker2"             => 29928,
                         "stallion"             => 1134,
                         "stallone"             => 10901,
                         "stamford"             => 8668,
                         "stampede"             => 9154,
                         "standart"             => 18104,
                         "standby"              => 6327,
                         "standrew"             => 23285,
                         "stang"                => 5454,
                         "stang1"               => 17141,
                         "stang50"              => 26093,
                         "stangs"               => 28536,
                         "stanisla"             => 26998,
                         "stanislav"            => 3716,
                         "stanky"               => 20741,
                         "stanle"               => 17172,
                         "stanley1"             => 4938,
                         "stanley2"             => 18429,
                         "stanly"               => 14701,
                         "staples1"             => 25710,
                         "star"                 => 439,
                         "star1"                => 8749,
                         "star11"               => 13241,
                         "star12"               => 7304,
                         "star123"              => 6891,
                         "star1234"             => 25910,
                         "star22"               => 21516,
                         "star69"               => 2008,
                         "star77"               => 24125,
                         "star99"               => 14893,
                         "starbase"             => 28461,
                         "starbuck"             => 1795,
                         "starbucks"            => 7331,
                         "starburs"             => 22152,
                         "starcraf"             => 3221,
                         "starcraft"            => 1445,
                         "stardog"              => 17100,
                         "stardust"             => 1295,
                         "starfire"             => 2610,
                         "starfish"             => 1802,
                         "starflee"             => 12135,
                         "starfleet"            => 27267,
                         "starfox"              => 7192,
                         "starfuck"             => 14892,
                         "starfury"             => 15857,
                         "stargat"              => 25434,
                         "stargate"             => 499,
                         "stargaze"             => 10622,
                         "stargazer"            => 17405,
                         "stargirl"             => 26145,
                         "starik"               => 21192,
                         "starion"              => 11929,
                         "starlet"              => 13852,
                         "starligh"             => 4153,
                         "starlight"            => 6858,
                         "starline"             => 23801,
                         "starlite"             => 7028,
                         "starman"              => 2851,
                         "starr1"               => 18157,
                         "starrr"               => 19873,
                         "starrs"               => 26478,
                         "stars1"               => 10236,
                         "stars2"               => 27424,
                         "starship"             => 2240,
                         "starsky"              => 9219,
                         "starss"               => 15963,
                         "start1"               => 4985,
                         "start123"             => 6378,
                         "startac"              => 10834,
                         "starter"              => 2951,
                         "startnow"             => 22710,
                         "startre"              => 25415,
                         "startrek"             => 230,
                         "startrek1"            => 28541,
                         "starwar"              => 5343,
                         "starwar1"             => 16415,
                         "starwars"             => 52,
                         "starwars1"            => 5360,
                         "starwood"             => 27733,
                         "starz"                => 22473,
                         "stasik"               => 3929,
                         "stason"               => 21564,
                         "stasya"               => 15309,
                         "state1"               => 20208,
                         "stater"               => 23658,
                         "static"               => 2553,
                         "static1"              => 29000,
                         "staticx"              => 20582,
                         "station1"             => 19858,
                         "station2"             => 23689,
                         "statistika"           => 29282,
                         "stayout"              => 5668,
                         "stealth"              => 863,
                         "stealth1"             => 10806,
                         "steam181"             => 28091,
                         "steamboa"             => 14443,
                         "steamforums"          => 28086,
                         "steaua"               => 5066,
                         "steeda"               => 19849,
                         "steel1"               => 8879,
                         "steeler"              => 2313,
                         "steeler1"             => 11456,
                         "steelers"             => 115,
                         "steelers1"            => 10998,
                         "steelhea"             => 9689,
                         "steels"               => 15676,
                         "stefa"                => 12432,
                         "stefano"              => 2279,
                         "steff"                => 12770,
                         "steffi"               => 3935,
                         "steffie"              => 18107,
                         "steinway"             => 12665,
                         "stella1"              => 8488,
                         "stella12"             => 28109,
                         "stellar"              => 5805,
                         "stellina"             => 17580,
                         "stepan"               => 3665,
                         "stepanov"             => 12240,
                         "stepanova"            => 12079,
                         "stepashka"            => 28344,
                         "steph"                => 2496,
                         "steph1"               => 10624,
                         "steph123"             => 23901,
                         "stephani"             => 927,
                         "stephe"               => 12784,
                         "stephen1"             => 4217,
                         "stephie"              => 13662,
                         "stephy"               => 9644,
                         "stepside"             => 26901,
                         "stereo"               => 2597,
                         "sterlin"              => 1967,
                         "sterne"               => 18727,
                         "sterva"               => 5094,
                         "steve01"              => 18987,
                         "steve1"               => 1951,
                         "steve12"              => 25875,
                         "steve121"             => 20690,
                         "steve123"             => 8999,
                         "steve2"               => 21906,
                         "steve22"              => 25501,
                         "steve69"              => 15886,
                         "steveg"               => 28918,
                         "steveh"               => 25906,
                         "stevek"               => 17698,
                         "steven1"              => 5114,
                         "steven2"              => 20630,
                         "stevenso"             => 21034,
                         "steveo"               => 8697,
                         "steves"               => 9963,
                         "stevie1"              => 23394,
                         "stevo"                => 20935,
                         "stewar"               => 25534,
                         "stewar1"              => 13666,
                         "stewart1"             => 6047,
                         "stewie"               => 10765,
                         "sthgrtst"             => 24273,
                         "sti2000"              => 16431,
                         "stick1"               => 14429,
                         "stickboy"             => 23378,
                         "stickdaddy77"         => 26818,
                         "stickman"             => 5449,
                         "sticks"               => 2115,
                         "sticky"               => 1183,
                         "sticky1"              => 17971,
                         "stiffie"              => 29730,
                         "stiffy"               => 3766,
                         "stifler"              => 17444,
                         "stigmata"             => 5070,
                         "stiletto"             => 6224,
                         "stillers"             => 27088,
                         "stillher"             => 24591,
                         "stimorol"             => 25942,
                         "stimpy"               => 1380,
                         "stimpy1"              => 17369,
                         "sting"                => 2801,
                         "sting1"               => 9530,
                         "stinger"              => 934,
                         "stinger1"             => 7298,
                         "stingers"             => 22268,
                         "stingray"             => 728,
                         "stinker"              => 4390,
                         "stinker1"             => 28964,
                         "stinky"               => 598,
                         "stinky1"              => 7383,
                         "stinkyfinger"         => 25302,
                         "stitch"               => 5713,
                         "stivone"              => 24342,
                         "stjabn"               => 12304,
                         "stjohns"              => 27638,
                         "stockcar"             => 23122,
                         "stockhol"             => 24571,
                         "stocking"             => 1234,
                         "stockpor"             => 28682,
                         "stocks"               => 2198,
                         "stokecit"             => 29926,
                         "stokrotka"            => 22456,
                         "stomatolog"           => 20491,
                         "stomper"              => 10487,
                         "stone1"               => 4960,
                         "stone32"              => 17646,
                         "stone55"              => 4093,
                         "stonecol"             => 1470,
                         "stonecold"            => 3350,
                         "stoned"               => 2911,
                         "stoner1"              => 27598,
                         "stones"               => 1041,
                         "stonewal"             => 6360,
                         "stoney"               => 2754,
                         "stonie"               => 26453,
                         "stooge"               => 6920,
                         "stooges"              => 7459,
                         "stoopid"              => 19140,
                         "stopit"               => 6814,
                         "stoppedb"             => 26713,
                         "stoppedby"            => 6623,
                         "storm"                => 1008,
                         "storm1"               => 4101,
                         "storm12"              => 28923,
                         "storm7"               => 26563,
                         "stormbri"             => 28857,
                         "stormie"              => 19989,
                         "stormin"              => 27417,
                         "stormy"               => 979,
                         "stormy1"              => 16369,
                         "storys"               => 8648,
                         "stpiliot"             => 29722,
                         "str8edge"             => 20098,
                         "strange1"             => 9149,
                         "stranger"             => 1402,
                         "strannik"             => 9687,
                         "strap"                => 5154,
                         "strapon"              => 15539,
                         "strat"                => 7310,
                         "strat1"               => 14017,
                         "stratcat"             => 26751,
                         "strateg"              => 20703,
                         "stratfor"             => 5065,
                         "strato"               => 8421,
                         "stratoca"             => 13719,
                         "stratocaster"         => 20925,
                         "stratos"              => 11450,
                         "strats"               => 18933,
                         "stratus"              => 3813,
                         "stratus1"             => 27024,
                         "strawber"             => 4720,
                         "strawberry"           => 3618,
                         "straycat"             => 12628,
                         "streaker"             => 18657,
                         "streaming"            => 5708,
                         "street1"              => 28745,
                         "streetball"           => 17632,
                         "strekoza"             => 13139,
                         "strela"               => 20462,
                         "strelec"              => 11467,
                         "strelok"              => 5529,
                         "strider"              => 1317,
                         "strider1"             => 16120,
                         "strife"               => 6397,
                         "strike"               => 757,
                         "strike1"              => 11163,
                         "strike3"              => 23022,
                         "striker"              => 1844,
                         "striker1"             => 12334,
                         "strip4me"             => 29403,
                         "stripclub"            => 14302,
                         "stripe"               => 7866,
                         "striper"              => 7067,
                         "stripper"             => 1894,
                         "stroker"              => 3545,
                         "stroller"             => 9939,
                         "stromb"               => 13232,
                         "strong1"              => 23248,
                         "strongbo"             => 28445,
                         "stronzo"              => 23191,
                         "structur"             => 18984,
                         "strummer"             => 13844,
                         "strumpf"              => 15228,
                         "struppi"              => 23655,
                         "strutter"             => 14159,
                         "stryder"              => 14680,
                         "stryke"               => 22647,
                         "stryker"              => 4733,
                         "stuart1"              => 16761,
                         "stubby"               => 4064,
                         "stud"                 => 1600,
                         "stud69"               => 25689,
                         "studboy"              => 14048,
                         "studen"               => 27815,
                         "student1"             => 12397,
                         "studio1"              => 22105,
                         "studio54"             => 12864,
                         "studioworks"          => 20313,
                         "studly"               => 2555,
                         "studly1"              => 23584,
                         "studman"              => 4466,
                         "studmuff"             => 12781,
                         "studmuffin"           => 22580,
                         "stuff1"               => 12213,
                         "stuffer"              => 9053,
                         "stufff"               => 22613,
                         "stuffit"              => 21920,
                         "stumpy"               => 2753,
                         "stunna"               => 20910,
                         "stunner"              => 2683,
                         "stunner1"             => 27630,
                         "stuntman"             => 18424,
                         "stupi"                => 14725,
                         "stupid"               => 274,
                         "stupid1"              => 4529,
                         "stupid12"             => 28368,
                         "stussy"               => 10466,
                         "stuttgar"             => 22570,
                         "stylus"               => 3812,
                         "stymie"               => 13481,
                         "suan"                 => 3470,
                         "subaru"               => 942,
                         "subito"               => 17072,
                         "sublime"              => 678,
                         "sublime1"             => 7422,
                         "submarin"             => 7896,
                         "submissi"             => 14416,
                         "submit"               => 3535,
                         "subrosa"              => 14309,
                         "subway"               => 2352,
                         "subwoofer"            => 13130,
                         "subzero"              => 3147,
                         "subzero1"             => 26603,
                         "succes"               => 7771,
                         "success"              => 277,
                         "success1"             => 4479,
                         "success2"             => 27235,
                         "sucess"               => 16711,
                         "sucesso"              => 24703,
                         "suchka"               => 12720,
                         "suck"                 => 1169,
                         "suck1"                => 27975,
                         "suck69"               => 29312,
                         "sucka"                => 23135,
                         "suckcock"             => 6510,
                         "suckdick"             => 5034,
                         "suckem"               => 29887,
                         "sucker"               => 538,
                         "sucker1"              => 14647,
                         "sucker69"             => 19164,
                         "suckers"              => 4325,
                         "suckfuck"             => 24697,
                         "suckit"               => 276,
                         "suckit1"              => 23299,
                         "suckit69"             => 17834,
                         "suckme"               => 661,
                         "suckme1"              => 29884,
                         "suckmeoff"            => 17486,
                         "suckmy1k"             => 26746,
                         "suckmyco"             => 22088,
                         "suckmycock"           => 17737,
                         "suckmydi"             => 19822,
                         "suckmydick"           => 4719,
                         "sucks"                => 1286,
                         "sucks1"               => 20293,
                         "suckthis"             => 15140,
                         "sucram"               => 17957,
                         "sudhakar"             => 24541,
                         "suede"                => 6205,
                         "suerte"               => 13527,
                         "sugar"                => 959,
                         "sugar1"               => 4192,
                         "sugar2"               => 29989,
                         "sugarbea"             => 12879,
                         "sugarbear"            => 15182,
                         "sugardog"             => 25936,
                         "sugaree"              => 16839,
                         "sugarray"             => 14233,
                         "sugars"               => 6735,
                         "suger"                => 22515,
                         "suikoden"             => 9117,
                         "sujatha"              => 23975,
                         "suka123"              => 12927,
                         "sukebe"               => 7814,
                         "sukkel"               => 25276,
                         "sukram"               => 17558,
                         "sulaco"               => 27048,
                         "sully"                => 9256,
                         "sultan"               => 2060,
                         "sumerki"              => 14352,
                         "sumitomo"             => 18650,
                         "summe"                => 6391,
                         "summer"               => 69,
                         "summer0"              => 15175,
                         "summer00"             => 17533,
                         "summer01"             => 9140,
                         "summer02"             => 28787,
                         "summer03"             => 21700,
                         "summer04"             => 18938,
                         "summer05"             => 12876,
                         "summer06"             => 12725,
                         "summer07"             => 19738,
                         "summer08"             => 28509,
                         "summer1"              => 1973,
                         "summer10"             => 14829,
                         "summer11"             => 14315,
                         "summer12"             => 8754,
                         "summer13"             => 25426,
                         "summer2"              => 13946,
                         "summer20"             => 13324,
                         "summer22"             => 27824,
                         "summer69"             => 5355,
                         "summer98"             => 21384,
                         "summer99"             => 4154,
                         "summerti"             => 9110,
                         "summertime"           => 8236,
                         "summit"               => 1984,
                         "summoner"             => 23811,
                         "sun123"               => 22182,
                         "sunbanna"             => 27961,
                         "sunbeam"              => 7770,
                         "sunbird"              => 8352,
                         "sunburst"             => 25206,
                         "sundance"             => 1056,
                         "sunday"               => 922,
                         "sunday1"              => 25927,
                         "sundaypunch"          => 22879,
                         "sunder"               => 29220,
                         "sunderla"             => 7746,
                         "sundevil"             => 4236,
                         "sundial"              => 22045,
                         "sundin"               => 12127,
                         "sundog"               => 24881,
                         "sundown"              => 8246,
                         "sundrop"              => 13706,
                         "sunfire"              => 4260,
                         "sunfish"              => 14694,
                         "sunflowe"             => 2599,
                         "sunflower"            => 3277,
                         "sungam"               => 27821,
                         "sunghi"               => 19726,
                         "sunghile"             => 12871,
                         "sungod"               => 23218,
                         "sunita"               => 10705,
                         "sunitha"              => 29144,
                         "sunking"              => 20039,
                         "sunkist"              => 7371,
                         "sunlight"             => 5795,
                         "sunmoon"              => 16810,
                         "sunnie"               => 11170,
                         "sunny1"               => 4197,
                         "sunny123"             => 12331,
                         "sunny2"               => 27405,
                         "sunny7"               => 21218,
                         "sunnyboy"             => 14286,
                         "sunnyd"               => 19736,
                         "sunnyday"             => 2564,
                         "sunnys"               => 21316,
                         "sunnysid"             => 18897,
                         "sunray"               => 14448,
                         "sunrise"              => 1284,
                         "sunrise1"             => 10254,
                         "sunse"                => 27793,
                         "sunset"               => 722,
                         "sunset1"              => 22555,
                         "sunsh1ne"             => 20358,
                         "sunshin"              => 2798,
                         "sunshin1"             => 28459,
                         "sunshine"             => 46,
                         "sunshine1"            => 5622,
                         "sunstar"              => 12148,
                         "suntan"               => 13747,
                         "suntzu"               => 7102,
                         "suomi"                => 26850,
                         "supafly"              => 26856,
                         "super"                => 563,
                         "super1"               => 1917,
                         "super12"              => 4158,
                         "super123"             => 1228,
                         "super2"               => 13351,
                         "super5"               => 21032,
                         "super7"               => 11416,
                         "super8"               => 13185,
                         "supera"               => 23456,
                         "superb"               => 3740,
                         "superbad"             => 16440,
                         "superbee"             => 11306,
                         "superbow"             => 7403,
                         "superboy"             => 11002,
                         "supercal"             => 29798,
                         "supercar"             => 17204,
                         "supercat"             => 27392,
                         "supercoo"             => 21174,
                         "supercop"             => 26316,
                         "superd"               => 12563,
                         "superdav"             => 25997,
                         "superdog"             => 12829,
                         "superdude"            => 23179,
                         "superdup"             => 10919,
                         "superduper"           => 13167,
                         "superfly"             => 1098,
                         "superfre"             => 20545,
                         "supergir"             => 14863,
                         "supergirl"            => 11954,
                         "superjet"             => 21676,
                         "superma"              => 3898,
                         "superma1"             => 19984,
                         "superman"             => 26,
                         "superman1"            => 2587,
                         "superman12"           => 28254,
                         "superman123"          => 23252,
                         "superman2"            => 15041,
                         "supermanboy"          => 15752,
                         "supermar"             => 16556,
                         "supermario"           => 24233,
                         "supermax"             => 19760,
                         "superme"              => 26948,
                         "supermen"             => 16016,
                         "supermom"             => 26575,
                         "supernov"             => 5007,
                         "supernova"            => 5685,
                         "superpuper"           => 16577,
                         "supers"               => 8369,
                         "supersex"             => 14373,
                         "superson"             => 11667,
                         "supersonic"           => 5942,
                         "supersta"             => 2432,
                         "superstar"            => 2058,
                         "supert"               => 28433,
                         "superted"             => 21547,
                         "supertra"             => 15968,
                         "superx"               => 23499,
                         "support1"             => 14412,
                         "supra"                => 5539,
                         "supra1"               => 15386,
                         "supras"               => 25228,
                         "supratt"              => 27616,
                         "sureno13"             => 21346,
                         "suresh"               => 11854,
                         "sureshot"             => 15694,
                         "surf"                 => 2236,
                         "surfboar"             => 17816,
                         "surfcity"             => 21603,
                         "surfe"                => 25504,
                         "surfer"               => 435,
                         "surfer1"              => 6619,
                         "surfer69"             => 25637,
                         "surfers"              => 13828,
                         "surfin"               => 10681,
                         "surfing"              => 1361,
                         "surfing1"             => 12814,
                         "surfside"             => 24015,
                         "surfsup"              => 7213,
                         "surrende"             => 27457,
                         "surveyor"             => 6286,
                         "survivor"             => 4182,
                         "susan1"               => 4917,
                         "susan69"              => 25687,
                         "susanb"               => 18618,
                         "susanne1"             => 21039,
                         "susans"               => 19998,
                         "sushi"                => 4203,
                         "sushi1"               => 9258,
                         "susie1"               => 18861,
                         "susieq"               => 6667,
                         "suslik"               => 5061,
                         "suspende"             => 17282,
                         "sustanon"             => 29821,
                         "sux2bu"               => 24743,
                         "suzanne1"             => 16327,
                         "suzenet"              => 11697,
                         "suzieq"               => 17012,
                         "suzjv8"               => 20052,
                         "suzuk"                => 15248,
                         "suzuki"               => 506,
                         "suzuki1"              => 14666,
                         "suzyq"                => 22715,
                         "svarog"               => 15756,
                         "sveiks"               => 26655,
                         "sverige"              => 7352,
                         "sveta"                => 3231,
                         "sveta123"             => 15626,
                         "svetasveta"           => 23703,
                         "svetik"               => 1916,
                         "svetka"               => 9758,
                         "svetlana"             => 465,
                         "svetlanka"            => 10648,
                         "svoboda"              => 3106,
                         "svoloch"              => 26921,
                         "swallow"              => 1387,
                         "swallows"             => 8895,
                         "swampfox"             => 15461,
                         "swampy"               => 7342,
                         "swanky"               => 9227,
                         "swanny"               => 21097,
                         "swansong"             => 23813,
                         "swapna"               => 29161,
                         "swatch"               => 7141,
                         "swatteam"             => 20877,
                         "swede"                => 9898,
                         "sweden1"              => 22339,
                         "sweeet"               => 24750,
                         "sweeper"              => 10802,
                         "sweeps"               => 6191,
                         "sweet1"               => 2846,
                         "sweet123"             => 19550,
                         "sweet16"              => 9751,
                         "sweet2"               => 27211,
                         "sweet666"             => 27766,
                         "sweet69"              => 14519,
                         "sweetass"             => 8711,
                         "sweetdream"           => 22902,
                         "sweetgirl"            => 16182,
                         "sweethea"             => 9930,
                         "sweethear"            => 16066,
                         "sweeti"               => 20613,
                         "sweetie1"             => 12231,
                         "sweeties"             => 28139,
                         "sweetnes"             => 3639,
                         "sweetness"            => 4495,
                         "sweetp"               => 16003,
                         "sweetpe"              => 17625,
                         "sweetpea"             => 963,
                         "sweetpus"             => 26683,
                         "sweetpussy"           => 21172,
                         "sweets"               => 1229,
                         "sweett"               => 22637,
                         "sweetu70"             => 28085,
                         "sweety"               => 885,
                         "sweety1"              => 19604,
                         "swetlana"             => 14173,
                         "swift1"               => 24908,
                         "swifty"               => 6774,
                         "swimmer"              => 2338,
                         "swimmer1"             => 13048,
                         "swimming"             => 773,
                         "swinger"              => 946,
                         "swinger1"             => 22561,
                         "swingers"             => 1829,
                         "swinging"             => 4671,
                         "swiss1"               => 22890,
                         "swissair"             => 22605,
                         "swoosh"               => 5693,
                         "sword"                => 2295,
                         "sword1"               => 13343,
                         "sword123"             => 26051,
                         "swordfis"             => 568,
                         "swordfish"            => 789,
                         "swords"               => 2853,
                         "swordsma"             => 29079,
                         "sxhq65"               => 11931,
                         "sybase"               => 25892,
                         "sycamore"             => 11183,
                         "syclone"              => 11790,
                         "sydne"                => 10142,
                         "sydnee"               => 27835,
                         "sydney"               => 291,
                         "sydney1"              => 8901,
                         "sydney12"             => 20266,
                         "sylvan"               => 14635,
                         "sylvania"             => 10281,
                         "sylveste"             => 4849,
                         "sylvi"                => 16913,
                         "sylvia1"              => 13466,
                         "sylwia"               => 16820,
                         "symantec"             => 28466,
                         "symow8"               => 18066,
                         "synapse"              => 13943,
                         "syncmast"             => 11722,
                         "syncmaster"           => 2705,
                         "syndicat"             => 27526,
                         "synergy"              => 4570,
                         "syoung"               => 28968,
                         "syphon"               => 15240,
                         "syracuse"             => 1717,
                         "syrinx"               => 9883,
                         "sys64738"             => 26036,
                         "sysadmin"             => 10522,
                         "sysman"               => 29858,
                         "system1"              => 6729,
                         "system12"             => 23890,
                         "system32"             => 10211,
                         "systemofadown"        => 27784,
                         "syzygy"               => 3433,
                         "szevasz"              => 10977,
                         "t123456"              => 11494,
                         "t26gn4"               => 12218,
                         "t34vfrc1991"          => 11041,
                         "t3fkvkmj"             => 16688,
                         "t4nvp7"               => 13362,
                         "ta8g4w"               => 14084,
                         "tabaco"               => 26470,
                         "tabaluga"             => 22778,
                         "tabasco"              => 4699,
                         "tabby1"               => 28826,
                         "tabbycat"             => 13959,
                         "table54781"           => 24740,
                         "tabletop"             => 25491,
                         "taburetka"            => 29555,
                         "tachyon"              => 28147,
                         "tacit"                => 9769,
                         "taco"                 => 4373,
                         "tacobell"             => 1485,
                         "tacoma"               => 1531,
                         "tadmichaels"          => 19917,
                         "tadpole"              => 6528,
                         "taekwond"             => 10722,
                         "taekwondo"            => 4832,
                         "taffy"                => 6255,
                         "taffy1"               => 13034,
                         "tafkap"               => 26991,
                         "tagada"               => 25752,
                         "taganrog"             => 25847,
                         "tagheuer"             => 10411,
                         "tahira"               => 27200,
                         "tahiti"               => 7093,
                         "tahoe"                => 8243,
                         "tahoe1"               => 10380,
                         "tahoes"               => 29827,
                         "taichi"               => 6166,
                         "tailgate"             => 7206,
                         "tailhook"             => 29695,
                         "taipan"               => 6494,
                         "taison"               => 26947,
                         "tajmahal"             => 12414,
                         "takagi"               => 16560,
                         "takamine"             => 8240,
                         "takashi"              => 9378,
                         "takayuki"             => 21282,
                         "take8422"             => 12606,
                         "takedown"             => 17970,
                         "takehana"             => 11029,
                         "takeit"               => 18762,
                         "takeme"               => 27773,
                         "takeshi"              => 13110,
                         "talgat"               => 8567,
                         "taliesin"             => 15496,
                         "talisker"             => 18676,
                         "talisman"             => 2964,
                         "talk87"               => 27511,
                         "talktome"             => 22172,
                         "tallboy"              => 27403,
                         "tallen"               => 29641,
                         "tallguy"              => 16437,
                         "tallulah"             => 21646,
                         "tallyho"              => 12114,
                         "talon"                => 3304,
                         "talon1"               => 11063,
                         "talonesi"             => 24815,
                         "talons"               => 13592,
                         "taltos"               => 14348,
                         "talula"               => 23128,
                         "tamada"               => 25683,
                         "tamere"               => 17662,
                         "tamerlan"             => 6026,
                         "tamia1"               => 17364,
                         "tamila"               => 17304,
                         "tamiya"               => 29921,
                         "tammy1"               => 6001,
                         "tammys"               => 21098,
                         "tampa1"               => 26779,
                         "tampabay"             => 5703,
                         "tampico"              => 24253,
                         "tamplier"             => 29334,
                         "tamuna"               => 9516,
                         "tamwsn3sja"           => 16594,
                         "tane4ka"              => 19553,
                         "tanechka"             => 8983,
                         "tanelorn"             => 28556,
                         "tangerin"             => 6876,
                         "tangerine"            => 12270,
                         "tango"                => 2764,
                         "tango1"               => 5676,
                         "tango123"             => 24481,
                         "tango2"               => 18383,
                         "tangos"               => 26137,
                         "tangsoo"              => 25101,
                         "tanguy"               => 27932,
                         "tanita"               => 29201,
                         "tanith"               => 18098,
                         "tanker"               => 1335,
                         "tankist"              => 20697,
                         "tanman"               => 13617,
                         "tanne"                => 18499,
                         "tannenbau"            => 23537,
                         "tanner1"              => 21138,
                         "tanstaaf"             => 13175,
                         "tantra"               => 5573,
                         "tanuki"               => 20979,
                         "tanusha"              => 21976,
                         "tanushka"             => 25275,
                         "tanya1"               => 5414,
                         "tanya123"             => 20392,
                         "tanyshka"             => 28666,
                         "tanzen"               => 27040,
                         "tapout"               => 18423,
                         "taproot"              => 25799,
                         "tarado"               => 23885,
                         "tarakan"              => 5474,
                         "tarantul"             => 9553,
                         "taras"                => 11864,
                         "tarasov"              => 16754,
                         "tarasova"             => 15779,
                         "taratata"             => 24489,
                         "tarawa"               => 24451,
                         "tarbaby"              => 20296,
                         "tarbit"               => 23375,
                         "tardis"               => 1557,
                         "tardis1"              => 14995,
                         "tarelka"              => 23180,
                         "targa"                => 20698,
                         "targa1"               => 24797,
                         "target"               => 831,
                         "target1"              => 14393,
                         "tarheel"              => 1337,
                         "tarheel1"             => 12587,
                         "tarheels"             => 739,
                         "tarkan"               => 17446,
                         "tarkin"               => 19057,
                         "tarkus"               => 18889,
                         "tarpon"               => 5466,
                         "tartan"               => 9541,
                         "tarzan"               => 1089,
                         "tarzan1"              => 23478,
                         "tascam"               => 17081,
                         "tasha1"               => 5234,
                         "tashas"               => 25968,
                         "tashkent"             => 9240,
                         "tassadar"             => 21786,
                         "tassie"               => 14580,
                         "tasty"                => 3951,
                         "tatanka"              => 12882,
                         "tatarin"              => 4131,
                         "tater"                => 8094,
                         "taters"               => 16539,
                         "tatertot"             => 18420,
                         "tatian"               => 10809,
                         "tatiana1"             => 22867,
                         "tatjana"              => 6835,
                         "tatoo"                => 21126,
                         "tatooine"             => 15598,
                         "tattoo"               => 814,
                         "tattoo1"              => 23101,
                         "tatung"               => 15130,
                         "tatyana"              => 1602,
                         "tauchen"              => 16102,
                         "taucher"              => 19932,
                         "taurus"               => 660,
                         "taurus1"              => 22231,
                         "tautt1"               => 24985,
                         "tavasz"               => 23165,
                         "tawnee"               => 11968,
                         "taxicab"              => 18674,
                         "taxman"               => 3587,
                         "taylo"                => 6372,
                         "taylor01"             => 22433,
                         "taylor1"              => 2538,
                         "taylor11"             => 26545,
                         "taylor12"             => 10366,
                         "taylor2"              => 12330,
                         "taylor9"              => 26596,
                         "taylorc"              => 25967,
                         "taylorma"             => 19691,
                         "tayson"               => 15862,
                         "taz123"               => 18584,
                         "tazdevil"             => 10006,
                         "tazman"               => 1401,
                         "tazman1"              => 16091,
                         "tazmania"             => 2453,
                         "tazz"                 => 5749,
                         "tazzer"               => 22449,
                         "tazzie"               => 17294,
                         "tazzman"              => 24416,
                         "tazzzz"               => 12176,
                         "tbbucs"               => 19149,
                         "tbear"                => 23229,
                         "tbird"                => 6245,
                         "tbird1"               => 29610,
                         "tbirds"               => 13973,
                         "tbivbn"               => 18628,
                         "tbone"                => 4028,
                         "tbone1"               => 12703,
                         "tbones"               => 15688,
                         "tbontb"               => 18486,
                         "tcglyued"             => 23223,
                         "tdeir8b2"             => 27910,
                         "tdfyutkbjy"           => 25505,
                         "tdutif"               => 20042,
                         "tdutybq"              => 1923,
                         "tdutybz"              => 3198,
                         "tea4two"              => 20889,
                         "teabag"               => 9083,
                         "teache"               => 11983,
                         "teacher"              => 903,
                         "teacher1"             => 7906,
                         "teacup"               => 11121,
                         "teagan"               => 24267,
                         "team3x"               => 15880,
                         "teamlosi"             => 27352,
                         "teamo"                => 14707,
                         "teamomuch"            => 27251,
                         "teamster"             => 22116,
                         "teamwork"             => 8795,
                         "teaparty"             => 17653,
                         "teapot"               => 7063,
                         "teardrop"             => 14661,
                         "teaseme"              => 14367,
                         "teaser"               => 6769,
                         "teatime"              => 15185,
                         "tecate"               => 14474,
                         "tech1"                => 29486,
                         "techdeck"             => 22512,
                         "techie"               => 13800,
                         "techman"              => 24073,
                         "techn9ne"             => 24977,
                         "technic"              => 15793,
                         "technica"             => 25751,
                         "technici"             => 29476,
                         "technics"             => 1882,
                         "technik"              => 27743,
                         "techno"               => 1025,
                         "techno1"              => 17139,
                         "technolo"             => 14687,
                         "tecktonik"            => 18320,
                         "tecumseh"             => 8062,
                         "tedbear"              => 24953,
                         "teddie"               => 11855,
                         "teddies"              => 21026,
                         "teddy1"               => 3036,
                         "teddy123"             => 12407,
                         "teddy2"               => 12675,
                         "teddyb"               => 10337,
                         "teddybea"             => 3021,
                         "teddybear"            => 3372,
                         "teddys"               => 15556,
                         "teejay"               => 8783,
                         "teen"                 => 1177,
                         "teen1"                => 27875,
                         "teenfuck"             => 28769,
                         "teengirl"             => 16604,
                         "teenie"               => 9389,
                         "teenlove"             => 24542,
                         "teens"                => 775,
                         "teens1"               => 13784,
                         "teensex"              => 6274,
                         "teenslut"             => 23500,
                         "teepee"               => 20574,
                         "teetime"              => 12634,
                         "tefjps"               => 21050,
                         "teflon"               => 12392,
                         "teh012"               => 21765,
                         "teiubesc"             => 11577,
                         "tekila"               => 14413,
                         "tekken"               => 2268,
                         "tekken3"              => 22279,
                         "telecast"             => 9647,
                         "telecaster"           => 21131,
                         "telecom"              => 6981,
                         "telefon"              => 1773,
                         "telefone"             => 23133,
                         "telefono"             => 18279,
                         "telefoon"             => 22628,
                         "telekom"              => 15565,
                         "telemark"             => 12050,
                         "telephon"             => 3562,
                         "teleport"             => 12460,
                         "telescop"             => 27592,
                         "televisi"             => 12210,
                         "televizor"            => 9681,
                         "tellme"               => 15909,
                         "telnet"               => 12915,
                         "telstar"              => 19286,
                         "telus01"              => 25996,
                         "tema1234"             => 27394,
                         "temitope"             => 19770,
                         "temp"                 => 2232,
                         "temp01"               => 21990,
                         "temp1"                => 21022,
                         "temp12"               => 29140,
                         "temp123"              => 3493,
                         "temp1234"             => 10216,
                         "tempest"              => 1529,
                         "tempest1"             => 15813,
                         "tempgod"              => 15436,
                         "templar"              => 3254,
                         "templar1"             => 29752,
                         "temple1"              => 23474,
                         "temporar"             => 11179,
                         "temppass"             => 3775,
                         "temppassword"         => 20527,
                         "temptress"            => 7933,
                         "tempus"               => 12442,
                         "temujin"              => 27599,
                         "tenchi"               => 4870,
                         "tenchu"               => 12187,
                         "tenerife"             => 8041,
                         "teng"                 => 3141,
                         "tennesse"             => 5922,
                         "tenni"                => 11816,
                         "tennis"               => 146,
                         "tennis1"              => 5068,
                         "tennis11"             => 18449,
                         "tennis12"             => 14431,
                         "tenore"               => 20049,
                         "tenorsax"             => 27746,
                         "tenpin"               => 10105,
                         "tenshi"               => 20239,
                         "tentacle"             => 21440,
                         "teodor"               => 14155,
                         "tequier"              => 6471,
                         "tequiero"             => 7825,
                         "tequil"               => 24095,
                         "tequila"              => 1359,
                         "tequila1"             => 11173,
                         "tequilla"             => 16771,
                         "tercel"               => 11913,
                         "terces"               => 18372,
                         "terefon"              => 5055,
                         "teremok"              => 17861,
                         "teres"                => 9408,
                         "teresa1"              => 16845,
                         "termin"               => 21276,
                         "terminat"             => 4169,
                         "terminato"            => 24280,
                         "terminator"           => 1824,
                         "termite"              => 6006,
                         "terorist"             => 20839,
                         "terps"                => 20454,
                         "terps1"               => 20544,
                         "terran"               => 7226,
                         "terrapin"             => 2746,
                         "terras"               => 19851,
                         "terrell1"             => 26226,
                         "terri1"               => 23572,
                         "terrier"              => 5667,
                         "terriers"             => 8086,
                         "terror"               => 1827,
                         "terry1"               => 6964,
                         "terry123"             => 25077,
                         "terry2"               => 18959,
                         "terrys"               => 18058,
                         "tesoro"               => 17585,
                         "tessa1"               => 21768,
                         "test"                 => 93,
                         "test01"               => 13311,
                         "test1"                => 1355,
                         "test11"               => 9342,
                         "test12"               => 5006,
                         "test123"              => 594,
                         "test1234"             => 2584,
                         "test2"                => 8862,
                         "test3"                => 23952,
                         "test99"               => 15133,
                         "testdrive"            => 27472,
                         "teste"                => 9328,
                         "tester"               => 475,
                         "tester1"              => 15959,
                         "testerer"             => 24024,
                         "testibil"             => 8267,
                         "testicle"             => 15571,
                         "testin"               => 22215,
                         "testing"              => 398,
                         "testing1"             => 4108,
                         "testing123"           => 12030,
                         "testing2"             => 18827,
                         "testit"               => 15747,
                         "testme"               => 10945,
                         "testme2"              => 11907,
                         "testpass"             => 3526,
                         "testuser"             => 19125,
                         "tetas"                => 23261,
                         "tetons"               => 16928,
                         "tetris"               => 6230,
                         "tetsuo"               => 5791,
                         "teufel"               => 8845,
                         "teufelo7"             => 23267,
                         "tevion"               => 26958,
                         "texaco"               => 7810,
                         "texans"               => 7230,
                         "texas1"               => 1992,
                         "texas123"             => 17129,
                         "texas2"               => 10927,
                         "texass"               => 8894,
                         "texmex"               => 15920,
                         "tgbxtcrbq"            => 25064,
                         "tgbyhn"               => 12950,
                         "tgkbxfgy"             => 27700,
                         "tgo4466"              => 19724,
                         "tgwdvu"               => 18591,
                         "th0mas"               => 26444,
                         "thailand"             => 800,
                         "thales"               => 12063,
                         "thaman"               => 18572,
                         "thanatos"             => 2521,
                         "thankgod"             => 14825,
                         "thanku"               => 25105,
                         "thankyou"             => 1650,
                         "thanos"               => 7586,
                         "thatguy"              => 28513,
                         "thatsit"              => 12918,
                         "thatsme"              => 7952,
                         "thc420"               => 25692,
                         "thd1shr"              => 23467,
                         "theband"              => 27240,
                         "thebeach"             => 15356,
                         "thebear"              => 5697,
                         "thebears"             => 18899,
                         "thebeast"             => 6107,
                         "thebeatl"             => 23591,
                         "thebeatles"           => 24947,
                         "thebes"               => 10347,
                         "thebest"              => 6066,
                         "theblues"             => 17764,
                         "thebomb"              => 10670,
                         "theboss"              => 2378,
                         "theboy"               => 13792,
                         "theboys"              => 7577,
                         "thebull"              => 16319,
                         "thebus"               => 28043,
                         "thecakeisalie"        => 29530,
                         "thecat"               => 2530,
                         "thechamp"             => 21842,
                         "theclash"             => 8278,
                         "theclown"             => 16580,
                         "thecount"             => 28157,
                         "thecrow"              => 4397,
                         "thecure"              => 4686,
                         "thecure1"             => 26158,
                         "thedark"              => 29700,
                         "thedead"              => 20773,
                         "thedevil"             => 16616,
                         "thedoc"               => 22833,
                         "thedog"               => 2886,
                         "thedon"               => 5388,
                         "thedoors"             => 3268,
                         "thedream"             => 28378,
                         "thedude"              => 3060,
                         "theduke"              => 7634,
                         "theedge"              => 8296,
                         "theend"               => 2616,
                         "theflash"             => 9556,
                         "thefly"               => 28280,
                         "theforce"             => 5158,
                         "thefox"               => 19762,
                         "thefrog"              => 24200,
                         "thegame"              => 1432,
                         "thegame1"             => 15643,
                         "theghost"             => 17573,
                         "thegirl"              => 26698,
                         "thegirls"             => 16679,
                         "thegod"               => 28257,
                         "thegreat"             => 2838,
                         "thehip"               => 19109,
                         "thehulk"              => 14935,
                         "thehun"               => 22239,
                         "thejoker"             => 10404,
                         "thekid"               => 2012,
                         "thekids"              => 23476,
                         "thekiller"            => 19717,
                         "theking"              => 1788,
                         "theking1"             => 22553,
                         "thekiwi1"             => 24916,
                         "thelast1"             => 9339,
                         "thelema"              => 11237,
                         "thema"                => 17271,
                         "themack"              => 27702,
                         "theman"               => 261,
                         "theman1"              => 8498,
                         "theman22"             => 29320,
                         "themaste"             => 21401,
                         "themaster"            => 13399,
                         "thematri"             => 9786,
                         "thematrix"            => 9650,
                         "themis"               => 26253,
                         "themoon"              => 21467,
                         "theone"               => 809,
                         "theone1"              => 12522,
                         "thepower"             => 26909,
                         "thepro"               => 28953,
                         "therat"               => 15171,
                         "theraven"             => 10944,
                         "thered"               => 14604,
                         "thereds"              => 24460,
                         "theresa1"             => 15342,
                         "thering"              => 26802,
                         "therion"              => 10175,
                         "theriver"             => 25786,
                         "thermo"               => 15922,
                         "theroc"               => 14450,
                         "therock"              => 378,
                         "therock1"             => 4983,
                         "thesaint"             => 8275,
                         "thesame"              => 23947,
                         "theshit"              => 8016,
                         "thesims"              => 2526,
                         "thesims2"             => 23333,
                         "thesims3"             => 27513,
                         "thesnake"             => 21091,
                         "thespot"              => 25068,
                         "thestone"             => 23656,
                         "thesun"               => 26878,
                         "thetachi"             => 10048,
                         "thetaxi"              => 23839,
                         "thething"             => 7797,
                         "thetick"              => 11731,
                         "thetruth"             => 7041,
                         "thewall"              => 8922,
                         "theway"               => 13716,
                         "thewho"               => 4452,
                         "thewolf"              => 25765,
                         "theword"              => 28169,
                         "theworld"             => 9278,
                         "theworm"              => 22418,
                         "thiago"               => 23401,
                         "thicknes"             => 21113,
                         "thicluv"              => 21663,
                         "thierry"              => 5568,
                         "thinkbig"             => 21905,
                         "thinker"              => 9989,
                         "thinkpad"             => 9254,
                         "thinline"             => 28303,
                         "thirdeye"             => 10349,
                         "thirteen"             => 2638,
                         "thisis"               => 14561,
                         "thisisit"             => 4012,
                         "thisisme"             => 11900,
                         "thisone"              => 11762,
                         "thissuck"             => 9642,
                         "thissucks"            => 17154,
                         "thistle"              => 8025,
                         "thoma"                => 3394,
                         "thomas0"              => 26841,
                         "thomas01"             => 10888,
                         "thomas1"              => 1616,
                         "thomas10"             => 22936,
                         "thomas11"             => 18124,
                         "thomas12"             => 9698,
                         "thomas123"            => 14047,
                         "thomas13"             => 22021,
                         "thomas19"             => 18475,
                         "thomas2"              => 10344,
                         "thomas21"             => 26622,
                         "thomas7"              => 29688,
                         "thomasd"              => 26862,
                         "thomasj"              => 29166,
                         "thong"                => 3781,
                         "thongs"               => 2717,
                         "thor"                 => 2063,
                         "thor5200"             => 13669,
                         "thor99"               => 27994,
                         "thoradin"             => 22980,
                         "thordog"              => 22158,
                         "thorny"               => 23444,
                         "thorsten"             => 9145,
                         "thoth"                => 27997,
                         "thrawn"               => 8530,
                         "three11"              => 16628,
                         "three3"               => 10342,
                         "threee"               => 26832,
                         "threesom"             => 4310,
                         "throatfuck"           => 25899,
                         "throbber"             => 29481,
                         "thuggin"              => 16375,
                         "thuglife"             => 1015,
                         "thuglove"             => 25312,
                         "thugstools"           => 26911,
                         "thumbnils"            => 7205,
                         "thumbs"               => 3137,
                         "thumper"              => 477,
                         "thumper1"             => 5522,
                         "thunde"               => 11581,
                         "thunder"              => 79,
                         "thunder0"             => 26570,
                         "thunder1"             => 1351,
                         "thunder2"             => 12857,
                         "thunder3"             => 19353,
                         "thunder5"             => 14370,
                         "thunder6"             => 27686,
                         "thunder7"             => 15517,
                         "thunder9"             => 17480,
                         "thunderb"             => 3129,
                         "thunderbird"          => 9279,
                         "thunderc"             => 21517,
                         "thunders"             => 10228,
                         "thvfrjdf"             => 24370,
                         "thwack"               => 29341,
                         "thx113"               => 23904,
                         "thx1138"              => 208,
                         "tiamat"               => 5989,
                         "tian"                 => 3309,
                         "tiao"                 => 3690,
                         "tibbar"               => 28906,
                         "tiberian"             => 7528,
                         "tiberium"             => 15288,
                         "tiberius"             => 2816,
                         "tiburo"               => 25544,
                         "tiburon"              => 3537,
                         "tiburon1"             => 23696,
                         "tical"                => 7568,
                         "ticketmaster"         => 20540,
                         "tickle"               => 911,
                         "tickleme"             => 15338,
                         "tickler"              => 6527,
                         "tickling"             => 6698,
                         "ticklish"             => 5604,
                         "ticktock"             => 7238,
                         "tictac"               => 6548,
                         "tiddles"              => 22150,
                         "tiedomi"              => 26663,
                         "tiedup"               => 10832,
                         "tiern"                => 22712,
                         "tiesto"               => 12578,
                         "tiffan"               => 8717,
                         "tiffany1"             => 3011,
                         "tiffany2"             => 18519,
                         "tiffy"                => 22682,
                         "tifosi"               => 16850,
                         "tiger"                => 210,
                         "tiger00"              => 29023,
                         "tiger01"              => 16554,
                         "tiger1"               => 693,
                         "tiger11"              => 20350,
                         "tiger12"              => 16854,
                         "tiger123"             => 3577,
                         "tiger2"               => 3710,
                         "tiger200"             => 20387,
                         "tiger21"              => 27312,
                         "tiger22"              => 23134,
                         "tiger23"              => 27626,
                         "tiger25"              => 23364,
                         "tiger5"               => 27529,
                         "tiger6"               => 21142,
                         "tiger69"              => 13565,
                         "tiger7"               => 8916,
                         "tiger8"               => 25100,
                         "tiger99"              => 17162,
                         "tigerboy"             => 21522,
                         "tigercat"             => 5843,
                         "tigereye"             => 23390,
                         "tigerfan"             => 26275,
                         "tigerlil"             => 11028,
                         "tigerman"             => 11242,
                         "tigerpaw"             => 16275,
                         "tigerr"               => 22895,
                         "tigers"               => 121,
                         "tigers01"             => 18563,
                         "tigers1"              => 3788,
                         "tigers11"             => 24583,
                         "tigers12"             => 20301,
                         "tigers2"              => 26147,
                         "tigertig"             => 24287,
                         "tigerwoo"             => 10918,
                         "tigerwoods"           => 16774,
                         "tigge"                => 4386,
                         "tigger"               => 44,
                         "tigger01"             => 9823,
                         "tigger1"              => 2611,
                         "tigger11"             => 19141,
                         "tigger12"             => 9363,
                         "tigger13"             => 27934,
                         "tigger2"              => 3708,
                         "tigger3"              => 28171,
                         "tigger69"             => 12504,
                         "tigger99"             => 22739,
                         "tiggers"              => 22477,
                         "tight1"               => 26049,
                         "tightass"             => 10754,
                         "tightend"             => 21426,
                         "tights"               => 2692,
                         "tigran"               => 12571,
                         "tigre"                => 8946,
                         "tigre1"               => 28148,
                         "tigrenok"             => 15021,
                         "tigres"               => 21066,
                         "tigress"              => 9032,
                         "tigris"               => 16910,
                         "tiikeri"              => 26817,
                         "tijger"               => 15933,
                         "tiktak"               => 16048,
                         "tiktonik"             => 21330,
                         "tileman"              => 27883,
                         "tim123"               => 8743,
                         "tima123"              => 29918,
                         "timati"               => 24114,
                         "timber"               => 1014,
                         "timber1"              => 14183,
                         "timberla"             => 18757,
                         "timberland"           => 22622,
                         "timberwo"             => 18288,
                         "timberwolf"           => 20283,
                         "timbo"                => 10763,
                         "timdog"               => 29892,
                         "time1"                => 16719,
                         "time123"              => 27736,
                         "time2go"              => 28326,
                         "timebomb"             => 13553,
                         "timelord"             => 7821,
                         "timeout"              => 4840,
                         "timepass"             => 14830,
                         "timeport"             => 12058,
                         "timewarp"             => 17394,
                         "timex"                => 12031,
                         "timexx"               => 27532,
                         "timmie"               => 12247,
                         "timmy1"               => 8472,
                         "timmy123"             => 20607,
                         "timmys"               => 29890,
                         "timofei"              => 14978,
                         "timofey"              => 14801,
                         "timoha"               => 11410,
                         "timon"                => 14906,
                         "timosha"              => 4968,
                         "timoshka"             => 29232,
                         "timoth"               => 17279,
                         "timoth1"              => 22709,
                         "timothy1"             => 6962,
                         "timoxa"               => 16386,
                         "timoxa94"             => 6606,
                         "timt42"               => 23427,
                         "timur"                => 6868,
                         "tincan"               => 18300,
                         "tinchair"             => 28068,
                         "tincouch"             => 20606,
                         "tincup"               => 11185,
                         "tinfloor"             => 15948,
                         "ting"                 => 3313,
                         "tinhorse"             => 14939,
                         "tinker"               => 565,
                         "tinker1"              => 9055,
                         "tinkerbe"             => 4301,
                         "tinkerbel"            => 13581,
                         "tinkerbell"           => 2915,
                         "tinman"               => 2035,
                         "tinroof"              => 27581,
                         "tintable"             => 21520,
                         "tinti"                => 24301,
                         "tintin"               => 1125,
                         "tinuviel"             => 29704,
                         "tinytim"              => 13759,
                         "tipper"               => 3778,
                         "tippmann"             => 18140,
                         "tippy"                => 7500,
                         "tippy1"               => 10770,
                         "tiptop"               => 7090,
                         "tiramisu"             => 10949,
                         "tiribon12"            => 23130,
                         "tirpitz"              => 23826,
                         "tishka"               => 15161,
                         "tissot"               => 14255,
                         "titan"                => 3872,
                         "titan1"               => 8757,
                         "titan2"               => 27843,
                         "titani"               => 17966,
                         "titania"              => 26269,
                         "titanic"              => 586,
                         "titanic1"             => 9372,
                         "titanik"              => 15187,
                         "titanium"             => 2543,
                         "titans"               => 1133,
                         "titans1"              => 19220,
                         "titfuck"              => 5773,
                         "tities"               => 9843,
                         "titleist"             => 1551,
                         "titlover"             => 9559,
                         "titman"               => 6296,
                         "titmouse"             => 22719,
                         "titone"               => 24323,
                         "titova"               => 20316,
                         "tits"                 => 375,
                         "tits1"                => 17838,
                         "titsnass"             => 11875,
                         "titten"               => 3080,
                         "titti"                => 23260,
                         "titties"              => 2009,
                         "titts"                => 5704,
                         "titty"                => 2744,
                         "tittys"               => 8325,
                         "tivoli"               => 15191,
                         "tiziana"              => 19351,
                         "tiziano"              => 26579,
                         "tk421"                => 15691,
                         "tkachenko"            => 19750,
                         "tkachuk"              => 21916,
                         "tkbpfdtnf"            => 4143,
                         "tkfkdg"               => 7493,
                         "tkfkdgo"              => 9238,
                         "tktyf"                => 22308,
                         "tlaloc"               => 27377,
                         "tlbyjhju"             => 26024,
                         "tm371855"             => 15292,
                         "tmjxn151"             => 14299,
                         "tmoney"               => 11544,
                         "tnt123"               => 25052,
                         "toadfrog"             => 28924,
                         "toadie"               => 19832,
                         "toadman"              => 26464,
                         "toast1"               => 20087,
                         "toaster"              => 3839,
                         "toasty"               => 7199,
                         "tobasco"              => 26553,
                         "tobbie"               => 29041,
                         "tobias1"              => 25914,
                         "toby1"                => 17576,
                         "toby12"               => 25213,
                         "toby22"               => 27517,
                         "tobydog"              => 6405,
                         "toccata"              => 25075,
                         "tocool"               => 28107,
                         "today1"               => 7681,
                         "today2"               => 25134,
                         "todays"               => 19761,
                         "todiefor"             => 23046,
                         "toejam"               => 4105,
                         "toeman"               => 27376,
                         "toenail"              => 15704,
                         "toering"              => 18589,
                         "toffee"               => 4027,
                         "togepi"               => 22346,
                         "toggle"               => 9840,
                         "tokenbad"             => 12242,
                         "tokiohotel"           => 4355,
                         "tokyo1"               => 22588,
                         "tolik"                => 12509,
                         "tolkein"              => 29665,
                         "tolkien"              => 1980,
                         "tolkien1"             => 27708,
                         "tolstoy"              => 11830,
                         "toltec"               => 21052,
                         "tom123"               => 7231,
                         "tom204"               => 24869,
                         "tomahawk"             => 4456,
                         "tomas1"               => 19548,
                         "tomass"               => 26867,
                         "tomat"                => 16525,
                         "tomate"               => 8403,
                         "tomato"               => 2129,
                         "tomato1"              => 19326,
                         "tomatoe"              => 28486,
                         "tomboy"               => 8411,
                         "tombraid"             => 19637,
                         "tombraider"           => 19378,
                         "tombston"             => 13851,
                         "tomcat"               => 338,
                         "tomcat1"              => 12583,
                         "tomcat14"             => 16934,
                         "tomek1"               => 18387,
                         "tomjerry"             => 23282,
                         "tomjones"             => 19208,
                         "tomkat"               => 20360,
                         "tommaso"              => 18397,
                         "tommi"                => 16155,
                         "tommy1"               => 2151,
                         "tommy123"             => 12984,
                         "tommy2"               => 12418,
                         "tommyb"               => 23005,
                         "tommyboy"             => 2461,
                         "tommycat"             => 27108,
                         "tommyd"               => 20097,
                         "tommygun"             => 11688,
                         "tommylee"             => 19645,
                         "tommys"               => 11091,
                         "tommyt"               => 13371,
                         "tommyy"               => 26763,
                         "tomservo"             => 8521,
                         "tomtom1"              => 25827,
                         "tomuch"               => 29551,
                         "tomwaits"             => 16905,
                         "tonchin"              => 24890,
                         "tonedup"              => 16882,
                         "tonino"               => 13787,
                         "tonite"               => 21995,
                         "tonka"                => 8169,
                         "tonka1"               => 21203,
                         "tonna"                => 24586,
                         "tonto"                => 7931,
                         "tonto1"               => 26618,
                         "tontos"               => 27612,
                         "tony1"                => 9839,
                         "tony12"               => 25414,
                         "tony123"              => 13442,
                         "tony22"               => 28529,
                         "tony44"               => 28371,
                         "tony45"               => 25543,
                         "tony69"               => 26711,
                         "tony88"               => 22569,
                         "tony_t"               => 24799,
                         "tonyhawk"             => 8082,
                         "toobad"               => 10308,
                         "toobig"               => 18021,
                         "toocool"              => 5241,
                         "toodles"              => 13026,
                         "toogood"              => 16694,
                         "toohot"               => 7633,
                         "tookie"               => 9946,
                         "tool69"               => 18474,
                         "toolbox"              => 5099,
                         "toolfan"              => 29708,
                         "tooling"              => 22022,
                         "toolman"              => 3256,
                         "toolong"              => 19503,
                         "tools1"               => 23894,
                         "toolshed"             => 11420,
                         "tooltime"             => 8077,
                         "toomuch"              => 5901,
                         "toon"                 => 3205,
                         "toonami"              => 24133,
                         "toonarmy"             => 5141,
                         "toonces"              => 8361,
                         "toonporn"             => 13125,
                         "toons"                => 9360,
                         "toonsex"              => 24210,
                         "toosexy"              => 14757,
                         "tooshort"             => 10441,
                         "toosweet"             => 10831,
                         "tootall"              => 17212,
                         "tooter"               => 12003,
                         "tootie"               => 3630,
                         "tooting"              => 25463,
                         "tootsie"              => 2168,
                         "tootsie1"             => 27914,
                         "topaz"                => 7947,
                         "topaz1"               => 20023,
                         "topazz"               => 29516,
                         "topcat"               => 1756,
                         "topcop"               => 24153,
                         "topdawg"              => 21499,
                         "topdevice"            => 15873,
                         "topdog"               => 1786,
                         "topeka"               => 13323,
                         "topflite"             => 14684,
                         "topfuel"              => 11207,
                         "topgun"               => 365,
                         "topgun1"              => 11600,
                         "tophat"               => 4596,
                         "topher"               => 2531,
                         "toplay"               => 24568,
                         "topman"               => 13805,
                         "topolino"             => 6344,
                         "toppdogg"             => 25714,
                         "topper"               => 1577,
                         "topsecre"             => 8805,
                         "topsecret"            => 6652,
                         "topshelf"             => 28462,
                         "topspin"              => 7479,
                         "topten"               => 23551,
                         "torana"               => 13155,
                         "torben"               => 14651,
                         "torey"                => 15463,
                         "toriamos"             => 4971,
                         "torino"               => 4385,
                         "torito"               => 25739,
                         "tornado"              => 823,
                         "tornado1"             => 12488,
                         "tornados"             => 24029,
                         "tornike"              => 23131,
                         "torock"               => 27262,
                         "toront"               => 18409,
                         "toronto"              => 996,
                         "toronto1"             => 10550,
                         "torrent"              => 7796,
                         "torrente"             => 22639,
                         "torrents"             => 23361,
                         "torres9"              => 28828,
                         "torsten"              => 12458,
                         "tort02"               => 17326,
                         "tortoise"             => 6389,
                         "tortue"               => 19662,
                         "tortuga"              => 7252,
                         "tos8217"              => 23123,
                         "tosca"                => 23471,
                         "toscana"              => 23747,
                         "toshiba"              => 920,
                         "toshiba1"             => 9953,
                         "toshiro"              => 27295,
                         "toshka"               => 29369,
                         "tosser"               => 5040,
                         "totalwar"             => 15931,
                         "totem"                => 12807,
                         "totenkopf"            => 25601,
                         "toto99"               => 23900,
                         "totoro"               => 6261,
                         "tottenha"             => 1231,
                         "tottenham"            => 3188,
                         "totti"                => 24794,
                         "touareg"              => 29141,
                         "toucan"               => 15134,
                         "touchdow"             => 9268,
                         "touchme"              => 10151,
                         "toughguy"             => 11071,
                         "toulouse"             => 7164,
                         "toutoune"             => 21602,
                         "tower1"               => 12851,
                         "towing"               => 11122,
                         "towncar"              => 18471,
                         "towson"               => 19039,
                         "towtruck"             => 21618,
                         "toybox"               => 26540,
                         "toyboy"               => 17997,
                         "toyman"               => 21625,
                         "toyot"                => 12383,
                         "toyota"               => 209,
                         "toyota1"              => 8777,
                         "toyota91"             => 23516,
                         "toystory"             => 18441,
                         "tplate"               => 26031,
                         "tr1993"               => 23324,
                         "trabajo"              => 28544,
                         "trabant"              => 25053,
                         "trace1"               => 27219,
                         "tracer"               => 4914,
                         "tracey1"              => 25125,
                         "track1"               => 19276,
                         "tracker"              => 2900,
                         "tracker1"             => 17032,
                         "tracksta"             => 29672,
                         "tractor"              => 1819,
                         "tracy1"               => 6707,
                         "tracy123"             => 25028,
                         "tracy71"              => 12223,
                         "trademan"             => 17508,
                         "trader"               => 2489,
                         "trader1"              => 19475,
                         "trader12"             => 9968,
                         "trafalga"             => 27751,
                         "traffic1"             => 19410,
                         "trafford"             => 10601,
                         "trailer1"             => 18344,
                         "trailers"             => 7763,
                         "train1"               => 10403,
                         "trainer"              => 3485,
                         "trainman"             => 14954,
                         "trajan"               => 14816,
                         "traktor"              => 6408,
                         "tralala"              => 5738,
                         "tralfaz"              => 15314,
                         "trample"              => 6158,
                         "trance"               => 1440,
                         "tranmere"             => 13174,
                         "tranny"               => 4167,
                         "tranquil"             => 22518,
                         "trans1"               => 29649,
                         "transalp"             => 29869,
                         "transam"              => 915,
                         "transam1"             => 10995,
                         "transcend"            => 24539,
                         "transexual"           => 7293,
                         "transfor"             => 9042,
                         "transits"             => 28248,
                         "translator"           => 2427,
                         "transpor"             => 11792,
                         "trantor"              => 21371,
                         "tranzit"              => 22107,
                         "trapdoor"             => 17238,
                         "trapper"              => 2871,
                         "trash1"               => 19583,
                         "trashman"             => 10209,
                         "tratata"              => 11985,
                         "travail"              => 29118,
                         "travel"               => 953,
                         "travel1"              => 17726,
                         "traveler"             => 2756,
                         "travelle"             => 10876,
                         "travesti"             => 13006,
                         "travi"                => 14947,
                         "travis1"              => 5647,
                         "travka"               => 29997,
                         "travolta"             => 15842,
                         "traxdata"             => 24962,
                         "traxxas"              => 24341,
                         "treacle"              => 10134,
                         "treasure"             => 2098,
                         "trebla"               => 22976,
                         "treble"               => 5798,
                         "trebor"               => 1513,
                         "tree1"                => 23756,
                         "tree123"              => 28428,
                         "treech"               => 29714,
                         "treefrog"             => 5536,
                         "treehous"             => 19455,
                         "treeman"              => 12621,
                         "trees1"               => 20619,
                         "treess"               => 19032,
                         "treetop"              => 5569,
                         "treetops"             => 12960,
                         "trek"                 => 5890,
                         "trekbike"             => 25618,
                         "trekker"              => 8380,
                         "trekkie"              => 14415,
                         "tremendo"             => 28757,
                         "tremere"              => 10855,
                         "trento"               => 20952,
                         "tresor"               => 24286,
                         "trevo"                => 19481,
                         "trevoga"              => 24820,
                         "trevon"               => 28322,
                         "trevor1"              => 12553,
                         "trfnthby"             => 26710,
                         "trfnthbyf"            => 965,
                         "tri5a3"               => 17340,
                         "triada"               => 24877,
                         "trial1"               => 12131,
                         "triangle"             => 2788,
                         "triathlo"             => 23452,
                         "tribbles"             => 15234,
                         "tribe1"               => 12682,
                         "trick1"               => 28943,
                         "trickle"              => 12893,
                         "tricky"               => 1749,
                         "tricky1"              => 19754,
                         "tricolor"             => 21027,
                         "trident"              => 2311,
                         "trident1"             => 21579,
                         "triforce"             => 13873,
                         "trigger"              => 871,
                         "trigger1"             => 10640,
                         "trigger2"             => 27361,
                         "trigun"               => 6055,
                         "trill"                => 27419,
                         "trillian"             => 15450,
                         "trillium"             => 26904,
                         "trim7gun"             => 25137,
                         "trinit"               => 16215,
                         "triniti"              => 20669,
                         "trinitro"             => 4504,
                         "trinitron"            => 6012,
                         "trinity"              => 353,
                         "trinity1"             => 5394,
                         "trinity3"             => 15572,
                         "trinity7"             => 27273,
                         "trinket"              => 10456,
                         "tripleh"              => 5202,
                         "triplet"              => 23536,
                         "triplets"             => 7903,
                         "triplex"              => 6098,
                         "tripod"               => 3559,
                         "tripper"              => 3692,
                         "trippy"               => 14148,
                         "trish1"               => 26076,
                         "tristan1"             => 9780,
                         "tristar"              => 9532,
                         "triste"               => 19921,
                         "tristen"              => 11824,
                         "triston"              => 26731,
                         "tristram"             => 18675,
                         "triton"               => 1880,
                         "triton1"              => 26285,
                         "triumph"              => 1024,
                         "triumph1"             => 14160,
                         "trivia"               => 8960,
                         "trivium"              => 21558,
                         "trixi"                => 28751,
                         "trixie"               => 1093,
                         "trixie1"              => 26461,
                         "trogdor"              => 12536,
                         "troika"               => 22130,
                         "trojan"               => 1085,
                         "trojan1"              => 18558,
                         "trojans"              => 1883,
                         "trojans1"             => 8825,
                         "troll"                => 4335,
                         "troll1"               => 29092,
                         "trololo"              => 17594,
                         "trombone"             => 1124,
                         "trompete"             => 25393,
                         "tronic"               => 24467,
                         "trooper"              => 776,
                         "trooper1"             => 5832,
                         "trooper2"             => 22525,
                         "troopers"             => 11250,
                         "tropic"               => 12081,
                         "trotsky"              => 11626,
                         "trotters"             => 25163,
                         "trouble"              => 301,
                         "trouble1"             => 4246,
                         "trouble2"             => 20803,
                         "trousers"             => 7477,
                         "trout1"               => 6670,
                         "troutbum"             => 26971,
                         "trouts"               => 10975,
                         "troyboy"              => 17707,
                         "trrim777"             => 28376,
                         "trs8f7"               => 13763,
                         "trstno1"              => 15317,
                         "truck"                => 1135,
                         "truck1"               => 7029,
                         "truck2"               => 20106,
                         "trucker"              => 941,
                         "trucker1"             => 8644,
                         "truckers"             => 10554,
                         "truckin"              => 9199,
                         "trucking"             => 4678,
                         "truckman"             => 19527,
                         "trucks"               => 820,
                         "trueblue"             => 6250,
                         "truegrit"             => 24825,
                         "truelov"              => 25961,
                         "truelove"             => 1978,
                         "trueno"               => 22705,
                         "truffle"              => 10019,
                         "truffles"             => 6971,
                         "truls"                => 19289,
                         "trumpet"              => 972,
                         "trumpet1"             => 5521,
                         "trunks"               => 1184,
                         "trunks1"              => 28395,
                         "truskawka"            => 25781,
                         "trust1"               => 9957,
                         "trustme"              => 5439,
                         "trustn01"             => 9528,
                         "trustno"              => 5609,
                         "trustno1"             => 36,
                         "trustnoo"             => 13757,
                         "trustnoone"           => 11036,
                         "truth1"               => 16804,
                         "tryagain"             => 8333,
                         "trythis"              => 18526,
                         "tsalagi"              => 26963,
                         "tsmith"               => 25729,
                         "tsubasa"              => 23025,
                         "tsunami"              => 2143,
                         "tsunami1"             => 26586,
                         "tsv1860"              => 18181,
                         "ttocs"                => 22123,
                         "ttttt1"               => 15542,
                         "tttttt1"              => 15732,
                         "tttttt99"             => 26521,
                         "ttttttt1"             => 24609,
                         "tu190022"             => 28444,
                         "tubaman"              => 21100,
                         "tubby1"               => 27935,
                         "tubgtn"               => 26888,
                         "tubitzen"             => 14219,
                         "tuborg"               => 9911,
                         "tucke"                => 24913,
                         "tucker1"              => 8792,
                         "tucson"               => 6198,
                         "tuczno18"             => 15647,
                         "tuesday"              => 1835,
                         "tuesday1"             => 20267,
                         "tuesday2"             => 29710,
                         "tuffgong"             => 29461,
                         "tuffguy"              => 19007,
                         "tuffy"                => 9468,
                         "tuffy1"               => 16288,
                         "tugboat"              => 7136,
                         "tugger"               => 10237,
                         "tujazopi"             => 15186,
                         "tujheirf"             => 15630,
                         "tujhjdf"              => 20000,
                         "tujhrf"               => 5755,
                         "tulane"               => 8159,
                         "tulip"                => 7318,
                         "tulipan"              => 25733,
                         "tulips"               => 3164,
                         "tulpan"               => 27090,
                         "tumadre"              => 22145,
                         "tummybed"             => 29507,
                         "tunafish"             => 2422,
                         "tundra"               => 2191,
                         "tuning"               => 3761,
                         "tupac"                => 4820,
                         "tupac1"               => 19720,
                         "tupacshakur"          => 25419,
                         "tupelo"               => 10066,
                         "tuppence"             => 23020,
                         "turambar"             => 24085,
                         "turandot"             => 19683,
                         "turbo"                => 1153,
                         "turbo1"               => 2573,
                         "turbo2"               => 14331,
                         "turbo6"               => 29349,
                         "turbo911"             => 24912,
                         "turbodog"             => 17234,
                         "turbos"               => 6086,
                         "turbot"               => 23557,
                         "turga"                => 28798,
                         "turismo"              => 15308,
                         "turk182"              => 7767,
                         "turkey"               => 653,
                         "turkey1"              => 12173,
                         "turkey50"             => 2146,
                         "turkiye"              => 21099,
                         "turnb"                => 21329,
                         "turner1"              => 28417,
                         "turnip"               => 4821,
                         "turntabl"             => 28469,
                         "turtl"                => 25204,
                         "turtle"               => 241,
                         "turtle1"              => 7624,
                         "turtle2"              => 28936,
                         "turtles"              => 6383,
                         "turtoise"             => 18302,
                         "tuscan"               => 12897,
                         "tuscl"                => 5442,
                         "tusymo"               => 16563,
                         "tuxedo"               => 6096,
                         "tv612se"              => 23994,
                         "tvxtjk7r"             => 16459,
                         "tweaker"              => 23773,
                         "tweeker"              => 12912,
                         "tweet"                => 10551,
                         "tweeter"              => 12744,
                         "tweety"               => 654,
                         "tweety1"              => 15313,
                         "twenty1"              => 22178,
                         "twenty2"              => 27675,
                         "twentyon"             => 29964,
                         "twice2"               => 17988,
                         "twiddle"              => 23409,
                         "twiggy"               => 4617,
                         "twilight"             => 1302,
                         "twinboys"             => 16336,
                         "twincam"              => 26577,
                         "twingo"               => 10692,
                         "twink"                => 21484,
                         "twinkie"              => 5201,
                         "twinkle"              => 2720,
                         "twinkles"             => 21880,
                         "twinky"               => 18094,
                         "twins1"               => 19839,
                         "twins2"               => 7858,
                         "twinss"               => 20289,
                         "twinturb"             => 26119,
                         "twinz"                => 15930,
                         "twista"               => 21701,
                         "twisted"              => 2163,
                         "twisted1"             => 12954,
                         "twister"              => 1262,
                         "twisters"             => 17750,
                         "twisty"               => 16558,
                         "twistys"              => 25072,
                         "twiztid"              => 9677,
                         "twizzler"             => 21297,
                         "twocats"              => 15357,
                         "twodogs"              => 9419,
                         "twogirls"             => 17687,
                         "twolves"              => 22217,
                         "twoone"               => 21762,
                         "twopac"               => 18245,
                         "twostep"              => 8484,
                         "twothree"             => 29088,
                         "twotone"              => 25577,
                         "tycobb"               => 14699,
                         "tycoon"               => 5334,
                         "tyghbn"               => 18972,
                         "tyler1"               => 2161,
                         "tyler123"             => 11756,
                         "tyler2"               => 12295,
                         "tylerb"               => 20281,
                         "tylerd"               => 25041,
                         "tylerj"               => 23392,
                         "tylers"               => 8709,
                         "type40"               => 14586,
                         "typhon"               => 28230,
                         "typhoon"              => 2364,
                         "tyrant"               => 6583,
                         "tyrese"               => 28457,
                         "tyrik123"             => 16514,
                         "tyrone1"              => 29987,
                         "tyson1"               => 5248,
                         "tyson123"             => 26083,
                         "tysons"               => 20743,
                         "tyvugq"               => 11154,
                         "tzpvaw"               => 11198,
                         "u23456"               => 29083,
                         "u4slpwra"             => 19778,
                         "uaeuaeman"            => 25656,
                         "ub6ib9"               => 8540,
                         "ubique"               => 22113,
                         "ublhjgjybrf"          => 29623,
                         "ubnfhf"               => 9947,
                         "ubvyfpbz"             => 19498,
                         "ucht36"               => 29285,
                         "uconn"                => 18870,
                         "udacha"               => 7616,
                         "udbwsk"               => 12430,
                         "udders"               => 24976,
                         "ue8fpw"               => 17869,
                         "uekmyfhf"             => 18931,
                         "ueptkm"               => 27425,
                         "ufdibyjd"             => 24695,
                         "ufgyndmv"             => 19555,
                         "ufhhbgjnnth"          => 21215,
                         "ufhvjybz"             => 8830,
                         "ufkbyf"               => 2636,
                         "ufkfrnbrf"            => 16021,
                         "ufkjxrf"              => 26235,
                         "ufkxjyjr"             => 29848,
                         "ufyljy"               => 18502,
                         "ugejvp"               => 12804,
                         "uhbujhbq"             => 8435,
                         "uhbyuj"               => 12629,
                         "uhfdbwfgf"            => 27539,
                         "uhfvjnf"              => 20253,
                         "uhjpysq"              => 29073,
                         "uhtqneyu"             => 25104,
                         "uiegu451"             => 16977,
                         "ujhijr"               => 21048,
                         "ujhjl312"             => 25920,
                         "ujkjdf"               => 20931,
                         "ujkjdjkjvrf"          => 19346,
                         "ujnbrf"               => 22499,
                         "ujujkm"               => 20929,
                         "ukflbfnjh"            => 13177,
                         "ukflbjkec"            => 11270,
                         "ukqmwhj6"             => 27604,
                         "ukraina"              => 10163,
                         "ukrnet"               => 26906,
                         "uliana"               => 22468,
                         "ulises"               => 17949,
                         "ulisse"               => 11969,
                         "ultima"               => 2052,
                         "ultimate"             => 1075,
                         "ultimo"               => 17809,
                         "ultra"                => 4009,
                         "ultra1"               => 13476,
                         "ultra123"             => 25293,
                         "ultraman"             => 8940,
                         "ultras"               => 9552,
                         "ulugbek"              => 19586,
                         "ulyana"               => 23040,
                         "ulysse"               => 11255,
                         "umberto"              => 13280,
                         "umbrella"             => 2373,
                         "ummagumma"            => 26885,
                         "umpire"               => 4360,
                         "unb4g9ty"             => 22243,
                         "uncencored"           => 7803,
                         "unclebob"             => 23389,
                         "unclesam"             => 22218,
                         "undead"               => 4262,
                         "under1"               => 27019,
                         "underdog"             => 2388,
                         "undergro"             => 14234,
                         "underhil"             => 25527,
                         "undernet"             => 26564,
                         "underpar"             => 13523,
                         "undertak"             => 4066,
                         "undertaker"           => 2500,
                         "undertow"             => 7285,
                         "underwat"             => 21975,
                         "underwoo"             => 15932,
                         "underwor"             => 16083,
                         "unforgiv"             => 19798,
                         "unforgiven"           => 15150,
                         "unicor"               => 18453,
                         "unicorn"              => 860,
                         "unicorn1"             => 8175,
                         "uniden"               => 12262,
                         "union1"               => 24204,
                         "united1"              => 8556,
                         "united99"             => 28331,
                         "univer"               => 18788,
                         "univers"              => 18910,
                         "universa"             => 4810,
                         "universi"             => 8921,
                         "unknown1"             => 17163,
                         "unlimite"             => 17316,
                         "unreal"               => 1203,
                         "up9x8rww"             => 21399,
                         "updown"               => 11928,
                         "upiter"               => 29813,
                         "upnfmc"               => 11553,
                         "upskirt"              => 28766,
                         "upsman"               => 23041,
                         "uptheass"             => 27144,
                         "uptown"               => 5660,
                         "upupa68"              => 20178,
                         "upyours"              => 4194,
                         "uranus"               => 3792,
                         "urchin"               => 14174,
                         "urlacher"             => 20018,
                         "urlaub"               => 7543,
                         "ursitesux"            => 7515,
                         "usa123"               => 1704,
                         "usagi"                => 29526,
                         "usarmy"               => 2825,
                         "user1"                => 14697,
                         "user123"              => 24955,
                         "user345"              => 9205,
                         "usermane"             => 27919,
                         "username"             => 4211,
                         "usethis1"             => 21839,
                         "usmarine"             => 5844,
                         "usmc"                 => 2406,
                         "usmc01"               => 28699,
                         "usmc0311"             => 8943,
                         "usmc1"                => 25560,
                         "usmc1775"             => 11651,
                         "usmc69"               => 15973,
                         "usnavy"               => 2593,
                         "usopen"               => 24046,
                         "usuckballz1"          => 545,
                         "utahjazz"             => 7895,
                         "utfp5e"               => 19656,
                         "uthvfy"               => 17219,
                         "uthvfybz"             => 27796,
                         "utjhubq"              => 6569,
                         "utjuhfabz"            => 18232,
                         "utjvtnhbz"            => 15192,
                         "uto29321"             => 21708,
                         "utopia"               => 2107,
                         "utvols"               => 10454,
                         "utyyflbq"             => 12221,
                         "uuuuu1"               => 17143,
                         "uuuuuu1"              => 23030,
                         "uuuuuuu1"             => 24509,
                         "uvdwgt"               => 20053,
                         "uvmrysez"             => 18858,
                         "uwrl7c"               => 12875,
                         "uyxnyd"               => 13578,
                         "uzumaki"              => 13257,
                         "uzumymw"              => 8774,
                         "v00d00"               => 25754,
                         "v12345"               => 14494,
                         "v123456"              => 15094,
                         "v123456789"           => 27800,
                         "v2jmsz"               => 18239,
                         "v55555"               => 27525,
                         "va2001"               => 26544,
                         "vacation"             => 1522,
                         "vader"                => 1694,
                         "vader1"               => 4318,
                         "vader123"             => 26192,
                         "vaders"               => 23607,
                         "vadim"                => 3385,
                         "vadimka"              => 9324,
                         "vaduz"                => 26781,
                         "vaffanculo"           => 26331,
                         "vagabond"             => 5245,
                         "vagina"               => 736,
                         "vagner"               => 17440,
                         "vakantie"             => 24981,
                         "valdemar"             => 10285,
                         "valdepen"             => 9495,
                         "valenci"              => 20918,
                         "valenok"              => 24353,
                         "valentin"             => 590,
                         "valentina"            => 869,
                         "valera"               => 974,
                         "valeria1"             => 26412,
                         "valerie1"             => 11435,
                         "valerik"              => 22985,
                         "valeriy"              => 15985,
                         "valeriya"             => 6175,
                         "valerka"              => 13974,
                         "valhalla"             => 1797,
                         "valheru"              => 17213,
                         "valjean"              => 15570,
                         "valkiria"             => 22886,
                         "valkyrie"             => 3022,
                         "valley1"              => 23018,
                         "valleywa"             => 6751,
                         "valmet"               => 25893,
                         "valter"               => 14075,
                         "vampir"               => 4837,
                         "vampire"              => 403,
                         "vampire1"             => 5707,
                         "vampiro"              => 13823,
                         "vampyr"               => 19363,
                         "vampyre"              => 9929,
                         "vancouve"             => 5132,
                         "vandal"               => 7908,
                         "vandam"               => 12937,
                         "vandamme"             => 17497,
                         "vander"               => 11191,
                         "vanechka"             => 19237,
                         "vanes"                => 20299,
                         "vaness"               => 7118,
                         "vanessa1"             => 5011,
                         "vangar"               => 22170,
                         "vangelis"             => 24411,
                         "vangogh"              => 7907,
                         "vanguard"             => 3765,
                         "vanhalen"             => 1304,
                         "vanill"               => 24622,
                         "vanilla"              => 1670,
                         "vanilla1"             => 19776,
                         "vanille"              => 12819,
                         "vanman"               => 14869,
                         "vannasx"              => 26932,
                         "vantage"              => 6489,
                         "vanya"                => 22405,
                         "vanyarespekt"         => 11955,
                         "varadero"             => 16458,
                         "varsha"               => 25953,
                         "varvara"              => 3756,
                         "vaseline"             => 8372,
                         "vasile"               => 23662,
                         "vasilek"              => 12866,
                         "vasileva"             => 13505,
                         "vasili"               => 18776,
                         "vasilii"              => 11916,
                         "vasilina"             => 21443,
                         "vasilisa"             => 3227,
                         "vasilisk"             => 23144,
                         "vasiliy"              => 7877,
                         "vassago"              => 23424,
                         "vasya"                => 11119,
                         "vatech"               => 13095,
                         "vatoloco"             => 10317,
                         "vauxhall"             => 5085,
                         "vavilon"              => 12006,
                         "vaz2101"              => 20700,
                         "vaz2105"              => 29706,
                         "vaz2106"              => 15923,
                         "vaz2107"              => 12649,
                         "vaz21074"             => 28661,
                         "vaz2108"              => 17074,
                         "vaz2109"              => 13393,
                         "vaz21093"             => 21577,
                         "vaz21099"             => 10775,
                         "vaz2110"              => 18333,
                         "vaz2114"              => 25220,
                         "vaz2115"              => 24213,
                         "vball"                => 14607,
                         "vbhevbh"              => 7872,
                         "vbhjckfd"             => 29740,
                         "vbhjckfdf"            => 17384,
                         "vbhjh123"             => 28741,
                         "vbhjndjhtw"           => 29531,
                         "vbienrf"              => 6696,
                         "vbifyz"               => 7212,
                         "vbitkm"               => 26302,
                         "vbitymrf"             => 18134,
                         "vbkbwbz"              => 10127,
                         "vbkfirf"              => 5004,
                         "vbkfyf"               => 9994,
                         "vbkkbjy"              => 24289,
                         "vbktyf"               => 11746,
                         "vbnhjafy"             => 24254,
                         "vbnmrf"               => 19397,
                         "vbrjkf"               => 14260,
                         "vcradq"               => 13700,
                         "vdlxuc"               => 14660,
                         "vecmrf"               => 15698,
                         "vector"               => 2482,
                         "vectra"               => 1753,
                         "vedder"               => 3069,
                         "veedub"               => 15552,
                         "vegas1"               => 6924,
                         "vegas123"             => 8582,
                         "veget"                => 27298,
                         "vegeta"               => 641,
                         "vegeta1"              => 29857,
                         "vegita"               => 9246,
                         "vegitta"              => 6484,
                         "vegitto"              => 5889,
                         "vehpbkrf"             => 12447,
                         "vehpbr"               => 4859,
                         "vehvfycr"             => 28911,
                         "vehxbr"               => 25520,
                         "vekmnbr"              => 17443,
                         "velcro"               => 10177,
                         "veloce"               => 22657,
                         "velosiped"            => 22685,
                         "velvet"               => 1278,
                         "vendetta"             => 4523,
                         "venera"               => 3063,
                         "venezuel"             => 9524,
                         "vengence"             => 20846,
                         "venkat"               => 12562,
                         "venom"                => 5535,
                         "venom1"               => 20428,
                         "venom121293"          => 11739,
                         "venom123"             => 24757,
                         "ventrue"              => 17278,
                         "ventura1"             => 24686,
                         "venture1"             => 28591,
                         "venus1"               => 10103,
                         "vepsrf"               => 8228,
                         "vepsrfyn"             => 29546,
                         "verbati"              => 27163,
                         "verbatim"             => 1248,
                         "verboten"             => 22161,
                         "verdun"               => 12241,
                         "verga"                => 15640,
                         "vergesse"             => 25092,
                         "vergeten"             => 9151,
                         "vergil"               => 29053,
                         "veritas"              => 1690,
                         "veritas1"             => 19680,
                         "veritech"             => 12967,
                         "verity"               => 10872,
                         "verizon"              => 3593,
                         "verizon1"             => 12055,
                         "verlaat"              => 22948,
                         "vermont"              => 2354,
                         "vermont1"             => 10617,
                         "vernost"              => 28823,
                         "verochka"             => 19957,
                         "veronda"              => 24995,
                         "veronic"              => 7581,
                         "veronik"              => 21818,
                         "veronika"             => 872,
                         "veroniqu"             => 20056,
                         "versace"              => 4057,
                         "vertigo"              => 1492,
                         "very1"                => 19560,
                         "verycool"             => 14779,
                         "verygood"             => 7856,
                         "verygoodbot"          => 15116,
                         "veryhot"              => 17613,
                         "verymuch"             => 26133,
                         "verynice"             => 18020,
                         "verysexy"             => 20452,
                         "vespa"                => 13420,
                         "vesper"               => 9551,
                         "vespucci"             => 27347,
                         "vestax"               => 11818,
                         "vetalik"              => 21343,
                         "veterok"              => 18703,
                         "vette"                => 1863,
                         "vette1"               => 7428,
                         "vetteman"             => 16460,
                         "vettes"               => 17689,
                         "vfcmrf"               => 27112,
                         "vfcnth"               => 6748,
                         "vfczyz"               => 2182,
                         "vfdhif"               => 22216,
                         "vfhbfyyf"             => 18681,
                         "vfhbif"               => 15023,
                         "vfhbirf"              => 7764,
                         "vfhbyf"               => 526,
                         "vfhbyfvfhbyf"         => 26826,
                         "vfhbyjxrf"            => 7111,
                         "vfhbyrf"              => 9438,
                         "vfhcbr"               => 12919,
                         "vfhctkm"              => 15355,
                         "vfhecmrf"             => 15064,
                         "vfhecz"               => 1530,
                         "vfhfnbr"              => 29587,
                         "vfhnby"               => 20242,
                         "vfhnbyb"              => 15253,
                         "vfhnsirf"             => 7537,
                         "vfhnsyjdf"            => 25867,
                         "vfhrbp"               => 10838,
                         "vfhrbpf"              => 16642,
                         "vfhufhbnf"            => 2465,
                         "vfhufhbnrf"           => 18489,
                         "vfhujif"              => 6578,
                         "vfhvtkfl"             => 11212,
                         "vfhvtkflrf"           => 20461,
                         "vfibyf"               => 3752,
                         "vfiekmrf"             => 21620,
                         "vfiekz"               => 10856,
                         "vfif123"              => 24871,
                         "vfitymrf"             => 3730,
                         "vfkbyf"               => 8261,
                         "vfkbyrf"              => 14555,
                         "vfkmdbyf"             => 12990,
                         "vfksirf"              => 2227,
                         "vfktymrfz"            => 21082,
                         "vflfufcrfh"           => 6936,
                         "vfnbkmlf"             => 8718,
                         "vfndtq"               => 5744,
                         "vfnehsv"              => 23462,
                         "vfnhbwf"              => 10811,
                         "vfnhjcrby"            => 18331,
                         "vfntvfnbrf"           => 5393,
                         "vfpfafrf"             => 7413,
                         "vfr750"               => 9144,
                         "vfr800"               => 20656,
                         "vfrcbr"               => 14027,
                         "vfrcbv"               => 649,
                         "vfrcbv123"            => 16238,
                         "vfrcbvec"             => 11009,
                         "vfrcbvev"             => 21198,
                         "vfrcbvjd"             => 25257,
                         "vfrcbvjdf"            => 20419,
                         "vfrcbvrf"             => 1864,
                         "vfrcbvvfrcbv"         => 24656,
                         "vfrfhjd"              => 27776,
                         "vfrfhjdf"             => 14114,
                         "vfrfhjys"             => 12690,
                         "vfrfrf"               => 15148,
                         "vfuflfy"              => 23096,
                         "vfufpby"              => 28805,
                         "vfuyjkbz"             => 18295,
                         "vfvekbxrf"            => 18482,
                         "vfvekmrf"             => 29907,
                         "vfvektxrf"            => 17575,
                         "vfvekz"               => 2179,
                         "vfvf12"               => 27804,
                         "vfvf123"              => 11744,
                         "vfvf2011"             => 21829,
                         "vfvfbgfgf"            => 11813,
                         "vfvfgfgf"             => 2664,
                         "vfvfgfgf123"          => 23108,
                         "vfvfgfgfz"            => 13122,
                         "vfvfktyf"             => 21311,
                         "vfvfvskfhfve"         => 9618,
                         "vfvjxrf"              => 1132,
                         "vfvjyn"               => 24606,
                         "vfylfhby"             => 8437,
                         "vfylfhbyrf"           => 15336,
                         "vfyxtcnth"            => 22882,
                         "vg08k714"             => 17189,
                         "vgfun2"               => 27353,
                         "vgfun4"               => 17013,
                         "vgfun8"               => 19890,
                         "vgirl"                => 7022,
                         "vh5150"               => 2460,
                         "vhou812"              => 19698,
                         "viagra"               => 2323,
                         "vialli"               => 17266,
                         "viborg"               => 20451,
                         "vibrate"              => 8143,
                         "vibrator"             => 11841,
                         "vicecity"             => 9348,
                         "vicelord"             => 29427,
                         "vicki1"               => 12136,
                         "vicky1"               => 14992,
                         "victo"                => 9039,
                         "victoire"             => 17130,
                         "victor1"              => 8656,
                         "victori"              => 5981,
                         "victoria1"            => 11714,
                         "victoriya"            => 28207,
                         "victory"              => 648,
                         "victory1"             => 6842,
                         "victory7"             => 27956,
                         "vid2600"              => 21651,
                         "vidadi1"              => 20020,
                         "video1"               => 5762,
                         "videoes"              => 7727,
                         "videogam"             => 23405,
                         "videoman"             => 23992,
                         "vides"                => 6163,
                         "viewsoni"             => 4388,
                         "viewsonic"            => 2511,
                         "viggen"               => 18842,
                         "vika123"              => 11466,
                         "vika1995"             => 26949,
                         "vika1996"             => 21895,
                         "vika1998"             => 21755,
                         "vika2010"             => 19264,
                         "vika2011"             => 22939,
                         "vikes"                => 28991,
                         "vikin"                => 28845,
                         "viking"               => 243,
                         "viking1"              => 7773,
                         "vikings"              => 513,
                         "vikings1"             => 3916,
                         "vikings2"             => 28981,
                         "viktor"               => 791,
                         "viktori"              => 15062,
                         "viktoria"             => 1792,
                         "viktorija"            => 16382,
                         "viktoriy"             => 14486,
                         "viktoriya"            => 3918,
                         "viktory"              => 24578,
                         "villa1"               => 15854,
                         "villan"               => 21710,
                         "villevalo"            => 24901,
                         "vinbylrj"             => 20828,
                         "vincen"               => 9805,
                         "vincent1"             => 4830,
                         "vinicius"             => 26274,
                         "vinny"                => 12532,
                         "vinny1"               => 21514,
                         "vinograd"             => 19262,
                         "vintage"              => 4118,
                         "vintelok"             => 21537,
                         "vinter"               => 19432,
                         "violator"             => 7275,
                         "violentj"             => 26937,
                         "violet1"              => 21992,
                         "violetta"             => 3479,
                         "violin"               => 3680,
                         "violin1"              => 28939,
                         "vip123"               => 18913,
                         "viper"                => 446,
                         "viper01"              => 26282,
                         "viper1"               => 1433,
                         "viper12"              => 25192,
                         "viper123"             => 9465,
                         "viper2"               => 14175,
                         "viper69"              => 24608,
                         "viper7"               => 23149,
                         "viper9"               => 18524,
                         "viper99"              => 20727,
                         "vipergts"             => 5341,
                         "viperman"             => 21235,
                         "vipers"               => 1921,
                         "virago"               => 6469,
                         "virgin"               => 1053,
                         "virgin1"              => 21462,
                         "virgini"              => 8035,
                         "virginie"             => 5674,
                         "virgo"                => 6944,
                         "virgo1"               => 12858,
                         "virgos"               => 27338,
                         "virtua"               => 10635,
                         "virtuagirl"           => 19675,
                         "virus1"               => 17630,
                         "visa"                 => 3942,
                         "vishal"               => 24891,
                         "vishenka"             => 19371,
                         "visigoth"             => 26011,
                         "vision"               => 613,
                         "vision1"              => 13819,
                         "visionar"             => 28942,
                         "vitae"                => 16937,
                         "vitali"               => 12791,
                         "vitalik"              => 2196,
                         "vitalik1"             => 25479,
                         "vitalina"             => 18766,
                         "vitaliy"              => 9777,
                         "vitalogy"             => 28951,
                         "vitaly"               => 14702,
                         "vitalya"              => 13638,
                         "vitamin"              => 4611,
                         "vitamine"             => 29213,
                         "vitara"               => 14714,
                         "vitesse"              => 14490,
                         "vittoria"             => 13875,
                         "vittorio"             => 9942,
                         "vivahate"             => 16446,
                         "vivaldi"              => 8284,
                         "vivia"                => 25853,
                         "viviane"              => 16571,
                         "vivid"                => 7082,
                         "vivitron"             => 7183,
                         "vixen"                => 6800,
                         "vixens"               => 15952,
                         "vjcrdf"               => 3985,
                         "vjhjpjdf"             => 13849,
                         "vjhrjdrf"             => 11081,
                         "vjkjltw"              => 11994,
                         "vjkjrj"               => 4977,
                         "vjnjhjkf"             => 22048,
                         "vjqgfhjkm"            => 4575,
                         "vjqvbh"               => 28598,
                         "vjybnjh"              => 13776,
                         "vjzctvmz"             => 15232,
                         "vjzgjxnf"             => 14698,
                         "vkaxcs"               => 13443,
                         "vkfwx046"             => 28534,
                         "vkontakte"            => 1868,
                         "vlad"                 => 4875,
                         "vlad123"              => 24510,
                         "vlad1234"             => 25460,
                         "vlad1994"             => 22315,
                         "vlad1995"             => 16752,
                         "vlad1996"             => 10064,
                         "vlad1997"             => 12358,
                         "vlad1998"             => 18990,
                         "vlad2011"             => 29128,
                         "vlad777"              => 23070,
                         "vlad7788"             => 13520,
                         "vlada"                => 27345,
                         "vladik"               => 1862,
                         "vladimi"              => 22472,
                         "vladimir"             => 528,
                         "vladimir1"            => 24802,
                         "vladimirovna"         => 27795,
                         "vladislav"            => 2067,
                         "vladislava"           => 19333,
                         "vladvlad"             => 9122,
                         "vlasov"               => 17489,
                         "vlasova"              => 23009,
                         "vodafone"             => 6745,
                         "vodka1"               => 19347,
                         "vodolei"              => 17679,
                         "vodoley"              => 11574,
                         "voetbal"              => 10791,
                         "voiture"              => 9261,
                         "voivod"               => 25241,
                         "voland"               => 8902,
                         "volante"              => 24895,
                         "volcom"               => 3681,
                         "volcom1"              => 16644,
                         "voldemar"             => 17551,
                         "volgograd"            => 17926,
                         "volition"             => 13133,
                         "volkodav"             => 8227,
                         "volkov"               => 4910,
                         "volkova"              => 8601,
                         "volkswag"             => 4250,
                         "volkswagen"           => 7980,
                         "volley"               => 2152,
                         "volleyba"             => 5601,
                         "volodia"              => 26657,
                         "volodin"              => 9995,
                         "volodya"              => 9318,
                         "vologda"              => 12464,
                         "voltaire"             => 10022,
                         "voltron"              => 7323,
                         "voluntee"             => 15269,
                         "volvo"                => 2757,
                         "volvo1"               => 6465,
                         "volvo240"             => 19850,
                         "volvo850"             => 16077,
                         "volvos"               => 13884,
                         "volvos40"             => 16108,
                         "volvos60"             => 29137,
                         "volvos80"             => 17511,
                         "volvov70"             => 19374,
                         "vonnegut"             => 11579,
                         "voodoo"               => 299,
                         "voodoo1"              => 8737,
                         "voodoo2"              => 16126,
                         "vorlon"               => 7735,
                         "vorobey"              => 20401,
                         "vorona"               => 7481,
                         "voronin"              => 22611,
                         "voronina"             => 24058,
                         "vorpal"               => 19456,
                         "vortec"               => 16256,
                         "vortex"               => 1931,
                         "voshod"               => 28078,
                         "vostok"               => 9678,
                         "vova123"              => 12760,
                         "vova12345"            => 24814,
                         "vova1992"             => 29583,
                         "vova1994"             => 26436,
                         "vovan"                => 27081,
                         "vovan_lt"             => 29637,
                         "vovchik"              => 14158,
                         "vovochka"             => 16346,
                         "voyager"              => 347,
                         "voyager1"             => 4507,
                         "voyager2"             => 18698,
                         "voyeur"               => 2221,
                         "vp6y38"               => 15665,
                         "vpmfsz"               => 14922,
                         "vqsablpzla"           => 5189,
                         "vredina"              => 11609,
                         "vsajyjr"              => 29731,
                         "vsegda"               => 3700,
                         "vsevolod"             => 14335,
                         "vsijyjr"              => 10961,
                         "vsjasnel12"           => 3564,
                         "vsythb"               => 29021,
                         "vthctltc"             => 9570,
                         "vthokies"             => 29532,
                         "vthrehbq"             => 27174,
                         "vtkmybr"              => 22583,
                         "vtkrbq"               => 19106,
                         "vtldtlm"              => 7623,
                         "vtldtltd"             => 28575,
                         "vtufajy"              => 20259,
                         "vtufgjkbc"            => 17555,
                         "vulcan"               => 1734,
                         "vulture"              => 10372,
                         "vulva"                => 7282,
                         "vurdf5i2"             => 24191,
                         "vvvbbb"               => 15146,
                         "vvvvv1"               => 14068,
                         "vvvvvv1"              => 20610,
                         "vw198m2n"             => 14957,
                         "vwgolf"               => 8847,
                         "vwjetta"              => 15559,
                         "vwpassat"             => 26630,
                         "vyjujnjxbt"           => 12395,
                         "w00t88"               => 7364,
                         "w0rm1"                => 12144,
                         "w12345"               => 11040,
                         "w123456"              => 13181,
                         "w1234567"             => 23322,
                         "w1w2w3"               => 23419,
                         "w1w2w3w4"             => 10447,
                         "w2dlww3v5p"           => 19205,
                         "w4g8at"               => 10532,
                         "w8gkz2x1"             => 15392,
                         "w8sted"               => 20205,
                         "w8woord"              => 24473,
                         "w_pass"               => 4742,
                         "wabbit"               => 12705,
                         "wachovia"             => 22912,
                         "wachtwoord"           => 6716,
                         "waderh"               => 21568,
                         "waffenss"             => 7760,
                         "waffle"               => 4308,
                         "wagner1"              => 28950,
                         "wagoneer"             => 26608,
                         "waheguru"             => 18311,
                         "wahine"               => 27729,
                         "wahoo"                => 8794,
                         "wahooo"               => 23726,
                         "wahoos"               => 18771,
                         "waikiki"              => 20165,
                         "waitron"              => 23078,
                         "wakeboar"             => 21991,
                         "wakeup"               => 7792,
                         "waldemar"             => 17665,
                         "waldo1"               => 8625,
                         "waldorf"              => 12838,
                         "waleed"               => 20287,
                         "walera"               => 24909,
                         "wales1"               => 23369,
                         "walhalla"             => 24579,
                         "walker1"              => 9614,
                         "walker2"              => 27631,
                         "walkman"              => 10583,
                         "walkman555"           => 23311,
                         "wallace1"             => 10104,
                         "wallace2"             => 29211,
                         "walleye"              => 2156,
                         "walleye1"             => 17821,
                         "wallie"               => 27542,
                         "wallpape"             => 24423,
                         "wallst"               => 18573,
                         "wallstre"             => 18593,
                         "wallstreet"           => 25547,
                         "wally1"               => 6566,
                         "walmart"              => 2608,
                         "walnut"               => 1430,
                         "walrus"               => 2491,
                         "walstib"              => 28848,
                         "walte"                => 18782,
                         "walter1"              => 9501,
                         "walter34"             => 26154,
                         "wanderer"             => 4213,
                         "wanger"               => 14226,
                         "wanker"               => 635,
                         "wanker1"              => 14262,
                         "wankers"              => 14692,
                         "wanking"              => 5210,
                         "wannabe"              => 6153,
                         "wanrltw"              => 6223,
                         "wantit"               => 10093,
                         "wantsex"              => 25230,
                         "wantsome"             => 13740,
                         "wapapapa"             => 8049,
                         "wapbbs"               => 2575,
                         "wapbbs_1"             => 29465,
                         "wapiti"               => 18664,
                         "waqw3p"               => 16487,
                         "war123"               => 24980,
                         "war3demo"             => 16948,
                         "waratsea"             => 25341,
                         "warbird"              => 18765,
                         "warchild"             => 14349,
                         "warcraf"              => 20682,
                         "warcraft"             => 584,
                         "warcraft1"            => 10041,
                         "warcraft3"            => 6885,
                         "wardog"               => 14272,
                         "wareagle"             => 3031,
                         "warehous"             => 9054,
                         "warez"                => 4612,
                         "wargames"             => 10453,
                         "wargod"               => 16718,
                         "warhamer"             => 28721,
                         "warhamme"             => 5374,
                         "warhammer"            => 1946,
                         "warhammer40k"         => 25054,
                         "warhawk"              => 10446,
                         "warhol"               => 10887,
                         "warhorse"             => 27284,
                         "warior"               => 19824,
                         "warlock"              => 1106,
                         "warlock1"             => 17324,
                         "warlord"              => 2053,
                         "warlord1"             => 18588,
                         "warpten"              => 10505,
                         "warren1"              => 22724,
                         "warrio"               => 14723,
                         "warrior"              => 273,
                         "warrior1"             => 3939,
                         "warrior2"             => 15384,
                         "warrior3"             => 27187,
                         "warriors"             => 1383,
                         "warspite"             => 28191,
                         "warszawa"             => 17050,
                         "wartburg"             => 27533,
                         "warthog"              => 2769,
                         "warzone"              => 10967,
                         "was.here"             => 22663,
                         "wasabi"               => 4291,
                         "wasdwasd"             => 9214,
                         "wasdwasd1"            => 26700,
                         "washear"              => 23926,
                         "washere"              => 11438,
                         "washingt"             => 4115,
                         "washingto"            => 28515,
                         "wasser"               => 2635,
                         "wassup"               => 2411,
                         "watashi"              => 9736,
                         "watch1"               => 14238,
                         "watcher"              => 2600,
                         "watchmen"             => 13840,
                         "watchout"             => 27662,
                         "water1"               => 3683,
                         "water12"              => 28225,
                         "water123"             => 10101,
                         "waterboy"             => 5048,
                         "waterfal"             => 6201,
                         "waterloo"             => 1260,
                         "watermel"             => 11021,
                         "watermelon"           => 8152,
                         "waterpol"             => 12661,
                         "waterpolo"            => 8595,
                         "waters1"              => 21724,
                         "waterski"             => 6392,
                         "watford"              => 5135,
                         "watson1"              => 21394,
                         "waverly"              => 16789,
                         "waves1"               => 26886,
                         "wavmanuk"             => 17716,
                         "wavpzt"               => 11797,
                         "way2go"               => 17998,
                         "wayer"                => 8559,
                         "wayfarer"             => 20269,
                         "wayne1"               => 5623,
                         "wayner"               => 22329,
                         "waynes"               => 15990,
                         "wayout"               => 22047,
                         "wazzkaprivet"         => 29785,
                         "wazzup"               => 6244,
                         "wc18c2"               => 13428,
                         "wc4fun"               => 19842,
                         "wcksdypk"             => 17873,
                         "wcrfxtvgbjy"          => 27944,
                         "wdtnjr"               => 7222,
                         "wdtnjxtr"             => 6470,
                         "weaponx"              => 11958,
                         "weare138"             => 5864,
                         "weasel"               => 782,
                         "weasel1"              => 17892,
                         "weasle"               => 20829,
                         "weather1"             => 15480,
                         "webcam"               => 7345,
                         "webguy"               => 22078,
                         "webhead"              => 20893,
                         "webhompas"            => 3987,
                         "webhompass"           => 11669,
                         "webman"               => 20154,
                         "webmaste"             => 3322,
                         "webmaster"            => 1778,
                         "webpass"              => 29139,
                         "websol76"             => 6591,
                         "websolutions"         => 6594,
                         "websolutionssu"       => 27999,
                         "webstar"              => 16420,
                         "webster1"             => 13486,
                         "websters"             => 17071,
                         "webtvs"               => 24852,
                         "webuivalidat"         => 27358,
                         "wednesda"             => 6951,
                         "weeble"               => 10389,
                         "weed"                 => 1119,
                         "weed420"              => 5324,
                         "weeded"               => 20157,
                         "weedhead"             => 16132,
                         "weegee"               => 19694,
                         "weeman"               => 22059,
                         "weener"               => 12544,
                         "weenie"               => 7196,
                         "weetabix"             => 26955,
                         "weezer"               => 1486,
                         "weezer1"              => 25025,
                         "weezie"               => 18944,
                         "wehttam"              => 17958,
                         "weihnachte"           => 22615,
                         "weihnachten"          => 24466,
                         "weihnachtsbau"        => 27448,
                         "weihnachtsbaum"       => 29911,
                         "wejrpfpu"             => 23527,
                         "welcom"               => 4087,
                         "welcome"              => 112,
                         "welcome0"             => 28759,
                         "welcome01"            => 27075,
                         "welcome1"             => 770,
                         "welcome12"            => 14880,
                         "welcome123"           => 9822,
                         "welcome2"             => 7220,
                         "welcome4"             => 28144,
                         "welcome5"             => 27412,
                         "welcome7"             => 28971,
                         "welcome8"             => 17054,
                         "welder"               => 2802,
                         "welkom"               => 5997,
                         "welkom01"             => 11901,
                         "wellcome"             => 12054,
                         "welldone"             => 13454,
                         "wellhung"             => 8367,
                         "wellingt"             => 7084,
                         "welshman"             => 18819,
                         "wendy1"               => 4817,
                         "wendys"               => 8874,
                         "wenef45313"           => 15128,
                         "weng"                 => 3417,
                         "wer123"               => 14822,
                         "wer138"               => 27166,
                         "werder"               => 4067,
                         "werdna"               => 5677,
                         "werewolf"             => 1213,
                         "werken"               => 27150,
                         "weronika"             => 11430,
                         "werrew"               => 29366,
                         "wert12"               => 28123,
                         "wert1234"             => 22396,
                         "wert21"               => 29981,
                         "werter"               => 6627,
                         "werthrf"              => 17413,
                         "werthvfy"             => 17045,
                         "werty1"               => 15319,
                         "werty123"             => 25375,
                         "wertzu"               => 6786,
                         "werule"               => 26985,
                         "werwolf"              => 15217,
                         "wesdxc"               => 19050,
                         "wesker"               => 28874,
                         "wesley1"              => 11690,
                         "wessonnn"             => 16702,
                         "west123"              => 20681,
                         "west1234"             => 29949,
                         "westbrom"             => 11893,
                         "westcoas"             => 11300,
                         "westcoast"            => 10433,
                         "westend"              => 20024,
                         "western1"             => 17623,
                         "westham"              => 1115,
                         "westham1"             => 9048,
                         "westie"               => 9660,
                         "westin"               => 24819,
                         "westlife"             => 9304,
                         "westport"             => 11064,
                         "westsid"              => 20788,
                         "westside"             => 471,
                         "westwind"             => 11702,
                         "westwing"             => 18138,
                         "westwood"             => 2592,
                         "wetass"               => 21093,
                         "wetcunt"              => 17534,
                         "wetdog"               => 28562,
                         "wethepeople"          => 29384,
                         "wetone"               => 12503,
                         "wetpussy"             => 1036,
                         "wetsex"               => 26048,
                         "wetter"               => 5417,
                         "wetwilly"             => 22179,
                         "wetworks"             => 24229,
                         "wewiz"                => 25576,
                         "wg8e3wjf"             => 3623,
                         "whacko"               => 14902,
                         "whaler"               => 9067,
                         "whales"               => 6310,
                         "wharfrat"             => 26047,
                         "whateva"              => 22927,
                         "whateve"              => 7761,
                         "whatever"             => 104,
                         "whatever1"            => 9401,
                         "whatif"               => 17867,
                         "whatis"               => 27711,
                         "whatisit"             => 11074,
                         "whatluck"             => 25081,
                         "whatnow"              => 17836,
                         "whatsup"              => 2789,
                         "whatthe"              => 5883,
                         "whatthef"             => 21719,
                         "whatthefuck"          => 10541,
                         "whattheh"             => 17005,
                         "whatthehell"          => 17549,
                         "whatup"               => 6183,
                         "whdbtp"               => 15758,
                         "wheaties"             => 16895,
                         "wheels"               => 1446,
                         "whipit"               => 20365,
                         "whiplash"             => 5432,
                         "whipme"               => 23753,
                         "whippet"              => 14799,
                         "whirling"             => 21355,
                         "whiskers"             => 2843,
                         "whiskey"              => 1167,
                         "whiskey1"             => 10757,
                         "whisky"               => 2729,
                         "whisper"              => 2153,
                         "whisper1"             => 18214,
                         "whistler"             => 4731,
                         "white1"               => 4056,
                         "whiteboy"             => 4636,
                         "whitecat"             => 27213,
                         "whitedog"             => 14628,
                         "whitehea"             => 25859,
                         "whiteout"             => 4047,
                         "whitepower"           => 13151,
                         "whitesox"             => 2517,
                         "whitesta"             => 21324,
                         "whitetai"             => 19098,
                         "whitetail"            => 24401,
                         "whitewol"             => 23151,
                         "whitewolf"            => 17569,
                         "whitey"               => 2510,
                         "whitney1"             => 10582,
                         "whizzer"              => 29810,
                         "whkzyc"               => 10201,
                         "whoami"               => 9223,
                         "whoareyou"            => 17878,
                         "whocares"             => 1855,
                         "whodaman"             => 29472,
                         "whodat"               => 9311,
                         "whoknows"             => 6633,
                         "whome"                => 25917,
                         "whoopass"             => 9121,
                         "whopper"              => 9694,
                         "whore"                => 1131,
                         "whore1"               => 20678,
                         "whores"               => 6151,
                         "whosyourdaddy"        => 10496,
                         "whyme"                => 13809,
                         "whynot"               => 774,
                         "whynotme"             => 25221,
                         "whytesha"             => 17823,
                         "wibble"               => 2304,
                         "wiccan"               => 6727,
                         "wichsen"              => 22786,
                         "wicked"               => 909,
                         "wicked1"              => 9292,
                         "widder"               => 19299,
                         "wideglid"             => 19030,
                         "wideopen"             => 25502,
                         "widespre"             => 20040,
                         "widget"               => 5392,
                         "wifes"                => 7221,
                         "wifey"                => 3875,
                         "wifey1"               => 26654,
                         "wifey200"             => 20936,
                         "wiggles"              => 8493,
                         "wiggly"               => 14713,
                         "wiggum"               => 14564,
                         "wigwam"               => 20206,
                         "wiking"               => 11654,
                         "wiktoria"             => 20973,
                         "wilbur1"              => 27015,
                         "wilco"                => 18233,
                         "wild1"                => 13605,
                         "wildbill"             => 4265,
                         "wildblue"             => 11748,
                         "wildcard"             => 3513,
                         "wildcat"              => 699,
                         "wildcat1"             => 9575,
                         "wildcats"             => 564,
                         "wildchil"             => 26418,
                         "wildfire"             => 2066,
                         "wildman"              => 2859,
                         "wildman1"             => 17822,
                         "wildon"               => 24865,
                         "wildone"              => 5345,
                         "wildroid"             => 13086,
                         "wildrose"             => 11350,
                         "wildside"             => 17274,
                         "wildstar"             => 14420,
                         "wildthin"             => 14295,
                         "wildthing"            => 20163,
                         "wildwest"             => 14365,
                         "wildwood"             => 4534,
                         "wiley1"               => 25623,
                         "willee"               => 27114,
                         "willem"               => 6499,
                         "willi"                => 6671,
                         "willi1"               => 19019,
                         "willia1"              => 17342,
                         "william0"             => 22510,
                         "william1"             => 1200,
                         "william2"             => 8508,
                         "william3"             => 12441,
                         "william4"             => 29817,
                         "william6"             => 21823,
                         "william7"             => 21419,
                         "william8"             => 21761,
                         "williamj"             => 24999,
                         "williamm"             => 22225,
                         "williams1"            => 29498,
                         "willie1"              => 7173,
                         "willie12"             => 22051,
                         "willis1"              => 24109,
                         "willo"                => 15271,
                         "willow"               => 363,
                         "willow01"             => 28164,
                         "willow1"              => 8954,
                         "willy1"               => 7808,
                         "willy123"             => 29422,
                         "willyboy"             => 28824,
                         "willys"               => 10597,
                         "wilmar"               => 24432,
                         "wilso"                => 9739,
                         "wilson1"              => 10999,
                         "wilson2"              => 28873,
                         "win123"               => 27942,
                         "winam"                => 25233,
                         "winamp"               => 10669,
                         "winbig"               => 29875,
                         "winchest"             => 8680,
                         "windex"               => 11620,
                         "windmill"             => 3945,
                         "windows"              => 646,
                         "windows1"             => 7328,
                         "windows2"             => 26009,
                         "windows9"             => 19261,
                         "windsong"             => 16749,
                         "windsor"              => 2868,
                         "windsor1"             => 17491,
                         "windstar"             => 10126,
                         "windsurf"             => 3728,
                         "wingchun"             => 7887,
                         "wingman"              => 3738,
                         "wingnut"              => 4879,
                         "wings1"               => 11883,
                         "wingzero"             => 7349,
                         "winkie"               => 13419,
                         "winky"                => 10777,
                         "winne"                => 18813,
                         "winner"               => 187,
                         "winner1"              => 4147,
                         "winner12"             => 24173,
                         "winner69"             => 28145,
                         "winni"                => 14850,
                         "winnie1"              => 18969,
                         "winnipeg261"          => 17916,
                         "winsome"              => 29836,
                         "winsto"               => 12004,
                         "winston"              => 196,
                         "winston1"             => 2617,
                         "winston2"             => 11365,
                         "winston6"             => 28210,
                         "winstons"             => 20125,
                         "winte"                => 19258,
                         "winter"               => 186,
                         "winter0"              => 26737,
                         "winter00"             => 21728,
                         "winter01"             => 13409,
                         "winter1"              => 4517,
                         "winter11"             => 15977,
                         "winter12"             => 9924,
                         "winter2"              => 28732,
                         "winter99"             => 6339,
                         "wintermu"             => 26496,
                         "winxclub"             => 18041,
                         "wipeout"              => 10388,
                         "wirenut"              => 29331,
                         "wisconsi"             => 9488,
                         "wisdom"               => 1450,
                         "wisdom1"              => 24324,
                         "wiseguy"              => 5294,
                         "wishbone"             => 3056,
                         "wishmaster"           => 15067,
                         "wisper"               => 26220,
                         "wisteria"             => 26351,
                         "witch1"               => 17804,
                         "withlove"             => 14861,
                         "withyou"              => 12761,
                         "wizar"                => 14685,
                         "wizard"               => 175,
                         "wizard1"              => 4477,
                         "wizard12"             => 20064,
                         "wizardry"             => 24756,
                         "wizards"              => 5254,
                         "wizkid"               => 11821,
                         "wizzard"              => 6688,
                         "wladimir"             => 14090,
                         "wlafiga"              => 28847,
                         "wltfg4ta"             => 22362,
                         "wm00022"              => 17945,
                         "wm2006"               => 23565,
                         "wmegrfux"             => 20001,
                         "wnmaz7sd"             => 21298,
                         "woaini"               => 11542,
                         "wobble"               => 9753,
                         "wodahs"               => 24754,
                         "wojtek"               => 13838,
                         "woland"               => 14310,
                         "wolf01"               => 19004,
                         "wolf1"                => 12369,
                         "wolf100"              => 29090,
                         "wolf12"               => 17862,
                         "wolf123"              => 29489,
                         "wolf13"               => 29036,
                         "wolf359"              => 2513,
                         "wolf666"              => 12597,
                         "wolf69"               => 15853,
                         "wolfdog"              => 18416,
                         "wolfee"               => 24708,
                         "wolfen"               => 5161,
                         "wolfer"               => 12839,
                         "wolfgang"             => 906,
                         "wolfgar"              => 17315,
                         "wolfie"               => 2226,
                         "wolfman"              => 1270,
                         "wolfman1"             => 18793,
                         "wolfone"              => 27548,
                         "wolfpac"              => 4880,
                         "wolfpack"             => 681,
                         "wolley"               => 25641,
                         "wolve"                => 27756,
                         "wolverin"             => 587,
                         "wolverine"            => 1285,
                         "wolves"               => 730,
                         "wolves1"              => 11935,
                         "wolvie"               => 7918,
                         "womam"                => 6519,
                         "woman1"               => 23780,
                         "womans"               => 6130,
                         "wombat"               => 694,
                         "wombat1"              => 21653,
                         "wombats"              => 29052,
                         "women1"               => 26238,
                         "womens"               => 14080,
                         "womersle"             => 18803,
                         "wonder1"              => 12633,
                         "wonderbo"             => 22384,
                         "wonderboy"            => 5747,
                         "wonderbr"             => 29080,
                         "wonderfu"             => 6072,
                         "wonderwall"           => 23933,
                         "wonderwo"             => 24166,
                         "wonderwoman"          => 29977,
                         "wonka"                => 19953,
                         "wonkette"             => 11034,
                         "wonton"               => 9442,
                         "woobie"               => 12450,
                         "woodbird"             => 20102,
                         "woodchuc"             => 27436,
                         "wooddoor"             => 15695,
                         "woodduck"             => 12194,
                         "woodfish"             => 28239,
                         "woodie"               => 4332,
                         "woodland"             => 3733,
                         "woodlawn"             => 17925,
                         "woodpony"             => 22743,
                         "woodsink"             => 15624,
                         "woodstoc"             => 5278,
                         "woodstock"            => 7256,
                         "woodwind"             => 19426,
                         "woodwork"             => 7260,
                         "woody"                => 888,
                         "woody1"               => 1415,
                         "woody123"             => 20323,
                         "woodys"               => 11192,
                         "woofer"               => 3707,
                         "woofwoof"             => 2122,
                         "woogie"               => 11548,
                         "wooglin"              => 19693,
                         "woohoo"               => 2896,
                         "wookie"               => 1538,
                         "wookie1"              => 15509,
                         "wooody"               => 26665,
                         "wordlife"             => 18753,
                         "wordpass"             => 883,
                         "wordup"               => 5477,
                         "wordz"                => 27429,
                         "workhard"             => 18901,
                         "workit"               => 14746,
                         "worksuck"             => 20464,
                         "world1"               => 9345,
                         "world123"             => 26001,
                         "worldcom"             => 21166,
                         "worldcup"             => 8482,
                         "worldnet"             => 27430,
                         "worldwar"             => 22424,
                         "worldwid"             => 20654,
                         "wormix"               => 4943,
                         "wormwood"             => 12428,
                         "wotan"                => 13009,
                         "wouter"               => 20325,
                         "wow123"               => 16795,
                         "wow12345"             => 23535,
                         "wowlook1"             => 25986,
                         "wowser"               => 9915,
                         "wowsers"              => 29386,
                         "wp2003wp"             => 4665,
                         "wp2005"               => 16452,
                         "wpass"                => 27348,
                         "wpf8eu"               => 13675,
                         "wpoolejr"             => 20552,
                         "wqmfuh"               => 18373,
                         "wraith"               => 3376,
                         "wrangler"             => 821,
                         "wrench"               => 3769,
                         "wrest666"             => 13078,
                         "wrestle"              => 3105,
                         "wrestle1"             => 21043,
                         "wrestlin"             => 2314,
                         "wrestling1"           => 23850,
                         "wright1"              => 20524,
                         "wrinkle1"             => 1107,
                         "wrinkle5"             => 13290,
                         "wrinkles"             => 7034,
                         "writer1"              => 29243,
                         "writerspace"          => 26529,
                         "wrongway"             => 25670,
                         "wrxsti"               => 11461,
                         "wspanic"              => 27304,
                         "wsxedc"               => 6768,
                         "wsxqaz"               => 9723,
                         "wsxzaq"               => 7648,
                         "wtcacq"               => 22514,
                         "wtpfhm"               => 10018,
                         "wtpmjgda"             => 12232,
                         "wu4etd"               => 15465,
                         "wu9942"               => 28314,
                         "wulfgar"              => 13192,
                         "wuschel"              => 16068,
                         "wutang"               => 795,
                         "wutang1"              => 20901,
                         "wutang36"             => 18050,
                         "wvj5np"               => 16926,
                         "wwe123"               => 17799,
                         "wweraw"               => 21454,
                         "wwfwcw"               => 15080,
                         "wwr8x9pu"             => 23523,
                         "www111"               => 16106,
                         "www123"               => 7335,
                         "www333"               => 21909,
                         "wwww1"                => 29627,
                         "wwwww1"               => 12717,
                         "wwwwww1"              => 17142,
                         "wwwwwww1"             => 22904,
                         "wxcvb"                => 25511,
                         "wxcvbn"               => 5156,
                         "wyatt1"               => 19912,
                         "wysiwyg"              => 9064,
                         "wyvern"               => 7729,
                         "x002tp00"             => 29471,
                         "x12345"               => 19617,
                         "x123456"              => 13957,
                         "x1x2x3"               => 20371,
                         "x24ik3"               => 12152,
                         "x35v8l"               => 14071,
                         "x4ww5qdr"             => 22133,
                         "x5dxwp"               => 21273,
                         "x72jhhu3z"            => 8277,
                         "xaccess2"             => 12363,
                         "xakep1234"            => 13012,
                         "xakepy"               => 16008,
                         "xanadu"               => 1559,
                         "xanth"                => 24934,
                         "xantia"               => 5524,
                         "xavie"                => 24128,
                         "xavier"               => 331,
                         "xavier1"              => 9707,
                         "xbox36"               => 24526,
                         "xbox360"              => 2436,
                         "xboxlive"             => 10280,
                         "xcalibur"             => 20089,
                         "xcountry"             => 11332,
                         "xenocide"             => 16432,
                         "xenogear"             => 21748,
                         "xenon"                => 18860,
                         "xenon1"               => 24795,
                         "xenophon"             => 20237,
                         "xerxes"               => 3177,
                         "xexeylhf"             => 23768,
                         "xfactor"              => 10338,
                         "xfhkbr"               => 26179,
                         "xfiles"               => 841,
                         "xfiles1"              => 21655,
                         "xfqybr"               => 19961,
                         "xholes"               => 14977,
                         "xian"                 => 6080,
                         "xiang"                => 3259,
                         "xiaoyua123"           => 26530,
                         "ximen"                => 21055,
                         "xing"                 => 3532,
                         "xirt2k"               => 14936,
                         "xjy6721"              => 28870,
                         "xjznq5"               => 14658,
                         "xngwoj"               => 11279,
                         "xohzi3g4"             => 21638,
                         "xplorer"              => 19533,
                         "xpress"               => 14955,
                         "xpressmusic"          => 23035,
                         "xqgann"               => 12105,
                         "xrated"               => 8956,
                         "xrp23q"               => 11353,
                         "xsvnd4b2"             => 22386,
                         "xsw21qaz"             => 10327,
                         "xsw23edc"             => 12589,
                         "xswqaz"               => 18737,
                         "xswzaq"               => 18585,
                         "xtcnth"               => 28879,
                         "xterra"               => 9068,
                         "xthtgfirf"            => 10377,
                         "xthysq"               => 16671,
                         "xtkjdtr"              => 11448,
                         "xtr451"               => 26950,
                         "xtreme"               => 2043,
                         "xtutdfhf"             => 29070,
                         "xtvgbjy"              => 16074,
                         "xufrgemw"             => 24484,
                         "xwing"                => 13057,
                         "xxx111"               => 19200,
                         "xxx123"               => 2992,
                         "xxx12345"             => 27120,
                         "xxx666"               => 7875,
                         "xxx777"               => 7236,
                         "xxxjay"               => 25712,
                         "xxxman"               => 12802,
                         "xxxp455w0rd5"         => 29839,
                         "xxxpass"              => 3320,
                         "xxxsex"               => 15259,
                         "xxxx1"                => 20277,
                         "xxxxx1"               => 9178,
                         "xxxxxx1"              => 6415,
                         "xxxxxxx1"             => 17343,
                         "xxxyyy"               => 25749,
                         "xxxzzz"               => 7590,
                         "xyh28af4"             => 24188,
                         "xytfu7"               => 10235,
                         "xyz123"               => 3324,
                         "xyzzy"                => 7405,
                         "xyzzy1"               => 24440,
                         "xzibit"               => 15589,
                         "xzsawq"               => 29491,
                         "xzsawq21"             => 14218,
                         "y4kuz4"               => 23023,
                         "y9enkj"               => 16665,
                         "yackwin"              => 10029,
                         "yaglasph"             => 25260,
                         "yahweh"               => 8639,
                         "yakman"               => 17099,
                         "yakumo"               => 18095,
                         "yakuza"               => 11700,
                         "yamah"                => 11495,
                         "yamaha"               => 152,
                         "yamaha1"              => 7302,
                         "yamaha12"             => 27723,
                         "yamahar"              => 27714,
                         "yamahar1"             => 4533,
                         "yamahar6"             => 8206,
                         "yamakasi"             => 21216,
                         "yamato"               => 5741,
                         "yamoon6"              => 29391,
                         "yams7"                => 26653,
                         "yanina"               => 20917,
                         "yankee"               => 422,
                         "yankee1"              => 7474,
                         "yankeemp"             => 17371,
                         "yankees"              => 74,
                         "yankees0"             => 16996,
                         "yankees1"             => 977,
                         "yankees2"             => 3760,
                         "yankees3"             => 22969,
                         "yankees4"             => 22015,
                         "yankees7"             => 20260,
                         "yankees9"             => 22100,
                         "yanks"                => 8837,
                         "yanks1"               => 8113,
                         "yannic"               => 29967,
                         "yannick"              => 10315,
                         "yannis"               => 28516,
                         "yanochka"             => 14103,
                         "yanshi1982"           => 16714,
                         "yardbird"             => 10552,
                         "yarddog"              => 27954,
                         "yardman"              => 26759,
                         "yaroslav"             => 6590,
                         "yarrak"               => 23384,
                         "yasacrac"             => 26588,
                         "yasmi"                => 18755,
                         "yasmina"              => 13726,
                         "yasuhiro"             => 29763,
                         "yawetag"              => 27620,
                         "ybhdfyf"              => 14445,
                         "ybrbnbyf"             => 24449,
                         "ybrbnf"               => 1104,
                         "ybrbnf_25"            => 23174,
                         "ybrbnjc"              => 8268,
                         "ybrbnjcbr"            => 26607,
                         "ybrbnrf"              => 15692,
                         "ybrecz"               => 29340,
                         "ybrjkfq"              => 2501,
                         "ybrjkftd"             => 18797,
                         "ybrjkftdbx"           => 13858,
                         "ybrjkftdyf"           => 24014,
                         "ycwvrxxh"             => 20831,
                         "yeababy"              => 26797,
                         "yeah11"               => 16646,
                         "yeahbaby"             => 3435,
                         "yeahman"              => 29087,
                         "yeahrigh"             => 22372,
                         "yeahright"            => 26989,
                         "year2000"             => 13039,
                         "year2005"             => 9092,
                         "yecgaa"               => 10204,
                         "yeehaa"               => 24265,
                         "yeehaw"               => 13909,
                         "yejntb"               => 20076,
                         "yelena03"             => 27536,
                         "yelhsa"               => 27590,
                         "yello"                => 7650,
                         "yellow"               => 126,
                         "yellow1"              => 4476,
                         "yellow12"             => 19142,
                         "yellow22"             => 21248,
                         "yellow3"              => 26377,
                         "yellow5"              => 23874,
                         "yellow7"              => 29662,
                         "yelnats"              => 18747,
                         "yelrah"               => 26872,
                         "yendor"               => 10302,
                         "yensid"               => 17904,
                         "yes90125"             => 15475,
                         "yeshua"               => 7857,
                         "yesiam"               => 12000,
                         "yesican"              => 20382,
                         "yesman"               => 18601,
                         "yessir"               => 5129,
                         "yessss"               => 16341,
                         "yesterda"             => 8317,
                         "yfafyz"               => 9036,
                         "yfcnfcmz"             => 19360,
                         "yfcntyf"              => 6314,
                         "yfcntymrf"            => 3257,
                         "yfcnz"                => 19082,
                         "yfcnz1"               => 21420,
                         "yfcnz123"             => 14222,
                         "yfcnzvjz"             => 25742,
                         "yfcnzyfcnz"           => 21698,
                         "yfdbufnjh"            => 20546,
                         "yfeiybrb"             => 25837,
                         "yfgjktjy"             => 14868,
                         "yfhenj"               => 9229,
                         "yfhrjnbrb"            => 27216,
                         "yfl.irf"              => 23269,
                         "yfltymrf"             => 18412,
                         "yfnecbr"              => 15231,
                         "yfnecz"               => 27374,
                         "yfnfif"               => 597,
                         "yfnfirf"              => 6999,
                         "yfnfitymrf"           => 7471,
                         "yfnfkb"               => 4242,
                         "yfnfkbz"              => 9296,
                         "yfnfkmz"              => 3190,
                         "yfxfkmybr"            => 26584,
                         "yfz450"               => 23923,
                         "ygfxbkgt"             => 24917,
                         "yggdrasi"             => 27972,
                         "yhntgb"               => 12970,
                         "yhwnqc"               => 17259,
                         "yingyang"             => 11125,
                         "yinyang"              => 6195,
                         "yitbos"               => 7826,
                         "yja3vo"               => 17365,
                         "yjdbrjd"              => 26777,
                         "yjdbrjdf"             => 24726,
                         "yjdjcnbf"             => 22863,
                         "yjdsqgfhjkm"          => 3573,
                         "yjdsqujl"             => 10483,
                         "yjdujhjl"             => 22356,
                         "yjhbkmcr"             => 28325,
                         "ym3cautj"             => 23654,
                         "yngwie"               => 8114,
                         "yocrack"              => 29377,
                         "yoda"                 => 3027,
                         "yoda123"              => 28542,
                         "yoda69"               => 29916,
                         "yodaddy"              => 25767,
                         "yodude"               => 28301,
                         "yogibear"             => 4164,
                         "yojimbo"              => 16600,
                         "yoland"               => 18597,
                         "yomama"               => 1197,
                         "yomama1"              => 27490,
                         "yomamma"              => 21528,
                         "yomismo"              => 24653,
                         "yomomma"              => 10513,
                         "yonkers"              => 17036,
                         "yoohoo"               => 11133,
                         "yorkie"               => 6725,
                         "yorkshir"             => 10767,
                         "yorktown"             => 8331,
                         "yosemite"             => 2231,
                         "yoshi"                => 7920,
                         "yoshi1"               => 27748,
                         "yoshimi"              => 29959,
                         "yoshio"               => 26744,
                         "youandme"             => 8262,
                         "youare"               => 20498,
                         "youknow"              => 6521,
                         "young1"               => 5580,
                         "youngone"             => 21888,
                         "yourass"              => 21971,
                         "yourmama"             => 7851,
                         "yourmom"              => 1582,
                         "yourmom1"             => 20809,
                         "yourname"             => 19616,
                         "yousuck"              => 2463,
                         "yousuck1"             => 22633,
                         "youwish"              => 13471,
                         "yoyo123"              => 21385,
                         "yoyoma"               => 4770,
                         "yqlgr667"             => 14300,
                         "yqmbevgk"             => 17993,
                         "yr8wdxcq"             => 18643,
                         "yrrim7"               => 24690,
                         "yssup"                => 12147,
                         "yt1300"               => 19306,
                         "ytcnjh"               => 12754,
                         "ytdxz2ca"             => 22414,
                         "ytngfhjkz"            => 7606,
                         "ytnhjufnm"            => 20796,
                         "ytpyf."               => 26542,
                         "ytrewq"               => 766,
                         "ytreza"               => 12505,
                         "ytrhjvfyn"            => 9037,
                         "ytyfdbcnm"            => 9774,
                         "yugioh"               => 3841,
                         "yuitre12"             => 28629,
                         "yujyd360"             => 19653,
                         "yukon1"               => 15951,
                         "yuliya"               => 8130,
                         "yumiko"               => 16954,
                         "yummie"               => 16093,
                         "yummies"              => 29299,
                         "yummy"                => 3539,
                         "yummy1"               => 10852,
                         "yuo67"                => 17064,
                         "yvonne1"              => 20787,
                         "yvtte545"             => 13865,
                         "ywvxpz"               => 14896,
                         "yxcvbn"               => 10309,
                         "yxcvbnm"              => 10412,
                         "yxkck878"             => 14923,
                         "yy5rbfsc"             => 13142,
                         "yyyy1"                => 27180,
                         "yyyyy1"               => 11689,
                         "yyyyyy1"              => 9011,
                         "yyyyyyy1"             => 16419,
                         "yyz2112"              => 17183,
                         "yzerman"              => 2337,
                         "yzerman1"             => 15359,
                         "z12345"               => 6359,
                         "z123456"              => 6804,
                         "z1234567"             => 15812,
                         "z123456789"           => 15047,
                         "z123456z"             => 17932,
                         "z1x2c3"               => 2535,
                         "z1x2c3v4"             => 3095,
                         "z1x2c3v4b5"           => 6298,
                         "z1x2c3v4b5n6m7"       => 29171,
                         "z1z2z3"               => 21705,
                         "z1z2z3z4"             => 24043,
                         "z3cn2erv"             => 27131,
                         "zachar"               => 16002,
                         "zachar1"              => 26104,
                         "zacharia"             => 25073,
                         "zachary1"             => 4104,
                         "zadrot"               => 17083,
                         "zaebali"              => 16032,
                         "zafira"               => 12642,
                         "zagadka"              => 24927,
                         "zaharov"              => 14981,
                         "zaharova"             => 20718,
                         "zalupa"               => 3750,
                         "zamboni"              => 9965,
                         "zamira"               => 23090,
                         "zanardi"              => 23084,
                         "zang"                 => 3494,
                         "zanoza"               => 12410,
                         "zantac"               => 24387,
                         "zanuda"               => 20550,
                         "zanzibar"             => 4288,
                         "zapato"               => 28649,
                         "zaphod"               => 1935,
                         "zaphod42"             => 24450,
                         "zapidoo"              => 26507,
                         "zappa"                => 3272,
                         "zappa1"               => 8280,
                         "zapper"               => 5780,
                         "zaq!2wsx"             => 28180,
                         "zaq11qaz"             => 15796,
                         "zaq123"               => 1313,
                         "zaq12345"             => 7077,
                         "zaq123wsx"            => 16744,
                         "zaq12qaz"             => 24671,
                         "zaq12w"               => 19228,
                         "zaq12ws"              => 14089,
                         "zaq12wsx"             => 480,
                         "zaq1xsw2"             => 1484,
                         "zaq1xsw2cde3"         => 9499,
                         "zaqqaz"               => 14500,
                         "zaqwsx"               => 868,
                         "zaqwsx1"              => 24507,
                         "zaqwsx123"            => 14959,
                         "zaqwsxcde"            => 5259,
                         "zaqwsxcderfv"         => 24060,
                         "zaqxsw"               => 2120,
                         "zaqxsw123"            => 27916,
                         "zaqxswcde"            => 3869,
                         "zaratustra"           => 12653,
                         "zaraza"               => 3371,
                         "zardoz"               => 7188,
                         "zarina"               => 4609,
                         "zasada"               => 5052,
                         "zaskar"               => 13431,
                         "zasranec"             => 16709,
                         "zastava"              => 22328,
                         "zasxcd"               => 29993,
                         "zavilov"              => 24793,
                         "zaxscd"               => 8138,
                         "zaxscdvf"             => 10612,
                         "zaxxon"               => 14848,
                         "zcegth"               => 19104,
                         "zcfvfzkexifz"         => 29742,
                         "zcxfcnkbdf"           => 9436,
                         "zcxfcnkbdfz"          => 25358,
                         "zealot"               => 11772,
                         "zealots"              => 7309,
                         "zebedee"              => 22095,
                         "zebra"                => 4103,
                         "zebra1"               => 10156,
                         "zebra123"             => 24321,
                         "zebra3"               => 22278,
                         "zebras"               => 6828,
                         "zebulon"              => 13674,
                         "zelda1"               => 8321,
                         "zemanova"             => 28526,
                         "zemfira"              => 12812,
                         "zeng"                 => 3836,
                         "zenit2011"            => 13837,
                         "zenith"               => 2170,
                         "zephyr"               => 3744,
                         "zeppelin"             => 731,
                         "zepplin"              => 10523,
                         "zeratul"              => 27867,
                         "zerkalo"              => 17874,
                         "zermatt"              => 18251,
                         "zero00"               => 21226,
                         "zero000"              => 29191,
                         "zerocool"             => 2669,
                         "zesyrmvu"             => 18059,
                         "zeus"                 => 2623,
                         "zgjybz"               => 23631,
                         "zhai"                 => 3302,
                         "zhanna"               => 18832,
                         "zhao"                 => 3649,
                         "zhei"                 => 3012,
                         "zheng"                => 3101,
                         "zhenya"               => 9266,
                         "zhipo"                => 28007,
                         "zhjckfd"              => 3612,
                         "zhjckfdf"             => 18342,
                         "zhong"                => 2969,
                         "zhongguo"             => 28905,
                         "zhou"                 => 3211,
                         "zhuai"                => 3253,
                         "zhuan"                => 8043,
                         "zhuang"               => 3178,
                         "zhui"                 => 3441,
                         "zhukov"               => 19857,
                         "zhun"                 => 3218,
                         "zhuo"                 => 3656,
                         "zhv84kv"              => 29559,
                         "ziadma"               => 16217,
                         "zidan"                => 20844,
                         "zidane"               => 1873,
                         "zidane10"             => 14835,
                         "ziffle"               => 25822,
                         "zigazaga"             => 12615,
                         "ziggy"                => 2706,
                         "ziggy1"               => 5971,
                         "ziggy123"             => 19024,
                         "zigzag"               => 2823,
                         "zildjian"             => 3961,
                         "zilla"                => 23892,
                         "zimmerma"             => 23598,
                         "zinaida"              => 12454,
                         "zinedine"             => 13405,
                         "zinger"               => 6694,
                         "zip100"               => 22394,
                         "zipcode"              => 28642,
                         "zipdrive"             => 27591,
                         "zipper"               => 1063,
                         "zippo"                => 4532,
                         "zippo1"               => 21180,
                         "zippos"               => 27607,
                         "zippy"                => 2936,
                         "zippy1"               => 7942,
                         "zippy123"             => 19506,
                         "zircon"               => 22482,
                         "zjduc3"               => 18640,
                         "zjses9evpa"           => 23682,
                         "zldej102"             => 22206,
                         "zlzfrh"               => 13657,
                         "zmxncbv"              => 17161,
                         "znbvjd"               => 15828,
                         "zodiac"               => 4193,
                         "zodiak"               => 22139,
                         "zoedog"               => 24448,
                         "zoidberg"             => 17844,
                         "zoinks"               => 15215,
                         "zoloft"               => 13689,
                         "zoloto"               => 4645,
                         "zoltan"               => 12627,
                         "zoltar"               => 26416,
                         "zolushka"             => 8487,
                         "zombie"               => 608,
                         "zombie1"              => 13474,
                         "zombie13"             => 23121,
                         "zomu9q"               => 21285,
                         "zong"                 => 3582,
                         "zonker"               => 14235,
                         "zontik"               => 27678,
                         "zoomer"               => 7060,
                         "zooropa"              => 8116,
                         "zootsuit"             => 29574,
                         "zorba"                => 16328,
                         "zorglub"              => 10680,
                         "zorro"                => 2165,
                         "zorro1"               => 5722,
                         "zorro123"             => 28437,
                         "zorros"               => 16307,
                         "zoulou"               => 19756,
                         "zpflhjn1"             => 26443,
                         "zpxvwy"               => 16851,
                         "zqjphsyf6ctifgu"      => 16200,
                         "zrjdktdf"             => 22812,
                         "zse45rdx"             => 28031,
                         "zse4xdr5"             => 25798,
                         "zsecyus56"            => 25337,
                         "zsergn"               => 29769,
                         "zsfmpv"               => 18714,
                         "zsmj2v"               => 13251,
                         "zsxdcf"               => 17391,
                         "ztmfcq"               => 15052,
                         "zuan"                 => 3741,
                         "zucchero"             => 24147,
                         "zujlrf"               => 12205,
                         "zulu"                 => 6393,
                         "zvbxrpl"              => 17075,
                         "zverev"               => 27889,
                         "zvezda"               => 1878,
                         "zvfrfcb"              => 23321,
                         "zw6syj"               => 15581,
                         "zwezda"               => 25201,
                         "zx123456"             => 13378,
                         "zx123456789"          => 13920,
                         "zxasqw"               => 5224,
                         "zxasqw12"             => 2684,
                         "zxc12"                => 24291,
                         "zxc123"               => 697,
                         "zxc1234"              => 21224,
                         "zxc12345"             => 15858,
                         "zxc123456"            => 29945,
                         "zxc123zxc"            => 19462,
                         "zxc321"               => 14809,
                         "zxcasd"               => 2045,
                         "zxcasd123"            => 25454,
                         "zxcasdqw"             => 20676,
                         "zxcasdqwe"            => 2167,
                         "zxcasdqwe123"         => 4427,
                         "zxccxz"               => 6547,
                         "zxcdsa"               => 21000,
                         "zxcqweasd"            => 21502,
                         "zxcv12"               => 13519,
                         "zxcv123"              => 4878,
                         "zxcv1234"             => 1553,
                         "zxcv4321"             => 29001,
                         "zxcvasdf"             => 6789,
                         "zxcvb1"               => 9395,
                         "zxcvb123"             => 5730,
                         "zxcvb1234"            => 25349,
                         "zxcvb12345"           => 7645,
                         "zxcvbasdfg"           => 29074,
                         "zxcvbn"               => 57,
                         "zxcvbn1"              => 8725,
                         "zxcvbn12"             => 13930,
                         "zxcvbn123"            => 13991,
                         "zxcvbn123456"         => 25643,
                         "zxcvbnm"              => 39,
                         "zxcvbnm."             => 16802,
                         "zxcvbnm1"             => 2324,
                         "zxcvbnm12"            => 13439,
                         "zxcvbnm123"           => 3844,
                         "zxcvbnm123456789"     => 27983,
                         "zxcvbnma"             => 28488,
                         "zxcvbnmm"             => 12841,
                         "zxcvbnmz"             => 21221,
                         "zxcvfdsa"             => 16753,
                         "zxcvvcxz"             => 8183,
                         "zxgdqn"               => 17424,
                         "zydeco"               => 19846,
                         "zydfhm"               => 8857,
                         "zygote"               => 26853,
                         "zyjxrf"               => 5554,
                         "zyltrc"               => 19137,
                         "zymurgy"              => 26216,
                         "zz123456"             => 16564,
                         "zz6319"               => 23094,
                         "zz8807zpl"            => 8541,
                         "zzaaqq"               => 25313,
                         "zzr1100"              => 18329,
                         "zztop"                => 8650,
                         "zzxxcc"               => 7492,
                         "zzxxccvv"             => 19755,
                         "zzz111"               => 7793,
                         "zzz123"               => 8172,
                         "zzzxxx"               => 4086,
                         "zzzxxxccc"            => 22649,
                         "zzzz1"                => 25648,
                         "zzzzxxxx"             => 19063,
                         "zzzzz1"               => 8747,
                         "zzzzzz1"              => 9852,
                         "zzzzzzz1"             => 12604,
                       },
  surnames          => {
                         abad          => 8040,
                         abarca        => 8039,
                         abbate        => 6449,
                         abbott        => 414,
                         abdullah      => 4831,
                         abell         => 3503,
                         abercrombie   => 4756,
                         abernathy     => 1412,
                         abernethy     => 7421,
                         abeyta        => 4795,
                         ables         => 4794,
                         abner         => 3840,
                         abney         => 2270,
                         abrahamson    => 9254,
                         abrams        => 1154,
                         abramson      => 4793,
                         abrego        => 6353,
                         abreu         => 2403,
                         abron         => 9143,
                         absher        => 6448,
                         abshire       => 6961,
                         abston        => 9494,
                         acevedo       => 776,
                         aceves        => 7769,
                         acker         => 2083,
                         ackerman      => 1181,
                         ackley        => 3990,
                         acklin        => 8247,
                         acord         => 6634,
                         acosta        => 461,
                         acree         => 4353,
                         acton         => 5729,
                         acuff         => 7944,
                         acuna         => 2770,
                         adair         => 1545,
                         adame         => 2756,
                         adames        => 5971,
                         adamo         => 8812,
                         adams         => 34,
                         adamski       => 8370,
                         adamson       => 1995,
                         adcock        => 2032,
                         addington     => 5457,
                         addis         => 6840,
                         addison       => 1571,
                         adelman       => 9493,
                         adkins        => 359,
                         adkinson      => 7586,
                         adkison       => 8480,
                         adkisson      => 7685,
                         adler         => 2077,
                         adorno        => 4862,
                         agee          => 1953,
                         agnew         => 3085,
                         agosto        => 5539,
                         aguayo        => 3989,
                         aguero        => 7684,
                         aguiar        => 3481,
                         aguila        => 7768,
                         aguilar       => 327,
                         aguilera      => 1785,
                         aguirre       => 724,
                         ahearn        => 6839,
                         ahern         => 3369,
                         ahlers        => 7275,
                         ahner         => 6227,
                         ahrens        => 3350,
                         ahumada       => 8137,
                         aiello        => 3679,
                         aiken         => 2054,
                         aikens        => 4450,
                         ainsworth     => 2504,
                         aitken        => 7274,
                         aker          => 7191,
                         akers         => 929,
                         akin          => 3017,
                         akins         => 1305,
                         alamo         => 9028,
                         alanis        => 5223,
                         alaniz        => 1952,
                         alarcon       => 3368,
                         albanese      => 4512,
                         albano        => 7026,
                         albaugh       => 7420,
                         albee         => 9253,
                         albers        => 2915,
                         alberts       => 5079,
                         albertson     => 2724,
                         albin         => 6566,
                         albino        => 8136,
                         albrecht      => 1850,
                         albright      => 1130,
                         albritton     => 4141,
                         albro         => 9142,
                         alcala        => 3413,
                         alcantar      => 5010,
                         alcantara     => 5493,
                         alcaraz       => 4543,
                         alcorn        => 3084,
                         aldana        => 7419,
                         alday         => 9252,
                         alder         => 8701,
                         alderete      => 7418,
                         alderman      => 2365,
                         alderson      => 4966,
                         aldrich       => 1403,
                         aldridge      => 1180,
                         alegria       => 9739,
                         alejo         => 9492,
                         aleman        => 2639,
                         alessi        => 6447,
                         alexander     => 92,
                         alfano        => 6769,
                         alfaro        => 1619,
                         alford        => 774,
                         alger         => 3584,
                         alicea        => 2381,
                         alkire        => 8700,
                         allain        => 6768,
                         allaire       => 9141,
                         allard        => 2242,
                         alleman       => 6126,
                         allen         => 26,
                         alley         => 1789,
                         alleyne       => 4691,
                         allgood       => 4965,
                         allman        => 3635,
                         allmon        => 8246,
                         alloway       => 9140,
                         allred        => 1585,
                         almanza       => 3171,
                         almaraz       => 5009,
                         almazan       => 8369,
                         almeida       => 2655,
                         almendarez    => 9885,
                         almodovar     => 9027,
                         almon         => 9491,
                         almond        => 3281,
                         almonte       => 4419,
                         alpert        => 7273,
                         alston        => 765,
                         alsup         => 6708,
                         altamirano    => 5348,
                         althoff       => 9026,
                         altizer       => 9139,
                         altman        => 1822,
                         alvarado      => 382,
                         alvardo       => 7861,
                         alvares       => 9738,
                         alvarez       => 205,
                         alverez       => 6633,
                         alverson      => 7860,
                         alves         => 3031,
                         alvey         => 6707,
                         alvis         => 7859,
                         amador        => 2436,
                         aman          => 7683,
                         amann         => 9490,
                         amaral        => 3678,
                         amaro         => 5728,
                         amato         => 2681,
                         amaya         => 1994,
                         ambriz        => 4755,
                         amburgey      => 8601,
                         amerson       => 4895,
                         ames          => 1084,
                         amey          => 7504,
                         amezcua       => 9884,
                         amezquita     => 9362,
                         amick         => 6286,
                         amin          => 5970,
                         ammerman      => 8479,
                         ammons        => 2874,
                         amundson      => 3988,
                         anaya         => 1438,
                         ancheta       => 8038,
                         anders        => 2021,
                         andersen      => 879,
                         anderson      => 11,
                         anderton      => 4964,
                         andes         => 7682,
                         andino        => 6565,
                         andrade       => 957,
                         andreasen     => 9489,
                         andresen      => 5969,
                         andress       => 6511,
                         andrews       => 172,
                         andrus        => 3313,
                         andujar       => 8699,
                         ange          => 8478,
                         angell        => 4352,
                         anglin        => 2402,
                         anguiano      => 4568,
                         angulo        => 3658,
                         anselmo       => 8135,
                         ansley        => 6019,
                         anson         => 5591,
                         antonelli     => 7585,
                         anzalone      => 8811,
                         aparicio      => 5776,
                         apodaca       => 2671,
                         aponte        => 1694,
                         appel         => 3941,
                         appleby       => 4418,
                         applegate     => 2496,
                         appleton      => 3987,
                         applewhite    => 4270,
                         appling       => 6178,
                         aquilar       => 6909,
                         aquino        => 2226,
                         aragon        => 1652,
                         araiza        => 6564,
                         arana         => 5825,
                         aranda        => 2670,
                         arango        => 6838,
                         araujo        => 3986,
                         arbogast      => 4351,
                         arbuckle      => 6767,
                         arce          => 2159,
                         arceneaux     => 5146,
                         archambault   => 6706,
                         archer        => 876,
                         archibald     => 2914,
                         archuleta     => 2318,
                         arciniega     => 7767,
                         ardoin        => 4930,
                         arellano      => 1252,
                         arenas        => 6352,
                         arends        => 9883,
                         arevalo       => 2373,
                         argo          => 6177,
                         arguelles     => 7943,
                         arguello      => 5727,
                         argueta       => 5775,
                         arias         => 1043,
                         arispe        => 8908,
                         armbruster    => 5590,
                         armendariz    => 4299,
                         armenta       => 3731,
                         armentrout    => 6632,
                         armes         => 7858,
                         armijo        => 3160,
                         armistead     => 8368,
                         armitage      => 6446,
                         armour        => 4567,
                         armstead      => 2401,
                         armstrong     => 177,
                         arndt         => 2654,
                         arneson       => 8134,
                         arnett        => 2098,
                         arnold        => 161,
                         arnone        => 7942,
                         arocho        => 9882,
                         aronson       => 5222,
                         arredondo     => 1570,
                         arreola       => 2994,
                         arriaga       => 3265,
                         arrington     => 968,
                         arriola       => 4194,
                         arrowood      => 5110,
                         arroyo        => 870,
                         arruda        => 5635,
                         arsenault     => 2344,
                         arteaga       => 2755,
                         artis         => 2139,
                         artrip        => 8698,
                         arvizu        => 7417,
                         arwood        => 7353,
                         arzola        => 7584,
                         asberry       => 7352,
                         asbury        => 3480,
                         ascencio      => 9025,
                         ashbaugh      => 8367,
                         ashburn       => 5634,
                         ashby         => 1535,
                         ashcraft      => 2290,
                         ashe          => 3264,
                         asher         => 2298,
                         ashford       => 2653,
                         ashmore       => 3752,
                         ashworth      => 2723,
                         askew         => 1617,
                         askins        => 7190,
                         aston         => 5633,
                         astorga       => 9251,
                         atchison      => 3449,
                         atchley       => 4486,
                         atencio       => 6071,
                         atherton      => 3245,
                         athey         => 7857,
                         atkin         => 9138,
                         atkins        => 445,
                         atkinson      => 556,
                         attaway       => 6351,
                         atterberry    => 9737,
                         atwater       => 6705,
                         atwell        => 2609,
                         atwood        => 1434,
                         aube          => 8037,
                         aubin         => 6445,
                         aubuchon      => 8810,
                         aucoin        => 4417,
                         audet         => 6766,
                         audette       => 6125,
                         auger         => 4485,
                         auguste       => 9488,
                         auld          => 7503,
                         ault          => 3814,
                         aultman       => 7766,
                         auten         => 6397,
                         autrey        => 5387,
                         autry         => 3412,
                         avalos        => 1722,
                         avant         => 4386,
                         avelar        => 5492,
                         avent         => 6908,
                         averett       => 7189,
                         averill       => 5968,
                         avila         => 536,
                         aviles        => 1801,
                         avina         => 6631,
                         axtell        => 9736,
                         ayala         => 456,
                         aycock        => 4385,
                         ayer          => 6510,
                         ayers         => 591,
                         ayotte        => 6350,
                         ayres         => 2380,
                         azar          => 8366,
                         azevedo       => 4792,
                         azure         => 7765,
                         babb          => 1584,
                         babbitt       => 4791,
                         babcock       => 1429,
                         baber         => 4166,
                         babin         => 2638,
                         babineaux     => 6124,
                         baca          => 1163,
                         bach          => 3054,
                         bachman       => 2551,
                         bachmann      => 9137,
                         backer        => 6509,
                         backes        => 9735,
                         backman       => 6123,
                         backus        => 4327,
                         bacon         => 896,
                         bade          => 6837,
                         bader         => 3520,
                         badgett       => 8133,
                         badillo       => 4034,
                         baer          => 1990,
                         baez          => 1339,
                         baeza         => 4646,
                         bagby         => 4731,
                         baggett       => 1839,
                         bagley        => 1800,
                         bagwell       => 2400,
                         bahena        => 5589,
                         bahr          => 4416,
                         baier         => 6349,
                         bailes        => 7351,
                         bailey        => 58,
                         baillargeon   => 6907,
                         baily         => 5588,
                         bain          => 1544,
                         baines        => 2968,
                         bair          => 2588,
                         baird         => 787,
                         baisden       => 8245,
                         baker         => 35,
                         bakke         => 6906,
                         bakken        => 8132,
                         bakker        => 7350,
                         balch         => 5386,
                         balcom        => 7681,
                         balderas      => 3211,
                         baldridge     => 4078,
                         baldwin       => 307,
                         bales         => 2171,
                         ball          => 291,
                         ballance      => 7349,
                         ballard       => 387,
                         ballenger     => 6285,
                         ballentine    => 7764,
                         ballesteros   => 4894,
                         ballew        => 4269,
                         ballinger     => 4077,
                         ballou        => 4101,
                         baltazar      => 6348,
                         balzer        => 7856,
                         banas         => 6836,
                         bancroft      => 5008,
                         banda         => 2317,
                         bandy         => 2624,
                         bane          => 4449,
                         bangs         => 7855,
                         banister      => 6176,
                         bankhead      => 8477,
                         banks         => 200,
                         bankston      => 3069,
                         banning       => 9487,
                         bannister     => 2846,
                         bannon        => 6347,
                         banta         => 4830,
                         banuelos      => 3210,
                         baptiste      => 2781,
                         barahona      => 7116,
                         barajas       => 1388,
                         baran         => 4645,
                         baranowski    => 8244,
                         barba         => 3751,
                         barbee        => 2309,
                         barber        => 304,
                         barbieri      => 6444,
                         barbosa       => 2470,
                         barbour       => 1815,
                         barboza       => 5315,
                         barclay       => 2269,
                         bard          => 4100,
                         barden        => 3730,
                         bardwell      => 6960,
                         barela        => 3750,
                         barfield      => 2154,
                         barger        => 1734,
                         barham        => 3749,
                         barhorst      => 6346,
                         barker        => 287,
                         barksdale     => 1937,
                         barlow        => 849,
                         barnard       => 1142,
                         barner        => 4690,
                         barnes        => 75,
                         barnett       => 249,
                         barnette      => 2740,
                         barnhart      => 1561,
                         barnhill      => 2709,
                         barns         => 5878,
                         barnum        => 4607,
                         barnwell      => 4484,
                         baron         => 1874,
                         barone        => 3100,
                         barr          => 610,
                         barragan      => 4606,
                         barraza       => 2811,
                         barre         => 8365,
                         barrera       => 777,
                         barreras      => 8809,
                         barreto       => 3962,
                         barrett       => 254,
                         barrette      => 9250,
                         barrick       => 7025,
                         barrientos    => 4013,
                         barringer     => 4165,
                         barrios       => 1776,
                         barron        => 625,
                         barros        => 6018,
                         barroso       => 8907,
                         barrow        => 1510,
                         barrows       => 2708,
                         barstow       => 9618,
                         barta         => 6905,
                         bartel        => 5967,
                         bartell       => 7188,
                         bartels       => 3677,
                         bartelt       => 8600,
                         barter        => 9361,
                         barth         => 1847,
                         bartholomew   => 2013,
                         bartlett      => 605,
                         bartley       => 1553,
                         barton        => 423,
                         bartz         => 4730,
                         barwick       => 9024,
                         bascom        => 8131,
                         bash          => 5922,
                         basham        => 2545,
                         bashaw        => 6630,
                         basile        => 4448,
                         basinger      => 7680,
                         baskerville   => 6017,
                         baskin        => 3825,
                         basnight      => 9734,
                         bass          => 408,
                         bassett       => 1302,
                         basso         => 5921,
                         bastian       => 4689,
                         batchelder    => 4644,
                         batchelor     => 2873,
                         bateman       => 1411,
                         bates         => 267,
                         batey         => 6226,
                         batista       => 2560,
                         batiste       => 3379,
                         batres        => 9733,
                         batson        => 3467,
                         battaglia     => 3302,
                         batten        => 3170,
                         battista      => 8130,
                         battles       => 3301,
                         batton        => 7416,
                         batts         => 2066,
                         batty         => 7415,
                         baty          => 7679,
                         baucom        => 6443,
                         bauder        => 8808,
                         bauer         => 612,
                         baugh         => 2117,
                         baugher       => 5966,
                         baughman      => 2103,
                         baum          => 1908,
                         bauman        => 1989,
                         baumann       => 3030,
                         baumgardner   => 3923,
                         baumgartner   => 3196,
                         baur          => 7763,
                         bautista      => 1376,
                         baxley        => 3772,
                         baxter        => 497,
                         bayer         => 2993,
                         bayles        => 7348,
                         bayless       => 4643,
                         baylor        => 3539,
                         bayne         => 3791,
                         baynes        => 9617,
                         bays          => 3863,
                         bazan         => 6835,
                         bazemore      => 7024,
                         beach         => 814,
                         beacham       => 9486,
                         beadle        => 7762,
                         beahm         => 9732,
                         beaird        => 7023,
                         beal          => 1375,
                         beale         => 2967,
                         beall         => 2587,
                         beals         => 3502,
                         beam          => 1733,
                         beaman        => 4193,
                         beamon        => 4033,
                         bean          => 624,
                         beane         => 3813,
                         beard         => 534,
                         bearden       => 1679,
                         beardsley     => 4099,
                         beasley       => 503,
                         beason        => 5109,
                         beaton        => 6175,
                         beattie       => 2722,
                         beatty        => 978,
                         beaty         => 2020,
                         beauchamp     => 2428,
                         beaudette     => 7347,
                         beaudoin      => 2944,
                         beaudry       => 4216,
                         beaulieu      => 1936,
                         beaumont      => 7022,
                         beauregard    => 3432,
                         beavers       => 1775,
                         becerra       => 1755,
                         bechtel       => 4098,
                         bechtold      => 5774,
                         beck          => 271,
                         becker        => 354,
                         beckett       => 2399,
                         beckford      => 6704,
                         beckley       => 5824,
                         beckman       => 1765,
                         beckner       => 7502,
                         beckstead     => 9136,
                         beckwith      => 2476,
                         becnel        => 3169,
                         becton        => 8697,
                         bedard        => 3431,
                         bedell        => 4268,
                         bedford       => 2979,
                         bednar        => 9023,
                         bedwell       => 6345,
                         beebe         => 1784,
                         beecher       => 5221,
                         beeler        => 3411,
                         beem          => 8364,
                         beeman        => 4447,
                         beene         => 7346,
                         beers         => 2862,
                         beery         => 5726,
                         beesley       => 8129,
                         beeson        => 3985,
                         begay         => 1591,
                         beggs         => 5965,
                         begley        => 2435,
                         behling       => 7115,
                         behnke        => 9360,
                         behr          => 6284,
                         behrens       => 2475,
                         beier         => 9135,
                         beiler        => 9134,
                         bejarano      => 6629,
                         belanger      => 1442,
                         belcher       => 920,
                         belden        => 6508,
                         belew         => 7501,
                         belisle       => 6225,
                         belk          => 4642,
                         belknap       => 7854,
                         bell          => 56,
                         bellamy       => 1551,
                         beller        => 6765,
                         bellinger     => 4688,
                         belliveau     => 9133,
                         bello         => 2524,
                         bellows       => 6016,
                         belton        => 3053,
                         beltran       => 1045,
                         beltz         => 7114,
                         bemis         => 4566,
                         benally       => 5044,
                         benavides     => 1560,
                         benavidez     => 2379,
                         benbow        => 7678,
                         benda         => 9359,
                         bender        => 727,
                         benedetto     => 6563,
                         benefield     => 3634,
                         benevides     => 9881,
                         benfield      => 5632,
                         benford       => 4605,
                         benge         => 4140,
                         bengtson      => 9249,
                         benham        => 4565,
                         benites       => 8476,
                         benitez       => 1251,
                         benn          => 5272,
                         benner        => 2275,
                         bennet        => 5422,
                         bennett       => 73,
                         benning       => 7583,
                         bennington    => 7761,
                         benoit        => 1458,
                         benson        => 301,
                         bentley       => 689,
                         benton        => 651,
                         bentz         => 4641,
                         benz          => 5920,
                         berard        => 5678,
                         berardi       => 9358,
                         berg          => 661,
                         bergen        => 4511,
                         berger        => 763,
                         bergeron      => 1036,
                         berggren      => 9880,
                         bergin        => 6283,
                         berglund      => 6764,
                         bergman       => 1569,
                         bergmann      => 6174,
                         bergquist     => 7345,
                         bergstrom     => 3501,
                         berkey        => 7414,
                         berkley       => 5919,
                         berkowitz     => 5347,
                         berman        => 1942,
                         bermudez      => 1623,
                         bernabe       => 9248,
                         bernal        => 1159,
                         bernardi      => 9247,
                         berndt        => 4829,
                         berner        => 7021,
                         bernhardt     => 4012,
                         bernier       => 1873,
                         bernstein     => 1754,
                         berrios       => 2462,
                         berry         => 159,
                         berryhill     => 5491,
                         berryman      => 3616,
                         berthiaume    => 9731,
                         bertrand      => 2954,
                         bertsch       => 9246,
                         berube        => 2739,
                         bessette      => 5964,
                         betancourt    => 2225,
                         bethea        => 2360,
                         bethune       => 7677,
                         bettencourt   => 4164,
                         bettis        => 4118,
                         betts         => 1191,
                         betz          => 3676,
                         bevan         => 7676,
                         bever         => 9879,
                         beveridge     => 6344,
                         bevins        => 4032,
                         bevis         => 7675,
                         bewley        => 7500,
                         beyer         => 1819,
                         bianchi       => 5078,
                         bianco        => 5007,
                         bias          => 4446,
                         bibb          => 6442,
                         bibbs         => 5963,
                         bice          => 5108,
                         bickel        => 4754,
                         bickerstaff   => 7582,
                         bickford      => 3052,
                         bickley       => 9132,
                         bicknell      => 9022,
                         biddle        => 2456,
                         bidwell       => 5421,
                         bieber        => 6343,
                         bierman       => 4828,
                         bigelow       => 2523,
                         biggers       => 6562,
                         biggerstaff   => 6763,
                         biggs         => 1260,
                         bigham        => 4604,
                         bigler        => 5456,
                         bigley        => 7941,
                         bilbrey       => 7272,
                         biles         => 6628,
                         biller        => 7674,
                         billings      => 1110,
                         billingsley   => 2138,
                         billington    => 5587,
                         billiot       => 3729,
                         billman       => 8475,
                         bills         => 2550,
                         billups       => 2601,
                         bilodeau      => 3907,
                         bilyeu        => 6904,
                         binder        => 2577,
                         binette       => 6762,
                         binford       => 7271,
                         bingaman      => 7499,
                         bingham       => 1012,
                         binion        => 5725,
                         binkley       => 3560,
                         binns         => 6015,
                         birch         => 2532,
                         birchfield    => 5586,
                         bird          => 835,
                         birdsall      => 8474,
                         birdsong      => 4564,
                         birdwell      => 6834,
                         birkholz      => 9357,
                         birnbaum      => 8473,
                         biron         => 8906,
                         birt          => 8243,
                         bischoff      => 4510,
                         bish          => 6070,
                         bishop        => 202,
                         bissell       => 5877,
                         bisson        => 3633,
                         bissonnette   => 4729,
                         bitner        => 8242,
                         bittle        => 8807,
                         bittner       => 3500,
                         bivens        => 2833,
                         bivins        => 3499,
                         bixby         => 6342,
                         bixler        => 4603,
                         bjork         => 8599,
                         black         => 141,
                         blackburn     => 639,
                         blackford     => 5314,
                         blackman      => 1583,
                         blackmon      => 1239,
                         blackmore     => 6507,
                         blackshear    => 5631,
                         blackstock    => 6173,
                         blackstone    => 7673,
                         blackwell     => 538,
                         blackwood     => 3349,
                         blagg         => 9730,
                         blain         => 5313,
                         blair         => 336,
                         blais         => 3083,
                         blaisdell     => 6122,
                         blakely       => 2236,
                         blakemore     => 7344,
                         blakeney      => 5455,
                         blakeslee     => 7853,
                         blakey        => 7343,
                         blakley       => 6959,
                         blakney       => 7187,
                         blalock       => 1794,
                         blanc         => 7113,
                         blanchard     => 646,
                         blanchette    => 3184,
                         blanco        => 1238,
                         bland         => 884,
                         blanding      => 5538,
                         blaney        => 7112,
                         blank         => 1807,
                         blankenship   => 540,
                         blanks        => 4215,
                         blanton       => 941,
                         blaser        => 9021,
                         blasingame    => 8696,
                         blassingame   => 9485,
                         blatt         => 9131,
                         blaylock      => 3209,
                         bledsoe       => 1433,
                         blevins       => 630,
                         bliss         => 1625,
                         bloch         => 6903,
                         blocker       => 2495,
                         blodgett      => 2861,
                         blomquist     => 7672,
                         bloodworth    => 6441,
                         bloom         => 1194,
                         bloomer       => 5454,
                         bloomfield    => 4790,
                         bloomquist    => 8598,
                         blosser       => 9245,
                         blough        => 9616,
                         blouin        => 8128,
                         blount        => 1230,
                         blubaugh      => 9878,
                         bluhm         => 7498,
                         blum          => 1793,
                         blumberg      => 8695,
                         blume         => 5043,
                         blumenthal    => 7413,
                         blunt         => 2707,
                         boardman      => 4542,
                         boatman       => 4076,
                         boatner       => 9130,
                         boatright     => 3961,
                         boatwright    => 3728,
                         bobb          => 8127,
                         bobbitt       => 3559,
                         bober         => 9729,
                         bobo          => 2372,
                         bocanegra     => 6561,
                         bock          => 2823,
                         boddie        => 5490,
                         bode          => 4326,
                         boden         => 6703,
                         bodie         => 9244,
                         bodine        => 6506,
                         bodnar        => 7111,
                         bodner        => 9129,
                         boehm         => 3519,
                         boettcher     => 4011,
                         bogan         => 2966,
                         bogard        => 7581,
                         boger         => 5585,
                         boggess       => 6396,
                         boggs         => 877,
                         bogle         => 4509,
                         bogue         => 9128,
                         bohanan       => 9127,
                         bohannan      => 8363,
                         bohannon      => 2442,
                         bohn          => 3448,
                         bohon         => 9615,
                         bohrer        => 9877,
                         boisvert      => 3657,
                         bojorquez     => 6395,
                         boland        => 3558,
                         bolanos       => 5962,
                         bolden        => 971,
                         bolding       => 5537,
                         boldt         => 7020,
                         bolduc        => 2872,
                         bolen         => 3300,
                         boles         => 1729,
                         boley         => 7760,
                         bolick        => 5584,
                         bolin         => 2297,
                         boling        => 2455,
                         bolinger      => 5918,
                         bolling       => 3812,
                         bollinger     => 2097,
                         bollman       => 8806,
                         bolt          => 3410,
                         bolton        => 817,
                         bolyard       => 7759,
                         boman         => 8362,
                         bomar         => 7852,
                         bonanno       => 8036,
                         bonar         => 8905,
                         bond          => 492,
                         bonds         => 1566,
                         bondurant     => 9126,
                         boney         => 6560,
                         bonham        => 4415,
                         bonilla       => 1074,
                         bonin         => 6069,
                         bonneau       => 9125,
                         bonnell       => 6341,
                         bonner        => 743,
                         bonnett       => 5677,
                         bonnette      => 10000,
                         bonney        => 4963,
                         bono          => 6282,
                         bontrager     => 8694,
                         booher        => 4861,
                         booker        => 554,
                         bookman       => 8126,
                         bookout       => 8241,
                         boone         => 427,
                         boose         => 9243,
                         booth         => 518,
                         boothe        => 2992,
                         bopp          => 8125,
                         borchardt     => 8472,
                         borchers      => 8471,
                         bordelon      => 3498,
                         borden        => 1701,
                         borders       => 2549,
                         boren         => 2754,
                         borg          => 5077,
                         borges        => 2913,
                         borja         => 7940,
                         borkholder    => 8597,
                         borkowski     => 6761,
                         borland       => 9876,
                         borman        => 9356,
                         borowski      => 5724,
                         borrego       => 3811,
                         borrero       => 8035,
                         borst         => 6833,
                         borton        => 8904,
                         borum         => 9728,
                         bosch         => 5346,
                         bosley        => 4139,
                         bosse         => 8903,
                         bost          => 4445,
                         bostic        => 2235,
                         bostick       => 3132,
                         bostwick      => 5076,
                         boswell       => 1132,
                         bosworth      => 4444,
                         botelho       => 7186,
                         botello       => 4384,
                         botkin        => 9124,
                         bott          => 5191,
                         bottoms       => 3632,
                         botts         => 4483,
                         bouchard      => 1576,
                         boucher       => 875,
                         boudreau      => 2170,
                         boudreaux     => 1651,
                         bouffard      => 6902,
                         boughton      => 6440,
                         bouie         => 7110,
                         boulanger     => 8361,
                         bouldin       => 5145,
                         boulton       => 9875,
                         boulware      => 8240,
                         bounds        => 3001,
                         bourassa      => 6121,
                         bourdeau      => 9999,
                         bourdon       => 8805,
                         bourg         => 6172,
                         bourgeois     => 1661,
                         bourland      => 9484,
                         bourne        => 2637,
                         bourque       => 2248,
                         bousquet      => 6068,
                         boutin        => 5345,
                         bouton        => 6340,
                         boutte        => 6120,
                         boutwell      => 4640,
                         bova          => 7851,
                         bove          => 4962,
                         bowden        => 1089,
                         bowe          => 4687,
                         bowen         => 303,
                         bowens        => 2224,
                         bower         => 1166,
                         bowers        => 421,
                         bowes         => 5312,
                         bowie         => 1941,
                         bowker        => 7019,
                         bowles        => 1198,
                         bowlin        => 2965,
                         bowman        => 226,
                         bowser        => 1713,
                         bowyer        => 6014,
                         boyce         => 901,
                         boyd          => 126,
                         boyden        => 9874,
                         boyer         => 586,
                         boyes         => 8470,
                         boyett        => 4602,
                         boyette       => 4058,
                         boykin        => 1447,
                         boykins       => 5006,
                         boylan        => 4601,
                         boyle         => 850,
                         boyles        => 1728,
                         boynton       => 3312,
                         bozarth       => 6627,
                         bozeman       => 3656,
                         braaten       => 8596,
                         bracamonte    => 9998,
                         brace         => 4639,
                         bracey        => 6224,
                         brack         => 8239,
                         bracken       => 3940,
                         brackett      => 2680,
                         brackin       => 9483,
                         bracy         => 4929,
                         bradberry     => 6339,
                         bradburn      => 9242,
                         bradbury      => 3497,
                         braddock      => 6013,
                         braddy        => 6832,
                         braden        => 1764,
                         bradfield     => 6831,
                         bradshaw      => 614,
                         brady         => 402,
                         bragdon       => 8360,
                         bragg         => 1255,
                         braggs        => 8804,
                         brainard      => 7270,
                         braithwaite   => 4600,
                         brake         => 4893,
                         braley        => 6505,
                         bramblett     => 8238,
                         brame         => 7850,
                         bramlett      => 5005,
                         brammer       => 7185,
                         branch        => 629,
                         brandenburg   => 3538,
                         brandes       => 8034,
                         brandt        => 924,
                         branham       => 2012,
                         brann         => 5004,
                         brannan       => 4298,
                         brannen       => 7849,
                         brannon       => 1799,
                         branscum      => 7758,
                         branson       => 2636,
                         branstetter   => 8902,
                         brantley      => 1129,
                         branton       => 5876,
                         branum        => 6830,
                         brasfield     => 9241,
                         brashear      => 5453,
                         brashears     => 9020,
                         brasher       => 4686,
                         braswell      => 1678,
                         bratcher      => 3116,
                         brathwaite    => 9240,
                         bratton       => 3131,
                         braud         => 5385,
                         brauer        => 6504,
                         braun         => 984,
                         braunstein    => 9997,
                         bravo         => 1483,
                         brawley       => 5823,
                         brawner       => 5190,
                         braxton       => 1700,
                         bray          => 712,
                         brayton       => 7939,
                         brazell       => 8359,
                         brazelton     => 9123,
                         braziel       => 8358,
                         brazier       => 7848,
                         breault       => 6281,
                         breaux        => 2296,
                         breazeale     => 7412,
                         breckenridge  => 5075,
                         breeden       => 2448,
                         breedlove     => 3042,
                         breen         => 2531,
                         brehm         => 4443,
                         breland       => 4192,
                         bremer        => 6119,
                         brennan       => 648,
                         brenneman     => 7109,
                         brenner       => 1993,
                         breslin       => 9122,
                         bresnahan     => 7671,
                         bressler      => 9239,
                         breton        => 5003,
                         bretz         => 7269,
                         breuer        => 9121,
                         breunig       => 4638,
                         brewer        => 229,
                         brewington    => 4267,
                         brewster      => 1167,
                         brewton       => 5630,
                         briceno       => 7757,
                         bricker       => 4728,
                         brickey       => 8357,
                         brickhouse    => 9873,
                         bridgeman     => 6394,
                         bridgers      => 8033,
                         bridges       => 441,
                         bridgewater   => 8032,
                         bridwell      => 8595,
                         brien         => 5344,
                         briggs        => 394,
                         brigham       => 4191,
                         bright        => 791,
                         brigman       => 8901,
                         briley        => 3906,
                         brill         => 3748,
                         brim          => 3905,
                         brimmer       => 7756,
                         brindle       => 9727,
                         brink         => 2398,
                         brinker       => 7018,
                         brinkerhoff   => 9482,
                         brinkley      => 2045,
                         brinkman      => 3195,
                         brinson       => 2169,
                         brinton       => 7847,
                         briones       => 3223,
                         brisco        => 7017,
                         briscoe       => 1940,
                         briseno       => 3771,
                         brisson       => 8356,
                         brister       => 5629,
                         bristow       => 4637,
                         brito         => 2570,
                         britt         => 761,
                         brittain      => 3430,
                         britten       => 9872,
                         brittingham   => 8355,
                         britton       => 1009,
                         broach        => 9871,
                         broadbent     => 7755,
                         broaddus      => 7268,
                         broadnax      => 3984,
                         broadus       => 7108,
                         broadwater    => 6280,
                         brochu        => 7580,
                         brock         => 405,
                         brockington   => 5583,
                         brockman      => 3082,
                         brockway      => 5723,
                         brode         => 9019,
                         brodeur       => 5536,
                         brodsky       => 7754,
                         brody         => 3922,
                         brogan        => 3615,
                         brogdon       => 6279,
                         brokaw        => 7267,
                         bromley       => 4075,
                         bronson       => 2096,
                         brooker       => 6171,
                         brookins      => 3921,
                         brooks        => 70,
                         brookshire    => 4057,
                         broom         => 5582,
                         broome        => 2411,
                         broomfield    => 8354,
                         brophy        => 5961,
                         brotherton    => 4482,
                         brough        => 8124,
                         broughton     => 2422,
                         broussard     => 1006,
                         brousseau     => 8594,
                         browder       => 3143,
                         brower        => 1881,
                         brown         => 5,
                         browne        => 1347,
                         brownell      => 3960,
                         brownfield    => 6439,
                         browning      => 597,
                         brownlee      => 2308,
                         brownlow      => 9870,
                         broyles       => 2569,
                         brubaker      => 2780,
                         bruder        => 9120,
                         bruggeman     => 9238,
                         bruhn         => 9614,
                         brumbaugh     => 5489,
                         brumfield     => 2568,
                         brumley       => 5002,
                         brummett      => 5042,
                         brundage      => 6170,
                         brune         => 7016,
                         brunelle      => 4789,
                         bruner        => 1607,
                         brunet        => 5420,
                         brunette      => 7670,
                         brunner       => 2038,
                         bruns         => 2679,
                         brunson       => 1274,
                         brust         => 8593,
                         bruton        => 3496,
                         bryant        => 91,
                         bryson        => 1387,
                         bucci         => 7579,
                         buchan        => 9355,
                         buchanan      => 398,
                         bucher        => 3983,
                         buchholz      => 4481,
                         buchman       => 9613,
                         buck          => 657,
                         buckingham    => 3614,
                         buckles       => 5343,
                         buckley       => 652,
                         buckman       => 4860,
                         buckmaster    => 9996,
                         buckner       => 852,
                         budd          => 4246,
                         budde         => 6829,
                         buehler       => 4827,
                         buell         => 4727,
                         bueno         => 2461,
                         buenrostro    => 8237,
                         buettner      => 7846,
                         buffington    => 2515,
                         bufford       => 8031,
                         bugbee        => 9481,
                         bugg          => 4961,
                         buggs         => 5271,
                         buie          => 4097,
                         bulger        => 8236,
                         bullard       => 1148,
                         bullen        => 8469,
                         buller        => 6559,
                         bullington    => 5311,
                         bullins       => 6438,
                         bullis        => 7578,
                         bulloch       => 9612,
                         bullock       => 532,
                         bulluck       => 9995,
                         bulter        => 6012,
                         bumgardner    => 6828,
                         bumgarner     => 3602,
                         bumpus        => 9354,
                         bunce         => 8468,
                         bunch         => 910,
                         bundy         => 1915,
                         bunker        => 3479,
                         bunn          => 2124,
                         bunnell       => 3409,
                         buntin        => 9480,
                         bunting       => 3378,
                         bunton        => 5535,
                         buono         => 9869,
                         burbach       => 9611,
                         burbank       => 4190,
                         burch         => 754,
                         burcham       => 5270,
                         burchell      => 7845,
                         burchett      => 2503,
                         burchette     => 7342,
                         burchfield    => 2929,
                         burd          => 7266,
                         burden        => 1947,
                         burdett       => 4685,
                         burdette      => 2635,
                         burdick       => 1929,
                         burdine       => 6067,
                         burford       => 4753,
                         burg          => 5917,
                         burge         => 2652,
                         burgess       => 315,
                         burgett       => 4859,
                         burgin        => 5581,
                         burgos        => 1299,
                         burk          => 2212,
                         burke         => 222,
                         burkes        => 7015,
                         burkett       => 1242,
                         burkey        => 6702,
                         burkhalter    => 5189,
                         burkhardt     => 4325,
                         burkhart      => 1712,
                         burkhead      => 9353,
                         burkholder    => 3700,
                         burks         => 801,
                         burleigh      => 6760,
                         burleson      => 2329,
                         burley        => 3000,
                         burlingame    => 6901,
                         burman        => 9868,
                         burmeister    => 5188,
                         burnell       => 5488,
                         burnett       => 450,
                         burnette      => 1446,
                         burney        => 2410,
                         burnham       => 1781,
                         burns         => 134,
                         burnside      => 2721,
                         burr          => 1529,
                         burrell       => 1107,
                         burress       => 5580,
                         burris        => 809,
                         burroughs     => 1428,
                         burrow        => 3583,
                         burrows       => 1814,
                         burrus        => 4928,
                         burruss       => 8592,
                         burse         => 8591,
                         burson        => 5144,
                         burton        => 211,
                         burwell       => 4858,
                         busby         => 1548,
                         busch         => 1740,
                         bush          => 276,
                         bushey        => 4480,
                         bushman       => 6169,
                         bushnell      => 5107,
                         bushong       => 9867,
                         buss          => 3408,
                         bussard       => 7938,
                         busse         => 5676,
                         bussell       => 4684,
                         bussey        => 3235,
                         bustamante    => 2219,
                         bustos        => 3557,
                         butcher       => 1297,
                         butera        => 9994,
                         butler        => 87,
                         butterfield   => 2196,
                         butterworth   => 6900,
                         butts         => 981,
                         butz          => 7411,
                         buxton        => 3982,
                         buzzell       => 5628,
                         byars         => 3330,
                         bybee         => 5722,
                         byer          => 8030,
                         byerly        => 6278,
                         byers         => 820,
                         byington      => 6701,
                         byler         => 4683,
                         bynum         => 1445,
                         byram         => 9237,
                         byrd          => 238,
                         byrge         => 9119,
                         byrne         => 1042,
                         byrnes        => 2669,
                         byrum         => 5269,
                         caballero     => 1830,
                         caban         => 3904,
                         cabe          => 7669,
                         cabral        => 2110,
                         cabrales      => 8353,
                         cabrera       => 697,
                         caceres       => 6626,
                         caddell       => 6503,
                         cade          => 2691,
                         cadena        => 4541,
                         cadwell       => 7844,
                         cady          => 2769,
                         caffey        => 7107,
                         cagle         => 1883,
                         cahill        => 1404,
                         cahoon        => 5627,
                         cain          => 433,
                         caine         => 7341,
                         caines        => 7577,
                         cairns        => 5187,
                         calabrese     => 3790,
                         calabro       => 7937,
                         calahan       => 8803,
                         calder        => 5001,
                         caldera       => 5186,
                         calderon      => 751,
                         caldwell      => 246,
                         calfee        => 8590,
                         calhoon       => 9610,
                         calhoun       => 520,
                         calkins       => 2720,
                         callaghan     => 3862,
                         callahan      => 545,
                         callan        => 6700,
                         callaway      => 2031,
                         callen        => 5452,
                         callender     => 3367,
                         callihan      => 7410,
                         callis        => 4383,
                         callison      => 6625,
                         calloway      => 1374,
                         calton        => 7184,
                         calvert       => 1466,
                         calvillo      => 5534,
                         calvo         => 6277,
                         calzada       => 7106,
                         camacho       => 623,
                         camara        => 4056,
                         camarena      => 6899,
                         camargo       => 8467,
                         camarillo     => 3407,
                         cambell       => 3699,
                         camire        => 8352,
                         cammack       => 8589,
                         campa         => 9018,
                         campagna      => 7265,
                         campbell      => 44,
                         campion       => 7409,
                         campo         => 7576,
                         campos        => 543,
                         campuzano     => 8123,
                         canaday       => 7936,
                         canady        => 3366,
                         canale        => 8900,
                         canales       => 1872,
                         canas         => 9017,
                         canchola      => 9866,
                         candelario    => 6624,
                         candler       => 7843,
                         canfield      => 2388,
                         cann          => 6827,
                         cannady       => 5143,
                         canning       => 7183,
                         cannon        => 340,
                         cano          => 1222,
                         cansler       => 9118,
                         cantara       => 7575,
                         canter        => 4350,
                         cantin        => 9479,
                         cantor        => 5875,
                         cantrell      => 748,
                         cantu         => 684,
                         cantwell      => 3556,
                         canty         => 2608,
                         capel         => 8588,
                         capers        => 4726,
                         caples        => 9478,
                         caplinger     => 9117,
                         capps         => 1237,
                         capuano       => 7935,
                         caputo        => 4266,
                         caraballo     => 2607,
                         caraway       => 4010,
                         carbajal      => 3655,
                         carballo      => 9726,
                         carbaugh      => 5451,
                         carbone       => 2201,
                         carden        => 2978,
                         cardenas      => 679,
                         carder        => 3601,
                         cardin        => 6558,
                         cardinale     => 7753,
                         cardona       => 1699,
                         cardone       => 9477,
                         cardoso       => 7752,
                         cardoza       => 3263,
                         cardwell      => 1779,
                         cargile       => 8587,
                         cargill       => 4857,
                         carignan      => 9865,
                         carillo       => 5916,
                         carino        => 9864,
                         carle         => 9725,
                         carleton      => 6393,
                         carlile       => 6276,
                         carlin        => 2586,
                         carlisle      => 1179,
                         carlock       => 8235,
                         carlsen       => 7105,
                         carlson       => 231,
                         carlucci      => 8693,
                         carlyle       => 5960,
                         carmack       => 4096,
                         carmichael    => 1193,
                         carmody       => 5342,
                         carmona       => 1746,
                         carnahan      => 2753,
                         carnell       => 8692,
                         carner        => 6898,
                         carnes        => 1898,
                         carney        => 824,
                         caro          => 3311,
                         caron         => 1516,
                         carothers     => 4508,
                         carpenter     => 178,
                         carpentier    => 9016,
                         carper        => 4214,
                         carpio        => 8029,
                         carr          => 191,
                         carranza      => 2186,
                         carrasco      => 1703,
                         carrasquillo  => 4507,
                         carraway      => 4752,
                         carreiro      => 8802,
                         carrell       => 4245,
                         carreno       => 7497,
                         carreon       => 4599,
                         carreras      => 8691,
                         carrero       => 5341,
                         carrick       => 9863,
                         carrico       => 3839,
                         carrier       => 1633,
                         carrigan      => 4414,
                         carrillo      => 590,
                         carrington    => 1903,
                         carrion       => 3377,
                         carrizales    => 8122,
                         carroll       => 166,
                         carron        => 8899,
                         carruth       => 5959,
                         carruthers    => 5310,
                         carson        => 420,
                         carstens      => 9862,
                         carswell      => 3698,
                         cartagena     => 5626,
                         carter        => 38,
                         cartier       => 8586,
                         cartwright    => 1055,
                         carty         => 4265,
                         caruso        => 2076,
                         caruthers     => 4442,
                         carvajal      => 6223,
                         carvalho      => 3208,
                         carver        => 711,
                         carwile       => 9236,
                         casady        => 9861,
                         casares       => 5384,
                         casarez       => 4382,
                         casas         => 3051,
                         casavant      => 8585,
                         cascio        => 7934,
                         cash          => 816,
                         cashion       => 9116,
                         cashman       => 4540,
                         casiano       => 5958,
                         casias        => 7496,
                         casillas      => 2204,
                         caskey        => 3537,
                         cason         => 2082,
                         cass          => 3280,
                         cassady       => 5268,
                         cassel        => 8351,
                         cassell       => 3939,
                         cassidy       => 1263,
                         cassity       => 7408,
                         castaneda     => 798,
                         castano       => 8028,
                         castanon      => 7014,
                         casteel       => 2871,
                         castellano    => 3600,
                         castellanos   => 1999,
                         castelli      => 8690,
                         castello      => 8466,
                         castellon     => 8689,
                         castillo      => 193,
                         castleberry   => 2964,
                         castleman     => 6623,
                         casto         => 4960,
                         caston        => 6699,
                         castor        => 4959,
                         castorena     => 8465,
                         castrejon     => 9609,
                         castro        => 256,
                         caswell       => 2890,
                         catalan       => 7182,
                         catalano      => 3518,
                         cataldo       => 9015,
                         catchings     => 8234,
                         cate          => 4138,
                         cater         => 6698,
                         cates         => 1213,
                         cathcart      => 5309,
                         catlett       => 4095,
                         catlin        => 6826,
                         cato          => 2690,
                         caton         => 4788,
                         catron        => 3495,
                         caudell       => 7574,
                         caudill       => 1254,
                         caudillo      => 9993,
                         caudle        => 3365,
                         cauley        => 7573,
                         caulfield     => 7104,
                         causey        => 2179,
                         cauthen       => 6338,
                         cavallo       => 8688,
                         cavanaugh     => 2065,
                         cavazos       => 1774,
                         cavender      => 6275,
                         caver         => 9115,
                         cavin         => 8121,
                         caviness      => 6697,
                         cawley        => 6222,
                         cawthon       => 7495,
                         caylor        => 7494,
                         cazares       => 4163,
                         ceballos      => 4563,
                         cedeno        => 5142,
                         cedillo       => 5340,
                         ceja          => 4137,
                         celaya        => 9114,
                         celis         => 9235,
                         centeno       => 3364,
                         cepeda        => 4264,
                         cerda         => 2483,
                         cerna         => 8801,
                         cervantes     => 698,
                         cervantez     => 5721,
                         chabot        => 6696,
                         chacon        => 1599,
                         chadwell      => 7013,
                         chaffee       => 5915,
                         chaffin       => 2768,
                         chaffins      => 9234,
                         chafin        => 4682,
                         chaidez       => 9608,
                         chaisson      => 4636,
                         chalfant      => 8350,
                         chalmers      => 3194,
                         chamberlain   => 940,
                         chamberland   => 9352,
                         chamberlin    => 2779,
                         chambers      => 262,
                         chamblee      => 5625,
                         chambless     => 6118,
                         chambliss     => 3882,
                         chamness      => 6825,
                         champlin      => 5339,
                         chan          => 665,
                         chancey       => 5874,
                         chandler      => 293,
                         chaney        => 768,
                         chang         => 600,
                         chapa         => 2254,
                         chaparro      => 8027,
                         chapin        => 2792,
                         chaplin       => 4244,
                         chapman       => 195,
                         chappel       => 9233,
                         chappell      => 1046,
                         chapple       => 8026,
                         chaput        => 8800,
                         charbonneau   => 7340,
                         charest       => 8025,
                         charette      => 5267,
                         charland      => 8464,
                         charpentier   => 9476,
                         charron       => 4635,
                         chartier      => 5914,
                         chase         => 452,
                         chasse        => 4787,
                         chastain      => 1914,
                         chasteen      => 6274,
                         chatfield     => 8898,
                         chatham       => 6437,
                         chatman       => 1402,
                         chauvin       => 6436,
                         chavarria     => 2397,
                         chavers       => 8463,
                         chaves        => 3881,
                         chavez        => 182,
                         chavira       => 8233,
                         chavis        => 1897,
                         cheatham      => 2218,
                         chee          => 5675,
                         cheek         => 1759,
                         cheever       => 9113,
                         chen          => 631,
                         chenault      => 4958,
                         cheney        => 1962,
                         cheng         => 2064,
                         chenoweth     => 5338,
                         chesley       => 8687,
                         chesney       => 8897,
                         chesnut       => 9860,
                         chesser       => 3631,
                         chesson       => 7572,
                         chestnut      => 2247,
                         cheung        => 3099,
                         chevalier     => 4892,
                         chew          => 3959,
                         chewning      => 8232,
                         chiang        => 7264,
                         chiasson      => 9724,
                         chidester     => 7571,
                         childers      => 915,
                         childress     => 914,
                         childs        => 888,
                         chiles        => 4725,
                         chilson       => 8896,
                         chilton       => 3329,
                         chin          => 1465,
                         chinn         => 4094,
                         chipman       => 5337,
                         chisholm      => 2328,
                         chism         => 3536,
                         chisolm       => 2845,
                         chitwood      => 4009,
                         chiu          => 4093,
                         chivers       => 9992,
                         choate        => 2262,
                         choe          => 5074,
                         choi          => 1281,
                         choquette     => 9607,
                         chouinard     => 6824,
                         chow          => 2460,
                         chrisman      => 4349,
                         christensen   => 391,
                         christenson   => 2307,
                         christiansen  => 1559,
                         christianson  => 2651,
                         christman     => 3115,
                         christner     => 7842,
                         christofferso => 8895,
                         christopherso => 4786,
                         chronister    => 7407,
                         chumley       => 6759,
                         chunn         => 8799,
                         churchill     => 2295,
                         churchwell    => 6695,
                         cifuentes     => 9232,
                         cimino        => 6502,
                         cintron       => 2352,
                         cioffi        => 7668,
                         cirillo       => 9991,
                         cisco         => 5073,
                         cisneros      => 1062,
                         claar         => 5957,
                         clack         => 7493,
                         claiborne     => 7103,
                         clanton       => 3068,
                         clapp         => 3067,
                         clapper       => 4957,
                         clardy        => 7667,
                         clark         => 20,
                         clarke        => 429,
                         clarkson      => 2752,
                         clary         => 2285,
                         clausen       => 4031,
                         claussen      => 7492,
                         clawson       => 3098,
                         claxton       => 6011,
                         clayborn      => 8894,
                         claycomb      => 6557,
                         claypool      => 5220,
                         claypoole     => 6694,
                         claytor       => 7263,
                         cleary        => 2081,
                         cleaver       => 5956,
                         cleaves       => 8024,
                         cleek         => 9475,
                         clegg         => 3697,
                         cleghorn      => 6273,
                         cleland       => 8349,
                         clem          => 3142,
                         clemens       => 2494,
                         clements      => 797,
                         clemmer       => 5487,
                         clemmons      => 3050,
                         clemons       => 784,
                         clevenger     => 2044,
                         click         => 3599,
                         clift         => 5106,
                         cline         => 523,
                         clinkscales   => 8231,
                         cloninger     => 7262,
                         clontz        => 9231,
                         clopton       => 9606,
                         cloud         => 1928,
                         clough        => 2870,
                         clouse        => 4117,
                         clouser       => 9230,
                         cloutier      => 1998,
                         clow          => 7491,
                         clower        => 7490,
                         clowers       => 8462,
                         cloyd         => 7102,
                         cluck         => 9351,
                         cluff         => 7933,
                         clukey        => 9990,
                         clyburn       => 5822,
                         clymer        => 8461,
                         coakley       => 4724,
                         coan          => 8230,
                         coates        => 1171,
                         coats         => 1773,
                         cobb          => 364,
                         cobbs         => 2844,
                         coble         => 2869,
                         cobos         => 5720,
                         coburn        => 1970,
                         cochran       => 451,
                         cochrane      => 3429,
                         cockerham     => 5624,
                         cockrell      => 2434,
                         coddington    => 8798,
                         coelho        => 8120,
                         coen          => 7339,
                         cofer         => 4826,
                         coffelt       => 7570,
                         coffey        => 738,
                         coffield      => 9474,
                         coffin        => 2668,
                         coffman       => 1016,
                         cofield       => 4413,
                         cogan         => 8119,
                         cogburn       => 9605,
                         coggins       => 3981,
                         cogswell      => 7666,
                         cohan         => 9014,
                         cohen         => 331,
                         cohn          => 3049,
                         coil          => 8023,
                         coker         => 1122,
                         colangelo     => 7101,
                         colbert       => 1109,
                         colburn       => 2454,
                         coldiron      => 8348,
                         cole          => 103,
                         colella       => 6117,
                         coleman       => 78,
                         coles         => 1780,
                         coley         => 1606,
                         colgan        => 8686,
                         collado       => 3770,
                         collard       => 6272,
                         collazo       => 2234,
                         collett       => 4074,
                         colletti      => 7261,
                         colley        => 2963,
                         collier       => 437,
                         collings      => 8460,
                         collins       => 48,
                         collinsworth  => 7100,
                         collis        => 9604,
                         collum        => 7489,
                         colman        => 6271,
                         colombo       => 6556,
                         colon         => 380,
                         colquitt      => 6555,
                         colson        => 2889,
                         colston       => 4243,
                         colter        => 6010,
                         colucci       => 5486,
                         colunga       => 4723,
                         colvin        => 1259,
                         colwell       => 3114,
                         colyer        => 9350,
                         combs         => 479,
                         comeau        => 5041,
                         comeaux       => 4008,
                         comer         => 1628,
                         compton       => 780,
                         comstock      => 2585,
                         conant        => 5579,
                         conard        => 9229,
                         conaway       => 3494,
                         conde         => 5185,
                         conder        => 8797,
                         condon        => 2559,
                         cone          => 2738,
                         coney         => 4598,
                         confer        => 7488,
                         congdon       => 6897,
                         conger        => 3727,
                         conklin       => 1161,
                         conley        => 448,
                         conlin        => 6554,
                         conlon        => 4722,
                         conn          => 1336,
                         connally      => 7932,
                         connell       => 1532,
                         connelly      => 1410,
                         conner        => 358,
                         conners       => 3726,
                         connolly      => 1138,
                         connors       => 1565,
                         conover       => 3041,
                         conroy        => 1854,
                         constantine   => 5955,
                         constantino   => 6553,
                         conte         => 3838,
                         conti         => 2860,
                         contreras     => 495,
                         converse      => 5184,
                         conway        => 572,
                         conwell       => 6116,
                         conyers       => 3244,
                         cook          => 54,
                         cooke         => 857,
                         cooks         => 2888,
                         cooksey       => 3837,
                         cookson       => 8022,
                         cooley        => 741,
                         coolidge      => 8347,
                         coombs        => 3130,
                         coomer        => 6009,
                         coomes        => 9603,
                         coon          => 1493,
                         cooney        => 2421,
                         coonrod       => 8796,
                         coons         => 3613,
                         cooper        => 60,
                         coots         => 9349,
                         cope          => 1290,
                         copeland      => 400,
                         copenhaver    => 7099,
                         copley        => 3097,
                         coppage       => 7665,
                         copple        => 9602,
                         coppock       => 9348,
                         coppola       => 3810,
                         corbett       => 956,
                         corbin        => 1044,
                         corbitt       => 3675,
                         corby         => 9723,
                         corcoran      => 1645,
                         cordeiro      => 5183,
                         corder        => 4681,
                         cordero       => 1296,
                         cordes        => 5419,
                         cordle        => 8685,
                         cordoba       => 7931,
                         cordova       => 946,
                         coria         => 9013,
                         corley        => 1335,
                         cormier       => 1245,
                         cornejo       => 4055,
                         cornelison    => 6823,
                         cornett       => 1219,
                         cornish       => 2306,
                         cornwell      => 2268,
                         coronado      => 1676,
                         coronel       => 7338,
                         corpuz        => 7337,
                         corr          => 8021,
                         corral        => 2962,
                         corrales      => 5418,
                         correa        => 1078,
                         correia       => 3363,
                         correll       => 4479,
                         corrigan      => 3159,
                         corriveau     => 6115,
                         corso         => 6270,
                         corson        => 5773,
                         cortes        => 1365,
                         cortese       => 7930,
                         cortez        => 428,
                         cortinas      => 9722,
                         corum         => 6552,
                         corwin        => 3861,
                         cosby         => 2453,
                         cosentino     => 8118,
                         cosey         => 9112,
                         cosgrove      => 3466,
                         cosme         => 4562,
                         cosper        => 6337,
                         coss          => 6896,
                         cossey        => 9347,
                         costa         => 923,
                         costanzo      => 7260,
                         costello      => 1093,
                         coston        => 5308,
                         cota          => 2548,
                         cote          => 778,
                         cothran       => 3836,
                         cotten        => 4539,
                         cotter        => 2697,
                         cottingham    => 5105,
                         cottle        => 4136,
                         cotto         => 4856,
                         cotton        => 744,
                         cottrell      => 1798,
                         cottrill      => 8584,
                         couch         => 1050,
                         coughlin      => 2168,
                         coulombe      => 5873,
                         coulson       => 6066,
                         coulter       => 1329,
                         countryman    => 6435,
                         counts        => 2751,
                         cournoyer     => 9012,
                         coursey       => 9601,
                         courson       => 6065,
                         courtemanche  => 9600,
                         courtright    => 9473,
                         courville     => 9989,
                         coury         => 9472,
                         cousins       => 2689,
                         couto         => 9721,
                         couture       => 1788,
                         covarrubias   => 4927,
                         covell        => 9011,
                         covert        => 3328,
                         covey         => 3517,
                         covington     => 906,
                         cowan         => 868,
                         cowans        => 6693,
                         coward        => 3406,
                         cowart        => 2396,
                         cowden        => 6692,
                         cowell        => 3938,
                         cowen         => 4926,
                         cowgill       => 7751,
                         cowles        => 3747,
                         cowley        => 3746,
                         cox           => 62,
                         coyle         => 1693,
                         coyne         => 3096,
                         cozart        => 5623,
                         crabb         => 5040,
                         crabtree      => 966,
                         craddock      => 3207,
                         craft         => 783,
                         crafton       => 6008,
                         craighead     => 7841,
                         crain         => 1488,
                         craine        => 9859,
                         cram          => 6622,
                         cramer        => 992,
                         crampton      => 7259,
                         crandall      => 1564,
                         crandell      => 5000,
                         cranford      => 3299,
                         cranmer       => 8684,
                         cranston      => 9988,
                         crase         => 9346,
                         craven        => 1907,
                         cravens       => 5219,
                         craver        => 6114,
                         crawford      => 125,
                         crawley       => 2253,
                         cray          => 8346,
                         crayton       => 3141,
                         creamer       => 3465,
                         creasy        => 7929,
                         creech        => 1846,
                         creed         => 4162,
                         creekmore     => 5913,
                         creel         => 3048,
                         creighton     => 2991,
                         crenshaw      => 1474,
                         crespo        => 2053,
                         cress         => 4161,
                         creswell      => 8583,
                         crews         => 1158,
                         cribb         => 7336,
                         cribbs        => 5533,
                         crick         => 8795,
                         crider        => 2623,
                         crigger       => 8345,
                         crim          => 5872,
                         crimmins      => 9010,
                         criner        => 8229,
                         crippen       => 7664,
                         crisp         => 1853,
                         criss         => 4956,
                         crissman      => 8020,
                         crist         => 2469,
                         criswell      => 3654,
                         critchlow     => 9471,
                         crites        => 4955,
                         crittenden    => 3362,
                         crittendon    => 9345,
                         crochet       => 8117,
                         crocker       => 1118,
                         crockett      => 1053,
                         croft         => 1865,
                         cromer        => 2887,
                         cromwell      => 2327,
                         crone         => 7569,
                         cronin        => 1684,
                         cronk         => 5578,
                         crook         => 1732,
                         crooks        => 2547,
                         croom         => 5104,
                         cropper       => 5622,
                         crosby        => 660,
                         cross         => 318,
                         crossland     => 6392,
                         crossley      => 5182,
                         crossman      => 4242,
                         crosson       => 7406,
                         croteau       => 2696,
                         crotty        => 6822,
                         crouch        => 1029,
                         crouse        => 2146,
                         crow          => 1008,
                         crowder       => 1165,
                         crowe         => 881,
                         crowell       => 1399,
                         crowl         => 8228,
                         crowley       => 907,
                         crowson       => 6895,
                         crowther      => 8344,
                         croy          => 4855,
                         crozier       => 5772,
                         cruce         => 7840,
                         crum          => 945,
                         crumb         => 6958,
                         crumbley      => 9470,
                         crumley       => 5307,
                         crump         => 1268,
                         crumpler      => 6821,
                         crumpton      => 4116,
                         cruse         => 3361,
                         crutcher      => 2606,
                         crutchfield   => 2778,
                         cruz          => 112,
                         cuellar       => 1913,
                         cueto         => 9987,
                         cuevas        => 1030,
                         culberson     => 8683,
                         culbertson    => 2719,
                         culbreth      => 6691,
                         cull          => 7405,
                         cullen        => 1558,
                         culler        => 5450,
                         culley        => 7750,
                         cullinan      => 9344,
                         cullins       => 9228,
                         cullum        => 7749,
                         culp          => 2223,
                         culpepper     => 2167,
                         culver        => 1528,
                         cumberbatch   => 8682,
                         cummings      => 305,
                         cummins       => 1215,
                         cundiff       => 4721,
                         cunha         => 6957,
                         cunningham    => 170,
                         cuomo         => 5719,
                         cupp          => 3516,
                         curcio        => 7928,
                         cureton       => 4825,
                         curiel        => 4324,
                         curl          => 5954,
                         curlee        => 9469,
                         curley        => 2116,
                         curran        => 1210,
                         currey        => 8582,
                         currie        => 1503,
                         currier       => 2195,
                         currin        => 6007,
                         curry         => 284,
                         curtin        => 3405,
                         curtiss       => 6336,
                         curtsinger    => 9720,
                         cusack        => 8343,
                         cushing       => 4160,
                         cushman       => 3598,
                         cusick        => 5306,
                         custer        => 2868,
                         cuthbertson   => 7568,
                         cutler        => 1829,
                         cutlip        => 9719,
                         cutright      => 8227,
                         cutshall      => 7258,
                         cutts         => 9599,
                         dabbs         => 4189,
                         dabney        => 3769,
                         dabrowski     => 8794,
                         dacosta       => 4241,
                         dade          => 8581,
                         daggett       => 4891,
                         dagostino     => 4213,
                         dahl          => 1316,
                         dahlberg      => 7567,
                         dahlgren      => 6551,
                         daigle        => 1715,
                         dail          => 6894,
                         dailey        => 919,
                         dalessandro   => 6550,
                         dalessio      => 6621,
                         daley         => 1267,
                         dalrymple     => 4538,
                         dalton        => 535,
                         daly          => 1137,
                         damato        => 6064,
                         dambrosio     => 7012,
                         dameron       => 6335,
                         damiano       => 7487,
                         damico        => 2600,
                         dampier       => 7748,
                         damron        => 3066,
                         dancy         => 3065,
                         dandrea       => 4925,
                         dandridge     => 6221,
                         danford       => 7663,
                         danforth      => 4159,
                         dangelo       => 3064,
                         dangerfield   => 7566,
                         daniels       => 142,
                         danielson     => 2859,
                         danley        => 5912,
                         danner        => 2650,
                         dansby        => 5072,
                         dantzler      => 4999,
                         darby         => 1453,
                         dardar        => 4597,
                         darden        => 1470,
                         darr          => 4680,
                         darrah        => 8681,
                         darrow        => 4596,
                         dart          => 8019,
                         dasher        => 6690,
                         dashiell      => 8342,
                         dasilva       => 3493,
                         daugherty     => 762,
                         daughtery     => 9598,
                         daughtry      => 3903,
                         davalos       => 9227,
                         davenport     => 453,
                         daves         => 6893,
                         davey         => 4720,
                         davidson      => 239,
                         davie         => 7565,
                         davies        => 935,
                         davila        => 1021,
                         davis         => 6,
                         davison       => 1273,
                         davisson      => 7181,
                         davy          => 7747,
                         dawes         => 4478,
                         dawkins       => 1384,
                         dawson        => 279,
                         daye          => 5383,
                         dayton        => 3492,
                         deanda        => 5141,
                         deangelis     => 4561,
                         deans         => 5953,
                         dearborn      => 6063,
                         dearing       => 4412,
                         dearman       => 7404,
                         deas          => 6006,
                         deason        => 4411,
                         deatherage    => 9111,
                         deaton        => 1896,
                         deaver        => 7011,
                         deberry       => 3980,
                         deboer        => 4212,
                         debolt        => 9343,
                         debord        => 9597,
                         debose        => 5871,
                         decamp        => 9226,
                         decarlo       => 6269,
                         decastro      => 6168,
                         decicco       => 9342,
                         deckard       => 5870,
                         decker        => 558,
                         decosta       => 5071,
                         decoteau      => 4410,
                         dedmon        => 9596,
                         dedrick       => 9009,
                         deegan        => 8018,
                         deel          => 7098,
                         deemer        => 8893,
                         deen          => 5336,
                         deering       => 4409,
                         dees          => 2886,
                         deese         => 4679,
                         deeter        => 9595,
                         defazio       => 8341,
                         defelice      => 6758,
                         deford        => 9858,
                         deforest      => 7839,
                         degeorge      => 9986,
                         degraff       => 9225,
                         degraw        => 8017,
                         degroot       => 8226,
                         deguzman      => 6334,
                         dehaan        => 8892,
                         dehart        => 2634,
                         dehaven       => 4441,
                         deherrera     => 7746,
                         deitz         => 6620,
                         dejesus       => 842,
                         dejong        => 7662,
                         delacruz      => 840,
                         delafuente    => 5218,
                         delagarza     => 2622,
                         delancey      => 8340,
                         delaney       => 802,
                         delano        => 5621,
                         delao         => 6892,
                         delapaz       => 5103,
                         delapena      => 9341,
                         delarosa      => 1018,
                         delatorre     => 2030,
                         delcastillo   => 9008,
                         deleo         => 8680,
                         deleon        => 517,
                         delgadillo    => 3491,
                         delgado       => 326,
                         delisle       => 4348,
                         delk          => 5952,
                         dellinger     => 2858,
                         deloach       => 2241,
                         deloatch      => 8891,
                         delong        => 1632,
                         delorenzo     => 7486,
                         delossantos   => 2558,
                         delozier      => 7661,
                         delp          => 6333,
                         delreal       => 8679,
                         delrio        => 4323,
                         delrosario    => 7180,
                         deltoro       => 7335,
                         deluca        => 2281,
                         delucia       => 9224,
                         deluna        => 5039,
                         delvalle      => 2351,
                         delvecchio    => 8580,
                         demaio        => 8678,
                         demarco       => 2737,
                         demars        => 7097,
                         demby         => 9857,
                         demello       => 6167,
                         dement        => 6166,
                         demers        => 3081,
                         deming        => 5140,
                         demoss        => 5038,
                         demps         => 8677,
                         dempsey       => 1061,
                         denby         => 9985,
                         dendy         => 6332,
                         denham        => 2867,
                         denison       => 4751,
                         denman        => 4092,
                         dennard       => 5869,
                         denney        => 2459,
                         dennie        => 9718,
                         denning       => 2961,
                         dennison      => 1484,
                         densmore      => 5266,
                         denson        => 1797,
                         dent          => 1842,
                         denton        => 1035,
                         depalma       => 7838,
                         depasquale    => 9223,
                         depew         => 4924,
                         depriest      => 4506,
                         derosa        => 3824,
                         derose        => 7257,
                         derosier      => 6619,
                         derouen       => 7745,
                         derr          => 3428,
                         derry         => 5577,
                         derryberry    => 7096,
                         desai         => 4297,
                         desalvo       => 7927,
                         desantiago    => 9468,
                         desantis      => 3040,
                         deschamps     => 9340,
                         deshields     => 9594,
                         desilva       => 5181,
                         desimone      => 3745,
                         desjardins    => 4188,
                         desmarais     => 5070,
                         desousa       => 9593,
                         desouza       => 8225,
                         despain       => 6820,
                         despres       => 9984,
                         desrochers    => 5771,
                         desroches     => 9467,
                         desrosiers    => 4537,
                         destefano     => 5485,
                         detweiler     => 9983,
                         detwiler      => 7179,
                         devaney       => 7334,
                         devaughn      => 7485,
                         devault       => 8459,
                         deveau        => 8676,
                         dever         => 4890,
                         devers        => 9982,
                         deville       => 6062,
                         devine        => 1277,
                         devito        => 3279,
                         devlin        => 2767,
                         devoe         => 4322,
                         devore        => 2252,
                         devries       => 2953,
                         dewald        => 9856,
                         dewall        => 8675,
                         dewar         => 7926,
                         dewberry      => 7256,
                         deweese       => 5180,
                         dews          => 6113,
                         deyo          => 8579,
                         deyoung       => 4054,
                         dial          => 2599,
                         dias          => 1871,
                         diaz          => 94,
                         dibble        => 4053,
                         dibenedetto   => 8793,
                         dicarlo       => 6331,
                         dicken        => 6618,
                         dickens       => 1244,
                         dickenson     => 4954,
                         dickerson     => 459,
                         dickey        => 1056,
                         dickinson     => 1005,
                         dickman       => 5674,
                         dickson       => 695,
                         diehl         => 1983,
                         diemer        => 9339,
                         diep          => 6891,
                         dietrich      => 1935,
                         dietz         => 1806,
                         diez          => 7403,
                         diggins       => 7660,
                         diggs         => 1515,
                         digiacomo     => 7659,
                         digiovanni    => 7333,
                         dilbeck       => 9855,
                         dildy         => 9981,
                         dileo         => 8792,
                         dill          => 1476,
                         dillard       => 764,
                         diller        => 8458,
                         dilley        => 5821,
                         dillinger     => 9854,
                         dillingham    => 5139,
                         dillion       => 6061,
                         dillman       => 6060,
                         dillon        => 717,
                         dillow        => 6757,
                         dills         => 9466,
                         dilorenzo     => 7658,
                         dilworth      => 4634,
                         dimaggio      => 6165,
                         dimarco       => 7837,
                         dimmick       => 8339,
                         dinardo       => 9465,
                         dineen        => 8457,
                         dinger        => 7095,
                         dingess       => 5179,
                         dingle        => 4187,
                         dingman       => 5484,
                         dingus        => 7925,
                         dinh          => 5532,
                         dinkins       => 3902,
                         dinsmore      => 5382,
                         dinwiddie     => 9007,
                         diorio        => 7924,
                         dipasquale    => 9592,
                         dipietro      => 5820,
                         dirks         => 7836,
                         dishman       => 4953,
                         dismuke       => 7484,
                         distefano     => 5911,
                         dittman       => 8456,
                         dittmer       => 8116,
                         dixon         => 131,
                         dixson        => 6756,
                         dizon         => 7744,
                         doak          => 6391,
                         doan          => 3095,
                         doane         => 4824,
                         dobbins       => 1692,
                         dobbs         => 1792,
                         dobson        => 1099,
                         doby          => 7332,
                         dockery       => 2433,
                         dodd          => 913,
                         dodds         => 3958,
                         dodge         => 1278,
                         dodson        => 619,
                         doering       => 6330,
                         doerr         => 4505,
                         doggett       => 5265,
                         doherty       => 1233,
                         doiron        => 8016,
                         dolan         => 1266,
                         dolby         => 9110,
                         dole          => 7094,
                         dombrowski    => 5381,
                         dominguez     => 476,
                         dominquez     => 3880,
                         donahoe       => 8791,
                         donahue       => 950,
                         donaldson     => 683,
                         donato        => 3937,
                         donegan       => 8224,
                         donelson      => 7657,
                         dones         => 9222,
                         doney         => 6890,
                         donley        => 4073,
                         donnelly      => 1106,
                         donofrio      => 5770,
                         donoghue      => 9980,
                         donohoe       => 7656,
                         donohue       => 2544,
                         doody         => 7564,
                         dooley        => 1048,
                         doolittle     => 3936,
                         dorado        => 7255,
                         doran         => 1639,
                         dore          => 5868,
                         dorman        => 1982,
                         dorn          => 2822,
                         dorr          => 5178,
                         dorsett       => 5483,
                         dorsey        => 531,
                         dortch        => 3725,
                         dorton        => 7743,
                         doss          => 1190,
                         doster        => 8674,
                         dostie        => 7254,
                         dotson        => 662,
                         doty          => 1552,
                         doucet        => 4678,
                         doucette      => 4030,
                         doud          => 7655,
                         dougherty     => 878,
                         doughty       => 2502,
                         dove          => 1650,
                         dover         => 2990,
                         dowd          => 2233,
                         dowdell       => 4135,
                         dowden        => 6819,
                         dowdle        => 9006,
                         dowdy         => 1573,
                         dowell        => 1997,
                         dowler        => 8890,
                         dowling       => 1927,
                         downer        => 5769,
                         downes        => 4052,
                         downey        => 1047,
                         downie        => 9109,
                         downing       => 948,
                         downs         => 833,
                         doyle         => 377,
                         doyon         => 6220,
                         dozier        => 1711,
                         draeger       => 9464,
                         drain         => 4381,
                         drake         => 410,
                         drakeford     => 9591,
                         drakes        => 9717,
                         draper        => 1151,
                         drayton       => 3724,
                         drees         => 6889,
                         dreher        => 5217,
                         dreiling      => 9463,
                         drennan       => 6219,
                         drennen       => 7010,
                         dressler      => 5673,
                         drews         => 8015,
                         drexler       => 9853,
                         dreyer        => 5867,
                         driggers      => 4072,
                         drinkard      => 9462,
                         driscoll      => 1315,
                         driskell      => 5264,
                         driskill      => 8673,
                         drouin        => 7742,
                         drucker       => 9979,
                         drumm         => 8338,
                         drummond      => 1351,
                         drury         => 2912,
                         dryden        => 5037,
                         drye          => 7483,
                         duarte        => 1150,
                         dubay         => 9221,
                         dube          => 1751,
                         dubin         => 9338,
                         dubois        => 1058,
                         dubose        => 1689,
                         ducharme      => 4440,
                         duckett       => 3080,
                         duckworth     => 1969,
                         duclos        => 8337,
                         duda          => 6112,
                         dudek         => 6434,
                         duenas        => 4719,
                         duff          => 1810,
                         duffey        => 6059,
                         duffield      => 8889,
                         duffy         => 770,
                         dufour        => 6888,
                         dufrene       => 7563,
                         dufresne      => 5672,
                         dugan         => 1432,
                         dugas         => 3768,
                         duggan        => 2350,
                         dugger        => 2901,
                         duggins       => 7331,
                         duguay        => 8672,
                         duhon         => 5718,
                         duke          => 759,
                         dukes         => 1178,
                         dulaney       => 4134,
                         duley         => 8455,
                         dulin         => 7009,
                         dumas         => 1250,
                         dumont        => 3979,
                         dunagan       => 6058,
                         dunaway       => 2678,
                         dunbar        => 974,
                         duncan        => 167,
                         dunford       => 6268,
                         dungan        => 7402,
                         dunham        => 1121,
                         dunigan       => 7482,
                         dunkelberger  => 9852,
                         dunkin        => 6755,
                         dunkle        => 6501,
                         dunkley       => 9461,
                         dunlap        => 734,
                         dunleavy      => 7330,
                         dunlop        => 6433,
                         dunmire       => 8888,
                         dunn          => 151,
                         dunne         => 3427,
                         dunnigan      => 9108,
                         dunning       => 2447,
                         dunphy        => 8790,
                         dunson        => 6689,
                         dunston       => 6111,
                         dunton        => 6110,
                         duong         => 3490,
                         duplessis     => 6617,
                         dupont        => 2706,
                         dupre         => 1849,
                         dupree        => 1201,
                         duprey        => 5819,
                         dupuis        => 2695,
                         dupuy         => 9851,
                         duque         => 6616,
                         duquette      => 5620,
                         duran         => 528,
                         durand        => 3744,
                         durant        => 2075,
                         durante       => 8578,
                         durbin        => 2006,
                         durden        => 3348,
                         duren         => 8115,
                         durfee        => 6109,
                         durgin        => 9005,
                         durham        => 608,
                         durkee        => 5818,
                         durkin        => 3879,
                         duron         => 6688,
                         durr          => 3464,
                         durrant       => 9220,
                         durrett       => 5717,
                         durso         => 8671,
                         durst         => 4718,
                         dusek         => 9219,
                         dutcher       => 4889,
                         dutra         => 6057,
                         dutton        => 1577,
                         duval         => 2943,
                         duvall        => 1452,
                         dvorak        => 4823,
                         dwyer         => 1153,
                         dycus         => 8887,
                         dyer          => 493,
                         dyess         => 9107,
                         dyke          => 5716,
                         dykes         => 1769,
                         dykstra       => 4408,
                         dyson         => 2060,
                         eaddy         => 7741,
                         eades         => 4560,
                         eads          => 4071,
                         eady          => 5069,
                         eagan         => 5910,
                         eakin         => 7253,
                         eakins        => 7178,
                         ealey         => 9337,
                         eames         => 7481,
                         eanes         => 7835,
                         earhart       => 9850,
                         earles        => 9460,
                         earley        => 2766,
                         earls         => 3767,
                         earp          => 7093,
                         easley        => 1482,
                         eason         => 1498,
                         easterday     => 7834,
                         easterling    => 2832,
                         easterwood    => 9590,
                         eastman       => 1395,
                         easton        => 3243,
                         eatmon        => 7654,
                         eaton         => 522,
                         eaves         => 2605,
                         ebeling       => 9004,
                         eberhardt     => 5619,
                         eberhart      => 8670,
                         eberle        => 5380,
                         eberly        => 6818,
                         ebersole      => 7480,
                         ebert         => 2240,
                         ebner         => 7833,
                         eccles        => 6956,
                         eccleston     => 9336,
                         echevarria    => 3310,
                         echeverria    => 5768,
                         echols        => 1500,
                         eckard        => 8577,
                         eckenrode     => 8336,
                         ecker         => 7092,
                         eckert        => 1739,
                         eckhardt      => 6687,
                         eckhoff       => 9335,
                         eckles        => 9459,
                         ecklund       => 8576,
                         eckman        => 6005,
                         eckstein      => 6817,
                         eddings       => 5531,
                         eddington     => 7923,
                         eddins        => 5263,
                         edelman       => 5951,
                         edelstein     => 5671,
                         edenfield     => 9589,
                         edens         => 4296,
                         edgerton      => 5715,
                         edgington     => 8575,
                         edington      => 6164,
                         edmiston      => 5670,
                         edmonds       => 1128,
                         edmondson     => 1683,
                         edmonson      => 5576,
                         edmunds       => 4240,
                         edmundson     => 7653,
                         edson         => 5575,
                         edwards       => 47,
                         eells         => 8789,
                         egan          => 1359,
                         egbert        => 4536,
                         eggen         => 9218,
                         egger         => 7652,
                         eggers        => 4407,
                         eggert        => 5482,
                         eggleston     => 2316,
                         ehlers        => 4535,
                         ehlert        => 9334,
                         ehrhardt      => 9217,
                         ehrlich       => 4785,
                         eichelberger  => 6754,
                         eicher        => 6163,
                         eichhorn      => 7091,
                         eichler       => 7651,
                         eidson        => 5714,
                         eiland        => 6267,
                         eilers        => 8886,
                         eisele        => 8114,
                         eisenberg     => 4633,
                         eisenhauer    => 9003,
                         eisenman      => 9849,
                         eklund        => 7740,
                         elam          => 1976,
                         elder         => 865,
                         eldred        => 4998,
                         eldredge      => 5216,
                         eldridge      => 983,
                         eley          => 5481,
                         elgin         => 7739,
                         eliason       => 6390,
                         elizalde      => 9333,
                         elizondo      => 2942,
                         elkin         => 8669,
                         elkins        => 998,
                         elledge       => 6004,
                         ellender      => 8014,
                         eller         => 1988,
                         ellinger      => 6432,
                         ellingson     => 5177,
                         ellington     => 2203,
                         elliott       => 181,
                         ellis         => 108,
                         ellison       => 581,
                         ellzey        => 9458,
                         elmore        => 991,
                         elrod         => 2294,
                         elson         => 6955,
                         elston        => 3489,
                         elswick       => 7738,
                         elwell        => 4677,
                         embree        => 6753,
                         embrey        => 8574,
                         embry         => 3129,
                         emerick       => 4559,
                         emmert        => 6218,
                         emmons        => 2305,
                         emrich        => 8573,
                         emrick        => 8013,
                         encarnacion   => 7650,
                         encinas       => 9716,
                         enciso        => 8454,
                         enders        => 9588,
                         endicott      => 5669,
                         endres        => 6500,
                         endsley       => 7008,
                         engel         => 1346,
                         engelhardt    => 5379,
                         engen         => 9457,
                         engle         => 1457,
                         englehart     => 8788,
                         engleman      => 8012,
                         engler        => 5417,
                         englert       => 5036,
                         engram        => 8223,
                         engstrom      => 4997,
                         enloe         => 7401,
                         enlow         => 9456,
                         ennis         => 1796,
                         enos          => 3234,
                         enright       => 3823,
                         enriquez      => 1225,
                         ensley        => 8787,
                         ensor         => 7737,
                         epley         => 7479,
                         epperson      => 1836,
                         epps          => 1286,
                         epstein       => 2750,
                         erdman        => 4822,
                         erdmann       => 3957,
                         erickson      => 355,
                         ericson       => 5102,
                         erikson       => 9002,
                         ernst         => 1710,
                         erskine       => 4888,
                         erving        => 9001,
                         escalante     => 2621,
                         escalera      => 8453,
                         escamilla     => 2501,
                         escobar       => 947,
                         escobedo      => 1763,
                         eshelman      => 7177,
                         eskew         => 6217,
                         eskridge      => 4091,
                         eslinger      => 8452,
                         espada        => 9000,
                         esparza       => 1164,
                         espinal       => 2791,
                         espino        => 3696,
                         espinosa      => 1088,
                         espinoza      => 463,
                         esposito      => 1595,
                         esqueda       => 7649,
                         esquibel      => 5668,
                         esquivel      => 1673,
                         essary        => 8113,
                         esser         => 8668,
                         estabrook     => 6431,
                         estep         => 2200,
                         estes         => 618,
                         esteves       => 9587,
                         estevez       => 4090,
                         estrada       => 371,
                         etheridge     => 1912,
                         ethridge      => 3822,
                         etienne       => 8011,
                         etter         => 6003,
                         eubank        => 4477,
                         eubanks       => 1350,
                         eudy          => 5416,
                         eure          => 8572,
                         evangelista   => 6329,
                         evans         => 46,
                         eveland       => 8335,
                         evens         => 8667,
                         evenson       => 5449,
                         everhart      => 2441,
                         everitt       => 8666,
                         everly        => 9106,
                         evers         => 3206,
                         eversole      => 6056,
                         everson       => 3878,
                         ewald         => 5305,
                         ewell         => 5304,
                         ewers         => 8334,
                         ewing         => 740,
                         exley         => 9586,
                         exum          => 5448,
                         eyler         => 7400,
                         eyre          => 7176,
                         ezell         => 1682,
                         ezzell        => 8333,
                         faber         => 3278,
                         fabrizio      => 7736,
                         fagan         => 1681,
                         fagundes      => 9585,
                         fahey         => 3298,
                         fain          => 2928,
                         fairbanks     => 2718,
                         fairchild     => 1895,
                         faircloth     => 4534,
                         fairfield     => 8571,
                         fairley       => 2843,
                         fairman       => 8885,
                         faison        => 2952,
                         fajardo       => 3094,
                         falco         => 6887,
                         falcone       => 4676,
                         falconer      => 8999,
                         falgoust      => 5378,
                         falgout       => 7252,
                         falk          => 2667,
                         falkner       => 7007,
                         fancher       => 4295,
                         fanelli       => 6752,
                         fann          => 6954,
                         fannin        => 4133,
                         fanning       => 2576,
                         fant          => 5215,
                         farber        => 4923,
                         faria         => 4952,
                         farias        => 3113,
                         farina        => 5713,
                         faris         => 4595,
                         farkas        => 5618,
                         farley        => 718,
                         farlow        => 9584,
                         farmer        => 325,
                         farnham       => 6108,
                         farnsworth    => 2102,
                         farnum        => 9715,
                         farr          => 1206,
                         farrar        => 1845,
                         farrell       => 575,
                         farrer        => 9455,
                         farrington    => 2530,
                         farris        => 954,
                         farrow        => 2378,
                         farthing      => 7735,
                         farwell       => 6266,
                         fasano        => 8332,
                         fassett       => 6549,
                         faucett       => 9216,
                         faucher       => 7090,
                         faught        => 8222,
                         faulk         => 1649,
                         faulkner      => 668,
                         faust         => 1731,
                         favela        => 5767,
                         fawcett       => 4070,
                         fazio         => 5335,
                         feagin        => 8998,
                         feaster       => 4594,
                         featherston   => 7478,
                         featherstone  => 6686,
                         fecteau       => 6430,
                         feder         => 7175,
                         fedor         => 8786,
                         feeley        => 7089,
                         feeney        => 3404,
                         fehr          => 8451,
                         feinberg      => 6886,
                         feinstein     => 8010,
                         felder        => 1758,
                         feldman       => 1285,
                         feldmann      => 9105,
                         feliciano     => 1231,
                         felker        => 4504,
                         feller        => 4750,
                         fellers       => 8450,
                         fellows       => 3743,
                         feltner       => 7648,
                         felts         => 3956,
                         felty         => 8665,
                         fenderson     => 8009,
                         fendley       => 7647,
                         fenn          => 4784,
                         fennell       => 2217,
                         fenner        => 3347,
                         fenske        => 8449,
                         fenton        => 1638,
                         fenwick       => 4158,
                         ferebee       => 5480,
                         fergerson     => 9583,
                         ferguson      => 148,
                         ferland       => 5866,
                         fernandes     => 2377,
                         fernandez     => 208,
                         ferrante      => 4783,
                         ferrara       => 2493,
                         ferraro       => 2900,
                         ferree        => 7646,
                         ferreira      => 1334,
                         ferrel        => 8664,
                         ferrell       => 747,
                         ferrer        => 2666,
                         ferretti      => 7832,
                         ferri         => 7477,
                         ferrin        => 8221,
                         ferris        => 1185,
                         ferro         => 4211,
                         fessler       => 8112,
                         fetter        => 4951,
                         fetters       => 9582,
                         fetzer        => 9848,
                         fewell        => 7006,
                         fick          => 5303,
                         fidler        => 4996,
                         fiedler       => 4887,
                         fielder       => 3723,
                         fielding      => 4995,
                         fields        => 188,
                         fierro        => 3183,
                         fife          => 3653,
                         fifield       => 6389,
                         figueroa      => 419,
                         fike          => 4321,
                         fikes         => 6429,
                         fillmore      => 4922,
                         finch         => 827,
                         fincher       => 2911,
                         findlay       => 5865,
                         findley       => 2989,
                         fink          => 1105,
                         finke         => 8331,
                         finkel        => 9215,
                         finkelstein   => 7399,
                         finkle        => 8111,
                         finlay        => 7398,
                         finley        => 642,
                         finn          => 1364,
                         finnegan      => 3515,
                         finnell       => 7476,
                         finnerty      => 9714,
                         finney        => 1708,
                         fiore         => 3630,
                         fiorentino    => 8785,
                         firestone     => 8784,
                         firth         => 8008,
                         fischer       => 488,
                         fiscus        => 7831,
                         fisher        => 107,
                         fishman       => 3182,
                         fisk          => 2468,
                         fiske         => 7562,
                         fitch         => 1328,
                         fite          => 3789,
                         fitts         => 3447,
                         fitz          => 5817,
                         fitzgerald    => 375,
                         fitzgibbon    => 9978,
                         fitzhugh      => 6816,
                         fitzpatrick   => 771,
                         fitzsimmons   => 3297,
                         fitzwater     => 5138,
                         flack         => 5864,
                         flagg         => 3597,
                         flaherty      => 1768,
                         flake         => 7329,
                         flanagan      => 944,
                         flanders      => 2688,
                         flanigan      => 3955,
                         flannery      => 2857,
                         flannigan     => 8884,
                         flatt         => 5667,
                         fleck         => 3391,
                         fleenor       => 6162,
                         fleetwood     => 5816,
                         fleischer     => 6953,
                         fleischmann   => 9847,
                         fleisher      => 9846,
                         fleming       => 235,
                         flemming      => 3652,
                         flesher       => 8220,
                         fleshman      => 8883,
                         fletcher      => 265,
                         fleury        => 5574,
                         flick         => 4239,
                         flickinger    => 8570,
                         flinn         => 5815,
                         flint         => 1627,
                         flippen       => 9977,
                         flood         => 1667,
                         flores        => 85,
                         florez        => 3612,
                         florio        => 8330,
                         flory         => 6002,
                         flournoy      => 3920,
                         flowers       => 363,
                         fluellen      => 8110,
                         fluker        => 7174,
                         flynn         => 462,
                         flynt         => 8448,
                         fogarty       => 3877,
                         fogel         => 6001,
                         fogg          => 3978,
                         fogle         => 2420,
                         foley         => 604,
                         folger        => 9332,
                         follett       => 7830,
                         folmar        => 9845,
                         folse         => 3296,
                         folsom        => 2567,
                         foltz         => 3901,
                         fong          => 2941,
                         fonseca       => 2557,
                         fontaine      => 2074,
                         fontana       => 5909,
                         fontanez      => 8329,
                         fontenot      => 995,
                         fontes        => 7088,
                         foote         => 1664,
                         foran         => 8569,
                         forbes        => 844,
                         forbis        => 7922,
                         forcier       => 8568,
                         ford          => 97,
                         forde         => 4632,
                         fordham       => 5035,
                         fordyce       => 9331,
                         fore          => 5415,
                         forehand      => 7645,
                         foreman       => 837,
                         forester      => 6216,
                         foret         => 3651,
                         forman        => 2222,
                         forney        => 3478,
                         forsberg      => 6328,
                         forster       => 3860,
                         forsyth       => 2951,
                         forsythe      => 2349,
                         forte         => 2409,
                         fortenberry   => 3376,
                         fortier       => 2274,
                         fortin        => 2446,
                         fortner       => 2166,
                         fortney       => 4186,
                         fortson       => 6615,
                         fortunato     => 7328,
                         foshee        => 8663,
                         foss          => 2011,
                         foster        => 89,
                         foti          => 8219,
                         foulk         => 8783,
                         fountain      => 1189,
                         fournier      => 1441,
                         foust         => 2145,
                         fouts         => 5137,
                         fowler        => 228,
                         fowlkes       => 4115,
                         fox           => 175,
                         foxworth      => 6499,
                         frady         => 8218,
                         fraga         => 6215,
                         fraire        => 9454,
                         fraizer       => 8662,
                         frakes        => 9453,
                         fraley        => 2144,
                         frampton      => 7921,
                         franck        => 7561,
                         franco        => 728,
                         francois      => 2777,
                         franke        => 4782,
                         frankel       => 4781,
                         franklin      => 186,
                         franko        => 8567,
                         franks        => 830,
                         frantz        => 2419,
                         franz         => 2899,
                         franzen       => 5863,
                         fraser        => 1157,
                         frasher       => 8782,
                         frausto       => 6548,
                         frawley       => 6214,
                         frazee        => 5573,
                         frazer        => 3629,
                         frazier       => 221,
                         frechette     => 5908,
                         fredericks    => 3695,
                         frederickson  => 6751,
                         fredette      => 5766,
                         fredricks     => 8661,
                         fredrickson   => 3694,
                         freed         => 3463,
                         freedman      => 3327,
                         freeland      => 4069,
                         freeman       => 117,
                         freer         => 8781,
                         freese        => 3954,
                         fregoso       => 7734,
                         freitag       => 6327,
                         freitas       => 2940,
                         frenette      => 9844,
                         fretwell      => 7087,
                         freund        => 3514,
                         frey          => 1082,
                         frias         => 3168,
                         frick         => 3477,
                         fricke        => 7005,
                         friedman      => 883,
                         friel         => 6326,
                         frier         => 9843,
                         frierson      => 3513,
                         friesen       => 5862,
                         frink         => 5530,
                         frisbie       => 6213,
                         frisby        => 5712,
                         frisch        => 6815,
                         frison        => 8997,
                         fritch        => 9330,
                         frith         => 5262,
                         fritsch       => 8780,
                         fritts        => 4476,
                         frizzell      => 3650,
                         froehlich     => 6885,
                         fromm         => 8109,
                         frost         => 637,
                         fruge         => 7829,
                         fry           => 756,
                         fryar         => 8660,
                         frye          => 766,
                         fryer         => 3649,
                         fryman        => 9452,
                         fuchs         => 2717,
                         fudge         => 5529,
                         fuentes       => 687,
                         fugate        => 1721,
                         fuhrman       => 4950,
                         fujii         => 9842,
                         fujimoto      => 8447,
                         fulbright     => 7251,
                         fulcher       => 3555,
                         fulford       => 5666,
                         fulgham       => 8779,
                         fulk          => 4994,
                         fulkerson     => 4132,
                         fulks         => 5861,
                         fuller        => 215,
                         fullerton     => 3360,
                         fullmer       => 5665,
                         fullwood      => 9451,
                         fulmer        => 2977,
                         fulton        => 749,
                         fults         => 7475,
                         fultz         => 2149,
                         funches       => 8446,
                         funderburg    => 9976,
                         funderburk    => 3462,
                         fung          => 5479,
                         funk          => 1218,
                         funke         => 7250,
                         funkhouser    => 7004,
                         fuqua         => 3309,
                         furey         => 9975,
                         furlong       => 4051,
                         furlow        => 9329,
                         furman        => 2649,
                         furr          => 2804,
                         furry         => 9974,
                         furst         => 8566,
                         furtado       => 4886,
                         fusco         => 3674,
                         fuson         => 9104,
                         fussell       => 5478,
                         futch         => 8565,
                         futrell       => 5447,
                         gabaldon      => 8882,
                         gabbard       => 4157,
                         gabel         => 4475,
                         gable         => 2810,
                         gabrielson    => 9328,
                         gadbois       => 8881,
                         gaddis        => 2458,
                         gaddy         => 2927,
                         gadsden       => 9713,
                         gadson        => 4885,
                         gaffney       => 2315,
                         gafford       => 9327,
                         gage          => 1568,
                         gagliano      => 7828,
                         gagliardi     => 7733,
                         gagne         => 1509,
                         gagnon        => 973,
                         gailey        => 5664,
                         gainer        => 5711,
                         gaines        => 483,
                         gainey        => 3809,
                         gaitan        => 5101,
                         gaither       => 2165,
                         galan         => 6685,
                         galarza       => 3233,
                         galaviz       => 9326,
                         galbraith     => 3403,
                         galbreath     => 5100,
                         gales         => 7474,
                         galicia       => 7327,
                         galindo       => 1221,
                         gall          => 4185,
                         gallagher     => 482,
                         gallaher      => 4593,
                         gallant       => 2387,
                         gallardo      => 1736,
                         gallaway      => 7249,
                         gallego       => 6428,
                         gallegos      => 551,
                         galligan      => 8007,
                         gallimore     => 9581,
                         gallion       => 8217,
                         gallman       => 7248,
                         gallo         => 1622,
                         galloway      => 720,
                         gallup        => 6161,
                         galvan        => 890,
                         galvez        => 2620,
                         galvin        => 3093,
                         gamache       => 5136,
                         gambill       => 7003,
                         gambino       => 9214,
                         gamble        => 694,
                         gamboa        => 2543,
                         gambrell      => 4263,
                         gamez         => 2178,
                         gammage       => 9213,
                         gammon        => 4294,
                         gandy         => 2239,
                         ganey         => 9580,
                         gann          => 1891,
                         gannon        => 2101,
                         gant          => 1889,
                         gantt         => 2648,
                         gantz         => 8216,
                         gaona         => 5068,
                         garay         => 3876,
                         garber        => 2960,
                         garces        => 9212,
                         garcia        => 17,
                         gard          => 6884,
                         gardea        => 9325,
                         gardiner      => 2326,
                         gardner       => 155,
                         garey         => 8659,
                         garibay       => 4380,
                         garica        => 6055,
                         garlock       => 8658,
                         garman        => 4592,
                         garmon        => 3446,
                         garner        => 319,
                         garnes        => 9211,
                         garnica       => 9579,
                         garofalo      => 7920,
                         garrard       => 8006,
                         garren        => 8657,
                         garretson     => 6265,
                         garrett       => 217,
                         garrick       => 5528,
                         garrido       => 5034,
                         garris        => 3242,
                         garrison      => 507,
                         garrity       => 4379,
                         garrow        => 8328,
                         gartman       => 9578,
                         gartner       => 5572,
                         garton        => 7827,
                         garver        => 6264,
                         garvey        => 2926,
                         garvin        => 2010,
                         garza         => 209,
                         gasaway       => 8445,
                         gaskill       => 5176,
                         gaskin        => 3277,
                         gaskins       => 1968,
                         gaspar        => 5099,
                         gaspard       => 6814,
                         gasper        => 7732,
                         gass          => 3673,
                         gassaway      => 8005,
                         gast          => 7644,
                         gastelum      => 6813,
                         gates         => 455,
                         gatewood      => 3512,
                         gathers       => 8996,
                         gatlin        => 2029,
                         gatling       => 5663,
                         gattis        => 6812,
                         gatto         => 6263,
                         gaudet        => 6160,
                         gaudette      => 6498,
                         gaudreau      => 8215,
                         gaughan       => 8214,
                         gaul          => 6325,
                         gault         => 4007,
                         gause         => 4631,
                         gauthier      => 1762,
                         gautreaux     => 9973,
                         gauvin        => 8327,
                         gay           => 674,
                         gayden        => 8326,
                         gaylor        => 4591,
                         gaynor        => 4320,
                         gaytan        => 4184,
                         gayton        => 6811,
                         gearhart      => 4050,
                         geary         => 2267,
                         gebhardt      => 6952,
                         gebhart       => 6497,
                         geddes        => 7643,
                         geer          => 3722,
                         gehring       => 6614,
                         gehrke        => 6496,
                         geier         => 7642,
                         geiger        => 1590,
                         geis          => 7473,
                         geise         => 9450,
                         geisler       => 4675,
                         geissler      => 8880,
                         geist         => 5477,
                         gelinas       => 8444,
                         geller        => 4674,
                         gendron       => 5033,
                         genovese      => 5527,
                         gentile       => 2440,
                         gentry        => 589,
                         geraci        => 8995,
                         gerber        => 2100,
                         gerdes        => 5135,
                         gerena        => 8443,
                         gerhardt      => 5950,
                         gerhart       => 7641,
                         gerken        => 9712,
                         gerlach       => 4673,
                         germain       => 4406,
                         gerner        => 9841,
                         gerth         => 9840,
                         gertz         => 9972,
                         gervais       => 5134,
                         getchell      => 9577,
                         geter         => 6262,
                         getty         => 7560,
                         getz          => 3582,
                         geyer         => 4533,
                         gholston      => 7731,
                         giannini      => 9576,
                         giardina      => 9711,
                         gibb          => 8325,
                         gibbons       => 986,
                         gibbs         => 373,
                         gibson        => 110,
                         giddens       => 4558,
                         giddings      => 6159,
                         giese         => 4672,
                         giffin        => 7173,
                         gifford       => 1557,
                         giglio        => 6613,
                         giguere       => 7086,
                         gilbertson    => 3977,
                         gilbreath     => 3953,
                         gilchrist     => 2052,
                         gilder        => 8656,
                         gile          => 8442,
                         giles         => 638,
                         gilkey        => 6107,
                         gill          => 381,
                         gillam        => 5949,
                         gillard       => 4590,
                         gilleland     => 9103,
                         gillen        => 3039,
                         gillenwater   => 7172,
                         gillespie     => 686,
                         gillett       => 6684,
                         gillette      => 2246,
                         gilley        => 2386,
                         gilliam       => 845,
                         gilliard      => 5765,
                         gillies       => 8324,
                         gilligan      => 4854,
                         gilliland     => 2143,
                         gillis        => 1418,
                         gillispie     => 6000,
                         gillman       => 5571,
                         gillum        => 4156,
                         gilman        => 2132,
                         gilmer        => 3900,
                         gilmore       => 475,
                         gilpin        => 4319,
                         gilreath      => 5860,
                         gilroy        => 7171,
                         gilson        => 3535,
                         gilstrap      => 6495,
                         ginder        => 8108,
                         gingerich     => 7002,
                         gingras       => 8323,
                         gingrich      => 7472,
                         ginn          => 3016,
                         ginsberg      => 5999,
                         ginsburg      => 9839,
                         ginter        => 7559,
                         giordano      => 2364,
                         gipson        => 1258,
                         girard        => 1961,
                         giron         => 3721,
                         girouard      => 8778,
                         giroux        => 3766,
                         gish          => 4671,
                         gist          => 3015,
                         gittens       => 6750,
                         givens        => 1117,
                         gladden       => 3014,
                         gladney       => 3534,
                         gladstone     => 7919,
                         glantz        => 9710,
                         glasco        => 8655,
                         glaser        => 3079,
                         glasper       => 7247,
                         glaspie       => 9449,
                         glass         => 564,
                         glasscock     => 6683,
                         glasser       => 6810,
                         glassman      => 6951,
                         glaze         => 3835,
                         glazer        => 8107,
                         glazier       => 8441,
                         gleason       => 1243,
                         glick         => 4949,
                         glidden       => 5334,
                         glidewell     => 6547,
                         glisson       => 5907,
                         glover        => 329,
                         gluck         => 7170,
                         glynn         => 3029,
                         goad          => 2910,
                         gober         => 5764,
                         goble         => 3013,
                         godbey        => 8322,
                         goddard       => 1527,
                         godfrey       => 943,
                         godin         => 6427,
                         godinez       => 3935,
                         godoy         => 4884,
                         godsey        => 4347,
                         godwin        => 1160,
                         goebel        => 3596,
                         goetz         => 1987,
                         goff          => 815,
                         goforth       => 2705,
                         goggin        => 8879,
                         goguen        => 9102,
                         goines        => 6749,
                         goings        => 4921,
                         goins         => 1028,
                         gokey         => 9324,
                         goldberg      => 1027,
                         goldenberg    => 9101,
                         goldfarb      => 8213,
                         golding       => 4131,
                         goldman       => 1386,
                         goldsberry    => 5859,
                         goldsmith     => 1666,
                         goldstein     => 997,
                         goldston      => 9323,
                         golightly     => 8777,
                         gomes         => 1424,
                         gomez         => 115,
                         gonsalez      => 7001,
                         gonsalves     => 3742,
                         gonzales      => 90,
                         gonzalez      => 36,
                         gooch         => 2158,
                         goodale       => 5814,
                         goodall       => 5476,
                         goode         => 1156,
                         goodell       => 4821,
                         gooden        => 2115,
                         goodin        => 3899,
                         gooding       => 3934,
                         goodlett      => 9322,
                         goodloe       => 7730,
                         goodman       => 351,
                         goodner       => 9838,
                         goodrich      => 1481,
                         goodrum       => 7640,
                         goodsell      => 8004,
                         goodson       => 1663,
                         goodwin       => 344,
                         goodwyn       => 9448,
                         goolsby       => 3898,
                         gordan        => 6809,
                         gorden        => 8994,
                         gordon        => 135,
                         gordy         => 6494,
                         gore          => 953,
                         goree         => 8212,
                         gorham        => 3181,
                         gorman        => 1003,
                         gormley       => 7169,
                         gorrell       => 9100,
                         gorski        => 5617,
                         gorton        => 6748,
                         goshorn       => 7168,
                         gosnell       => 4780,
                         goss          => 902,
                         gosselin      => 4293,
                         gossett       => 2418,
                         gott          => 4883,
                         gottfried     => 9971,
                         gottlieb      => 5261,
                         gottschalk    => 8003,
                         goudeau       => 9837,
                         goudy         => 9321,
                         gouge         => 7639,
                         gough         => 2575,
                         gould         => 708,
                         goulding      => 8993,
                         goulet        => 3476,
                         gourdine      => 8776,
                         gourley       => 4853,
                         gouveia       => 8440,
                         govan         => 5662,
                         gove          => 6682,
                         govea         => 8564,
                         gowan         => 7397,
                         gowdy         => 9575,
                         gowen         => 5813,
                         gower         => 4068,
                         goyette       => 8439,
                         graber        => 4717,
                         grable        => 9574,
                         grabowski     => 4292,
                         gracey        => 9836,
                         graf          => 2137,
                         graff         => 2803,
                         grafton       => 8563,
                         gragg         => 3933,
                         graham        => 99,
                         grainger      => 8654,
                         grajeda       => 6747,
                         grammer       => 5032,
                         granado       => 5812,
                         granados      => 3167,
                         granata       => 9970,
                         grandberry    => 9099,
                         granger       => 1417,
                         granier       => 9573,
                         granillo      => 8653,
                         grant         => 146,
                         grantham      => 2051,
                         grasso        => 4920,
                         gratton       => 9969,
                         grau          => 8321,
                         gravely       => 6388,
                         graver        => 9098,
                         graves        => 250,
                         gravitt       => 7246,
                         gravois       => 7085,
                         gray          => 67,
                         graybill      => 5302,
                         grayer        => 9572,
                         grays         => 7396,
                         grayson       => 1357,
                         graziano      => 5031,
                         greathouse    => 3788,
                         greaves       => 5414,
                         greco         => 2109,
                         greear        => 9835,
                         greeley       => 6158,
                         green         => 33,
                         greenawalt    => 9320,
                         greenberg     => 1605,
                         greene        => 180,
                         greenfield    => 2408,
                         greenhaw      => 8562,
                         greenhill     => 9968,
                         greening      => 8106,
                         greenlaw      => 8320,
                         greenleaf     => 4948,
                         greenspan     => 9097,
                         greenstein    => 9834,
                         greenwald     => 5214,
                         greenway      => 6746,
                         greenwell     => 5098,
                         greenwood     => 1077,
                         greer         => 383,
                         greeson       => 7729,
                         greggs        => 9571,
                         gregoire      => 4291,
                         greig         => 7638,
                         greiner       => 3326,
                         grenier       => 2716,
                         gresham       => 2230,
                         gribble       => 6387,
                         grice         => 2988,
                         grider        => 4029,
                         grieco        => 6950,
                         griego        => 4779,
                         grier         => 1688,
                         griffen       => 4630,
                         griffie       => 9967,
                         griffin       => 93,
                         griffis       => 3140,
                         griffith      => 308,
                         griffiths     => 2371,
                         grigg         => 4919,
                         griggs        => 922,
                         grigsby       => 2108,
                         grijalva      => 5301,
                         grillo        => 6261,
                         grim          => 4589,
                         grimaldi      => 7826,
                         grimaldo      => 7167,
                         grimes        => 494,
                         grimm         => 1272,
                         grimmett      => 5175,
                         grimsley      => 4993,
                         grindle       => 7918,
                         grindstaff    => 9709,
                         griner        => 7917,
                         grinnell      => 9096,
                         grisby        => 8438,
                         grisham       => 3028,
                         grissett      => 9319,
                         grissom       => 2148,
                         griswold      => 3346,
                         grizzle       => 5570,
                         groce         => 3672,
                         groff         => 4114,
                         grogan        => 2370,
                         groh          => 8002,
                         grondin       => 9318,
                         grooms        => 2885,
                         groover       => 9095,
                         grose         => 5569,
                         gross         => 374,
                         grossman      => 1761,
                         grosso        => 7245,
                         grote         => 8652,
                         groth         => 5333,
                         grove         => 1271,
                         groves        => 1054,
                         grubb         => 1813,
                         grubbs        => 1309,
                         grube         => 6260,
                         gruber        => 2314,
                         grullon       => 9570,
                         grundy        => 6106,
                         guajardo      => 2284,
                         guardado      => 5811,
                         guarino       => 5300,
                         guay          => 4210,
                         gudino        => 9833,
                         guenther      => 2987,
                         guerin        => 3648,
                         guerra        => 548,
                         guerrero      => 370,
                         guertin       => 5661,
                         guevara       => 1631,
                         guffey        => 3205,
                         guice         => 9569,
                         guido         => 4130,
                         guidry        => 1333,
                         guilford      => 7825,
                         guillen       => 2289,
                         guillory      => 1687,
                         guillot       => 6883,
                         guimond       => 7084,
                         guinn         => 1864,
                         guiterrez     => 8651,
                         gulick        => 6493,
                         gulledge      => 6745,
                         gullett       => 5097,
                         gulley        => 2556,
                         gully         => 9094,
                         gumm          => 7326,
                         gump          => 7728,
                         gunderson     => 2348,
                         gunn          => 1076,
                         gunter        => 1085,
                         gunther       => 3345,
                         gupta         => 5858,
                         gupton        => 7083,
                         gurley        => 2359,
                         gurney        => 4918,
                         gurrola       => 6681,
                         gurule        => 6259,
                         gusman        => 6157,
                         gustafson     => 1209,
                         gustin        => 4716,
                         guth          => 7395,
                         guthrie       => 846,
                         gutierez      => 9708,
                         gutierrez     => 189,
                         gutirrez      => 9966,
                         gutshall      => 7394,
                         guyer         => 4670,
                         guyette       => 8105,
                         guyton        => 2363,
                         guzman        => 288,
                         gwaltney      => 8992,
                         gwin          => 5763,
                         gwinn         => 4346,
                         gwynn         => 9832,
                         haack         => 9317,
                         haag          => 2566,
                         haas          => 872,
                         haase         => 4028,
                         haber         => 5616,
                         haberman      => 7824,
                         habib         => 9568,
                         hackett       => 1416,
                         hackler       => 6105,
                         hackman       => 6492,
                         hackney       => 2619,
                         hackworth     => 5568,
                         haddad        => 4129,
                         hadden        => 3808,
                         haddix        => 5133,
                         haddock       => 4439,
                         haden         => 9210,
                         hadfield      => 8211,
                         hadley        => 1308,
                         hadlock       => 8001,
                         hafer         => 6324,
                         haffner       => 7393,
                         hafner        => 7558,
                         haga          => 8319,
                         hagan         => 1385,
                         hagans        => 5446,
                         hagar         => 8318,
                         hage          => 6808,
                         hagedorn      => 9831,
                         hageman       => 6612,
                         hagen         => 1327,
                         hager         => 1326,
                         hagerman      => 5413,
                         hagerty       => 6744,
                         haggard       => 2884,
                         haggerty      => 2765,
                         haggins       => 8991,
                         hagler        => 5377,
                         hagood        => 6949,
                         hague         => 5526,
                         hagy          => 8000,
                         hahn          => 800,
                         haider        => 9316,
                         haigh         => 6948,
                         haight        => 3241,
                         haigler       => 9707,
                         haile         => 5857,
                         haines        => 1039,
                         haire         => 5998,
                         hairston      => 1186,
                         haith         => 7727,
                         hake          => 6258,
                         halbert       => 4345,
                         halcomb       => 3295,
                         hale          => 268,
                         hales         => 3445,
                         halford       => 6807,
                         hall          => 25,
                         hallam        => 9209,
                         halle         => 7637,
                         hallenbeck    => 9447,
                         haller        => 3581,
                         hallett       => 4588,
                         halliburton   => 7244,
                         halliday      => 6323,
                         halligan      => 9830,
                         hallman       => 3294,
                         hallmark      => 6156,
                         hallock       => 4438,
                         halloran      => 5906,
                         halloway      => 9446,
                         hallowell     => 7000,
                         halpern       => 6322,
                         halpin        => 6054,
                         halsey        => 3741,
                         halstead      => 3580,
                         halter        => 5997,
                         halterman     => 8650,
                         halverson     => 3344,
                         halvorsen     => 7916,
                         halvorson     => 4437,
                         hamann        => 5948,
                         hamblin       => 2574,
                         hambrick      => 4238,
                         hamby         => 1727,
                         hamel         => 2500,
                         hamer         => 3012,
                         hames         => 8210,
                         hamill        => 4474,
                         hamilton      => 98,
                         hamlett       => 4503,
                         hamlin        => 1363,
                         hamm          => 985,
                         hammack       => 5947,
                         hamman        => 8209,
                         hammel        => 6999,
                         hammett       => 3193,
                         hammock       => 4502,
                         hammon        => 6212,
                         hammond       => 362,
                         hammonds      => 1975,
                         hammons       => 1894,
                         hamner        => 6998,
                         hampson       => 8317,
                         hampton       => 347,
                         hamrick       => 2633,
                         hance         => 5810,
                         hancock       => 481,
                         handley       => 2764,
                         handy         => 1760,
                         hanes         => 2856,
                         haney         => 829,
                         hanke         => 8437,
                         hankins       => 1208,
                         hanks         => 1658,
                         hanley        => 1550,
                         hanlon        => 2999,
                         hann          => 5525,
                         hanna         => 867,
                         hannan        => 3976,
                         hanner        => 8104,
                         hannigan      => 7823,
                         hannon        => 2343,
                         hannum        => 9208,
                         hanrahan      => 5475,
                         hansel        => 5996,
                         hansen        => 207,
                         hansford      => 9829,
                         hanshaw       => 9207,
                         hanson        => 223,
                         harada        => 9828,
                         haralson      => 9206,
                         harbaugh      => 6882,
                         harber        => 7392,
                         harbin        => 2395,
                         harbison      => 4669,
                         hardaway      => 3975,
                         hardcastle    => 6611,
                         hardee        => 4027,
                         hardeman      => 6321,
                         harden        => 965,
                         hardesty      => 2687,
                         hardie        => 6546,
                         hardiman      => 4917,
                         hardin        => 547,
                         harding       => 635,
                         hardison      => 2185,
                         hardman       => 2394,
                         hardnett      => 8103,
                         hardt         => 9093,
                         hardwick      => 2704,
                         hardy         => 282,
                         hare          => 1582,
                         hargett       => 4209,
                         hargis        => 3038,
                         hargrave      => 4006,
                         hargrove      => 1127,
                         harjo         => 9567,
                         harker        => 5260,
                         harkey        => 7166,
                         harkins       => 2261,
                         harkless      => 9706,
                         harkness      => 5259,
                         harless       => 4128,
                         harlow        => 2514,
                         harman        => 1787,
                         harmon        => 332,
                         harms         => 2059,
                         harner        => 8208,
                         harness       => 2821,
                         harney        => 4501,
                         harnish       => 9827,
                         haro          => 4067,
                         harp          => 1960,
                         harper        => 174,
                         harr          => 3875,
                         harrel        => 9092,
                         harrell       => 525,
                         harrelson     => 4237,
                         harrigan      => 4668,
                         harrill       => 9091,
                         harriman      => 4290,
                         harrington    => 426,
                         harris        => 14,
                         harrison      => 109,
                         harrod        => 5030,
                         harrold       => 7471,
                         harshman      => 9315,
                         hart          => 169,
                         harte         => 9445,
                         harter        => 3011,
                         hartfield     => 5524,
                         hartford      => 4916,
                         hartigan      => 9965,
                         hartle        => 5710,
                         hartley       => 863,
                         hartman       => 513,
                         hartmann      => 3390,
                         hartnett      => 4089,
                         hartsell      => 6386,
                         hartsfield    => 5615,
                         hartshorn     => 7557,
                         hartsock      => 6806,
                         hartung       => 5660,
                         hartwell      => 3693,
                         hartwig       => 4992,
                         harty         => 7636,
                         hartz         => 7391,
                         hartzell      => 4262,
                         hartzler      => 9826,
                         hartzog       => 7165,
                         harvell       => 5474,
                         harvey        => 210,
                         harville      => 6947,
                         harvin        => 7915,
                         harwell       => 3533,
                         harwood       => 3262,
                         hash          => 5709,
                         hashimoto     => 6881,
                         haskell       => 2632,
                         haskin        => 8775,
                         haskins       => 1304,
                         haslam        => 9205,
                         hass          => 3325,
                         hassell       => 3293,
                         hassett       => 8207,
                         hassler       => 7635,
                         hasson        => 5995,
                         hastings      => 961,
                         hasty         => 5132,
                         hatch         => 1098,
                         hatcher       => 908,
                         hatchett      => 3324,
                         hatfield      => 634,
                         hathaway      => 1223,
                         hathcock      => 6426,
                         hathorn       => 8561,
                         hatley        => 3628,
                         hatmaker      => 9444,
                         hatten        => 5376,
                         hatter        => 7164,
                         hatton        => 2095,
                         hauck         => 4820,
                         haug          => 5762,
                         hauge         => 9964,
                         haugen        => 3192,
                         haugh         => 7325,
                         haught        => 7163,
                         haun          => 4852,
                         haupt         => 5174,
                         hauser        => 2251,
                         hausman       => 9090,
                         havard        => 6946,
                         havens        => 2283,
                         haviland      => 7556,
                         hawes         => 2529,
                         hawk          => 1594,
                         hawkes        => 5523,
                         hawkins       => 150,
                         hawkinson     => 7822,
                         hawks         => 2202,
                         hawley        => 1745,
                         hawn          => 7390,
                         haworth       => 4236,
                         haws          => 5761,
                         hawthorne     => 1726,
                         hayashi       => 6880,
                         hayden        => 735,
                         haydon        => 7162,
                         hayes         => 95,
                         haygood       => 4473,
                         hayman        => 6945,
                         hayner        => 7999,
                         haynes        => 273,
                         haynie        => 5258,
                         hays          => 793,
                         hayward       => 1934,
                         hayworth      => 9089,
                         hazard        => 6385,
                         hazelton      => 4436,
                         hazelwood     => 4629,
                         hazen         => 4318,
                         hazlett       => 5213,
                         hazzard       => 5029,
                         heacock       => 9204,
                         headley       => 2749,
                         headrick      => 2909,
                         heady         => 7821,
                         heald         => 5708,
                         healey        => 2925,
                         healy         => 1456,
                         heaney        => 7726,
                         hearn         => 1514,
                         hearne        => 4947,
                         hearns        => 8649,
                         heatherly     => 8316,
                         heaton        => 2177,
                         hebert        => 678,
                         hecht         => 4405,
                         heck          => 2028,
                         hecker        => 5760,
                         heckman       => 3139,
                         hedden        => 7634,
                         hedge         => 5905,
                         hedgepeth     => 4088,
                         hedges        => 2986,
                         hedlund       => 9705,
                         hedrick       => 1325,
                         heffernan     => 4946,
                         heffner       => 3158,
                         hefley        => 9443,
                         heflin        => 3475,
                         hefner        => 3078,
                         hegarty       => 8560,
                         hegwood       => 8648,
                         heiden        => 9963,
                         heil          => 6104,
                         heilman       => 4183,
                         heim          => 3112,
                         hein          => 2528,
                         heine         => 5567,
                         heinemann     => 9314,
                         heinrich      => 4005,
                         heins         => 7243,
                         heintz        => 5173,
                         heinz         => 2985,
                         heise         => 7820,
                         heiser        => 5212,
                         heisler       => 4778,
                         heitman       => 8990,
                         helfrich      => 8436,
                         helgeson      => 8206,
                         helland       => 9704,
                         heller        => 1217,
                         hellman       => 6805,
                         helm          => 1946,
                         helman        => 6804,
                         helmer        => 5904,
                         helmick       => 4378,
                         helms         => 900,
                         helmuth       => 8315,
                         helton        => 1112,
                         helwig        => 8205,
                         hembree       => 3897,
                         hemenway      => 8647,
                         hemingway     => 5994,
                         hemphill      => 1648,
                         hendershot    => 4882,
                         henderson     => 77,
                         hendley       => 5809,
                         hendon        => 3834,
                         hendren       => 5946,
                         hendrick      => 2908,
                         hendricks     => 675,
                         hendrickson   => 1033,
                         hendry        => 6211,
                         henke         => 3532,
                         henkel        => 5993,
                         henley        => 1205,
                         hennessey     => 3807,
                         hennessy      => 4377,
                         hennig        => 8774,
                         henning       => 2325,
                         henninger     => 5522,
                         henriques     => 7161,
                         henriquez     => 4472,
                         hensel        => 7470,
                         henshaw       => 4715,
                         hensley       => 491,
                         henson        => 552,
                         henton        => 7725,
                         hepburn       => 7469,
                         hepler        => 6997,
                         hepner        => 7819,
                         hepworth      => 9703,
                         herbst        => 4471,
                         herd          => 4749,
                         heredia       => 3047,
                         hereford      => 6320,
                         hering        => 8646,
                         hermann       => 3647,
                         hermanson     => 9702,
                         hermosillo    => 7555,
                         hernadez      => 5614,
                         hernandes     => 4945,
                         hernandez     => 28,
                         herndon       => 1549,
                         herod         => 6996,
                         herold        => 4628,
                         heron         => 6680,
                         herr          => 3222,
                         herren        => 5759,
                         herrera       => 241,
                         herrick       => 2686,
                         herrin        => 3896,
                         herring       => 602,
                         herrington    => 1581,
                         herrmann      => 2342,
                         herrod        => 8559,
                         herron        => 989,
                         hersey        => 4667,
                         hersh         => 7914,
                         hershberger   => 3554,
                         hertel        => 6545,
                         hertz         => 7242,
                         herzog        => 2288,
                         hess          => 530,
                         hesse         => 4344,
                         hessler       => 9701,
                         hesson        => 7913,
                         hester        => 715,
                         heston        => 8645,
                         hetrick       => 4182,
                         hetzel        => 7998,
                         heuer         => 8314,
                         hewes         => 9566,
                         hewett        => 4557,
                         hewitt        => 836,
                         heyer         => 6679,
                         heyward       => 3859,
                         heywood       => 6944,
                         hiatt         => 2347,
                         hibbard       => 3232,
                         hibbert       => 8558,
                         hibbler       => 7912,
                         hibbs         => 5445,
                         hickerson     => 4627,
                         hickey        => 1001,
                         hickman       => 568,
                         hickok        => 8204,
                         hickox        => 7997,
                         hicks         => 124,
                         hickson       => 3488,
                         hidalgo       => 2221,
                         hiebert       => 8878,
                         hiers         => 8557,
                         higa          => 5945,
                         higbee        => 7724,
                         higdon        => 2790,
                         higginbotham  => 2086,
                         higgins       => 337,
                         higgs         => 2976,
                         highsmith     => 6155,
                         hight         => 4470,
                         hightower     => 1284,
                         higley        => 7082,
                         hilbert       => 4532,
                         hilburn       => 6879,
                         hildebrand    => 2907,
                         hildebrandt   => 5299,
                         hilderbrand   => 9825,
                         hildreth      => 3077,
                         hileman       => 7818,
                         hiles         => 5096,
                         hill          => 32,
                         hillard       => 3821,
                         hiller        => 3833,
                         hilliard      => 1073,
                         hillis        => 4469,
                         hillman       => 1767,
                         hillyer       => 7468,
                         hilson        => 9824,
                         himes         => 2474,
                         hinckley      => 6995,
                         hindman       => 3692,
                         hinds         => 1735,
                         hine          => 7817,
                         hiner         => 9823,
                         hines         => 306,
                         hinkle        => 1024,
                         hinkley       => 6384,
                         hinman        => 5067,
                         hinnant       => 8644,
                         hinojos       => 9442,
                         hinojosa      => 1707,
                         hinrichs      => 7081,
                         hinshaw       => 6257,
                         hinson        => 1394,
                         hinton        => 700,
                         hintz         => 5412,
                         hinz          => 7324,
                         hipp          => 5131,
                         hipps         => 9700,
                         hirsch        => 1841,
                         hirst         => 6743,
                         hitchcock     => 1926,
                         hite          => 2250,
                         hitt          => 2866,
                         hively        => 9699,
                         hixon         => 4468,
                         hixson        => 4049,
                         hoag          => 4155,
                         hoagland      => 4748,
                         hoang         => 2736,
                         hoard         => 5444,
                         hobart        => 6803,
                         hobbs         => 559,
                         hobgood       => 8877,
                         hobson        => 1526,
                         hoch          => 5298,
                         hochstetler   => 4289,
                         hock          => 7911,
                         hockenberry   => 6154,
                         hocker        => 9698,
                         hockett       => 6678,
                         hocking       => 9203,
                         hodgdon       => 9202,
                         hodge         => 460,
                         hodges        => 356,
                         hodgkins      => 6053,
                         hodgson       => 3166,
                         hodson        => 4376,
                         hoefer        => 9088,
                         hoeft         => 8773,
                         hoekstra      => 8313,
                         hoelscher     => 5411,
                         hoey          => 6256,
                         hofer         => 5375,
                         hoff          => 1744,
                         hoffer        => 5758,
                         hoffman       => 230,
                         hoffmann      => 2407,
                         hofmann       => 4235,
                         hofmeister    => 9565,
                         hogan         => 435,
                         hogg          => 2802,
                         hoggard       => 5659,
                         hogue         => 1480,
                         hohman        => 9697,
                         hoisington    => 9962,
                         hoke          => 3974,
                         holbert       => 5172,
                         holbrook      => 1176,
                         holcomb       => 826,
                         holcombe      => 3426,
                         holden        => 794,
                         holder        => 745,
                         holdren       => 9961,
                         holeman       => 8876,
                         holguin       => 3180,
                         holifield     => 5521,
                         holladay      => 7467,
                         holland       => 234,
                         hollander     => 5257,
                         hollar        => 4666,
                         hollaway      => 8875,
                         holleman      => 8989,
                         hollenbeck    => 3895,
                         holler        => 4626,
                         holley        => 886,
                         holliday      => 1184,
                         hollifield    => 5211,
                         holliman      => 4234,
                         hollinger     => 5992,
                         hollingshead  => 6677,
                         hollingsworth => 1102,
                         hollins       => 2427,
                         hollister     => 5374,
                         holloman      => 2820,
                         hollomon      => 9960,
                         hollon        => 8988,
                         holloway      => 404,
                         hollowell     => 5256,
                         holm          => 2173,
                         holman        => 682,
                         holmberg      => 6544,
                         holmes        => 137,
                         holmgren      => 6878,
                         holmquist     => 6383,
                         holsinger     => 8203,
                         holst         => 6103,
                         holstein      => 7633,
                         holston       => 4747,
                         holt          => 263,
                         holte         => 9087,
                         holter        => 8202,
                         holthaus      => 9822,
                         holton        => 2016,
                         holtz         => 3919,
                         holtzclaw     => 8643,
                         holtzman      => 9313,
                         holzer        => 6102,
                         holzman       => 9441,
                         homan         => 3402,
                         honaker       => 4375,
                         honea         => 6676,
                         honeycutt     => 1513,
                         hood          => 454,
                         hooks         => 1396,
                         hooper        => 753,
                         hoopes        => 7241,
                         hooten        => 4944,
                         hoover        => 502,
                         hopkins       => 240,
                         hoppe         => 3425,
                         hopper        => 719,
                         hopson        => 1888,
                         horan         => 3444,
                         hord          => 6610,
                         horgan        => 7816,
                         horn          => 509,
                         hornback      => 5808,
                         hornbeck      => 7389,
                         hornbuckle    => 8642,
                         horne         => 676,
                         horner        => 1301,
                         horning       => 4208,
                         hornsby       => 3157,
                         horowitz      => 3424,
                         horrell       => 9821,
                         horrocks      => 7910,
                         horsley       => 3646,
                         horst         => 4181,
                         horstman      => 9696,
                         horta         => 8312,
                         horton        => 252,
                         horvath       => 2715,
                         horwitz       => 8772,
                         hosey         => 4819,
                         hoskin        => 9086,
                         hoskins       => 1041,
                         hoskinson     => 8874,
                         hosler        => 8987,
                         hosley        => 8986,
                         hosmer        => 8102,
                         hostetler     => 3343,
                         hostetter     => 5807,
                         hotaling      => 9695,
                         hotchkiss     => 4343,
                         houchens      => 8201,
                         houchin       => 8985,
                         houck         => 2073,
                         hough         => 1672,
                         houghtaling   => 8873,
                         houghton      => 2647,
                         houk          => 4714,
                         houle         => 2211,
                         houlihan      => 6994,
                         houser        => 1232,
                         housley       => 6491,
                         housman       => 8556,
                         houston       => 390,
                         hovey         => 6943,
                         hovis         => 5520,
                         howard        => 63,
                         howarth       => 7080,
                         howe          => 699,
                         howell        => 204,
                         howells       => 7632,
                         hower         => 7323,
                         howerton      => 3671,
                         howery        => 9820,
                         howes         => 3874,
                         howie         => 7160,
                         howington     => 9959,
                         howland       => 2273,
                         howlett       => 5373,
                         howley        => 9819,
                         howse         => 7159,
                         howze         => 6153,
                         hoye          => 8200,
                         hoyer         => 8771,
                         hoyle         => 2432,
                         hoyos         => 8435,
                         hsieh         => 8770,
                         huang         => 1680,
                         hubbard       => 310,
                         hubbell       => 4818,
                         hubbert       => 9958,
                         hubble        => 7996,
                         hubbs         => 5443,
                         huber         => 848,
                         hubler        => 9201,
                         huck          => 7079,
                         huckaby       => 4915,
                         hudak         => 5991,
                         huddleston    => 1534,
                         hudgens       => 3806,
                         hudgins       => 1967,
                         hudnall       => 6543,
                         hudson        => 153,
                         hudspeth      => 4048,
                         huebner       => 6052,
                         huerta        => 1257,
                         huertas       => 7322,
                         huff          => 417,
                         huffman       => 474,
                         hufford       => 5944,
                         huggins       => 1145,
                         hughes        => 84,
                         hughey        => 3531,
                         hughley       => 9694,
                         hughs         => 7723,
                         huie          => 7158,
                         huizar        => 9957,
                         hulbert       => 4914,
                         hulett        => 4625,
                         huling        => 9564,
                         hull          => 595,
                         hulse         => 4665,
                         hulsey        => 2618,
                         humbert       => 7078,
                         humble        => 4913,
                         hume          => 4233,
                         humes         => 3276,
                         hummel        => 1992,
                         humphrey      => 526,
                         humphreys     => 1911,
                         humphries     => 1702,
                         hundley       => 2598,
                         huneycutt     => 4991,
                         hungerford    => 7240,
                         hunley        => 6382,
                         hunnicutt     => 7239,
                         hunsaker      => 5297,
                         hunsicker     => 8641,
                         hunsinger     => 9818,
                         hunt          => 140,
                         huntington    => 3645,
                         huntley       => 1706,
                         huntsman      => 6742,
                         hupp          => 5255,
                         hurd          => 1249,
                         hurdle        => 6490,
                         hurlburt      => 8311,
                         hurley        => 701,
                         hurst         => 577,
                         hurtado       => 2163,
                         hurtt         => 9956,
                         hurwitz       => 9693,
                         huskey        => 3595,
                         huskins       => 9440,
                         huss          => 5171,
                         hussain       => 8872,
                         hussey        => 3165,
                         husted        => 6542,
                         huston        => 1725,
                         hutchens      => 3594,
                         hutcherson    => 2584,
                         hutcheson     => 3443,
                         hutchings     => 2819,
                         hutchins      => 905,
                         hutchinson    => 529,
                         hutchison     => 1204,
                         huth          => 6489,
                         hutson        => 1925,
                         hutt          => 7466,
                         hutter        => 9563,
                         hutto         => 3179,
                         hutton        => 1612,
                         huynh         => 1575,
                         hwang         => 3323,
                         hyatt         => 1647,
                         hyde          => 843,
                         hyden         => 5990,
                         hyder         => 5210,
                         hyland        => 3765,
                         hylton        => 3894,
                         hymel         => 9085,
                         hynes         => 3423,
                         hysell        => 8101,
                         ibarra        => 904,
                         ibrahim       => 5473,
                         ickes         => 8310,
                         iglesias      => 4912,
                         ikeda         => 9200,
                         imes          => 6255,
                         imhoff        => 6210,
                         imler         => 9955,
                         infante       => 5066,
                         ingalls       => 4047,
                         ingersoll     => 4404,
                         ingham        => 7388,
                         ingle         => 3221,
                         ingraham      => 3832,
                         ingram        => 338,
                         iniguez       => 9199,
                         inman         => 1139,
                         innes         => 9312,
                         innis         => 9311,
                         inouye        => 9817,
                         iorio         => 9198,
                         ippolito      => 9816,
                         irby          => 2194,
                         irick         => 8309,
                         irizarry      => 1902,
                         irons         => 3893,
                         irvine        => 2959,
                         isaacs        => 2085,
                         isaacson      => 3342,
                         isbell        => 2210,
                         isenberg      => 6152,
                         isham         => 5296,
                         islas         => 7465,
                         isley         => 7321,
                         isom          => 2184,
                         ison          => 2565,
                         iversen       => 9954,
                         ives          => 3442,
                         ivey          => 1037,
                         ivie          => 6051,
                         izaguirre     => 7554,
                         izquierdo     => 9084,
                         izzo          => 5095,
                         jablonski     => 4851,
                         jackman       => 4004,
                         jackson       => 12,
                         jaco          => 7815,
                         jacobi        => 7631,
                         jacobo        => 6609,
                         jacobs        => 213,
                         jacobsen      => 1543,
                         jacobson      => 673,
                         jacoby        => 2906,
                         jacquez       => 7464,
                         jaeger        => 2801,
                         jaffe         => 4817,
                         jager         => 9692,
                         jaggers       => 7077,
                         jahn          => 7463,
                         jahnke        => 6608,
                         jaimes        => 6101,
                         jalbert       => 7722,
                         jamerson      => 4713,
                         jameson       => 1858,
                         jamieson      => 4087,
                         janes         => 2776,
                         janik         => 9815,
                         janke         => 9439,
                         jankowski     => 3858,
                         jansen        => 2050,
                         janson        => 7462,
                         janssen       => 3292,
                         janzen        => 9562,
                         jaques        => 7238,
                         jaquez        => 5707,
                         jara          => 5757,
                         jaramillo     => 1256,
                         jarboe        => 8199,
                         jardine       => 6607,
                         jarman        => 4232,
                         jarmon        => 5989,
                         jarrell       => 1906,
                         jasso         => 4180,
                         jauregui      => 6541,
                         jaworski      => 6488,
                         jaynes        => 3461,
                         jeanbaptiste  => 7553,
                         jeanlouis     => 7387,
                         jeffcoat      => 5065,
                         jefferies     => 3138,
                         jeffers       => 1373,
                         jefferson     => 412,
                         jeffords      => 8769,
                         jeffreys      => 8100,
                         jeffries      => 1101,
                         jellison      => 9438,
                         jemison       => 4624,
                         jenkins       => 79,
                         jenks         => 4990,
                         jennings      => 248,
                         jensen        => 236,
                         jenson        => 3611,
                         jepson        => 7157,
                         jerkins       => 9691,
                         jernigan      => 1574,
                         jeske         => 7909,
                         jessee        => 7461,
                         jessen        => 4712,
                         jessup        => 3359,
                         jeter         => 2037,
                         jett          => 2406,
                         jetton        => 9814,
                         jewett        => 3261,
                         jiles         => 4531,
                         jimenez       => 251,
                         jimerson      => 5806,
                         jiminez       => 5028,
                         jinks         => 6425,
                         jobe          => 2665,
                         johannsen     => 8871,
                         johansen      => 3220,
                         johanson      => 5613,
                         johns         => 539,
                         johnsen       => 5094,
                         johnson       => 2,
                         johnston      => 199,
                         johnstone     => 4664,
                         johson        => 9437,
                         joiner        => 1323,
                         jolin         => 7814,
                         jolley        => 3076,
                         jolly         => 1525,
                         jones         => 4,
                         joplin        => 7630,
                         jorgensen     => 1487,
                         jorgenson     => 3460,
                         josephson     => 6209,
                         josey         => 7552,
                         joslin        => 4261,
                         jost          => 6319,
                         joubert       => 6487,
                         jourdan       => 9197,
                         jowers        => 7813,
                         joyner        => 722,
                         juarez        => 583,
                         judd          => 1542,
                         judkins       => 3952,
                         junker        => 9953,
                         jurado        => 6877,
                         jurgens       => 9690,
                         justis        => 9436,
                         justus        => 3720,
                         kaczmarek     => 8555,
                         kaelin        => 8768,
                         kagan         => 9310,
                         kahl          => 4711,
                         kahle         => 7320,
                         kahler        => 5170,
                         kahn          => 2176,
                         kain          => 6741,
                         kaiser        => 1083,
                         kalinowski    => 9309,
                         kaminski      => 2677,
                         kaminsky      => 7076,
                         kammerer      => 8099,
                         kamp          => 7629,
                         kanagy        => 9813,
                         kane          => 650,
                         kang          => 2009,
                         kangas        => 9561,
                         kanter        => 8984,
                         kantor        => 8198,
                         kaplan        => 1192,
                         kapp          => 5903,
                         karcher       => 9435,
                         karnes        => 4816,
                         karns         => 6050,
                         karp          => 6151,
                         karpinski     => 8870,
                         karr          => 2865,
                         kass          => 8098,
                         kasten        => 6254,
                         kastner       => 5658,
                         kates         => 7156,
                         kato          => 5209,
                         katz          => 1004,
                         kauffman      => 1455,
                         kaufman       => 813,
                         kaufmann      => 5902,
                         kautz         => 6606,
                         kavanagh      => 6049,
                         kavanaugh     => 6253,
                         kaylor        => 4663,
                         kayser        => 7319,
                         kean          => 5988,
                         keane         => 3459,
                         kearney       => 1469,
                         kearns        => 1901,
                         kearse        => 6540,
                         keating       => 2027,
                         keaton        => 2492,
                         keck          => 3341,
                         keefe         => 3308,
                         keefer        => 3191,
                         keegan        => 3063,
                         keel          => 3062,
                         keele         => 6605,
                         keeler        => 2542,
                         keeling       => 2789,
                         keen          => 1362,
                         keene         => 1492,
                         keener        => 2597,
                         keeney        => 3178,
                         keesee        => 7386,
                         keeter        => 7995,
                         keeton        => 2924,
                         keever        => 8197,
                         keffer        => 8554,
                         kegley        => 9434,
                         kehoe         => 4288,
                         keil          => 5612,
                         keim          => 4943,
                         keiser        => 5566,
                         keister       => 4207,
                         keitt         => 8196,
                         kelch         => 8983,
                         kell          => 4206,
                         kellam        => 5987,
                         kellar        => 4881,
                         kelleher      => 3401,
                         keller        => 292,
                         kellerman     => 5611,
                         kellett       => 9560,
                         kelley        => 185,
                         kellner       => 6252,
                         kellogg       => 1887,
                         kellum        => 3805,
                         kelm          => 8308,
                         kelso         => 3027,
                         kelton        => 7075,
                         kemp          => 516,
                         kemper        => 3204,
                         kempf         => 5254,
                         kempton       => 8767,
                         kendricks     => 8307,
                         kennard       => 5410,
                         kennedy       => 129,
                         kennelly      => 8982,
                         kenner        => 5093,
                         kennett       => 9559,
                         kenney        => 1136,
                         kennison      => 9433,
                         kennon        => 5805,
                         kenworthy     => 8981,
                         kenyon        => 2238,
                         keough        => 8766,
                         keown         => 8097,
                         kephart       => 8096,
                         kepler        => 7237,
                         kerber        => 9812,
                         kerby         => 6150,
                         kerley        => 5657,
                         kern          => 1197,
                         kerner        => 9432,
                         kerney        => 9431,
                         kerns         => 1486,
                         kerr          => 632,
                         kerrigan      => 5472,
                         kersey        => 4113,
                         kershaw       => 6208,
                         kershner      => 7551,
                         kerwin        => 9308,
                         kesler        => 7074,
                         kessel        => 8306,
                         kessinger     => 6675,
                         kessler       => 1023,
                         kester        => 4374,
                         kesterson     => 8434,
                         ketcham       => 5565,
                         ketchum       => 3670,
                         ketron        => 6876,
                         key           => 691,
                         keyes         => 1662,
                         keys          => 1124,
                         keyser        => 3973,
                         khan          => 1451,
                         khoury        => 6048,
                         kibler        => 5372,
                         kidd          => 822,
                         kidder        => 4467,
                         kidwell       => 3553,
                         kiefer        => 3669,
                         kieffer       => 4880,
                         kiel          => 6424,
                         kiely         => 7318,
                         kiernan       => 6875,
                         kifer         => 9430,
                         kiger         => 5856,
                         kight         => 6318,
                         kilburn       => 4911,
                         kilby         => 6942,
                         kile          => 5855,
                         kilgore       => 1270,
                         killebrew     => 6993,
                         killen        => 7317,
                         killian       => 1924,
                         killingsworth => 4777,
                         killion       => 4710,
                         killough      => 5656,
                         kilmer        => 4342,
                         kilpatrick    => 2005,
                         kimball       => 980,
                         kimberlin     => 8433,
                         kimble        => 1524,
                         kimbrell      => 3552,
                         kimbro        => 6992,
                         kimbrough     => 1863,
                         kimes         => 6251,
                         kimmel        => 2975,
                         kimsey        => 6674,
                         kimura        => 4850,
                         kinard        => 3389,
                         kincaid       => 1497,
                         kinch         => 8869,
                         kinchen       => 9429,
                         kinder        => 2266,
                         kindle        => 7812,
                         kindred       => 4815,
                         king          => 29,
                         kingery       => 5943,
                         kingsbury     => 4231,
                         kingsley      => 3026,
                         kinlaw        => 6317,
                         kinley        => 9811,
                         kinnard       => 6802,
                         kinney        => 796,
                         kinsella      => 6801,
                         kinser        => 6207,
                         kinsey        => 1750,
                         kinsler       => 8095,
                         kinsley       => 8432,
                         kinslow       => 8305,
                         kinzer        => 7628,
                         kipp          => 4287,
                         kirby         => 473,
                         kircher       => 8868,
                         kirchner      => 3340,
                         kirkendall    => 8195,
                         kirkham       => 5027,
                         kirkland      => 821,
                         kirkman       => 5130,
                         kirkpatrick   => 967,
                         kirksey       => 5092,
                         kirkwood      => 3190,
                         kirsch        => 4373,
                         kirschner     => 4879,
                         kirtley       => 8553,
                         kirwan        => 7460,
                         kiser         => 1580,
                         kish          => 3951,
                         kisner        => 7385,
                         kissel        => 7994,
                         kissinger     => 6673,
                         kistler       => 5655,
                         kitchens      => 2714,
                         kite          => 4623,
                         kittle        => 6800,
                         kittredge     => 9810,
                         kittrell      => 5208,
                         kitts         => 6423,
                         kizer         => 4814,
                         klassen       => 8765,
                         klatt         => 5901,
                         klaus         => 5900,
                         klein         => 392,
                         kline         => 671,
                         kling         => 4286,
                         klingensmith  => 4372,
                         klinger       => 3579,
                         klink         => 6250,
                         klotz         => 5253,
                         klug          => 4403,
                         kluge         => 9952,
                         knapp         => 670,
                         knecht        => 8194,
                         kneeland      => 9558,
                         knepp         => 8980,
                         knepper       => 6422,
                         knight        => 147,
                         knighten      => 6672,
                         knighton      => 6486,
                         knisely       => 8979,
                         knisley       => 6421,
                         knoll         => 3260,
                         knopp         => 5854,
                         knorr         => 8304,
                         knott         => 2304,
                         knotts        => 4003,
                         knowles       => 856,
                         knowlton      => 2842,
                         knox          => 561,
                         knudsen       => 2703,
                         knudson       => 3593,
                         knuth         => 8193,
                         knutson       => 1637,
                         kobayashi     => 6381,
                         koch          => 644,
                         kocher        => 4910,
                         koehler       => 1660,
                         koehn         => 4435,
                         koenig        => 1589,
                         koepke        => 9307,
                         koerner       => 5207,
                         koester       => 4371,
                         koger         => 7721,
                         kohl          => 3458,
                         kohler        => 1886,
                         kohn          => 3644,
                         kolar         => 9809,
                         kolb          => 2473,
                         kollar        => 9557,
                         koller        => 5409,
                         konrad        => 7811,
                         koon          => 4556,
                         koonce        => 2984,
                         koons         => 5169,
                         koontz        => 2685,
                         koopman       => 7908,
                         kopec         => 9428,
                         kopp          => 2923,
                         kornegay      => 4402,
                         korte         => 7720,
                         koski         => 5026,
                         koss          => 6149,
                         koster        => 5332,
                         kovac         => 8094,
                         kovach        => 3551,
                         kovacs        => 4813,
                         koval         => 9083,
                         kowal         => 5471,
                         kowalczyk     => 6485,
                         kowalewski    => 7810,
                         kowalski      => 2107,
                         kozak         => 3857,
                         koziol        => 7809,
                         kozlowski     => 3219,
                         kraemer       => 4285,
                         kraft         => 1440,
                         krahn         => 9951,
                         krall         => 7719,
                         kramer        => 480,
                         krantz        => 4812,
                         kranz         => 5025,
                         kratz         => 6206,
                         kratzer       => 7907,
                         kraus         => 2260,
                         krause        => 964,
                         krauss        => 3578,
                         krawczyk      => 8192,
                         krebs         => 2405,
                         kremer        => 4530,
                         kress         => 5295,
                         krick         => 7155,
                         krieg         => 7808,
                         krieger       => 3487,
                         kroeger       => 5804,
                         krohn         => 7906,
                         krol          => 7993,
                         kroll         => 3550,
                         kropp         => 7154,
                         krouse        => 7459,
                         krueger       => 951,
                         krug          => 3892,
                         kruger        => 2209,
                         krull         => 8640,
                         krumm         => 8303,
                         krupa         => 9427,
                         krupp         => 9426,
                         kruse         => 1616,
                         kubiak        => 8552,
                         kubik         => 8978,
                         kucera        => 7905,
                         kuehl         => 7627,
                         kuehn         => 4587,
                         kugler        => 7992,
                         kuhl          => 4500,
                         kuhlman       => 6380,
                         kuhlmann      => 7807,
                         kuhn          => 1072,
                         kuhns         => 4555,
                         kujawa        => 6991,
                         kulp          => 8431,
                         kumar         => 4370,
                         kunkel        => 3231,
                         kunkle        => 5129,
                         kuntz         => 3441,
                         kunz          => 3457,
                         kunze         => 9306,
                         kurth         => 7316,
                         kurtz         => 1372,
                         kushner       => 7458,
                         kuster        => 8191,
                         kutz          => 5331,
                         kuykendall    => 2499,
                         kwan          => 4529,
                         kwiatkowski   => 6941,
                         kwon          => 5986,
                         kwong         => 9556,
                         kyles         => 4746,
                         kyser         => 6249,
                         labarbera     => 7550,
                         labarge       => 8977,
                         labbe         => 3358,
                         labelle       => 3873,
                         labonte       => 4066,
                         laborde       => 9082,
                         laboy         => 4709,
                         labrecque     => 5519,
                         labrie        => 5706,
                         lacasse       => 4708,
                         lach          => 8190,
                         lachance      => 2491,
                         lachapelle    => 8764,
                         lackey        => 1338,
                         laclair       => 7718,
                         lacombe       => 6100,
                         lacour        => 7315,
                         lacourse      => 9555,
                         lacroix       => 2684,
                         ladd          => 1615,
                         ladner        => 1125,
                         ladue         => 9950,
                         lafave        => 6604,
                         lafayette     => 7073,
                         lafferty      => 3719,
                         laflamme      => 3787,
                         lafleur       => 2898,
                         lafollette    => 8551,
                         lafond        => 6874,
                         lafontaine    => 6484,
                         laforge       => 9196,
                         lafountain    => 5705,
                         lafrance      => 5128,
                         lafreniere    => 7153,
                         lagasse       => 7072,
                         lagunas       => 7314,
                         lahr          => 4230,
                         lail          => 5064,
                         laing         => 4499,
                         lair          => 5371,
                         laird         => 1382,
                         lajoie        => 5206,
                         lakey         => 6205,
                         lakin         => 7236,
                         laliberte     => 5091,
                         lally         => 5853,
                         lalonde       => 4707,
                         lamanna       => 8093,
                         lamarre       => 9689,
                         lamas         => 8189,
                         lamb          => 425,
                         lambert       => 264,
                         lambrecht     => 8430,
                         lamere        => 7717,
                         lamkin        => 7991,
                         lamm          => 2604,
                         lammers       => 6873,
                         lamontagne    => 4179,
                         lamoreaux     => 8550,
                         lamothe       => 7152,
                         lamoureux     => 6148,
                         lampe         => 5063,
                         lamphere      => 9195,
                         lampkin       => 5024,
                         lampley       => 7457,
                         lancaster     => 804,
                         landa         => 6099,
                         landau        => 9081,
                         lander        => 5518,
                         landeros      => 5654,
                         landers       => 1356,
                         landes        => 5942,
                         landin        => 6799,
                         landis        => 1644,
                         landreth      => 4554,
                         landrum       => 1880,
                         landry        => 607,
                         landwehr      => 8867,
                         lane          => 171,
                         laney         => 2883,
                         lang          => 478,
                         langan        => 8092,
                         langdon       => 3275,
                         lange         => 1188,
                         langer        => 3820,
                         langevin      => 7071,
                         langford      => 1393,
                         langham       => 4745,
                         langley       => 855,
                         langlois      => 3061,
                         langston      => 1332,
                         lanham        => 2631,
                         lanier        => 1423,
                         lankford      => 2026,
                         lanning       => 3856,
                         lantz         => 2735,
                         lanza         => 5294,
                         lapierre      => 4528,
                         laplant       => 9808,
                         laplante      => 3092,
                         lapoint       => 8549,
                         lapointe      => 2522,
                         laporte       => 3322,
                         lapp          => 5370,
                         laprade       => 9807,
                         lara          => 592,
                         largent       => 5293,
                         larimore      => 9425,
                         larios        => 7549,
                         lariviere     => 7990,
                         lark          => 5653,
                         larkin        => 1200,
                         larkins       => 4811,
                         larocca       => 7716,
                         laroche       => 3872,
                         larochelle    => 5899,
                         larock        => 8429,
                         larosa        => 5517,
                         larose        => 3274,
                         larrabee      => 4401,
                         larrison      => 9080,
                         larsen        => 501,
                         larson        => 220,
                         lasalle       => 6047,
                         lasater       => 6671,
                         lash          => 3357,
                         lasher        => 5564,
                         lashley       => 3831,
                         laskey        => 9806,
                         laskowski     => 6940,
                         lasky         => 7806,
                         lasley        => 5408,
                         lasseter      => 8548,
                         lassiter      => 1593,
                         laster        => 3075,
                         latham        => 1064,
                         lathan        => 6990,
                         lathrop       => 4434,
                         latimer       => 3128,
                         latimore      => 9079,
                         latour        => 7313,
                         latta         => 4466,
                         lattimore     => 3691,
                         lauderdale    => 6483,
                         lauer         => 3690,
                         laughlin      => 1945,
                         laureano      => 6670,
                         lauria        => 9424,
                         laux          => 7151,
                         lauzon        => 8763,
                         lavallee      => 4284,
                         lavalley      => 4849,
                         lavender      => 3356,
                         lavergne      => 5090,
                         laverty       => 7989,
                         lavigne       => 2664,
                         lavin         => 5442,
                         lavine        => 7988,
                         lavoie        => 2467,
                         lawhorn       => 3891,
                         lawing        => 9554,
                         lawler        => 1852,
                         lawless       => 3230,
                         lawlor        => 5516,
                         lawson        => 187,
                         lawton        => 2153,
                         layfield      => 6939,
                         layman        => 2788,
                         laymon        => 9553,
                         layne         => 1991,
                         layton        => 1821,
                         lazar         => 6603,
                         lazenby       => 9423,
                         lazo          => 5407,
                         leach         => 599,
                         leahy         => 2974,
                         leake         => 3643,
                         leaks         => 9688,
                         leal          => 1170,
                         lear          => 2800,
                         leary         => 1611,
                         leasure       => 8976,
                         leath         => 5089,
                         leatherman    => 4205,
                         leathers      => 4260,
                         leatherwood   => 4810,
                         leavell       => 9949,
                         leavitt       => 2063,
                         lebeau        => 6872,
                         lebel         => 7235,
                         leblanc       => 596,
                         leboeuf       => 4127,
                         lebron        => 3577,
                         lebrun        => 5756,
                         lechner       => 7904,
                         lechuga       => 9422,
                         leclair       => 2573,
                         leclaire      => 8547,
                         leclerc       => 5168,
                         lecompte      => 5704,
                         ledbetter     => 1283,
                         lederman      => 8546,
                         ledesma       => 2457,
                         ledet         => 4112,
                         ledezma       => 6379,
                         ledford       => 1427,
                         ledger        => 8762,
                         ledoux        => 2950,
                         leduc         => 7715,
                         lee           => 23,
                         leech         => 4283,
                         leedy         => 9948,
                         leeper        => 3804,
                         lees          => 3972,
                         lefebvre      => 3422,
                         lefevre       => 5292,
                         leffler       => 7548,
                         lefkowitz     => 8761,
                         lefler        => 7547,
                         leflore       => 5803,
                         leftwich      => 5652,
                         legault       => 7903,
                         leger         => 2939,
                         legere        => 7312,
                         legette       => 9805,
                         legg          => 3111,
                         leggett       => 1933,
                         legrand       => 4527,
                         lehman        => 1011,
                         lehmann       => 2905,
                         lehr          => 5441,
                         leibowitz     => 6378,
                         leighton      => 3291,
                         leija         => 5703,
                         leiker        => 8302,
                         leininger     => 7234,
                         leister       => 7456,
                         leitch        => 9078,
                         leite         => 9687,
                         leith         => 8428,
                         leitner       => 9552,
                         leiva         => 6482,
                         lejeune       => 5406,
                         lemaire       => 9804,
                         lemaster      => 3549,
                         lemay         => 2713,
                         lemieux       => 2417,
                         lemire        => 5405,
                         lemke         => 3421,
                         lemley        => 5898,
                         lemmon        => 3486,
                         lemmons       => 5985,
                         lemoine       => 4586,
                         lemon         => 1686,
                         lemons        => 1783,
                         lemos         => 5755,
                         lemus         => 2596,
                         lenhart       => 6602,
                         lenihan       => 9305,
                         lennox        => 6147,
                         lenoir        => 5252,
                         lent          => 5610,
                         lentz         => 1812,
                         lenz          => 2841,
                         leong         => 5404,
                         leonhardt     => 8866,
                         leos          => 6989,
                         lepage        => 6046,
                         lepore        => 7384,
                         leppert       => 8975,
                         lerch         => 7987,
                         lerma         => 3189,
                         lerner        => 3576,
                         leroux        => 9803,
                         lesher        => 6539,
                         lesko         => 6871,
                         lesperance    => 8760,
                         lessard       => 3575,
                         letendre      => 6740,
                         letourneau    => 4465,
                         letson        => 9421,
                         lett          => 4909,
                         leung         => 2958,
                         levan         => 8545,
                         levasseur     => 4662,
                         leveille      => 8427,
                         leverett      => 4776,
                         levesque      => 2094,
                         levin         => 1932,
                         levine        => 819,
                         levinson      => 5403,
                         levitt        => 6045,
                         levy          => 758,
                         lewallen      => 8091,
                         lewandowski   => 2676,
                         lewellen      => 7383,
                         lewin         => 5563,
                         lewis         => 22,
                         leyba         => 7070,
                         leyva         => 2058,
                         lheureux      => 4848,
                         liberatore    => 9194,
                         licata        => 8865,
                         licon         => 9802,
                         liddell       => 3890,
                         liddle        => 8544,
                         lieb          => 6870,
                         lieberman     => 3871,
                         liggett       => 6316,
                         liggins       => 5023,
                         lightfoot     => 2818,
                         lightner      => 3819,
                         ligon         => 3218,
                         likens        => 9801,
                         liles         => 1981,
                         lillard       => 5852,
                         lilley        => 2855,
                         lima          => 2748,
                         limon         => 3177,
                         linares       => 3127,
                         lind          => 1724,
                         lindahl       => 8188,
                         lindberg      => 2922,
                         linde         => 9800,
                         lindell       => 6869,
                         lindeman      => 5515,
                         lindemann     => 8974,
                         linden        => 5470,
                         linder        => 2072,
                         linderman     => 8426,
                         lindgren      => 3786,
                         lindholm      => 7069,
                         lindley       => 2527,
                         lindner       => 4706,
                         lindo         => 8425,
                         lindquist     => 2439,
                         lindsley      => 8543,
                         lindstrom     => 3764,
                         lineberry     => 6315,
                         linehan       => 9551,
                         lingenfelter  => 8090,
                         lingerfelt    => 7311,
                         lingle        => 6868,
                         lingo         => 7714,
                         link          => 1345,
                         linker        => 5941,
                         linkous       => 3400,
                         linn          => 1910,
                         linton        => 2114,
                         linville      => 3668,
                         lipinski      => 8973,
                         lippert       => 5088,
                         lippincott    => 9686,
                         lipps         => 8301,
                         lipscomb      => 1828,
                         lipsey        => 6420,
                         liptak        => 9077,
                         lira          => 2787,
                         lirette       => 8759,
                         liriano       => 9420,
                         lister        => 3388,
                         liston        => 6739,
                         litchfield    => 6044,
                         litten        => 9947,
                         litteral      => 9685,
                         littlefield   => 1909,
                         littlejohn    => 1870,
                         littles       => 8187,
                         littleton     => 2564,
                         litton        => 5440,
                         littrell      => 5402,
                         lively        => 2369,
                         livengood     => 6248,
                         livermore     => 9550,
                         livesay       => 6938,
                         livingston    => 626,
                         lizarraga     => 8089,
                         lizotte       => 5609,
                         llamas        => 5167,
                         llanes        => 7382,
                         llanos        => 9549,
                         llewellyn     => 4369,
                         lockard       => 4498,
                         locke         => 1038,
                         lockett       => 1392,
                         lockhart      => 921,
                         locklear      => 2472,
                         lockman       => 7713,
                         lockridge     => 6419,
                         lockwood      => 1314,
                         loeb          => 8424,
                         loeffler      => 5401,
                         loehr         => 7712,
                         loera         => 3610,
                         loesch        => 7805,
                         lofgren       => 8758,
                         loftin        => 3548,
                         loftis        => 2712,
                         lofton        => 1772,
                         loftus        => 4111,
                         logan         => 407,
                         loggins       => 5251,
                         logsdon       => 2521,
                         logue         => 3574,
                         lohman        => 6098,
                         lohr          => 4229,
                         loiselle      => 9304,
                         lollar        => 7626,
                         lollis        => 8186,
                         lomas         => 5608,
                         lomax         => 2416,
                         lombard       => 3547,
                         lombardi      => 2313,
                         lombardo      => 1966,
                         lomeli        => 4622,
                         lonergan      => 8185,
                         loney         => 6669,
                         long          => 82,
                         longley       => 7150,
                         longmire      => 7804,
                         longo         => 3037,
                         longoria      => 1491,
                         longstreet    => 9303,
                         loomis        => 1675,
                         looney        => 1523,
                         looper        => 6798,
                         loos          => 5940,
                         loper         => 3511,
                         lopes         => 1905,
                         lopez         => 31,
                         lopresti      => 9419,
                         lorenz        => 2057,
                         lorenzen      => 8184,
                         loring        => 9302,
                         losey         => 9946,
                         lott          => 750,
                         lotz          => 8542,
                         loucks        => 4368,
                         loudermilk    => 6314,
                         lough         => 6797,
                         loughlin      => 8541,
                         loughran      => 9301,
                         lounsbury     => 9193,
                         louque        => 7455,
                         louviere      => 8972,
                         lovato        => 4317,
                         loveday       => 8757,
                         lovejoy       => 3126,
                         lovelace      => 2216,
                         lovelady      => 5851,
                         loveland      => 5166,
                         loveless      => 3125,
                         lovell        => 1096,
                         lovett        => 1389,
                         lovette       => 9300,
                         lovins        => 8540,
                         lowder        => 5939,
                         lowe          => 247,
                         lowery        => 576,
                         lowman        => 3763,
                         lowrance      => 8183,
                         lowrey        => 5514,
                         lowrie        => 8971,
                         lowry         => 1091,
                         lowther       => 6481,
                         loya          => 3870,
                         lozada        => 4585,
                         lozano        => 893,
                         lozier        => 7310,
                         lozoya        => 7803,
                         lubin         => 7546,
                         lucas         => 259,
                         luce          => 2646,
                         lucero        => 869,
                         lucey         => 9684,
                         lucier        => 6204,
                         luckett       => 2921,
                         luckey        => 5439,
                         ludlow        => 8423,
                         ludwick       => 6668,
                         ludwig        => 1677,
                         lueck         => 7545,
                         luedtke       => 9192,
                         luevano       => 5062,
                         lugo          => 934,
                         lujan         => 1572,
                         lukas         => 8539,
                         lukens        => 7233,
                         luker         => 4259,
                         lukes         => 9418,
                         lumley        => 8970,
                         lumpkin       => 2333,
                         lumpkins      => 8756,
                         luna          => 438,
                         lund          => 1141,
                         lundberg      => 3456,
                         lunde         => 8422,
                         lundgren      => 4046,
                         lundin        => 8864,
                         lundquist     => 5022,
                         lundy         => 1464,
                         lunn          => 4228,
                         lunsford      => 1665,
                         lunt          => 7232,
                         luong         => 4002,
                         luper         => 8639,
                         lupo          => 5165,
                         lusby         => 9799,
                         lusk          => 1501,
                         lussier       => 4989,
                         luster        => 3025,
                         lutes         => 6667,
                         luttrell      => 3124,
                         lutz          => 930,
                         lydon         => 7068,
                         lykins        => 5250,
                         lyles         => 1381,
                         lynch         => 216,
                         lyon          => 959,
                         lyons         => 296,
                         lytle         => 2080,
                         maas          => 3609,
                         mabe          => 3074,
                         mabrey        => 8638,
                         mabry         => 1879,
                         macaluso      => 6937,
                         macarthur     => 5562,
                         macdonald     => 713,
                         macdougall    => 6043,
                         mace          => 2415,
                         macedo        => 6538,
                         macfarlane    => 6796,
                         macgregor     => 5127,
                         mach          => 5400,
                         machado       => 1923,
                         machuca       => 6936,
                         macias        => 808,
                         maciel        => 5021,
                         mack          => 321,
                         mackay        => 3355,
                         mackey        => 909,
                         mackie        => 3627,
                         mackin        => 9299,
                         mackinnon     => 7454,
                         macklin       => 3164,
                         maclean       => 3530,
                         macleod       => 4026,
                         maclin        => 9683,
                         macmillan     => 4178,
                         macneil       => 7453,
                         macomber      => 5438,
                         macon         => 2520,
                         macpherson    => 4126,
                         madden        => 812,
                         maddock       => 9945,
                         maddox        => 654,
                         maddux        => 4497,
                         maddy         => 8863,
                         mader         => 5702,
                         madera        => 4001,
                         madewell      => 7231,
                         madigan       => 4154,
                         madore        => 5802,
                         madrid        => 1499,
                         madrigal      => 2152,
                         madsen        => 1709,
                         madson        => 7452,
                         maeda         => 8421,
                         maes          => 3510,
                         maestas       => 2809,
                         magallanes    => 7381,
                         magallon      => 9298,
                         magana        => 1974,
                         magdaleno     => 7711,
                         magee         => 939,
                         mager         => 9417,
                         magers        => 9548,
                         maggard       => 3932,
                         maggio        => 4705,
                         magill        => 5164,
                         magner        => 9682,
                         magness       => 6867,
                         magnuson      => 3855,
                         magoon        => 8862,
                         magruder      => 6097,
                         maguire       => 2015,
                         mahaffey      => 3785,
                         mahan         => 2123,
                         mahaney       => 9681,
                         mahar         => 9944,
                         maher         => 1508,
                         mahler        => 4704,
                         mahon         => 2113,
                         mahone        => 5754,
                         mahoney       => 918,
                         mahurin       => 8637,
                         maier         => 2541,
                         maillet       => 9680,
                         mailloux      => 8969,
                         maines        => 7544,
                         mair          => 8300,
                         maisonet      => 8968,
                         majewski      => 7230,
                         majors        => 2490,
                         maki          => 3626,
                         makowski      => 7229,
                         malave        => 4942,
                         maldonado     => 352,
                         malek         => 6988,
                         maley         => 6738,
                         malick        => 9943,
                         malin         => 9297,
                         malinowski    => 5126,
                         mallett       => 4584,
                         mallette      => 6795,
                         malley        => 3573,
                         mallon        => 6866,
                         malloy        => 1698,
                         malone        => 361,
                         maloney       => 972,
                         malott        => 8967,
                         maloy         => 6096,
                         manahan       => 8966,
                         mancilla      => 8538,
                         mancini       => 3387,
                         mancuso       => 2747,
                         mandel        => 4282,
                         mandell       => 8965,
                         mandeville    => 8420,
                         maness        => 3474,
                         maney         => 9416,
                         manfredi      => 9191,
                         mangan        => 6666,
                         mangold       => 9942,
                         mangrum       => 4496,
                         mangum        => 2583,
                         manigault     => 9415,
                         manion        => 6042,
                         manis         => 6794,
                         manke         => 8636,
                         manley        => 988,
                         mann          => 320,
                         manning       => 330,
                         mannino       => 5291,
                         manns         => 3592,
                         manos         => 8299,
                         manriquez     => 8298,
                         mansell       => 7380,
                         mansfield     => 1331,
                         manske        => 9798,
                         mansour       => 5701,
                         mantooth      => 7451,
                         manus         => 8182,
                         manzanares    => 6480,
                         manzano       => 4988,
                         manzi         => 9941,
                         manzo         => 3784,
                         mapes         => 4775,
                         maples        => 2362,
                         mapp          => 5205,
                         marable       => 6146,
                         marasco       => 8297,
                         marble        => 3783,
                         marcano       => 5753,
                         marceau       => 8419,
                         marchan       => 9797,
                         marchand      => 3803,
                         marchant      => 5061,
                         marchese      => 5290,
                         marchetti     => 6479,
                         marciano      => 8181,
                         marcotte      => 3529,
                         marcoux       => 7450,
                         marcum        => 1276,
                         marden        => 8088,
                         mardis        => 7543,
                         marek         => 5801,
                         mares         => 2595,
                         marez         => 8635,
                         margolis      => 9296,
                         mariani       => 8418,
                         marin         => 1253,
                         marinelli     => 6737,
                         mariscal      => 7309,
                         markel        => 7542,
                         markey        => 6418,
                         markham       => 2151,
                         markle        => 5204,
                         markley       => 3802,
                         markowitz     => 6793,
                         marks         => 567,
                         marlar        => 9295,
                         marler        => 3950,
                         marlow        => 2150,
                         marlowe       => 3339,
                         maroney       => 6935,
                         marotta       => 7228,
                         marquardt     => 4153,
                         marques       => 8296,
                         marquez       => 449,
                         marr          => 2734,
                         marra         => 4177,
                         marrero       => 1152,
                         marriott      => 6145,
                         marron        => 8087,
                         marroquin     => 2733,
                         marrs         => 4495,
                         marrufo       => 6601,
                         marsden       => 8634,
                         marsh         => 409,
                         marshall      => 113,
                         marshburn     => 9679,
                         marston       => 5020,
                         marte         => 7067,
                         martel        => 2229,
                         martell       => 2563,
                         martens       => 3073,
                         martin        => 15,
                         martindale    => 3123,
                         martineau     => 5800,
                         martinelli    => 6665,
                         martines      => 5897,
                         martinez      => 18,
                         martino       => 2136,
                         martins       => 3420,
                         martinson     => 3918,
                         martz         => 3273,
                         marx          => 2452,
                         mascarenas    => 6377,
                         mashburn      => 4987,
                         mason         => 127,
                         massa         => 4878,
                         massaro       => 8755,
                         masse         => 6664,
                         massenburg    => 9294,
                         massengale    => 6537,
                         massengill    => 9190,
                         massey        => 418,
                         massie        => 2630,
                         masson        => 8861,
                         mast          => 3801,
                         masters       => 1415,
                         masterson     => 2629,
                         mastin        => 5799,
                         mata          => 1020,
                         matheny       => 2897,
                         mather        => 4877,
                         matherly      => 5752,
                         matherne      => 4774,
                         mathers       => 5399,
                         mathes        => 4400,
                         matheson      => 3762,
                         mathews       => 486,
                         mathewson     => 6313,
                         mathias       => 3608,
                         mathieu       => 6247,
                         mathis        => 430,
                         mathison      => 4526,
                         matias        => 4086,
                         matlock       => 1900,
                         matney        => 3689,
                         matos         => 1547,
                         matson        => 1862,
                         matsumoto     => 8086,
                         matta         => 5369,
                         matte         => 7902,
                         mattern       => 6663,
                         matteson      => 3740,
                         matthes       => 9293,
                         matthews      => 160,
                         mattingly     => 1959,
                         mattis        => 9189,
                         mattison      => 2882,
                         mattos        => 3718,
                         mattox        => 2259,
                         mattson       => 1757,
                         matus         => 9547,
                         matz          => 6095,
                         mauck         => 9678,
                         mauk          => 8417,
                         mauldin       => 2131,
                         mauney        => 6600,
                         maupin        => 3290,
                         maurer        => 1490,
                         maus          => 6662,
                         maxey         => 2663,
                         maxfield      => 3917,
                         maxon         => 8180,
                         maxson        => 6736,
                         mayberry      => 1604,
                         mayer         => 773,
                         mayers        => 3642,
                         mayes         => 977,
                         mayfield      => 864,
                         mayhew        => 3259,
                         mayle         => 5398,
                         maynard       => 574,
                         mayne         => 7901,
                         maynor        => 6865,
                         mayo          => 733,
                         mayorga       => 5798,
                         mays          => 663,
                         maze          => 4433,
                         mazur         => 4773,
                         mazurek       => 8537,
                         mazza         => 3854,
                         mazzola       => 7379,
                         mazzone       => 8964,
                         mcabee        => 4772,
                         mcadams       => 2324,
                         mcadoo        => 5797,
                         mcafee        => 2617,
                         mcaleer       => 8963,
                         mcalister     => 2346,
                         mcallister    => 933,
                         mcalpin       => 6312,
                         mcalpine      => 5850,
                         mcanally      => 5896,
                         mcandrew      => 7149,
                         mcardle       => 5561,
                         mcarthur      => 2426,
                         mcatee        => 5938,
                         mcauley       => 6094,
                         mcauliffe     => 7066,
                         mcavoy        => 5796,
                         mcbee         => 3156,
                         mcbeth        => 8633,
                         mcbrayer      => 7625,
                         mcbride       => 389,
                         mcbroom       => 4771,
                         mcbryde       => 7710,
                         mcburney      => 7308,
                         mccabe        => 1022,
                         mccafferty    => 4770,
                         mccaffrey     => 3272,
                         mccain        => 1173,
                         mccaleb       => 6735,
                         mccall        => 588,
                         mccalla       => 6792,
                         mccallister   => 3528,
                         mccallum      => 3060,
                         mccammon      => 8179,
                         mccandless    => 5163,
                         mccann        => 928,
                         mccants       => 3916,
                         mccardle      => 9076,
                         mccarley      => 6734,
                         mccarroll     => 8860,
                         mccarron      => 7986,
                         mccarter      => 2332,
                         mccarthy      => 369,
                         mccartney     => 2208,
                         mccarty       => 739,
                         mccarver      => 7148,
                         mccary        => 6246,
                         mccaskill     => 3527,
                         mccaslin      => 5560,
                         mccauley      => 1207,
                         mccay         => 8416,
                         mcchesney     => 6311,
                         mcclain       => 487,
                         mcclanahan    => 2854,
                         mcclary       => 3949,
                         mcclean       => 6376,
                         mccleary      => 3931,
                         mcclellan     => 1095,
                         mcclelland    => 1809,
                         mcclendon     => 1149,
                         mcclintock    => 2949,
                         mcclinton     => 3948,
                         mccloskey     => 3122,
                         mccloud       => 1671,
                         mccluney      => 9188,
                         mcclung       => 2683,
                         mcclure       => 571,
                         mcclurg       => 5700,
                         mccluskey     => 5060,
                         mccollough    => 6478,
                         mccollum      => 1265,
                         mccomas       => 5849,
                         mccomb        => 6536,
                         mccombs       => 2513,
                         mcconnell     => 633,
                         mccool        => 3240,
                         mccord        => 1174,
                         mccorkle      => 2817,
                         mccormack     => 2019,
                         mccormick     => 403,
                         mccourt       => 6477,
                         mccowan       => 6144,
                         mccown        => 4341,
                         mccoy         => 203,
                         mccracken     => 1473,
                         mccrae        => 7900,
                         mccraney      => 9546,
                         mccrary       => 2106,
                         mccraw        => 5289,
                         mccray        => 811,
                         mccrea        => 4316,
                         mccready      => 6599,
                         mccreary      => 3258,
                         mccree        => 8962,
                         mccrimmon     => 9940,
                         mccrory       => 4204,
                         mccubbin      => 7985,
                         mccue         => 3217,
                         mccullar      => 8961,
                         mccullen      => 9677,
                         mcculley      => 4281,
                         mcculloch     => 2816,
                         mccullough    => 645,
                         mccullum      => 7541,
                         mccully       => 6535,
                         mccune        => 3338,
                         mccurdy       => 2280,
                         mccurley      => 9796,
                         mccurry       => 4000,
                         mccusker      => 7802,
                         mccutchen     => 5795,
                         mccutcheon    => 3155,
                         mcdade        => 3800,
                         mcdaniel      => 274,
                         mcdaniels     => 3176,
                         mcdavid       => 5288,
                         mcdermott     => 1032,
                         mcdevitt      => 4583,
                         mcdonald      => 111,
                         mcdonnell     => 2572,
                         mcdonough     => 1344,
                         mcdougal      => 3239,
                         mcdougald     => 7307,
                         mcdougall     => 3930,
                         mcdougle      => 8754,
                         mcdowell      => 549,
                         mcduffie      => 2258,
                         mceachern     => 5699,
                         mcelhaney     => 4525,
                         mcelrath      => 7449,
                         mcelroy       => 1052,
                         mcelveen      => 8632,
                         mcelyea       => 8753,
                         mcentee       => 8960,
                         mcentire      => 7065,
                         mcevoy        => 4553,
                         mcewen        => 3307,
                         mcfadden      => 818,
                         mcfall        => 3091,
                         mcfalls       => 9545,
                         mcfarland     => 709,
                         mcfarlane     => 2603,
                         mcfarlin      => 6093,
                         mcgaha        => 6534,
                         mcgann        => 6598,
                         mcgarry       => 5162,
                         mcgarvey      => 9544,
                         mcgary        => 6476,
                         mcgaughey     => 9795,
                         mcgee         => 324,
                         mcgehee       => 3667,
                         mcghee        => 970,
                         mcgill        => 1057,
                         mcginley      => 5059,
                         mcginn        => 4315,
                         mcginnis      => 952,
                         mcginty       => 4552,
                         mcglone       => 8178,
                         mcglothlin    => 5469,
                         mcglynn       => 6143,
                         mcgough       => 4176,
                         mcgovern      => 2393,
                         mcgowan       => 782,
                         mcgowen       => 8295,
                         mcgrady       => 9794,
                         mcgrane       => 9939,
                         mcgrath       => 962,
                         mcgraw        => 1235,
                         mcgregor      => 1944,
                         mcgrew        => 2948,
                         mcgriff       => 3929,
                         mcgruder      => 7227,
                         mcguigan      => 7624,
                         mcguinness    => 5751,
                         mcguire       => 440,
                         mchale        => 4908,
                         mchenry       => 2489,
                         mchone        => 8859,
                         mchugh        => 1878,
                         mcilwain      => 6533,
                         mcinerney     => 7623,
                         mcinnis       => 3072,
                         mcintire      => 2662,
                         mcintosh      => 643,
                         mcinturff     => 8752,
                         mcintyre      => 680,
                         mciver        => 5249,
                         mckain        => 8631,
                         mckamey       => 7540,
                         mckay         => 737,
                         mckean        => 5019,
                         mckee         => 611,
                         mckeehan      => 8085,
                         mckeever      => 3666,
                         mckellar      => 6375,
                         mckelvey      => 4399,
                         mckenna       => 1343,
                         mckenney      => 3591,
                         mckenzie      => 436,
                         mckeon        => 3853,
                         mckeown       => 3688,
                         mckibben      => 5794,
                         mckie         => 7984,
                         mckim         => 5895,
                         mckinney      => 258,
                         mckinnie      => 8536,
                         mckinnon      => 1659,
                         mckinsey      => 9292,
                         mckinzie      => 6417,
                         mckissick     => 6597,
                         mcknight      => 656,
                         mckown        => 7147,
                         mckoy         => 4340,
                         mclain        => 1643,
                         mclamb        => 8858,
                         mclane        => 4045,
                         mclaughlin    => 396,
                         mclaurin      => 2808,
                         mclean        => 585,
                         mclellan      => 4280,
                         mclemore      => 2661,
                         mclendon      => 2358,
                         mcleod        => 825,
                         mclin         => 7226,
                         mcloughlin    => 6416,
                         mcmahan       => 2093,
                         mcmahon       => 851,
                         mcmanis       => 9938,
                         mcmann        => 7899,
                         mcmanus       => 1241,
                         mcmaster      => 3590,
                         mcmasters     => 8084,
                         mcmath        => 9291,
                         mcmichael     => 4110,
                         mcmillan      => 659,
                         mcmillen      => 2973,
                         mcmillian     => 1838,
                         mcmillin      => 5018,
                         mcmillion     => 9676,
                         mcmillon      => 6733,
                         mcminn        => 5203,
                         mcmorris      => 5698,
                         mcmullan      => 9187,
                         mcmullen      => 1342,
                         mcmullin      => 4152,
                         mcmurray      => 2904,
                         mcmurry       => 6791,
                         mcmurtry      => 9290,
                         mcnabb        => 2540,
                         mcnair        => 1366,
                         mcnally       => 1506,
                         mcnamara      => 1341,
                         mcnamee       => 4203,
                         mcnary        => 7801,
                         mcnatt        => 9414,
                         mcnaughton    => 9289,
                         mcneal        => 1162,
                         mcneely       => 2616,
                         mcneese       => 7539,
                         mcneil        => 705,
                         mcneill       => 1168,
                         mcnew         => 5368,
                         mcniel        => 7898,
                         mcnulty       => 2392,
                         mcnutt        => 2391,
                         mcpeak        => 5437,
                         mcphail       => 5287,
                         mcphee        => 5697,
                         mcpherson     => 775,
                         mcquade       => 8415,
                         mcquaid       => 9413,
                         mcqueen       => 1115,
                         mcquiston     => 7897,
                         mcrae         => 1321,
                         mcreynolds    => 3607,
                         mcroberts     => 7538,
                         mcshane       => 6415,
                         mcspadden     => 9412,
                         mcswain       => 3354,
                         mcsweeney     => 8414,
                         mcvay         => 3257,
                         mcveigh       => 9793,
                         mcvey         => 2896,
                         mcvicker      => 9543,
                         mcwhirter     => 8413,
                         mcwhorter     => 2130,
                         mcwilliams    => 1320,
                         meacham       => 3419,
                         mead          => 1234,
                         meade         => 1070,
                         meader        => 8083,
                         meador        => 2257,
                         meadors       => 7896,
                         meadows       => 667,
                         meads         => 9288,
                         meagher       => 4279,
                         mears         => 3485,
                         mease         => 7800,
                         meaux         => 9411,
                         mebane        => 8535,
                         mecham        => 5848,
                         medeiros      => 1472,
                         medellin      => 6142,
                         medford       => 5559,
                         medina        => 227,
                         medley        => 1835,
                         medlin        => 2840,
                         medlock       => 3526,
                         medrano       => 1614,
                         meece         => 9675,
                         meehan        => 2287,
                         meek          => 2183,
                         meeker        => 3175,
                         meekins       => 6141,
                         meeks         => 892,
                         mefford       => 5696,
                         mehta         => 6475,
                         meier         => 1522,
                         meiners       => 8630,
                         meisner       => 9186,
                         meissner      => 7225,
                         mejia         => 649,
                         mejias        => 6790,
                         melancon      => 3010,
                         melanson      => 4986,
                         melcher       => 6789,
                         melchor       => 6934,
                         meldrum       => 8751,
                         mele          => 7622,
                         melendez      => 716,
                         melgar        => 7064,
                         mellen        => 9075,
                         mello         => 2799,
                         mellott       => 6596,
                         melnick       => 6474,
                         melo          => 4985,
                         melson        => 7224,
                         melton        => 490,
                         melville      => 7709,
                         mena          => 2323,
                         menard        => 2135,
                         menchaca      => 4661,
                         mendelson     => 9410,
                         mendenhall    => 2807,
                         mendes        => 4227,
                         mendez        => 275,
                         mendiola      => 6788,
                         mendonca      => 9185,
                         mendosa       => 9409,
                         mendoza       => 224,
                         menefee       => 6414,
                         menendez      => 3036,
                         meneses       => 6092,
                         menjivar      => 8177,
                         menke         => 5894,
                         mentzer       => 8750,
                         menzel        => 9408,
                         meraz         => 4432,
                         mercado       => 606,
                         merced        => 8629,
                         mercer        => 726,
                         merchant      => 1795,
                         mercier       => 2786,
                         mercurio      => 5513,
                         merida        => 6661,
                         merino        => 5202,
                         merkel        => 6203,
                         merkle        => 6787,
                         merrell       => 3971,
                         merriam       => 8628,
                         merrick       => 2831,
                         merrifield    => 5750,
                         merriman      => 3761,
                         merritt       => 555,
                         merriweather  => 4464,
                         merryman      => 6041,
                         mertens       => 6310,
                         mertz         => 5367,
                         merwin        => 7378,
                         mesa          => 3154,
                         messenger     => 3386,
                         messer        => 1216,
                         messick       => 5749,
                         messier       => 4984,
                         messina       => 2539,
                         messinger     => 7983,
                         messner       => 5748,
                         mestas        => 8294,
                         metcalf       => 1203,
                         metcalfe      => 6140,
                         metheny       => 8749,
                         metoyer       => 8748,
                         metts         => 5161,
                         metz          => 1391,
                         metzger       => 1705,
                         metzler       => 3153,
                         meunier       => 7982,
                         meyer         => 201,
                         meyers        => 506,
                         meza          => 1104,
                         miceli        => 8082,
                         michaelis     => 8412,
                         michaels      => 1986,
                         michaelson    => 6309,
                         michalak      => 7063,
                         michalski     => 5286,
                         michaud       => 1369,
                         michels       => 4202,
                         michelson     => 8959,
                         mickel        => 8534,
                         mickelson     => 4278,
                         mickens       => 3947,
                         mickle        => 5607,
                         middaugh      => 6987,
                         middendorf    => 9407,
                         middlebrook   => 9674,
                         middlebrooks  => 5330,
                         middleton     => 627,
                         midgett       => 7062,
                         midkiff       => 5847,
                         miele         => 5893,
                         mielke        => 6864,
                         mier          => 6786,
                         mikell        => 7621,
                         mikesell      => 7306,
                         milam         => 2293,
                         milazzo       => 8958,
                         milburn       => 2853,
                         miles         => 260,
                         miley         => 4175,
                         millan        => 4621,
                         millar        => 5436,
                         millen        => 7448,
                         miller        => 7,
                         millet        => 5793,
                         millett       => 8293,
                         millican      => 7377,
                         milligan      => 1087,
                         milliken      => 3641,
                         milliner      => 9074,
                         millner       => 6933,
                         mills         => 144,
                         millsap       => 5892,
                         millsaps      => 7447,
                         milne         => 3739,
                         milner        => 2228,
                         milstead      => 9073,
                         mims          => 1355,
                         minard        => 7061,
                         mincey        => 4398,
                         miner         => 1175,
                         mingo         => 5984,
                         minick        => 9673,
                         mink          => 4258,
                         minnich       => 7146,
                         minnick       => 3375,
                         minnis        => 9406,
                         minor         => 874,
                         minter        => 2538,
                         minton        => 1861,
                         mintz         => 3071,
                         minyard       => 8857,
                         mirabal       => 8747,
                         miramontes    => 5058,
                         mireles       => 2571,
                         misner        => 8957,
                         mistretta     => 9405,
                         mitchell      => 39,
                         mitchem       => 4314,
                         mitchum       => 6040,
                         mitton        => 8627,
                         mixon         => 1820,
                         miyamoto      => 8533,
                         mize          => 2079,
                         mizell        => 5017,
                         moats         => 4876,
                         moberg        => 8411,
                         moberly       => 8746,
                         mobley        => 979,
                         mock          => 1563,
                         modica        => 8532,
                         modlin        => 6374,
                         moeller       => 2193,
                         moen          => 3455,
                         moffatt       => 6139,
                         moffett       => 2025,
                         moffitt       => 2702,
                         mohan         => 6732,
                         mohler        => 5329,
                         mohr          => 1621,
                         moise         => 8745,
                         mojica        => 2498,
                         molina        => 472,
                         molinaro      => 9542,
                         moline        => 6863,
                         moll          => 3665,
                         moller        => 5747,
                         molloy        => 5248,
                         molnar        => 5937,
                         monaghan      => 3946,
                         monahan       => 2018,
                         moncada       => 8081,
                         moncrief      => 5695,
                         mondragon     => 4044,
                         monette       => 8856,
                         mong          => 7376,
                         monge         => 6308,
                         monger        => 6039,
                         moniz         => 3229,
                         monk          => 1958,
                         monreal       => 9672,
                         monroe        => 465,
                         monroy        => 4983,
                         monson        => 2920,
                         montague      => 2798,
                         montalvo      => 2004,
                         montanez      => 2043,
                         montano       => 1383,
                         monteiro      => 7223,
                         monteith      => 9072,
                         montejano     => 9671,
                         monteleone    => 9184,
                         montelongo    => 6473,
                         montemayor    => 3970,
                         montenegro    => 4174,
                         montero       => 3009,
                         montes        => 982,
                         montez        => 3799,
                         montgomery    => 196,
                         monti         => 7222,
                         montiel       => 6307,
                         montijo       => 9937,
                         montoya       => 546,
                         monzon        => 7446,
                         moody         => 365,
                         moon          => 658,
                         mooney        => 781,
                         mooneyham     => 8531,
                         moore         => 9,
                         moorefield    => 8530,
                         moorehead     => 4907,
                         moorer        => 5792,
                         moores        => 8410,
                         moorhead      => 7221,
                         moorman       => 3889,
                         mora          => 894,
                         morabito      => 7445,
                         morales       => 128,
                         moralez       => 6038,
                         moran         => 399,
                         morano        => 9287,
                         moreau        => 2839,
                         morehead      => 3024,
                         morehouse     => 4582,
                         moreira       => 4809,
                         morel         => 4660,
                         moreland      => 1512,
                         morell        => 7620,
                         morelli       => 6306,
                         morello       => 7981,
                         morelock      => 7980,
                         moreno        => 225,
                         morey         => 2519,
                         morgan        => 55,
                         mori          => 7537,
                         moriarty      => 3440,
                         morin         => 685,
                         morita        => 9404,
                         morley        => 2594,
                         morman        => 8176,
                         morningstar   => 9792,
                         morrell       => 2175,
                         morrill       => 2983,
                         morris        => 51,
                         morrison      => 206,
                         morrissette   => 5057,
                         morrissey     => 2122,
                         morrow        => 467,
                         morse         => 620,
                         mortensen     => 3337,
                         mortenson     => 5891,
                         morton        => 413,
                         mosby         => 3008,
                         moseley       => 1368,
                         mosely        => 5285,
                         moser         => 926,
                         mosher        => 1778,
                         mosier        => 3216,
                         moskowitz     => 7799,
                         mosley        => 499,
                         mosqueda      => 5435,
                         moss          => 322,
                         mossman       => 8956,
                         mota          => 4151,
                         moten         => 4109,
                         motes         => 9791,
                         motley        => 2207,
                         moton         => 6202,
                         mott          => 1766,
                         motta         => 7895,
                         moua          => 4744,
                         moulton       => 1922,
                         moultrie      => 3969,
                         mounts        => 6660,
                         mouton        => 4173,
                         mowery        => 3484,
                         mowry         => 6037,
                         moxley        => 5558,
                         moya          => 2003,
                         moye          => 2852,
                         moyer         => 987,
                         moyers        => 4494,
                         moynihan      => 6595,
                         mozingo       => 9541,
                         mudd          => 4703,
                         mudge         => 9540,
                         mueller       => 515,
                         muir          => 3023,
                         mulcahy       => 4941,
                         muldoon       => 7305,
                         muldrow       => 7060,
                         mulford       => 8744,
                         mulholland    => 4620,
                         mulkey        => 3818,
                         mull          => 2645,
                         mullane       => 9790,
                         mullaney      => 9183,
                         mullen        => 755,
                         mullenax      => 9286,
                         mullens       => 4367,
                         muller        => 1133,
                         mulligan      => 2431,
                         mullikin      => 9789,
                         mullin        => 2785,
                         mullinax      => 6245,
                         mullings      => 9670,
                         mullins       => 300,
                         mullis        => 3336,
                         mulvaney      => 6986,
                         mulvey        => 6413,
                         mulvihill     => 9182,
                         mumford       => 5087,
                         mummert       => 9181,
                         muncy         => 2425,
                         munday        => 7375,
                         mundell       => 8080,
                         munden        => 9936,
                         mundt         => 9935,
                         mundy         => 3640,
                         munford       => 7798,
                         munger        => 4108,
                         munguia       => 4581,
                         muniz         => 1059,
                         munn          => 3589,
                         munos         => 7894,
                         munoz         => 290,
                         munro         => 4808,
                         munroe        => 5247,
                         munsey        => 8079,
                         munson        => 1521,
                         murakami      => 9788,
                         murchison     => 5983,
                         murdoch       => 6244,
                         murdock       => 1131,
                         murguia       => 8409,
                         murillo       => 1311,
                         muro          => 5694,
                         murphey       => 5125,
                         murphree      => 6659,
                         murphy        => 57,
                         murr          => 7220,
                         murray        => 116,
                         murrell       => 2192,
                         murry         => 1857,
                         muse          => 2482,
                         musgrave      => 6243,
                         musgrove      => 3374,
                         musick        => 4875,
                         musselman     => 4125,
                         musser        => 3090,
                         musso         => 8292,
                         mutchler      => 9403,
                         muth          => 6731,
                         myatt         => 6730,
                         myer          => 4580,
                         myers         => 96,
                         myhre         => 8175,
                         myrick        => 1541,
                         nabors        => 3353,
                         nadeau        => 1367,
                         nader         => 8529,
                         nadler        => 8291,
                         nagel         => 2694,
                         nagle         => 2466,
                         nagy          => 2797,
                         najera        => 3089,
                         nakagawa      => 9071,
                         nakamura      => 3945,
                         nakano        => 6729,
                         nall          => 3717,
                         nalley        => 5746,
                         nally         => 9285,
                         nance         => 1010,
                         napier        => 1421,
                         napolitano    => 4940,
                         napper        => 6373,
                         naquin        => 1630,
                         naranjo       => 3798,
                         narcisse      => 8626,
                         nardi         => 6985,
                         nardone       => 8174,
                         narvaez       => 3968,
                         nash          => 443,
                         nason         => 4150,
                         natal         => 7708,
                         natale        => 4339,
                         natoli        => 9787,
                         naughton      => 7219,
                         naugle        => 8955,
                         nault         => 9669,
                         nauman        => 8743,
                         naumann       => 7444,
                         nava          => 1511,
                         navarra       => 7304,
                         navarrete     => 3546,
                         navarrette    => 8408,
                         navarro       => 524,
                         navas         => 9668,
                         nave          => 5124,
                         naylor        => 1674,
                         nazario       => 4769,
                         neace         => 5366,
                         neal          => 245,
                         neale         => 6036,
                         nealy         => 3509,
                         neary         => 5890,
                         necaise       => 4172,
                         needham       => 2497,
                         neel          => 3606,
                         neeley        => 2784,
                         neely         => 1019,
                         neese         => 5693,
                         neff          => 1468,
                         negrete       => 2518,
                         negron        => 1531,
                         neill         => 2815,
                         neilsen       => 9284,
                         neilson       => 4366,
                         nellis        => 9180,
                         nelms         => 3588,
                         nelsen        => 5056,
                         nelson        => 37,
                         nemeth        => 4043,
                         neri          => 6035,
                         nero          => 5468,
                         nesbit        => 4659,
                         nesbitt       => 1856,
                         nesmith       => 3716,
                         ness          => 2938,
                         nester        => 5123,
                         netherton     => 9402,
                         nettles       => 2322,
                         neubauer      => 5982,
                         neufeld       => 9179,
                         neuman        => 2851,
                         neumann       => 2215,
                         nevarez       => 3007,
                         nevels        => 6305,
                         neves         => 7059,
                         nevin         => 8625,
                         nevins        => 6532,
                         newberry      => 1973,
                         newbold       => 9070,
                         newby         => 1869,
                         newcomb       => 1749,
                         newcomer      => 7893,
                         newell        => 880,
                         newhouse      => 4939,
                         newkirk       => 2582,
                         newland       => 5055,
                         newlin        => 6728,
                         newman        => 272,
                         newsom        => 2134,
                         newsome       => 938,
                         newson        => 4938,
                         newton        => 335,
                         nguyen        => 212,
                         nicholes      => 9069,
                         nicholls      => 4847,
                         nichols       => 145,
                         nicholson     => 464,
                         nickell       => 4874,
                         nickels       => 5397,
                         nickelson     => 7443,
                         nickens       => 6658,
                         nickerson     => 1540,
                         nickles       => 6412,
                         nickols       => 9934,
                         nicks         => 6862,
                         nicoletti     => 9068,
                         nielsen       => 786,
                         nielson       => 2024,
                         nieman        => 6531,
                         niemann       => 8528,
                         niemeyer      => 8078,
                         niemi         => 5054,
                         nieto         => 2023,
                         nieves        => 832,
                         nightingale   => 6727,
                         nigro         => 6411,
                         nilsen        => 8077,
                         nilson        => 8624,
                         nilsson       => 6304,
                         nimmons       => 8173,
                         nino          => 5201,
                         nissen        => 5745,
                         nivens        => 9933,
                         nixon         => 578,
                         noble         => 603,
                         nobles        => 2042,
                         nocera        => 9667,
                         nock          => 7145,
                         noland        => 2303,
                         nolasco       => 6785,
                         nolen         => 2302,
                         noles         => 7374,
                         nolette       => 9178,
                         nolin         => 8172,
                         noll          => 3830,
                         nolte         => 5246,
                         noonan        => 2660,
                         norberg       => 9177,
                         norcross      => 9067,
                         nord          => 5557,
                         nordin        => 9066,
                         nordstrom     => 5284,
                         norfleet      => 3508,
                         noriega       => 2850,
                         norris        => 281,
                         norsworthy    => 8527,
                         northcutt     => 4579,
                         northrop      => 7303,
                         northrup      => 6861,
                         norton        => 416,
                         norvell       => 6372,
                         norwood       => 1068,
                         novak         => 1000,
                         novotny       => 4025,
                         nowak         => 2036,
                         nowakowski    => 8855,
                         nowell        => 4042,
                         nowicki       => 6242,
                         nowlin        => 3545,
                         noyes         => 2357,
                         nugent        => 1868,
                         null          => 3817,
                         nunes         => 2972,
                         nunez         => 386,
                         nunley        => 3418,
                         nunn          => 1685,
                         nunnally      => 6371,
                         nunnery       => 7979,
                         nuno          => 7536,
                         nuss          => 7619,
                         nussbaum      => 7218,
                         nutt          => 3256,
                         nutter        => 3852,
                         nutting       => 8954,
                         nyberg        => 7302,
                         nygaard       => 7892,
                         nystrom       => 7217,
                         oakes         => 1371,
                         oakley        => 1471,
                         oaks          => 3255,
                         oates         => 3035,
                         obannon       => 7891,
                         ober          => 7216,
                         oberg         => 5365,
                         oberle        => 9666,
                         oboyle        => 9932,
                         obregon       => 7618,
                         obrian        => 4702,
                         obrien        => 255,
                         obryan        => 3625,
                         obryant       => 5651,
                         ocampo        => 2341,
                         ocasio        => 2849,
                         ochoa         => 672,
                         ochs          => 3999,
                         oconnell      => 873,
                         oconner       => 3439,
                         oconnor       => 469,
                         odaniel       => 6932,
                         oday          => 7373,
                         oden          => 3188,
                         odle          => 7144,
                         odom          => 769,
                         odonnell      => 760,
                         odum          => 3967,
                         offutt        => 6726,
                         ogburn        => 6201,
                         ogden         => 1588,
                         ogilvie       => 9176,
                         ogle          => 1943,
                         oglesby       => 2331,
                         ogletree      => 6200,
                         ogrady        => 4873,
                         ohalloran     => 8526,
                         ohanlon       => 9175,
                         ohara         => 1361,
                         ohare         => 5981,
                         ohler         => 9401,
                         ojeda         => 1980,
                         okane         => 9539,
                         okeefe        => 2099,
                         okelley       => 6138,
                         olander       => 6931,
                         oldaker       => 9174,
                         oldenburg     => 8953,
                         oldfield      => 9173,
                         oldham        => 2008,
                         olds          => 3687,
                         oleary        => 1539,
                         oleson        => 7058,
                         olguin        => 6303,
                         olinger       => 4768,
                         oliphant      => 3321,
                         olivares      => 2245,
                         olivarez      => 2838,
                         olivas        => 2517,
                         oliveira      => 3070,
                         olivera       => 4431,
                         oliveri       => 8952,
                         olivo         => 3715,
                         oller         => 7372,
                         ollis         => 7371,
                         olmos         => 4807,
                         olmstead      => 2675,
                         olney         => 6302,
                         oloughlin     => 7617,
                         olsen         => 511,
                         olson         => 165,
                         olszewski     => 6301,
                         olvera        => 2312,
                         omalley       => 2390,
                         omara         => 5434,
                         omeara        => 6472,
                         oneal         => 477,
                         oneil         => 839,
                         oneill        => 669,
                         oney          => 8171,
                         ontiveros     => 2837,
                         oquendo       => 4171,
                         oquinn        => 5467,
                         orcutt        => 5283,
                         ordonez       => 3399,
                         ordway        => 6594,
                         orear         => 8951,
                         oreilly       => 3022,
                         orellana      => 3473,
                         orman         => 7535,
                         ormsby        => 7442,
                         orndorff      => 8170,
                         ornelas       => 1996,
                         orona         => 9665,
                         oropeza       => 9538,
                         orosco        => 3228,
                         orourke       => 2002,
                         orozco        => 932,
                         orr           => 557,
                         orta          => 3664,
                         ortega        => 348,
                         ortego        => 5364,
                         orth          => 4149,
                         ortiz         => 114,
                         orton         => 4201,
                         osborn        => 725,
                         osborne       => 368,
                         osburn        => 3187,
                         osgood        => 2998,
                         oshaughnessy  => 8525,
                         oshea         => 3663,
                         oshiro        => 8407,
                         osman         => 7890,
                         osorio        => 2430,
                         osteen        => 3686,
                         oster         => 4846,
                         osterman      => 6657,
                         ostler        => 8742,
                         ostrander     => 2775,
                         ostrom        => 7215,
                         ostrowski     => 8076,
                         osullivan     => 3254,
                         osuna         => 5744,
                         oswald        => 2830,
                         oswalt        => 3928,
                         otero         => 1426,
                         otey          => 7978,
                         otoole        => 2593,
                         otte          => 6784,
                         otten         => 5791,
                         ottinger      => 6410,
                         oubre         => 6241,
                         ouellette     => 1579,
                         ousley        => 5086,
                         ovalle        => 6725,
                         overbey       => 8950,
                         overby        => 3685,
                         overcash      => 7057,
                         overman       => 4701,
                         overstreet    => 2041,
                         overton       => 1293,
                         overturf      => 6930,
                         oviedo        => 8741,
                         owens         => 105,
                         owensby       => 7534,
                         owings        => 4806,
                         owsley        => 6137,
                         oxendine      => 7533,
                         oxley         => 6656,
                         oyler         => 6199,
                         ozuna         => 4845,
                         pabon         => 4937,
                         pace          => 594,
                         pacheco       => 562,
                         paddock       => 4313,
                         padgett       => 1135,
                         padilla       => 384,
                         padron        => 4397,
                         padula        => 9931,
                         paez          => 5889,
                         pagan         => 1026,
                         pagano        => 4257,
                         page          => 289,
                         pagel         => 7889,
                         paine         => 2249,
                         painter       => 1228,
                         paiva         => 8623,
                         paiz          => 7797,
                         palacio       => 5888,
                         palacios      => 1220,
                         palen         => 9664,
                         palermo       => 4906,
                         palladino     => 6471,
                         palmer        => 143,
                         palmieri      => 5846,
                         palmore       => 4982,
                         palmquist     => 9400,
                         palomares     => 8854,
                         palomino      => 5396,
                         palomo        => 5512,
                         palumbo       => 2581,
                         panek         => 8406,
                         paniagua      => 6091,
                         pankey        => 6198,
                         pannell       => 2937,
                         pantoja       => 3227,
                         paolucci      => 9399,
                         papa          => 5845,
                         pape          => 3816,
                         papenfuss     => 9537,
                         pappas        => 2368,
                         paquette      => 1808,
                         paquin        => 5016,
                         parada        => 7796,
                         paradis       => 2644,
                         pardo         => 3829,
                         pardue        => 4551,
                         pare          => 5844,
                         paredes       => 3163,
                         parente       => 9398,
                         parenteau     => 4936,
                         parham        => 1354,
                         parikh        => 9786,
                         parisi        => 4700,
                         parke         => 5843,
                         parker        => 45,
                         parkerson     => 8622,
                         parkhurst     => 4844,
                         parkin        => 7707,
                         parkins       => 7056,
                         parkinson     => 2971,
                         parkman       => 6370,
                         parks         => 278,
                         parmenter     => 6724,
                         parmer        => 5842,
                         parnell       => 1786,
                         parr          => 1603,
                         parra         => 1592,
                         parrett       => 7532,
                         parris        => 1951,
                         parrish       => 527,
                         parrott       => 2040,
                         parry         => 2836,
                         parsley       => 4905,
                         parson        => 1556,
                         parsons       => 395,
                         partain       => 6197,
                         partee        => 7370,
                         partida       => 4658,
                         partin        => 2947,
                         partlow       => 7977,
                         parton        => 4277,
                         partridge     => 2414,
                         pascale       => 9930,
                         paschal       => 4524,
                         paschall      => 4843,
                         pascoe        => 8405,
                         pascual       => 4842,
                         pasillas      => 9172,
                         pasley        => 7888,
                         passmore      => 3782,
                         pastore       => 6593,
                         pastrana      => 8740,
                         pate          => 803,
                         patel         => 519,
                         paterson      => 3034,
                         patillo       => 8621,
                         patino        => 3398,
                         patnode       => 7616,
                         patten        => 1860,
                         patterson     => 83,
                         pattison      => 4550,
                         patton        => 349,
                         paugh         => 8524,
                         pauley        => 2701,
                         paulin        => 7055,
                         paulino       => 5245,
                         paulk         => 4148,
                         paull         => 8949,
                         paulsen       => 2424,
                         paulson       => 1587,
                         paulus        => 6470,
                         pauly         => 9283,
                         pawlak        => 8948,
                         pawlowski     => 8947,
                         paxton        => 2071,
                         payan         => 9065,
                         payne         => 157,
                         paynter       => 6723,
                         payton        => 1051,
                         peabody       => 4767,
                         peachey       => 1844,
                         peacock       => 1349,
                         peake         => 4805,
                         pearce        => 887,
                         pearcy        => 7795,
                         pearlman      => 9785,
                         pearman       => 5511,
                         pearsall      => 4147,
                         pearson       => 233,
                         peart         => 7214,
                         pease         => 2062,
                         peaslee       => 7976,
                         peavy         => 6722,
                         peay          => 8290,
                         peck          => 690,
                         peckham       => 4430,
                         pecoraro      => 8404,
                         peden         => 5122,
                         pedersen      => 1931,
                         pederson      => 2049,
                         pedigo        => 4226,
                         pedraza       => 5200,
                         pedroza       => 4085,
                         peebles       => 2796,
                         peek          => 2674,
                         peel          => 3760,
                         peele         => 4463,
                         peeler        => 3797,
                         peeples       => 3152,
                         peery         => 6240,
                         pegram        => 6929,
                         pegues        => 5692,
                         peiffer       => 8289,
                         peirce        => 8620,
                         pelayo        => 4904,
                         pelfrey       => 8169,
                         pelham        => 8288,
                         pelkey        => 4872,
                         pell          => 6860,
                         pellegrini    => 7975,
                         pellegrino    => 4041,
                         pellerin      => 5743,
                         pelletier     => 1227,
                         peloquin      => 7887,
                         peltier       => 3759,
                         pelton        => 5053,
                         peluso        => 8403,
                         pemberton     => 2301,
                         pena          => 270,
                         pence         => 2423,
                         pender        => 3998,
                         pendergast    => 8402,
                         pendergrass   => 2774,
                         pendleton     => 1538,
                         pendley       => 6592,
                         penick        => 7054,
                         penland       => 6196,
                         penley        => 7143,
                         penn          => 1196,
                         pennell       => 3289,
                         penner        => 6469,
                         pennington    => 640,
                         pennock       => 8739,
                         penrod        => 4124,
                         penson        => 9784,
                         penton        => 6090,
                         peoples       => 1114,
                         pepe          => 6369,
                         pepin         => 4903,
                         peppers       => 4841,
                         perales       => 3151,
                         peralez       => 9929,
                         peralta       => 1714,
                         peraza        => 6928,
                         percival      => 9663,
                         perdomo       => 6655,
                         perdue        => 1475,
                         perea         => 3944,
                         pereira       => 1624,
                         peres         => 5650,
                         pereyra       => 8075,
                         perez         => 40,
                         perkins       => 152,
                         perlman       => 6368,
                         permenter     => 7886,
                         perna         => 9928,
                         pernell       => 7531,
                         perrault      => 8074,
                         perreault     => 3238,
                         perreira      => 7053,
                         perri         => 5841,
                         perrin        => 3385,
                         perrine       => 5840,
                         perron        => 3587,
                         perrone       => 4619,
                         perrotta      => 7530,
                         perry         => 80,
                         perryman      => 2133,
                         persaud       => 4935,
                         persinger     => 6239,
                         pesce         => 8073,
                         peterkin      => 8287,
                         peterman      => 2732,
                         peters        => 184,
                         petersen      => 504,
                         peterson      => 66,
                         petit         => 3253,
                         petree        => 8401,
                         petrella      => 9064,
                         petri         => 9783,
                         petrie        => 3544,
                         petrillo      => 7974,
                         petro         => 6859,
                         petrone       => 9782,
                         petry         => 5887,
                         pettaway      => 6468,
                         pettengill    => 9282,
                         petterson     => 6300,
                         pettey        => 8853,
                         pettiford     => 6195,
                         pettigrew     => 3738,
                         pettis        => 3624,
                         pettit        => 1496,
                         pettitt       => 9927,
                         pettus        => 4256,
                         pettway       => 3966,
                         petty         => 707,
                         peyton        => 3162,
                         pfaff         => 4429,
                         pfeffer       => 6238,
                         pfeifer       => 3586,
                         pfeiffer      => 2321,
                         pfister       => 6367,
                         pham          => 1224,
                         phan          => 2451,
                         phares        => 8738,
                         pharr         => 4871,
                         phelan        => 2450,
                         phelps        => 439,
                         phifer        => 4024,
                         philbrick     => 7615,
                         philbrook     => 9926,
                         phillips      => 43,
                         philpot       => 4523,
                         philpott      => 6721,
                         phinney       => 7529,
                         phipps        => 1081,
                         piatt         => 6530,
                         piazza        => 4107,
                         pichardo      => 4200,
                         pickard       => 2555,
                         pickel        => 7973,
                         pickens       => 1634,
                         pickering     => 2048,
                         pickett       => 731,
                         pieper        => 5121,
                         pierce        => 158,
                         piercy        => 5363,
                         pierson       => 994,
                         pifer         => 7441,
                         pigg          => 4276,
                         pike          => 976,
                         piland        => 9925,
                         pilcher       => 4023,
                         pilgrim       => 5742,
                         pilkington    => 4493,
                         pimental      => 6136,
                         pimentel      => 2078,
                         pina          => 1450,
                         pinard        => 8286,
                         pinckney      => 3737,
                         pinder        => 4840,
                         pineda        => 1080,
                         pinero        => 8400,
                         pinheiro      => 9781,
                         pinkard       => 7528,
                         pinkerton     => 3714,
                         pinkham       => 5606,
                         pinkney       => 4040,
                         pinkston      => 3572,
                         pinney        => 8737,
                         pino          => 3507,
                         pinon         => 7213,
                         pinson        => 2199,
                         pinto         => 2746,
                         piotrowski    => 8285,
                         piper         => 1094,
                         pipkin        => 3226,
                         pippin        => 3384,
                         pires         => 5936,
                         pirtle        => 4396,
                         pisano        => 6783,
                         pitchford     => 6984,
                         pitcock       => 9662,
                         pitman        => 3915,
                         pitre         => 3397,
                         pitt          => 2311,
                         pittman       => 401,
                         pitts         => 447,
                         pitzer        => 6858,
                         pixley        => 8946,
                         pizarro       => 5362,
                         placencia     => 7527,
                         plaisance     => 8852,
                         plank         => 4255,
                         plante        => 3161,
                         plascencia    => 6299,
                         plata         => 9661,
                         platt         => 1262,
                         plemmons      => 8072,
                         pless         => 6409,
                         plotkin       => 8523,
                         plott         => 7794,
                         plourde       => 4549,
                         plowman       => 6194,
                         plumb         => 5282,
                         plumlee       => 7614,
                         plumley       => 5361,
                         plummer       => 990,
                         plunk         => 9924,
                         plunkett      => 2936,
                         plyler        => 8522,
                         poche         => 7972,
                         poff          => 6857,
                         pogue         => 3150,
                         pohl          => 4934,
                         pohlman       => 9171,
                         poindexter    => 2256,
                         pointer       => 3215,
                         poirier       => 1843,
                         poisson       => 5839,
                         polak         => 9170,
                         polanco       => 2367,
                         polen         => 9660,
                         poling        => 3869,
                         polito        => 8071,
                         polk          => 912,
                         pollack       => 2773,
                         pollak        => 8619,
                         pollard       => 752,
                         polley        => 5328,
                         pollock       => 1214,
                         polson        => 5556,
                         polston       => 7301,
                         pomerleau     => 7613,
                         pomeroy       => 3781,
                         ponce         => 975,
                         pond          => 2814,
                         ponder        => 1921,
                         poole         => 406,
                         pooler        => 5466,
                         poore         => 2806,
                         pope          => 367,
                         popham        => 8284,
                         popovich      => 7706,
                         popp          => 3851,
                         porath        => 9923,
                         porras        => 4365,
                         porter        => 123,
                         porterfield   => 2700,
                         portillo      => 1920,
                         portis        => 4338,
                         posada        => 6782,
                         posey         => 1288,
                         posner        => 8283,
                         poss          => 8070,
                         poston        => 2835,
                         poteat        => 5980,
                         poteet        => 6193,
                         potter        => 343,
                         potts         => 721,
                         poulin        => 2162,
                         pouliot       => 7971,
                         poulos        => 6135,
                         poulsen       => 8736,
                         poulson       => 7885,
                         powe          => 4254,
                         powell        => 81,
                         powers        => 285,
                         poynter       => 6034,
                         prado         => 1972,
                         prater        => 1275,
                         prather       => 1598,
                         pratt         => 393,
                         preciado      => 5605,
                         preece        => 4395,
                         prejean       => 9780,
                         premo         => 9397,
                         prendergast   => 5741,
                         prentice      => 3320,
                         prentiss      => 7612,
                         prescott      => 1642,
                         presley       => 1530,
                         presnell      => 6529,
                         pressley      => 1950,
                         prevost       => 5555,
                         prewitt       => 2320,
                         price         => 72,
                         prichard      => 2982,
                         prickett      => 6856,
                         priddy        => 5244,
                         pridemore     => 6237,
                         pridgen       => 2895,
                         priebe        => 9779,
                         priest        => 1827,
                         priester      => 7052,
                         priestley     => 8851,
                         prieto        => 2615,
                         primm         => 7212,
                         prindle       => 8069,
                         prine         => 6720,
                         pringle       => 1893,
                         prins         => 9778,
                         prisco        => 8735,
                         pritchard     => 1092,
                         pritchett     => 1353,
                         privett       => 7970,
                         probst        => 4766,
                         prochaska     => 9281,
                         procter       => 9280,
                         proctor       => 891,
                         proffitt      => 2537,
                         prokop        => 9777,
                         propst        => 4364,
                         prosser       => 3454,
                         proulx        => 4981,
                         prouty        => 6654,
                         provencher    => 5327,
                         provenzano    => 8850,
                         provost       => 3319,
                         pruett        => 1877,
                         pruitt        => 544,
                         prunty        => 9922,
                         pryce         => 9776,
                         pryor         => 931,
                         puckett       => 854,
                         puente        => 2763,
                         puentes       => 8521,
                         puga          => 5160,
                         pugh          => 615,
                         pugliese      => 5979,
                         puleo         => 6983,
                         pulido        => 2795,
                         pullen        => 2198,
                         pulley        => 3506,
                         pulliam       => 1867,
                         pullum        => 9063,
                         pulver        => 6089,
                         puma          => 7793,
                         pumphrey      => 5159,
                         purcell       => 1303,
                         purdy         => 2129,
                         purifoy       => 7884,
                         purkey        => 7051,
                         purnell       => 2445,
                         purser        => 5281,
                         pursley       => 6653,
                         purvis        => 1449,
                         puryear       => 4548,
                         putman        => 2592,
                         putnam        => 1319,
                         pyatt         => 8068,
                         pyle          => 1919,
                         pyles         => 4462,
                         quach         => 7142,
                         quackenbush   => 7792,
                         quade         => 6652,
                         qualls        => 2128,
                         quarles       => 2047,
                         quattlebaum   => 7883,
                         quesada       => 4839,
                         quesenberry   => 8520,
                         quevedo       => 7969,
                         quezada       => 2070,
                         quigley       => 2214,
                         quijano       => 7526,
                         quiles        => 5510,
                         quillen       => 3914,
                         quimby        => 4337,
                         quinlan       => 3713,
                         quinn         => 366,
                         quinones      => 1031,
                         quinonez      => 3571,
                         quint         => 8618,
                         quintana      => 1140,
                         quintanilla   => 2142,
                         quintero      => 1134,
                         quirk         => 5280,
                         quiroga       => 9536,
                         quiroz        => 1918,
                         raab          => 6591,
                         rabb          => 7300,
                         rabe          => 6590,
                         raber         => 8282,
                         rabideau      => 7211,
                         rabinowitz    => 7141,
                         rabon         => 8067,
                         raby          => 4578,
                         racine        => 4522,
                         rackley       => 5052,
                         radcliff      => 5790,
                         radcliffe     => 4933,
                         rademacher    => 5509,
                         rader         => 1818,
                         radford       => 1957,
                         radke         => 8399,
                         radtke        => 5051,
                         rael          => 4870,
                         rafferty      => 3396,
                         ragan         => 2894,
                         rager         => 6088,
                         ragin         => 8519,
                         ragland       => 1520,
                         raglin        => 9659,
                         ragsdale      => 1753,
                         ragusa        => 9535,
                         rahman        => 6528,
                         rahn          => 5015,
                         railey        => 6651,
                         rainbolt      => 8168,
                         rainer        => 7369,
                         raines        => 1172,
                         rainey        => 1067,
                         rains         => 2438,
                         rainwater     => 4394,
                         rakes         => 6467,
                         raley         => 3684,
                         ralls         => 9534,
                         ralston       => 2197,
                         ramage        => 4743,
                         ramer         => 5433,
                         rameriz       => 6466,
                         ramey         => 1212,
                         ramires       => 8281,
                         ramirez       => 68,
                         ramos         => 132,
                         ramsay        => 3662,
                         ramsdell      => 7882,
                         ramsey        => 297,
                         rancourt      => 6650,
                         rand          => 3252,
                         randazzo      => 5508,
                         randel        => 8518,
                         randle        => 1463,
                         randles       => 9062,
                         raney         => 2997,
                         rangel        => 895,
                         rankin        => 866,
                         rankins       => 4657,
                         ransdell      => 8398,
                         ransom        => 1597,
                         ranson        => 6298,
                         raper         => 4980,
                         raposa        => 8167,
                         rapp          => 2279,
                         rasberry      => 6649,
                         rascon        => 5243,
                         rash          => 2711,
                         rashid        => 7299,
                         rasmussen     => 834,
                         ratchford     => 7705,
                         ratcliff      => 2191,
                         ratcliffe     => 6297,
                         rathbone      => 5395,
                         rathbun       => 5838,
                         rathburn      => 8734,
                         ratliff       => 810,
                         rauch         => 3383,
                         rausch        => 4065,
                         rawlings      => 2614,
                         rawlins       => 3525,
                         rawls         => 2613,
                         rawson        => 4521,
                         raya          => 7050,
                         rayborn       => 6589,
                         rayburn       => 2970,
                         rayfield      => 8066,
                         raymer        => 5789,
                         rayner        => 5465,
                         raynor        => 3736,
                         razo          => 3712,
                         reagan        => 1670,
                         reale         => 9658,
                         ream          => 7049,
                         reamer        => 9921,
                         reames        => 8849,
                         reams         => 5050,
                         reardon       => 1985,
                         rearick       => 9279,
                         reaves        => 1626,
                         reavis        => 4363,
                         reber         => 5394,
                         recio         => 8945,
                         rector        => 1748,
                         redd          => 1791,
                         redden        => 3271,
                         reddick       => 2762,
                         redding       => 1720,
                         reddy         => 3186,
                         redfield      => 9396,
                         redford       => 8166,
                         reding        => 9169,
                         redmon        => 3472,
                         redmond       => 1318,
                         reece         => 1079,
                         reed          => 53,
                         reeder        => 1409,
                         reedy         => 2471,
                         reel          => 4275,
                         rees          => 2481,
                         reese         => 339,
                         reeser        => 9775,
                         reeve         => 4064,
                         reeves        => 312,
                         regalado      => 3306,
                         regan         => 1730,
                         regis         => 8848,
                         rego          => 5604,
                         rehm          => 8517,
                         reich         => 2682,
                         reichard      => 6855,
                         reichel       => 8065,
                         reichert      => 3046,
                         reid          => 214,
                         reider        => 9395,
                         reidy         => 9394,
                         reiff         => 7140,
                         reilly        => 779,
                         reimer        => 4461,
                         reimers       => 7704,
                         reiner        => 7139,
                         reinert       => 7525,
                         reinhard      => 8733,
                         reinhardt     => 2536,
                         reinhart      => 3796,
                         reinhold      => 7524,
                         reinke        => 6033,
                         reis          => 2783,
                         reiser        => 8280,
                         reisinger     => 9061,
                         reiss         => 4199,
                         reiter        => 2488,
                         reitz         => 4106,
                         rembert       => 4460,
                         remillard     => 4979,
                         remington     => 4428,
                         remy          => 6719,
                         renaud        => 5507,
                         render        => 8397,
                         rendon        => 2376,
                         reneau        => 8064,
                         renfro        => 2628,
                         renfroe       => 5326,
                         renfrow       => 5649,
                         renn          => 8165,
                         renner        => 2292,
                         rennie        => 7791,
                         renninger     => 9168,
                         reno          => 3288,
                         renshaw       => 6527,
                         rentas        => 8944,
                         renteria      => 1876,
                         renwick       => 9393,
                         renz          => 8164,
                         repp          => 7440,
                         resendez      => 4699,
                         resnick       => 7368,
                         ressler       => 8163,
                         resto         => 8732,
                         restrepo      => 9533,
                         rettig        => 9392,
                         reuter        => 3943,
                         revell        => 6408,
                         revels        => 6854,
                         revis         => 6718,
                         reyes         => 133,
                         reynolds      => 106,
                         reynoso       => 2404,
                         rheaume       => 9060,
                         rhee          => 7968,
                         rhinehart     => 4577,
                         rhoades       => 1578,
                         rhoads        => 2272,
                         rhoden        => 3997,
                         rhodes        => 269,
                         rhone         => 5691,
                         rhymes        => 8617,
                         rhyne         => 4084,
                         ribeiro       => 7210,
                         ricci         => 2935,
                         ricciardi     => 6927,
                         riccio        => 7790,
                         rice          => 138,
                         rich          => 537,
                         richards      => 197,
                         richardson    => 61,
                         richburg      => 5360,
                         richerson     => 6588,
                         richert       => 8516,
                         richey        => 1292,
                         richins       => 9920,
                         richman       => 4618,
                         richmond      => 666,
                         richter       => 1126,
                         rickard       => 2946,
                         ricker        => 2512,
                         rickert       => 6587,
                         rickett       => 9657,
                         ricketts      => 2232,
                         rickman       => 3225,
                         ricks         => 1183,
                         riddell       => 4022,
                         riddick       => 2092,
                         riddle        => 757,
                         ridenhour     => 6586,
                         ridenour      => 3149,
                         rideout       => 6296,
                         rider         => 2017,
                         ridgeway      => 2487,
                         ridgway       => 5978,
                         ridings       => 8396,
                         ridley        => 1965,
                         riedel        => 4459,
                         riegel        => 8847,
                         rieger        => 6585,
                         riehl         => 8395,
                         riendeau      => 6407,
                         ries          => 5432,
                         rife          => 3711,
                         riffe         => 6648,
                         riffle        => 5648,
                         rigby         => 3780,
                         rigdon        => 7611,
                         riggins       => 2511,
                         riggle        => 6853,
                         riggleman     => 9919,
                         riggs         => 767,
                         rigney        => 5554,
                         rigsby        => 2903,
                         riker         => 7881,
                         riles         => 8063,
                         riley         => 176,
                         rimmer        => 5788,
                         rinaldi       => 3735,
                         rincon        => 4105,
                         rinehart      => 2112,
                         ringer        => 5553,
                         ringler       => 7880,
                         rinker        => 7703,
                         riojas        => 5158,
                         riordan       => 4336,
                         rios          => 357,
                         rioux         => 6982,
                         ripley        => 3203,
                         rippy         => 7138,
                         riser         => 9656,
                         risher        => 9774,
                         risinger      => 6526,
                         risley        => 6465,
                         risner        => 6236,
                         ritchey       => 3251,
                         ritchie       => 1111,
                         rittenhouse   => 4617,
                         ritter        => 969,
                         ritz          => 4902,
                         rivard        => 4083,
                         rivas         => 647,
                         rivera        => 59,
                         rivero        => 4170,
                         rivers        => 613,
                         rives         => 6852,
                         rizo          => 7789,
                         rizzi         => 9532,
                         rizzo         => 2356,
                         roach         => 664,
                         roan          => 8279,
                         roane         => 7702,
                         roark         => 1602,
                         robb          => 2227,
                         robbins       => 334,
                         roberge       => 3335,
                         roberson      => 422,
                         roberts       => 41,
                         robertson     => 139,
                         robeson       => 8278,
                         robey         => 3996,
                         robichaud     => 5359,
                         robichaux     => 5552,
                         robidoux      => 8943,
                         robinett      => 6366,
                         robinette     => 2035,
                         robins        => 2244,
                         robinson      => 19,
                         robison       => 1120,
                         robitaille    => 8846,
                         robledo       => 4104,
                         robles        => 533,
                         robson        => 3605,
                         roby          => 2437,
                         rocha         => 853,
                         roche         => 1719,
                         rochon        => 9655,
                         rockett       => 6981,
                         rockwell      => 2069,
                         rockwood      => 8277,
                         rodarte       => 5199,
                         rodas         => 6087,
                         roddy         => 4123,
                         roden         => 3373,
                         rodgers       => 333,
                         rodiguez      => 9918,
                         rodrigez      => 6647,
                         rodrigue      => 3185,
                         rodrigues     => 1169,
                         rodriguez     => 21,
                         rodriques     => 6525,
                         rodriquez     => 261,
                         roebuck       => 4253,
                         roeder        => 6646,
                         roehl         => 9167,
                         roemer        => 7048,
                         roesch        => 8515,
                         roesler       => 8394,
                         rogan         => 7047,
                         rogers        => 52,
                         rogerson      => 9773,
                         rogge         => 9391,
                         rohan         => 9772,
                         rohde         => 4146,
                         rohr          => 3570,
                         rohrbach      => 9771,
                         rohrbaugh     => 9770,
                         rohrer        => 6235,
                         rojas         => 565,
                         rojo          => 4576,
                         roldan        => 3623,
                         rolen         => 8942,
                         rolfe         => 4312,
                         rolle         => 8162,
                         rollins       => 693,
                         rollo         => 7298,
                         rolon         => 5242,
                         romano        => 1322,
                         romer         => 9059,
                         romero        => 218,
                         romig         => 9166,
                         romine        => 4427,
                         romo          => 1613,
                         ronan         => 9917,
                         rondeau       => 5241,
                         rondon        => 9278,
                         rone          => 7967,
                         roney         => 3110,
                         rood          => 4575,
                         rook          => 7966,
                         rooker        => 5837,
                         rooks         => 4362,
                         rooney        => 1805,
                         roop          => 5787,
                         roos          => 7046,
                         root          => 1537,
                         roper         => 1348,
                         roque         => 4021,
                         rorie         => 8514,
                         rosado        => 899,
                         rosales       => 790,
                         rosas         => 1280,
                         rosati        => 8616,
                         roseberry     => 5120,
                         roseboro      => 8161,
                         roselli       => 8845,
                         roseman       => 6926,
                         rosemond      => 7439,
                         rosen         => 1370,
                         rosenbaum     => 3569,
                         rosenberg     => 1248,
                         rosenberger   => 4765,
                         rosenberry    => 8276,
                         rosenblatt    => 7297,
                         rosenblum     => 5647,
                         rosenfeld     => 4804,
                         rosenthal     => 1804,
                         rosner        => 8731,
                         ross          => 76,
                         rosser        => 3305,
                         rossi         => 1337,
                         rossiter      => 7438,
                         rossman       => 5886,
                         rosson        => 8941,
                         rost          => 7209,
                         roth          => 573,
                         rothe         => 9531,
                         rother        => 9769,
                         rothman       => 4803,
                         rothrock      => 8393,
                         rothstein     => 6192,
                         rothwell      => 7965,
                         rotz          => 7367,
                         rouleau       => 7045,
                         rounds        => 2673,
                         roundtree     => 3927,
                         roundy        => 5551,
                         rountree      => 3270,
                         rourke        => 6980,
                         rouse         => 862,
                         roush         => 2345,
                         rousseau      => 3148,
                         roussel       => 3850,
                         routh         => 6925,
                         roux          => 7879,
                         rowan         => 1697,
                         rowden        => 5646,
                         rowe          => 346,
                         rowell        => 1555,
                         rowland       => 729,
                         rowles        => 7044,
                         rowlett       => 6365,
                         rowley        => 1899,
                         roybal        => 3926,
                         royer         => 3147,
                         royster       => 3021,
                         royston       => 6979,
                         rozell        => 9058,
                         rozier        => 5119,
                         ruano         => 7137,
                         ruark         => 9768,
                         rubalcava     => 8062,
                         rubenstein    => 7610,
                         rubino        => 5118,
                         rubinstein    => 9057,
                         rubio         => 996,
                         ruble         => 4616,
                         ruch          => 5885,
                         rucker        => 993,
                         ruckman       => 8513,
                         rudd          => 1586,
                         rudder        => 9767,
                         ruddy         => 9165,
                         ruder         => 9277,
                         rudnick       => 7788,
                         rueda         => 6406,
                         ruelas        => 4656,
                         ruff          => 1704,
                         ruffin        => 1195,
                         ruffner       => 6924,
                         rugg          => 8392,
                         ruggiero      => 4520,
                         ruggles       => 5690,
                         ruhl          => 6364,
                         ruiz          => 173,
                         rummel        => 7043,
                         rumph         => 5506,
                         rumsey        => 5325,
                         rundell       => 7208,
                         runge         => 4802,
                         runion        => 5645,
                         runkle        => 8512,
                         runnels       => 5324,
                         runyan        => 3683,
                         runyon        => 2190,
                         rupe          => 7136,
                         rupp          => 3045,
                         ruppert       => 5505,
                         rusch         => 8511,
                         rush          => 617,
                         rushing       => 1247,
                         rushton       => 7135,
                         rusk          => 5198,
                         russo         => 655,
                         rust          => 2612,
                         rutan         => 7878,
                         rutherford    => 937,
                         rutkowski     => 7609,
                         rutland       => 4869,
                         rutledge      => 795,
                         rutter        => 4169,
                         ruvalcaba     => 5431,
                         ryals         => 4492,
                         ryder         => 1691,
                         ryerson       => 9766,
                         rymer         => 8844,
                         saad          => 6295,
                         saari         => 6464,
                         saavedra      => 2486,
                         sabatini      => 9916,
                         sabin         => 4615,
                         sabo          => 3868,
                         sabol         => 7296,
                         sacco         => 3995,
                         sachs         => 4838,
                         sackett       => 6294,
                         saddler       => 4225,
                         sadler        => 1324,
                         sadowski      => 5240,
                         saechao       => 8160,
                         saenz         => 1340,
                         saez          => 6086,
                         safford       => 5740,
                         sage          => 2731,
                         sager         => 2659,
                         sagers        => 9654,
                         sain          => 6191,
                         saito         => 7042,
                         saiz          => 4868,
                         sala          => 7207,
                         salas         => 692,
                         salazar       => 311,
                         salcedo       => 2881,
                         salcido       => 3237,
                         saldana       => 1657,
                         saldivar      => 3965,
                         saleh         => 7366,
                         salerno       => 3758,
                         salgado       => 1226,
                         salguero      => 9765,
                         salinas       => 542,
                         salisbury     => 2141,
                         sallee        => 3453,
                         salley        => 3372,
                         salmeron      => 9530,
                         salmons       => 6293,
                         salo          => 8159,
                         salter        => 1536,
                         salters       => 8158,
                         saltsman      => 9390,
                         saltzman      => 8275,
                         salyer        => 4063,
                         salyers       => 6363,
                         salzman       => 8061,
                         samaniego     => 4574,
                         sammons       => 3020,
                         samons        => 5430,
                         samora        => 7701,
                         sample        => 1851,
                         samples       => 3109,
                         sampson       => 710,
                         sams          => 1669,
                         samuels       => 1034,
                         samuelson     => 4801,
                         sanabria      => 4764,
                         sanborn       => 2265,
                         sanches       => 3994,
                         sanchez       => 50,
                         sandberg      => 3964,
                         sander        => 2745,
                         sanderlin     => 8510,
                         sanders       => 71,
                         sanderson     => 1147,
                         sandidge      => 8157,
                         sandifer      => 5117,
                         sandler       => 5786,
                         sandlin       => 3137,
                         sandoval      => 372,
                         sands         => 1601,
                         sandstrom     => 6234,
                         sandusky      => 7523,
                         sanfilippo    => 9276,
                         sanger        => 9529,
                         sankey        => 6233,
                         sanmiguel     => 6978,
                         sanner        => 9056,
                         sansom        => 6977,
                         sansone       => 6232,
                         santacruz     => 6032,
                         santamaria    => 5550,
                         santana       => 696,
                         santangelo    => 9389,
                         santiago      => 280,
                         santillan     => 5603,
                         santini       => 8940,
                         santistevan   => 8730,
                         santoro       => 4122,
                         santos        => 316,
                         santoyo       => 6405,
                         santucci      => 9388,
                         sapp          => 1420,
                         sappington    => 7522,
                         sarabia       => 7608,
                         saravia       => 9055,
                         sargeant      => 7437,
                         sargent       => 831,
                         sarmiento     => 5504,
                         sartain       => 7295,
                         sartin        => 5239,
                         sarver        => 5238,
                         sasaki        => 7521,
                         sass          => 6584,
                         sasser        => 3108,
                         satchell      => 8843,
                         sather        => 7964,
                         sato          => 4335,
                         satterfield   => 2105,
                         satterlee     => 8842,
                         satterwhite   => 4655,
                         sattler       => 6190,
                         sauceda       => 4311,
                         saucedo       => 1718,
                         saucier       => 2934,
                         sauer         => 2243,
                         sauls         => 3202,
                         saunders      => 378,
                         sauter        => 8509,
                         savage        => 510,
                         saville       => 6781,
                         savino        => 7963,
                         savoie        => 5429,
                         savoy         => 3352,
                         sawicki       => 7436,
                         sawyer        => 457,
                         sawyers       => 3351,
                         saxon         => 3710,
                         saxton        => 2761,
                         sayer         => 8060,
                         sayers        => 3867,
                         sayler        => 9915,
                         sayles        => 4867,
                         saylor        => 2001,
                         sayre         => 3757,
                         scaggs        => 8939,
                         scaife        => 8391,
                         scala         => 8156,
                         scales        => 1885,
                         scalf         => 6362,
                         scalise       => 6780,
                         scanlan       => 5549,
                         scanlon       => 2744,
                         scannell      => 8729,
                         scarberry     => 6189,
                         scarborough   => 2147,
                         scarbrough    => 2957,
                         scates        => 8841,
                         schaaf        => 6923,
                         schaal        => 7365,
                         schade        => 6524,
                         schaefer      => 898,
                         schaeffer     => 2056,
                         schafer       => 1358,
                         schaff        => 9653,
                         schaffer      => 1636,
                         schaffner     => 6645,
                         schall        => 8390,
                         schaller      => 6292,
                         schank        => 9652,
                         schantz       => 9164,
                         scharf        => 6523,
                         schatz        => 5116,
                         schaub        => 6644,
                         schauer       => 7700,
                         schechter     => 9914,
                         scheel        => 7134,
                         scheer        => 4978,
                         scheetz       => 9054,
                         scheffler     => 5602,
                         scheid        => 9053,
                         schell        => 2055,
                         scheller      => 7206,
                         schenck       => 4654,
                         schenk        => 4224,
                         scherer       => 3044,
                         schermerhorn  => 8155,
                         schexnayder   => 6085,
                         schick        => 5739,
                         schiff        => 6463,
                         schiffer      => 9651,
                         schiffman     => 7787,
                         schiller      => 3779,
                         schilling     => 2174,
                         schimmel      => 9913,
                         schindler     => 3778,
                         schlegel      => 4901,
                         schleicher    => 7364,
                         schloss       => 9912,
                         schlosser     => 4458,
                         schlueter     => 6134,
                         schmid        => 2554,
                         schmidt       => 190,
                         schmit        => 7294,
                         schmitt       => 1086,
                         schmitz       => 1419,
                         schneck       => 9163,
                         schneider     => 299,
                         schnell       => 5358,
                         schock        => 6643,
                         schoen        => 4698,
                         schoenfeld    => 7607,
                         schofield     => 2189,
                         scholl        => 3709,
                         scholz        => 5884,
                         schooley      => 8840,
                         schoonmaker   => 6642,
                         schoonover    => 4020,
                         schorr        => 8839,
                         schott        => 3236,
                         schrader      => 2182,
                         schram        => 6583,
                         schramm       => 4168,
                         schreck       => 7699,
                         schreiber     => 1949,
                         schreiner     => 3888,
                         schrimsher    => 8059,
                         schrock       => 4763,
                         schroder      => 4334,
                         schroeder     => 512,
                         schrum        => 9162,
                         schubert      => 2880,
                         schuck        => 7293,
                         schuetz       => 8938,
                         schuh         => 7698,
                         schuler       => 2121,
                         schuller      => 6922,
                         schulman      => 5601,
                         schulte       => 2385,
                         schultz       => 286,
                         schulz        => 1618,
                         schulze       => 3622,
                         schumacher    => 1790,
                         schumaker     => 8838,
                         schuman       => 5085,
                         schumann      => 4977,
                         schuster      => 1956,
                         schutt        => 6522,
                         schutte       => 9275,
                         schutz        => 4976,
                         schuyler      => 8058,
                         schwab        => 2120,
                         schwartz      => 388,
                         schwarz       => 2157,
                         schweiger     => 9911,
                         schweitzer    => 3107,
                         scofield      => 5279,
                         scoggins      => 3438,
                         scoville      => 7041,
                         scranton      => 9387,
                         scribner      => 3913,
                         scrivner      => 8274,
                         scroggins     => 2188,
                         scruggs       => 1289,
                         scull         => 7962,
                         scurlock      => 9386,
                         scurry        => 7697,
                         seabolt       => 6361,
                         seabrook      => 8273,
                         seager        => 9385,
                         seagraves     => 7786,
                         seal          => 2286,
                         seale         => 4039,
                         sealey        => 7435,
                         seals         => 1202,
                         sealy         => 5548,
                         seaman        => 2068,
                         seamon        => 9161,
                         searcy        => 2658,
                         searle        => 4653,
                         searles       => 4975,
                         sears         => 732,
                         seaton        => 2919,
                         seaver        => 6976,
                         seavey        => 7133,
                         seawright     => 7877,
                         seay          => 1507,
                         sechrist      => 8389,
                         secor         => 9274,
                         seda          => 7205,
                         sedillo       => 6031,
                         seeger        => 6188,
                         seeley        => 3088,
                         seely         => 4145,
                         segal         => 4062,
                         segarra       => 7876,
                         segars        => 9528,
                         seger         => 4837,
                         segovia       => 4393,
                         segura        => 1390,
                         seibel        => 7040,
                         seiber        => 6521,
                         seibert       => 3318,
                         seidel        => 3621,
                         seidl         => 9273,
                         seidman       => 9910,
                         seifert       => 2879,
                         seiler        => 3682,
                         seitz         => 2384,
                         selby         => 2164,
                         sellars       => 4061,
                         sellers       => 601,
                         sells         => 3121,
                         selman        => 6975,
                         selph         => 9384,
                         seltzer       => 6641,
                         semple        => 8057,
                         senger        => 9909,
                         senn          => 4742,
                         senter        => 7434,
                         sepulveda     => 2535,
                         sequeira      => 8615,
                         serafin       => 9764,
                         sergent       => 7606,
                         serio         => 9763,
                         serna         => 1979,
                         serpa         => 9908,
                         serra         => 5600,
                         serrano       => 566,
                         serrato       => 5393,
                         servin        => 9762,
                         sessoms       => 4573,
                         setser        => 7696,
                         settles       => 4019,
                         setzer        => 5157,
                         severance     => 6640,
                         severson      => 3287,
                         sevier        => 8272,
                         sevigny       => 6921,
                         sevilla       => 5197,
                         seward        => 2271,
                         sewell        => 1063,
                         sexton        => 593,
                         seymore       => 3568,
                         shackelford   => 2480,
                         shackleford   => 6974,
                         shade         => 2657,
                         shaeffer      => 9052,
                         shafer        => 1015,
                         shaffer       => 484,
                         shah          => 1837,
                         shahan        => 8937,
                         shamblin      => 8056,
                         shanahan      => 4082,
                         shaner        => 4333,
                         shank         => 2693,
                         shankle       => 6291,
                         shanklin      => 5547,
                         shanks        => 2181,
                         shapiro       => 1398,
                         sharkey       => 3567,
                         sharma        => 5546,
                         sharp         => 302,
                         sharpe        => 805,
                         shatley       => 8728,
                         shattuck      => 5503,
                         shaughnessy   => 6717,
                         shaul         => 9761,
                         shaver        => 1462,
                         shavers       => 7292,
                         shaw          => 136,
                         shawver       => 8837,
                         shea          => 861,
                         shealy        => 5237,
                         shearer       => 1656,
                         shearin       => 8508,
                         shears        => 5644,
                         shedd         => 6360,
                         sheehan       => 1097,
                         sheehy        => 8154,
                         sheets        => 1408,
                         sheffer       => 8614,
                         sheffield     => 1187,
                         shehan        => 9383,
                         sheilds       => 9650,
                         shell         => 2007,
                         shelton       => 253,
                         shenk         => 8271,
                         shepard       => 677,
                         shepardson    => 8727,
                         sheperd       => 9272,
                         shephard      => 3620,
                         shepherd      => 500,
                         sheppard      => 621,
                         sherer        => 5464,
                         sherrard      => 9051,
                         sherrer       => 7132,
                         sherrod       => 2237,
                         sherwin       => 6716,
                         shetler       => 7961,
                         shewmaker     => 9649,
                         shick         => 7363,
                         shields       => 508,
                         shifflett     => 3639,
                         shiflett      => 8507,
                         shilling      => 5738,
                         shim          => 8388,
                         shimizu       => 9050,
                         shin          => 2893,
                         shinault      => 9527,
                         shinn         => 2546,
                         shipe         => 6187,
                         shipley       => 1485,
                         shipman       => 1610,
                         shipp         => 1826,
                         shippy        => 8506,
                         shirey        => 4457,
                         shirk         => 5785,
                         shively       => 3417,
                         shiver        => 5836,
                         shivers       => 3993,
                         shoaf         => 8936,
                         shockey       => 5115,
                         shockley      => 1817,
                         shoemake      => 4519,
                         shoemaker     => 936,
                         shoffner      => 5883,
                         shook         => 1313,
                         shoop         => 5737,
                         shope         => 6779,
                         shores        => 3585,
                         shorey        => 9648,
                         shorter       => 2479,
                         shortridge    => 8270,
                         shortt        => 9049,
                         shotwell      => 6639,
                         shoup         => 4572,
                         shouse        => 4741,
                         showalter     => 5643,
                         showers       => 4900,
                         shrader       => 3334,
                         shreve        => 5114,
                         shriver       => 4491,
                         shropshire    => 5196,
                         shrout        => 9160,
                         shroyer       => 8269,
                         shrum         => 5195,
                         shryock       => 8726,
                         shubert       => 6030,
                         shuck         => 6582,
                         shuey         => 9760,
                         shuler        => 2091,
                         shull         => 2710,
                         shults        => 6084,
                         shultz        => 1505,
                         shumaker      => 3437,
                         shuman        => 3214,
                         shumate       => 3201,
                         shumpert      => 7520,
                         shumway       => 5323,
                         shunk         => 9647,
                         shupe         => 4614,
                         shuster       => 5322,
                         shute         => 8935,
                         shutt         => 5689,
                         shuttleworth  => 9907,
                         sibert        => 7291,
                         sibley        => 2878,
                         siciliano     => 9382,
                         sickler       => 6973,
                         sickles       => 9526,
                         sieber        => 9525,
                         siebert       => 5278,
                         siegel        => 1431,
                         siegfried     => 7960,
                         sievers       => 5321,
                         sifuentes     => 6581,
                         sigala        => 9159,
                         sigler        => 2772,
                         sigman        => 7290,
                         sigmon        => 4223,
                         sikes         => 2206,
                         sikora        => 5599,
                         sikorski      => 8836,
                         siler         => 2611,
                         sill          => 7605,
                         sills         => 3925,
                         silva         => 232,
                         silvas        => 6083,
                         silveira      => 4740,
                         silverberg    => 9048,
                         silverman     => 2104,
                         silvers       => 3661,
                         silverstein   => 5320,
                         silvestri     => 8835,
                         silvey        => 4899,
                         simard        => 7204,
                         simas         => 7362,
                         simkins       => 9759,
                         simmers       => 8505,
                         simmon        => 6290,
                         simmonds      => 9906,
                         simmons       => 88,
                         simms         => 942,
                         simonds       => 4613,
                         simoneau      => 7131,
                         simoneaux     => 7130,
                         simons        => 1144,
                         simonsen      => 8613,
                         simonson      => 3436,
                         simonton      => 7129,
                         simpkins      => 2140,
                         simpson       => 120,
                         sims          => 183,
                         sinclair      => 949,
                         sine          => 8504,
                         sines         => 6778,
                         singh         => 1100,
                         singletary    => 1875,
                         singleton     => 431,
                         singley       => 6580,
                         sinnott       => 9381,
                         sipe          => 4361,
                         sipes         => 3524,
                         sipple        => 6082,
                         sirois        => 5357,
                         sisco         => 3566,
                         sisk          => 2090,
                         sisler        => 9380,
                         sisneros      => 5428,
                         sisson        => 2412,
                         sistrunk      => 6920,
                         sitton        => 7604,
                         sizemore      => 1199,
                         sizer         => 9047,
                         skaggs        => 1609,
                         skeen         => 4103,
                         skeens        => 7289,
                         skelly        => 7433,
                         skelton       => 1917,
                         skiba         => 9271,
                         skidmore      => 2220,
                         skiles        => 4739,
                         skinner       => 470,
                         slack         => 2643,
                         slade         => 1978,
                         slagle        => 3250,
                         slate         => 5236,
                         slater        => 799,
                         slaton        => 3815,
                         slattery      => 3734,
                         slaugh        => 8612,
                         slaughter     => 871,
                         slavin        => 5784,
                         slawson       => 9905,
                         slay          => 6029,
                         slayton       => 3963,
                         sledge        => 2264,
                         sloan         => 582,
                         sloat         => 6851,
                         slocum        => 2743,
                         slone         => 2319,
                         slover        => 8055,
                         sluder        => 8725,
                         slusher       => 6081,
                         smalley       => 2383,
                         smalls        => 1696,
                         smallwood     => 1397,
                         smedley       => 7039,
                         smelser       => 8387,
                         smeltzer      => 9904,
                         smith         => 1,
                         smither       => 8934,
                         smitherman    => 4800,
                         smithers      => 4697,
                         smithey       => 9524,
                         smithson      => 3249,
                         smock         => 5463,
                         smoot         => 2642,
                         smothers      => 3286,
                         smtih         => 7128,
                         smyth         => 3471,
                         snapp         => 5835,
                         snavely       => 8268,
                         snead         => 2813,
                         sneed         => 1269,
                         snell         => 1040,
                         snelling      => 7127,
                         snelson       => 8834,
                         snider        => 789,
                         snipes        => 3224,
                         snoddy        => 8933,
                         snodgrass     => 1955,
                         snook         => 4038,
                         snow          => 498,
                         snowden       => 1939,
                         snyder        => 168,
                         soares        => 2918,
                         sobel         => 8503,
                         sobers        => 8932,
                         socha         => 9046,
                         soderberg     => 9646,
                         sohn          => 7785,
                         soileau       => 4144,
                         sokol         => 4974,
                         solano        => 2771,
                         solares       => 8833,
                         solari        => 9645,
                         solberg       => 6133,
                         soler         => 5688,
                         soles         => 8931,
                         solis         => 636,
                         soliz         => 2805,
                         sollars       => 7038,
                         soloman       => 7288,
                         solorio       => 4252,
                         solorzano     => 6080,
                         somers        => 2829,
                         somerville    => 3828,
                         sommers       => 2444,
                         sommerville   => 7287,
                         songer        => 8267,
                         sonnenberg    => 9523,
                         sonnier       => 4222,
                         soper         => 4221,
                         sorensen      => 1103,
                         sorenson      => 1717,
                         soria         => 3435,
                         soriano       => 2580,
                         sorrell       => 3120,
                         sorrells      => 4310,
                         sorrentino    => 8832,
                         sosa          => 828,
                         sosebee       => 9158,
                         sotelo        => 2516,
                         soto          => 243,
                         sotomayor     => 8724,
                         soucy         => 5084,
                         souder        => 8930,
                         souders       => 8929,
                         soukup        => 7432,
                         soule         => 4037,
                         sours         => 8928,
                         sousa         => 1803,
                         southall      => 9045,
                         southard      => 3483,
                         southerland   => 3119,
                         southwick     => 7431,
                         southworth    => 5427,
                         souza         => 1422,
                         sowards       => 8927,
                         sowder        => 6520,
                         sowell        => 2375,
                         sowers        => 2510,
                         spaeth        => 8723,
                         spahn         => 9157,
                         spalding      => 3395,
                         spangler      => 1437,
                         spann         => 1930,
                         spano         => 8386,
                         sparkman      => 3106,
                         sparks        => 415,
                         sparrow       => 3105,
                         spates        => 7430,
                         spaulding     => 1307,
                         speakman      => 8926,
                         spear         => 2126,
                         spearman      => 2981,
                         spears        => 628,
                         specht        => 7286,
                         speck         => 5545,
                         spector       => 7037,
                         speegle       => 9903,
                         speer         => 1916,
                         speicher      => 9902,
                         speight       => 3849,
                         speights      => 9644,
                         speller       => 8722,
                         spellman      => 3248,
                         spence        => 702,
                         spencer       => 154,
                         sperling      => 5502,
                         sperry        => 3681,
                         spicer        => 1461,
                         spiegel       => 5882,
                         spielman      => 6919,
                         spiers        => 7784,
                         spies         => 7036,
                         spiller       => 4360,
                         spillman      => 3848,
                         spina         => 6462,
                         spindler      => 8721,
                         spinelli      => 5392,
                         spinks        => 3604,
                         spires        => 5235,
                         spitler       => 7783,
                         spitz         => 8266,
                         spitzer       => 4696,
                         spivey        => 963,
                         spooner       => 2933,
                         spotts        => 8611,
                         spradlin      => 3317,
                         spradling     => 8385,
                         spraggins     => 7782,
                         sprague       => 1295,
                         spratt        => 7959,
                         sprayberry    => 7781,
                         spriggs       => 3756,
                         springer      => 917,
                         sprinkle      => 4426,
                         sproul        => 7429,
                         sprouse       => 3146,
                         spruill       => 2509,
                         spry          => 8265,
                         spurgeon      => 3847,
                         spurlin       => 8720,
                         spurling      => 8502,
                         spurlock      => 2205,
                         squire        => 6579,
                         squires       => 1825,
                         sroka         => 8831,
                         staab         => 9270,
                         staats        => 6850,
                         stabler       => 8501,
                         stack         => 2932,
                         stackhouse    => 3708,
                         stadler       => 6028,
                         stafford      => 550,
                         stagg         => 7603,
                         staggs        => 3136,
                         stagner       => 7875,
                         stahl         => 1502,
                         stahlman      => 9269,
                         staley        => 1439,
                         stallard      => 6132,
                         stallings     => 1407,
                         stallworth    => 2656,
                         stalnaker     => 6461,
                         stalvey       => 9522,
                         stambaugh     => 6972,
                         stamey        => 6186,
                         stamm         => 3707,
                         stamper       => 2089,
                         stamps        => 2672,
                         stancil       => 4425,
                         standifer     => 6777,
                         standish      => 8719,
                         standley      => 4932,
                         standridge    => 6404,
                         stanek        => 9379,
                         stanfield     => 2340,
                         stanfill      => 6079,
                         stange        => 9901,
                         stanger       => 7035,
                         stanhope      => 9378,
                         stannard      => 9521,
                         stansberry    => 4167,
                         stansbury     => 4392,
                         stanton       => 788,
                         staples       => 1495,
                         stapleton     => 1380,
                         stapp         => 9643,
                         starcher      => 8610,
                         stark         => 746,
                         starke        => 9377,
                         starkey       => 1904,
                         starks        => 1182,
                         starling      => 2828,
                         starnes       => 1546,
                         starr         => 958,
                         starrett      => 9520,
                         staten        => 2877,
                         statler       => 9642,
                         staton        => 1467,
                         staub         => 6519,
                         stauffer      => 3269,
                         stclair       => 2339,
                         stcyr         => 6578,
                         steadman      => 3733,
                         stearns       => 1771,
                         stebbins      => 4973,
                         steck         => 7780,
                         stedman       => 7958,
                         steed         => 2534,
                         steele        => 283,
                         steelman      => 5356,
                         steen         => 2039,
                         stefanski     => 9641,
                         steffen       => 3200,
                         steffens      => 6577,
                         steffey       => 9640,
                         stegall       => 3543,
                         steger        => 5277,
                         steib         => 6518,
                         steiger       => 7034,
                         stein         => 723,
                         steinbach     => 7519,
                         steinberg     => 2627,
                         steiner       => 1460,
                         steinke       => 6289,
                         steinman      => 6849,
                         steinmetz     => 4309,
                         stell         => 9376,
                         stelly        => 8153,
                         stenger       => 8925,
                         stennett      => 9519,
                         stenson       => 8264,
                         stephens      => 156,
                         stephenson    => 563,
                         stepp         => 2172,
                         stern         => 1379,
                         sternberg     => 6185,
                         sterner       => 5156,
                         sterrett      => 8924,
                         stevens       => 121,
                         stevenson     => 314,
                         steverson     => 7602,
                         steward       => 1017,
                         stewart       => 49,
                         stgeorge      => 8830,
                         stgermain     => 5462,
                         sthilaire     => 6359,
                         stice         => 9156,
                         stickler      => 7033,
                         stickley      => 8718,
                         stickney      => 4518,
                         stidham       => 3416,
                         stier         => 7874,
                         stiffler      => 6288,
                         stiles        => 1298,
                         stillings     => 9900,
                         stillman      => 4018,
                         stills        => 9758,
                         stillwell     => 3382,
                         stiltner      => 3006,
                         stilwell      => 5501,
                         stimpson      => 8717,
                         stine         => 2699,
                         stines        => 8500,
                         stinnett      => 2742,
                         stinson       => 903,
                         stites        => 5687,
                         stith         => 4836,
                         stitt         => 3706,
                         stiver        => 9375,
                         stivers       => 7779,
                         stjean        => 9899,
                         stjohn        => 1884,
                         stlaurent     => 8263,
                         stlouis       => 5500,
                         stockdale     => 6460,
                         stocker       => 4456,
                         stockman      => 4359,
                         stockstill    => 9639,
                         stockton      => 1770,
                         stockwell     => 5049,
                         stoddard      => 1882,
                         stoffel       => 6971,
                         stogner       => 7957,
                         stoker        => 3887,
                         stokes        => 376,
                         stoll         => 3104,
                         stollings     => 6776,
                         stoltz        => 5391,
                         stoltzfus     => 4612,
                         stone         => 149,
                         stoneking     => 9898,
                         stoner        => 1824,
                         stonge        => 4081,
                         stoops        => 5642,
                         storer        => 5834,
                         storey        => 1834,
                         storms        => 4571,
                         stott         => 3846,
                         stotts        => 6358,
                         stouffer      => 6027,
                         stout         => 714,
                         stovall       => 1519,
                         stover        => 1155,
                         stowe         => 2626,
                         stowell       => 4799,
                         stowers       => 4198,
                         stpeter       => 8262,
                         stpierre      => 2827,
                         strachan      => 8054,
                         strader       => 4220,
                         strahan       => 6517,
                         strain        => 2864,
                         strait        => 4308,
                         straka        => 7873,
                         straley       => 7285,
                         strand        => 2931,
                         strang        => 9155,
                         strasser      => 7361,
                         stratton      => 1279,
                         straub        => 3924,
                         strauch       => 9154,
                         straus        => 9897,
                         strauss       => 2508,
                         strawn        => 4455,
                         strawser      => 6638,
                         strayer       => 8829,
                         streeter      => 2022,
                         streit        => 8499,
                         stribling     => 5426,
                         stricker      => 6970,
                         strickland    => 341,
                         strickler     => 4547,
                         stricklin     => 4219,
                         stringer      => 1352,
                         stringfellow  => 5977,
                         stringfield   => 8716,
                         stringham     => 8609,
                         stripling     => 7518,
                         strobel       => 5390,
                         strode        => 6459,
                         stroh         => 5976,
                         strom         => 4121,
                         stroman       => 5234,
                         stromberg     => 5641,
                         strong        => 570,
                         strope        => 9757,
                         strother      => 2602,
                         stroud        => 1069,
                         stroup        => 3912,
                         stroupe       => 9638,
                         strouse       => 6918,
                         struble       => 6078,
                         strunk        => 3434,
                         stubblefield  => 2526,
                         stubbs        => 1291,
                         stuckey       => 2698,
                         studebaker    => 9518,
                         studer        => 4307,
                         stull         => 3059,
                         stultz        => 5598,
                         stump         => 2382,
                         stumpf        => 5048,
                         sturdivant    => 3845,
                         sturgeon      => 3174,
                         sturges       => 7956,
                         sturgill      => 3145,
                         sturgis       => 3844,
                         sturm         => 3452,
                         sturtevant    => 7872,
                         stutz         => 8152,
                         stutzman      => 4490,
                         styron        => 9268,
                         suarez        => 706,
                         suazo         => 7695,
                         suber         => 4454,
                         sublett       => 5975,
                         sudduth       => 5640,
                         suggs         => 1378,
                         suiter        => 6131,
                         sullins       => 6130,
                         sullivan      => 100,
                         sumlin        => 9153,
                         summerlin     => 3843,
                         summers       => 444,
                         summerville   => 4972,
                         summey        => 9637,
                         sumner        => 1310,
                         sumpter       => 3043,
                         sumrall       => 5461,
                         sundberg      => 6184,
                         sunderland    => 5155,
                         sundquist     => 9044,
                         surber        => 5154,
                         surles        => 8828,
                         surratt       => 4060,
                         sussman       => 5935,
                         suter         => 7284,
                         sutherland    => 1113,
                         sutphin       => 5597,
                         sutter        => 3058,
                         suttle        => 6576,
                         suttles       => 5233,
                         sutton        => 257,
                         swafford      => 2338,
                         swaim         => 5934,
                         swain         => 885,
                         swan          => 1236,
                         swaney        => 6969,
                         swanger       => 8498,
                         swank         => 3333,
                         swann         => 1954,
                         swanner       => 8151,
                         swanson       => 350,
                         swarey        => 6458,
                         swart         => 8497,
                         swartz        => 1123,
                         swearingen    => 3911,
                         sweatman      => 9517,
                         sweatt        => 5833,
                         sweeney       => 569,
                         sweeny        => 8384,
                         sweitzer      => 6715,
                         swensen       => 9043,
                         swenson       => 1448,
                         swett         => 6077,
                         swick         => 7955,
                         swift         => 1177,
                         swiger        => 5933,
                         swilley       => 8923,
                         swindell      => 5232,
                         swindle       => 4762,
                         swinehart     => 9042,
                         swiney        => 9516,
                         swinford      => 7871,
                         swingle       => 9636,
                         swink         => 5974,
                         swinney       => 4738,
                         swinson       => 7126,
                         swint         => 7954,
                         swinton       => 5425,
                         swisher       => 2892,
                         switzer       => 2084,
                         swope         => 3842,
                         sydnor        => 7125,
                         sykes         => 730,
                         symonds       => 8827,
                         symons        => 7870,
                         synder        => 7953,
                         szabo         => 4866,
                         szeto         => 9756,
                         szymanski     => 4391,
                         tabares       => 9374,
                         tabb          => 4453,
                         taber         => 3316,
                         tabor         => 1620,
                         tackett       => 1655,
                         tadlock       => 8715,
                         tafoya        => 4218,
                         taft          => 2610,
                         taggart       => 2980,
                         tague         => 7869,
                         tait          => 5083,
                         takahashi     => 5832,
                         talamantes    => 8496,
                         talarico      => 8922,
                         talavera      => 7283,
                         talbert       => 2255,
                         talbot        => 1562,
                         talbott       => 3482,
                         taliaferro    => 7124,
                         talkington    => 8495,
                         tallant       => 9755,
                         tallent       => 3910,
                         talley        => 807,
                         tallman       => 4306,
                         tally         => 9515,
                         talton        => 7203,
                         tamayo        => 3033,
                         tamez         => 6287,
                         tanaka        => 3005,
                         tang          => 1777,
                         tanguay       => 7517,
                         tankersley    => 4546,
                         tanksley      => 9152,
                         tanner        => 560,
                         tapia         => 1066,
                         tapley        => 5783,
                         tapp          => 3660,
                         tapper        => 8608,
                         tarango       => 6129,
                         tarantino     => 9151,
                         tarbox        => 8053,
                         tardif        => 7516,
                         tardiff       => 5736,
                         tarpley       => 7778,
                         tarr          => 4251,
                         tarrant       => 4971,
                         tart          => 6848,
                         tarter        => 6457,
                         tarver        => 3019,
                         tarvin        => 9514,
                         tasker        => 8052,
                         tate          => 317,
                         tatro         => 4695,
                         tatum         => 927,
                         tauber        => 9513,
                         tavares       => 2553,
                         tavarez       => 6516,
                         taveras       => 6128,
                         taylor        => 10,
                         teague        => 1075,
                         teal          => 3173,
                         teasley       => 6575,
                         tedder        => 5355,
                         tedeschi      => 8150,
                         tedesco       => 4652,
                         tedford       => 6574,
                         teel          => 2337,
                         teeter        => 3470,
                         teeters       => 7952,
                         teets         => 8149,
                         teixeira      => 5544,
                         tejada        => 3505,
                         tejeda        => 3755,
                         telford       => 7601,
                         telles        => 6456,
                         tellez        => 3199,
                         tellier       => 9754,
                         tello         => 5543,
                         templeton     => 2014,
                         templin       => 7951,
                         tennant       => 3057,
                         tenney        => 3523,
                         tennison      => 8148,
                         tennyson      => 5686,
                         tenorio       => 6357,
                         teran         => 7123,
                         terrazas      => 4737,
                         terrill       => 3886,
                         terwilliger   => 6847,
                         tesch         => 6026,
                         teske         => 9041,
                         tessier       => 6714,
                         testa         => 4305,
                         testerman     => 7428,
                         teter         => 7427,
                         tetreault     => 4517,
                         thach         => 8261,
                         thacker       => 1330,
                         thames        => 3795,
                         tharp         => 1890,
                         tharpe        => 5424,
                         thatcher      => 3542,
                         thaxton       => 6356,
                         thayer        => 1504,
                         theis         => 4651,
                         theisen       => 4390,
                         theiss        => 8494,
                         thelen        => 7868,
                         theobald      => 7032,
                         theriault     => 3705,
                         theriot       => 3866,
                         theroux       => 9040,
                         therrien      => 4545,
                         theus         => 9753,
                         thibault      => 4516,
                         thibeault     => 5499,
                         thibodaux     => 9896,
                         thibodeau     => 2485,
                         thibodeaux    => 2465,
                         thiel         => 3777,
                         thiele        => 7950,
                         thielen       => 5596,
                         thies         => 5782,
                         thigpen       => 2507,
                         thom          => 4736,
                         thomason      => 1116,
                         thomasson     => 7426,
                         thompkins     => 4931,
                         thompson      => 16,
                         thoms         => 9512,
                         thomsen       => 3469,
                         thomson       => 1240,
                         thorn         => 2336,
                         thornberry    => 8383,
                         thornburg     => 3704,
                         thorne        => 1444,
                         thornhill     => 3394,
                         thornton      => 323,
                         thorp         => 4017,
                         thorpe        => 1317,
                         thorsen       => 9752,
                         thorson       => 5047,
                         thorton       => 3144,
                         thrash        => 3619,
                         thrasher      => 2125,
                         threadgill    => 7867,
                         threatt       => 7949,
                         thrift        => 6917,
                         throckmorton  => 8260,
                         thrower       => 5231,
                         thurber       => 5498,
                         thurlow       => 9373,
                         thurmond      => 4761,
                         thurston      => 1833,
                         tibbetts      => 3732,
                         tibbs         => 2641,
                         tice          => 3087,
                         tichenor      => 8826,
                         tidwell       => 1146,
                         tierney       => 2876,
                         tighe         => 6183,
                         tigner        => 9511,
                         tijerina      => 2730,
                         tilghman      => 7202,
                         tiller        => 3565,
                         tillery       => 2812,
                         tillett       => 7694,
                         tilley        => 1635,
                         tillis        => 6076,
                         tillman       => 688,
                         tillotson     => 6182,
                         tilton        => 2956,
                         timberlake    => 5595,
                         timm          => 3638,
                         timmerman     => 4120,
                         timmins       => 8607,
                         timmons       => 1360,
                         timms         => 5932,
                         tims          => 8259,
                         tincher       => 6231,
                         tindall       => 4036,
                         tindell       => 9267,
                         tindle        => 8258,
                         tiner         => 9266,
                         tingle        => 5831,
                         tingley       => 7201,
                         tinney        => 5594,
                         tinnin        => 9265,
                         tinsley       => 1743,
                         tippett       => 8493,
                         tipton        => 1071,
                         tirado        => 2300,
                         tisdale       => 2552,
                         tittle        => 7282,
                         tobar         => 7600,
                         tobey         => 5354,
                         tobin         => 1478,
                         toland        => 7031,
                         tolar         => 9510,
                         tolbert       => 1060,
                         toledo        => 2794,
                         tolentino     => 5460,
                         toler         => 2848,
                         toles         => 8825,
                         toliver       => 3086,
                         tolle         => 6455,
                         tollefson     => 7425,
                         tolley        => 4035,
                         tollison      => 8824,
                         tolliver      => 2464,
                         tolman        => 5685,
                         tolson        => 5684,
                         toman         => 9751,
                         tomaszewski   => 9264,
                         tomblin       => 8492,
                         tomes         => 8257,
                         tomlin        => 2213,
                         tomlinson     => 1108,
                         tompkins      => 1264,
                         toms          => 5153,
                         toner         => 6075,
                         tong          => 3564,
                         toole         => 4650,
                         tooley        => 4970,
                         toombs        => 4735,
                         toomer        => 8147,
                         toomey        => 4969,
                         topete        => 9509,
                         topping       => 7599,
                         torain        => 9263,
                         torgerson     => 5152,
                         toro          => 3135,
                         torre         => 8051,
                         torrence      => 3433,
                         torres        => 65,
                         torrey        => 4835,
                         torrez        => 1840,
                         toscano       => 4197,
                         toth          => 1866,
                         totten        => 3703,
                         toussaint     => 5353,
                         tovar         => 1533,
                         towe          => 6573,
                         towery        => 8491,
                         towle         => 4217,
                         towne         => 4304,
                         towner        => 6127,
                         townes        => 3794,
                         townley       => 6403,
                         townsel       => 8921,
                         townsend      => 342,
                         townsley      => 7598,
                         trafton       => 9750,
                         trahan        => 2046,
                         trainor       => 4358,
                         tramel        => 7281,
                         trammel       => 7777,
                         trammell      => 2413,
                         tran          => 424,
                         trantham      => 4250,
                         trapp         => 2917,
                         trask         => 3304,
                         traub         => 9635,
                         traver        => 8920,
                         trawick       => 7597,
                         traxler       => 9262,
                         traylor       => 1690,
                         traynor       => 6968,
                         treadway      => 3393,
                         treadwell     => 2826,
                         treece        => 4734,
                         trejo         => 1654,
                         tremblay      => 3103,
                         tressler      => 9039,
                         trevino       => 541,
                         trexler       => 7122,
                         tribble       => 3371,
                         trice         => 2969,
                         trigg         => 5830,
                         triggs        => 9508,
                         trimble       => 1848,
                         triplett      => 1401,
                         tripp         => 1282,
                         troche        => 8919,
                         troiano       => 9895,
                         trombley      => 4080,
                         trosclair     => 9038,
                         trost         => 7515,
                         trotman       => 5497,
                         trott         => 4898,
                         trotta        => 8823,
                         trotter       => 1294,
                         trottier      => 7693,
                         troup         => 7776,
                         troupe        => 5230,
                         trout         => 2111,
                         troutman      => 2278,
                         troutt        => 8822,
                         trowbridge    => 4143,
                         troxel        => 8918,
                         troxell       => 6916,
                         troxler       => 8256,
                         troyer        => 5781,
                         truax         => 5113,
                         trudeau       => 3637,
                         trueblood     => 7596,
                         truesdale     => 5352,
                         truesdell     => 8821,
                         truett        => 7595,
                         truex         => 9749,
                         truitt        => 2834,
                         trujillo      => 580,
                         trull         => 6025,
                         trump         => 7360,
                         truong        => 2161,
                         truss         => 6915,
                         trussell      => 5542,
                         trusty        => 7775,
                         tsai          => 5931,
                         tsang         => 6713,
                         tsosie        => 4570,
                         tubbs         => 2277,
                         tucci         => 5639,
                         tuck          => 2729,
                         tucker        => 122,
                         tudor         => 4274,
                         tufts         => 8917,
                         tuggle        => 3134,
                         tull          => 6024,
                         tullis        => 6402,
                         tully         => 4389,
                         tunnell       => 5829,
                         tunstall      => 6355,
                         tupper        => 7200,
                         turcotte      => 4834,
                         turek         => 9261,
                         turgeon       => 6354,
                         turk          => 2728,
                         turley        => 2825,
                         turman        => 3827,
                         turnage       => 4332,
                         turnbow       => 5973,
                         turnbull      => 3213,
                         turner        => 42,
                         turney        => 3172,
                         turpin        => 2180,
                         tussey        => 9372,
                         tuten         => 9037,
                         tutt          => 6967,
                         tuttle        => 1049,
                         tweed         => 7424,
                         tweedy        => 8382,
                         twigg         => 6515,
                         twilley       => 8490,
                         twitchell     => 8606,
                         twitty        => 6775,
                         twombly       => 8146,
                         twomey        => 6401,
                         twyman        => 7514,
                         tyndall       => 5389,
                         tyner         => 3285,
                         tynes         => 6454,
                         tyrrell       => 5423,
                         tyus          => 7513,
                         ulibarri      => 6572,
                         ullman        => 7199,
                         ulloa         => 4489,
                         ullrich       => 7512,
                         ulmer         => 4102,
                         ulrich        => 1816,
                         umana         => 9634,
                         underhill     => 3381,
                         underwood     => 434,
                         unger         => 2034,
                         unknow        => 8050,
                         unruh         => 5459,
                         upchurch      => 2506,
                         updike        => 9507,
                         upham         => 9260,
                         upshaw        => 3118,
                         upton         => 1984,
                         urbanski      => 9894,
                         urbina        => 2945,
                         urena         => 4273,
                         urias         => 4865,
                         uribe         => 2355,
                         urquhart      => 5930,
                         urrutia       => 6846,
                         usher         => 3865,
                         ussery        => 4303,
                         utley         => 3247,
                         utter         => 5780,
                         utterback     => 9506,
                         vaca          => 6074,
                         vaccaro       => 5638,
                         vachon        => 5683,
                         vaden         => 6774,
                         vadnais       => 8489,
                         vail          => 2449,
                         vaillancourt  => 5276,
                         valadez       => 2484,
                         valdes        => 2366,
                         valdez        => 309,
                         valdivia      => 5229,
                         valdovinos    => 7511,
                         valencia      => 838,
                         valente       => 5972,
                         valenti       => 3754,
                         valentine     => 653,
                         valentino     => 4249,
                         valenzuela    => 772,
                         valerio       => 3198,
                         valero        => 7510,
                         valladares    => 5194,
                         valle         => 1459,
                         vallee        => 8381,
                         vallejo       => 2727,
                         vallejos      => 8820,
                         valles        => 2996,
                         valliere      => 6514,
                         valverde      => 5228,
                         vanarsdale    => 9505,
                         vanatta       => 8255,
                         vanburen      => 3776,
                         vanbuskirk    => 5046,
                         vancleave     => 7359,
                         vandenberg    => 5496,
                         vandergriff   => 9893,
                         vanderpool    => 4424,
                         vandeusen     => 8916,
                         vandiver      => 3885,
                         vandusen      => 5275,
                         vandyke       => 2088,
                         vanegas       => 6571,
                         vanetten      => 9892,
                         vanfleet      => 9891,
                         vang          => 860,
                         vangundy      => 9890,
                         vanhook       => 8049,
                         vanhoose      => 3468,
                         vanhorn       => 2335,
                         vanhouten     => 5682,
                         vankirk       => 8380,
                         vanlandingham => 6637,
                         vanmeter      => 3315,
                         vann          => 1641,
                         vannatta      => 8488,
                         vanness       => 7030,
                         vannoy        => 5735,
                         vanover       => 3775,
                         vanpelt       => 4331,
                         vanscoy       => 8379,
                         vansickle     => 4515,
                         vantassel     => 8145,
                         vanvalkenburg => 8605,
                         vanwinkle     => 3451,
                         vanwormer     => 9150,
                         vanzandt      => 8254,
                         vanzant       => 6773,
                         varela        => 1747,
                         varga         => 5319,
                         vargas        => 237,
                         vargo         => 5082,
                         varnado       => 6966,
                         varnell       => 9371,
                         varner        => 1436,
                         varney        => 2156,
                         vasques       => 8253,
                         vasquez       => 192,
                         vassallo      => 8487,
                         vassar        => 7594,
                         vasser        => 9259,
                         vaughan       => 742,
                         vaughn        => 277,
                         vaught        => 2726,
                         vazquez       => 458,
                         veach         => 5681,
                         veal          => 3541,
                         veasey        => 8486,
                         veatch        => 8915,
                         vega          => 328,
                         veilleux      => 4488,
                         vela          => 1261,
                         velarde       => 5680,
                         velasco       => 1811,
                         velasquez     => 598,
                         velazquez     => 858,
                         velez         => 616,
                         veliz         => 6230,
                         veloz         => 7774,
                         venable       => 3133,
                         venegas       => 3332,
                         venezia       => 9370,
                         ventura       => 1430,
                         verdin        => 3563,
                         verdugo       => 5929,
                         verduzco      => 4760,
                         vereen        => 6636,
                         vergara       => 3909,
                         vermillion    => 4514,
                         verner        => 9748,
                         verret        => 6712,
                         verrill       => 9633,
                         vest          => 2330,
                         vestal        => 5828,
                         vetter        => 3004,
                         vick          => 1600,
                         vickers       => 1090,
                         vickery       => 2692,
                         vidal         => 2505,
                         vidrine       => 5734,
                         vieira        => 3884,
                         viera         => 3314,
                         vierra        => 5193,
                         vigil         => 1065,
                         vigue         => 8048,
                         villa         => 916,
                         villagomez    => 4119,
                         villalba      => 7509,
                         villalobos    => 1489,
                         villalpando   => 6181,
                         villani       => 9504,
                         villanueva    => 897,
                         villar        => 7692,
                         villareal     => 3284,
                         villarreal    => 587,
                         villasenor    => 3540,
                         villatoro     => 7121,
                         villegas      => 1143,
                         villeneuve    => 8485,
                         vinci         => 8819,
                         vines         => 2276,
                         vineyard      => 5014,
                         vining        => 4611,
                         vinson        => 841,
                         vinyard       => 8604,
                         viramontes    => 9149,
                         visser        => 8378,
                         vitale        => 2995,
                         voelker       => 6914,
                         vogel         => 1119,
                         vogler        => 6913,
                         vogt          => 1640,
                         voight        => 7691,
                         voigt         => 4142,
                         volk          => 4649,
                         volkman       => 7866,
                         vollmer       => 5827,
                         volpe         => 4733,
                         volz          => 4079,
                         voorhees      => 5112,
                         voss          => 1246,
                         vowell        => 8144,
                         voyles        => 6711,
                         vreeland      => 9632,
                         vroman        => 8818,
                         vuong         => 6513,
                         wachter       => 4330,
                         wacker        => 6453,
                         waddell       => 1211,
                         waddle        => 4759,
                         wade          => 242,
                         wadley        => 6023,
                         wadsworth     => 2562,
                         wagers        => 7198,
                         wages         => 6073,
                         waggoner      => 2127,
                         wagner        => 162,
                         wagoner       => 1964,
                         wagstaff      => 6845,
                         waguespack    => 9258,
                         wahl          => 2478,
                         wainscott     => 9369,
                         wainwright    => 4798,
                         waite         => 1723,
                         waiters       => 8714,
                         waites        => 5351,
                         waits         => 4248,
                         wakefield     => 1938,
                         wakeman       => 9747,
                         walcott       => 7358,
                         walczak       => 7593,
                         wald          => 7357,
                         walden        => 925,
                         waldman       => 6022,
                         waldon        => 4897,
                         waldrep       => 9503,
                         waldron       => 1596,
                         waldrop       => 2310,
                         waldrup       => 8143,
                         walker        => 24,
                         walkup        => 9631,
                         wall          => 489,
                         wallace       => 101,
                         wallen        => 3659,
                         waller        => 681,
                         walley        => 6570,
                         wallin        => 4196,
                         walling       => 2591,
                         wallis        => 2061,
                         walls         => 609,
                         walmsley      => 9630,
                         walser        => 8713,
                         walsh         => 295,
                         walston       => 3522,
                         walters       => 244,
                         walther       => 4452,
                         waltman       => 7508,
                         walton        => 345,
                         waltz         => 4833,
                         walz          => 4272,
                         wampler       => 3603,
                         wamsley       => 9746,
                         wang          => 882,
                         wanner        => 9502,
                         ward          => 64,
                         wardell       => 7197,
                         warden        => 2067,
                         wardlaw       => 8047,
                         wardlow       => 8712,
                         ware          => 471,
                         warfield      => 2793,
                         wargo         => 6965,
                         waring        => 5111,
                         warman        => 8142,
                         warner        => 313,
                         warnke        => 8484,
                         warnock       => 4271,
                         warr          => 8483,
                         warren        => 130,
                         warrick       => 4968,
                         warrington    => 5274,
                         warwick       => 4832,
                         washam        => 8711,
                         washburn      => 1479,
                         washer        => 8252,
                         washington    => 86,
                         wasserman     => 5881,
                         wasson        => 2955,
                         watanabe      => 4329,
                         waterhouse    => 6635,
                         waterman      => 2087,
                         waters        => 385,
                         watkins       => 164,
                         watson        => 69,
                         watt          => 1802,
                         watters       => 2590,
                         watterson     => 6180,
                         watts         => 266,
                         waugh         => 2291,
                         wayland       => 7280,
                         wayman        => 4388,
                         waymire       => 8817,
                         weakley       => 8914,
                         weatherby     => 5826,
                         weatherford   => 2863,
                         weatherly     => 3003,
                         weathers      => 1823,
                         weathersby    => 4648,
                         weatherspoon  => 4357,
                         weaver        => 179,
                         webb          => 119,
                         webber        => 955,
                         weber         => 294,
                         webster       => 360,
                         weddington    => 9036,
                         weddle        => 3680,
                         wedgeworth    => 9629,
                         weeden        => 7690,
                         weekley       => 5733,
                         weeks         => 622,
                         weems         => 2477,
                         weese         => 6710,
                         wegener       => 9035,
                         wegner        => 4694,
                         weibel        => 9501,
                         weidman       => 7029,
                         weidner       => 4758,
                         weigand       => 7689,
                         weigel        => 5151,
                         weikel        => 8816,
                         weil          => 4693,
                         weiland       => 5318,
                         weiler        => 4247,
                         weimer        => 4423,
                         weinberg      => 3826,
                         weinberger    => 8251,
                         weiner        => 2119,
                         weinstein     => 2354,
                         weintraub     => 6772,
                         weir          => 1425,
                         weis          => 3562,
                         weisberg      => 8046,
                         weise         => 5637,
                         weiser        => 6229,
                         weisman       => 6569,
                         weiss         => 579,
                         weissman      => 7773,
                         weitzel       => 7196,
                         welborn       => 4569,
                         welch         => 219,
                         welker        => 3702,
                         weller        => 1782,
                         wellman       => 2000,
                         wells         => 118,
                         welsh         => 1025,
                         welter        => 6964,
                         welton        => 5013,
                         welty         => 5150,
                         wendel        => 5388,
                         wendling      => 8377,
                         wendt         => 2589,
                         wenger        => 3774,
                         wentworth     => 2930,
                         wentz         => 3415,
                         wentzel       => 8376,
                         wenzel        => 2760,
                         wert          => 5317,
                         werth         => 6568,
                         werts         => 8710,
                         wertz         => 2725,
                         wescott       => 5149,
                         wesner        => 9745,
                         wessel        => 5045,
                         wessels       => 7865,
                         wesson        => 4356,
                         west          => 104,
                         westberg      => 8815,
                         westberry     => 8375,
                         westbrook     => 1518,
                         westbrooks    => 6072,
                         westcott      => 4610,
                         wester        => 3561,
                         westerfield   => 7592,
                         westerman     => 5779,
                         westfall      => 2525,
                         westfield     => 9500,
                         westgate      => 8709,
                         westlake      => 9034,
                         westlund      => 7864,
                         westman       => 8708,
                         westmoreland  => 2282,
                         westover      => 5778,
                         westphal      => 4487,
                         wetherell     => 9033,
                         wethington    => 7772,
                         wetmore       => 5636,
                         wetzel        => 1855,
                         wexler        => 6400,
                         weyant        => 9368,
                         whalen        => 1400,
                         whaley        => 1014,
                         wharton       => 2741,
                         whatley       => 1752,
                         wheat         => 2160,
                         wheatley      => 1948,
                         wheaton       => 3212,
                         wheeler       => 194,
                         wheelock      => 7863,
                         whelan        => 3504,
                         whetstone     => 4302,
                         whetzel       => 8913,
                         whidden       => 9148,
                         whipkey       => 9628,
                         whipple       => 1977,
                         whisenant     => 6709,
                         whisenhunt    => 7688,
                         whisler       => 8250,
                         whitacre      => 5227,
                         whitaker      => 468,
                         whitcomb      => 3056,
                         white         => 13,
                         whiteaker     => 9499,
                         whited        => 3380,
                         whitefield    => 8603,
                         whitehead     => 505,
                         whitehouse    => 4301,
                         whitehurst    => 2759,
                         whiteley      => 6399,
                         whiteman      => 4016,
                         whitener      => 5012,
                         whitesell     => 7356,
                         whiteside     => 2902,
                         whitesides    => 9367,
                         whitfield     => 806,
                         whitford      => 5148,
                         whiting       => 2155,
                         whitley       => 859,
                         whitlock      => 1653,
                         whitlow       => 2875,
                         whitman       => 1608,
                         whitmer       => 5011,
                         whitmire      => 3268,
                         whitmore      => 1695,
                         whitson       => 2374,
                         whitt         => 1567,
                         whittaker     => 1477,
                         whitted       => 5273,
                         whittemore    => 4864,
                         whitten       => 1517,
                         whittier      => 7195,
                         whittington   => 1716,
                         whittle       => 2758,
                         whitton       => 7591,
                         whitworth     => 2579,
                         whorton       => 5081,
                         whyte         => 3773,
                         wible         => 9627,
                         wick          => 3793,
                         wicker        => 2463,
                         wickersham    => 9626,
                         wickham       => 4015,
                         wicklund      => 7507,
                         wickman       => 8482,
                         wicks         => 2561,
                         wideman       => 7948,
                         widener       => 6844,
                         widmer        => 7194,
                         widner        => 7947,
                         wiebe         => 9257,
                         wiegand       => 5350,
                         wieland       => 5928,
                         wiener        => 5541,
                         wiens         => 9147,
                         wiese         => 3331,
                         wiesner       => 9366,
                         wiest         => 9744,
                         wigfall       => 5732,
                         wiggins       => 485,
                         wigginton     => 8707,
                         wiggs         => 6452,
                         wight         => 6021,
                         wigley        => 8045,
                         wilbanks      => 2625,
                         wilborn       => 4692,
                         wilbourn      => 8249,
                         wilcher       => 5593,
                         wilcox        => 446,
                         wilde         => 2533,
                         wilder        => 736,
                         wilds         => 7687,
                         wiles         => 2231,
                         wiley         => 521,
                         wilfong       => 5349,
                         wilhelm       => 1859,
                         wilhite       => 3618,
                         wilhoit       => 8374,
                         wilhoite      => 9889,
                         wiliams       => 9625,
                         wilk          => 6843,
                         wilke         => 3636,
                         wilken        => 9624,
                         wilkens       => 5927,
                         wilkerson     => 442,
                         wilkes        => 1414,
                         wilkey        => 7506,
                         wilkie        => 5080,
                         wilkins       => 432,
                         wilkinson     => 553,
                         wilks         => 2353,
                         willaims      => 8373,
                         willams       => 8044,
                         willcox       => 8814,
                         wille         => 7423,
                         willett       => 1832,
                         willey        => 1971,
                         willhite      => 8043,
                         williams      => 3,
                         williamson    => 198,
                         williford     => 3055,
                         willingham    => 1738,
                         willis        => 163,
                         willison      => 8141,
                         willman       => 7355,
                         willoughby    => 1737,
                         wills         => 999,
                         willson       => 2782,
                         wilmot        => 5926,
                         wilmoth       => 3617,
                         wilson        => 8,
                         wilt          => 3392,
                         wiltse        => 9256,
                         wimberly      => 3246,
                         wimbush       => 8042,
                         wimer         => 7120,
                         wimmer        => 4422,
                         winburn       => 8372,
                         winbush       => 9743,
                         winchell      => 5495,
                         winchester    => 3117,
                         winder        => 5494,
                         windham       => 2299,
                         windle        => 7279,
                         windley       => 9498,
                         windom        => 7119,
                         winebrenner   => 9032,
                         winegar       => 8481,
                         wines         => 6963,
                         winfield      => 2578,
                         winfree       => 9742,
                         winfrey       => 3370,
                         wingard       => 4387,
                         wingate       => 3283,
                         winger        => 5226,
                         wingert       => 9365,
                         wingfield     => 3282,
                         wingo         => 4896,
                         winkelman     => 7193,
                         winkfield     => 9888,
                         winkle        => 7118,
                         winkler       => 1413,
                         winn          => 1377,
                         winslow       => 1668,
                         winstead      => 2361,
                         winters       => 584,
                         winton        => 5731,
                         wireman       => 8140,
                         wirth         => 3267,
                         wirtz         => 9364,
                         wise          => 379,
                         wiseman       => 1229,
                         wisner        => 6512,
                         wisniewski    => 3450,
                         witcher       => 3883,
                         witham        => 5880,
                         withers       => 2429,
                         witherspoon   => 1494,
                         withrow       => 3753,
                         witkowski     => 5925,
                         witmer        => 7192,
                         witt          => 792,
                         witte         => 3414,
                         witten        => 7278,
                         wittman       => 6771,
                         witzel        => 9887,
                         wofford       => 2334,
                         wojciechowski => 9741,
                         wojcik        => 5225,
                         wolcott       => 4059,
                         wold          => 4451,
                         wolf          => 466,
                         wolfe         => 298,
                         wolfenbarger  => 7505,
                         wolff         => 1443,
                         wolford       => 2389,
                         wolfson       => 6912,
                         wolter        => 7422,
                         wolters       => 8139,
                         wolverton     => 9031,
                         womack        => 911,
                         womble        => 4421,
                         wong          => 411,
                         wood          => 74,
                         woodall       => 1629,
                         woodard       => 514,
                         woodberry     => 9497,
                         woodbury      => 3701,
                         woodcock      => 2916,
                         woodell       => 9740,
                         woodford      => 5458,
                         woodham       => 6962,
                         woodhouse     => 5147,
                         woodley       => 3102,
                         woodman       => 4967,
                         woodring      => 5924,
                         woodruff      => 1007,
                         woodrum       => 7771,
                         woods         => 102,
                         woodside      => 8706,
                         woodson       => 1300,
                         woodward      => 641,
                         woodworth     => 2847,
                         woodyard      => 8138,
                         woolard       => 5879,
                         wooldridge    => 3303,
                         woolery       => 6451,
                         wooley        => 3841,
                         woolf         => 6020,
                         woolfolk      => 7277,
                         woolford      => 8912,
                         woolley       => 4355,
                         woolridge     => 7590,
                         woolsey       => 4300,
                         woosley       => 6398,
                         wooster       => 8041,
                         wooten        => 847,
                         wooton        => 7946,
                         worden        => 3002,
                         workman       => 823,
                         worley        => 1002,
                         worrell       => 2033,
                         worsham       => 3992,
                         worsley       => 7589,
                         wortham       => 3864,
                         worthen       => 5224,
                         worthington   => 1742,
                         worthy        => 2640,
                         wortman       => 6179,
                         wotring       => 9363,
                         wozniak       => 4797,
                         wray          => 1435,
                         wren          => 2263,
                         wrenn         => 4863,
                         wright        => 30,
                         wrigley       => 8705,
                         wroblewski    => 8704,
                         wulf          => 7588,
                         wulff         => 9623,
                         wunderlich    => 7028,
                         wurth         => 6842,
                         wyant         => 3908,
                         wyatt         => 496,
                         wyche         => 4609,
                         wyckoff       => 4513,
                         wylie         => 2443,
                         wyman         => 2118,
                         wymer         => 9496,
                         wynn          => 785,
                         wynne         => 3101,
                         wyrick        => 4544,
                         wysocki       => 6228,
                         xiong         => 1454,
                         yaeger        => 8911,
                         yager         => 4420,
                         yamada        => 4757,
                         yamamoto      => 3792,
                         yamashita     => 9622,
                         yancey        => 1963,
                         yancy         => 4354,
                         yandell       => 7686,
                         yanez         => 2187,
                         yang          => 704,
                         yarber        => 6911,
                         yarborough    => 4195,
                         yarbrough     => 889,
                         yardley       => 9621,
                         yarnell       => 9255,
                         yates         => 353,
                         yazzie        => 1554,
                         ybarra        => 1406,
                         yeager        => 1287,
                         yeary         => 8602,
                         yelverton     => 9146,
                         yepez         => 7770,
                         yerger        => 9495,
                         yetter        => 9145,
                         yeung         => 7862,
                         yingling      => 5316,
                         yoakum        => 8248,
                         yockey        => 7117,
                         yocum         => 3991,
                         yoder         => 960,
                         yoho          => 5592,
                         yoon          => 3521,
                         yoshida       => 5679,
                         yost          => 1756,
                         youmans       => 4796,
                         young         => 27,
                         youngblood    => 1405,
                         youngman      => 6770,
                         youngs        => 5192,
                         yount         => 3032,
                         younts        => 7027,
                         yuen          => 5730,
                         zabala        => 9030,
                         zabel         => 8910,
                         zacharias     => 8909,
                         zackery       => 9620,
                         zahn          => 5540,
                         zajac         => 7276,
                         zalewski      => 9886,
                         zamarripa     => 7945,
                         zambrano      => 3942,
                         zamora        => 703,
                         zamudio       => 5777,
                         zapata        => 1646,
                         zaragoza      => 3018,
                         zarate        => 2891,
                         zavala        => 1312,
                         zayas         => 4732,
                         zeigler       => 1892,
                         zelaya        => 5923,
                         zeller        => 3266,
                         zellers       => 7587,
                         zellmer       => 9144,
                         zeman         => 9619,
                         zendejas      => 8371,
                         zepeda        => 1741,
                         zerbe         => 8813,
                         zeringue      => 6910,
                         zhang         => 3197,
                         ziegler       => 1306,
                         zielinski     => 2824,
                         zimmer        => 1831,
                         zimmerman     => 397,
                         zimmermann    => 4647,
                         zink          => 4014,
                         zinn          => 4328,
                         zirkle        => 9029,
                         zito          => 6450,
                         zook          => 2757,
                         zorn          => 6567,
                         zuber         => 4608,
                         zucker        => 7354,
                         zuckerman     => 8703,
                         zukowski      => 8702,
                         zumwalt       => 6841,
                         zuniga        => 1013,
                       },
  us_tv_and_film    => {
                         "a'ight"                 => 17720,
                         "a'right"                => 19162,
                         "aaaaa"                  => 7672,
                         "aaaaaa"                 => 12769,
                         "aaaaaaa"                => 13930,
                         "aaaaaaaa"               => 13929,
                         "aaaaaaaaaa"             => 19161,
                         "aaaaaaaaaaaaa"          => 17719,
                         "aaaaaaaaah"             => 19160,
                         "aaaaaaah"               => 13349,
                         "aaaaaah"                => 9394,
                         "aaaaah"                 => 5998,
                         "aaaaahh"                => 14674,
                         "aaaaargh"               => 17718,
                         "aaaaarrrrrrggghhh"      => 12768,
                         "aaaah"                  => 3644,
                         "aaaahh"                 => 16507,
                         "aaaahhh"                => 13928,
                         "aaaahhhh"               => 11866,
                         "aaagh"                  => 9393,
                         "aaah"                   => 3114,
                         "aaahh"                  => 10435,
                         "aaahhh"                 => 8997,
                         "aaahhhh"                => 15525,
                         "aaand"                  => 10736,
                         "aaargh"                 => 10735,
                         "aahhh"                  => 10434,
                         "aargh"                  => 16506,
                         "aawwww"                 => 12767,
                         "ababwa"                 => 15524,
                         "aback"                  => 15523,
                         "abandon"                => 2508,
                         "abandoning"             => 5557,
                         "abbotts"                => 6258,
                         "abdomenizer"            => 19159,
                         "abdominal"              => 5755,
                         "abduct"                 => 8266,
                         "abducted"               => 3727,
                         "abducting"              => 15522,
                         "abduction"              => 5592,
                         "abductions"             => 15521,
                         "abductor"               => 13927,
                         "aberrant"               => 17717,
                         "aberration"             => 14673,
                         "abetted"                => 16505,
                         "abetting"               => 5877,
                         "abide"                  => 5556,
                         "abiding"                => 5652,
                         "abject"                 => 9882,
                         "able"                   => 344,
                         "abnormality"            => 11865,
                         "abnormally"             => 14672,
                         "aboard"                 => 2294,
                         "abominable"             => 13348,
                         "abomination"            => 7541,
                         "aboot"                  => 15520,
                         "abort"                  => 4478,
                         "aborted"                => 9392,
                         "abortion"               => 3243,
                         "abound"                 => 13347,
                         "about"                  => 27,
                         "abouts"                 => 12766,
                         "aboveboard"             => 16504,
                         "abrasions"              => 13926,
                         "abreast"                => 15519,
                         "abrusso"                => 15518,
                         "absconded"              => 16503,
                         "absences"               => 19158,
                         "absentee"               => 12321,
                         "absolute"               => 2016,
                         "absolutely"             => 419,
                         "absolutes"              => 19157,
                         "absolution"             => 7829,
                         "absolve"                => 9391,
                         "absolved"               => 15517,
                         "absolvo"                => 19156,
                         "absorb"                 => 5182,
                         "absorbent"              => 19155,
                         "abstain"                => 14671,
                         "abstinence"             => 7426,
                         "absurd"                 => 2429,
                         "absurdity"              => 15516,
                         "absurdly"               => 19154,
                         "abuela"                 => 5651,
                         "abundantly"             => 7425,
                         "abused"                 => 4325,
                         "abuser"                 => 14670,
                         "abusing"                => 6486,
                         "abusive"                => 5591,
                         "abydos"                 => 11445,
                         "abysmal"                => 12320,
                         "acathla"                => 8996,
                         "accelerant"             => 7424,
                         "accent"                 => 2744,
                         "accents"                => 8593,
                         "accentuate"             => 13925,
                         "accept"                 => 691,
                         "acceptable"             => 3675,
                         "accepting"              => 2608,
                         "accessorizing"          => 13924,
                         "accessory"              => 3931,
                         "accident"               => 579,
                         "accidental"             => 4700,
                         "accidentally"           => 2206,
                         "accidently"             => 14669,
                         "accidents"              => 2758,
                         "acclimate"              => 19153,
                         "acclimated"             => 19152,
                         "accommodating"          => 8782,
                         "accommodations"         => 6050,
                         "accompli"               => 15515,
                         "accomplice"             => 3323,
                         "accomplices"            => 11069,
                         "accomplish"             => 2393,
                         "accomplished"           => 2228,
                         "accomplishes"           => 17716,
                         "accomplishing"          => 14668,
                         "accomplishment"         => 5220,
                         "accosted"               => 9390,
                         "accountable"            => 5876,
                         "accountant"             => 3338,
                         "accountants"            => 7299,
                         "accoutrements"          => 16502,
                         "accursed"               => 16501,
                         "accusation"             => 3726,
                         "accusations"            => 2716,
                         "accuse"                 => 2368,
                         "accuser"                => 15514,
                         "accusers"               => 19151,
                         "accuses"                => 7423,
                         "accusing"               => 1970,
                         "accustomed"             => 5754,
                         "ached"                  => 16500,
                         "aches"                  => 6592,
                         "aching"                 => 5708,
                         "achingly"               => 19150,
                         "achoo"                  => 13923,
                         "acidosis"               => 13922,
                         "acing"                  => 14667,
                         "acknowledge"            => 3134,
                         "acquaint"               => 13346,
                         "acquaintance"           => 4219,
                         "acquaintances"          => 8781,
                         "acquainted"             => 3831,
                         "acquittal"              => 9635,
                         "acrost"                 => 16499,
                         "acted"                  => 1753,
                         "actin"                  => 7422,
                         "acting"                 => 690,
                         "actionable"             => 19149,
                         "activate"               => 4839,
                         "activator"              => 17715,
                         "activators"             => 19148,
                         "actuality"              => 12319,
                         "actualization"          => 16498,
                         "actually"               => 163,
                         "actuarial"              => 19147,
                         "acula"                  => 19146,
                         "acupuncture"            => 11864,
                         "acupuncturist"          => 19145,
                         "adage"                  => 11068,
                         "adama"                  => 11444,
                         "adamant"                => 5136,
                         "adamantium"             => 17714,
                         "addendum"               => 15513,
                         "addict"                 => 3412,
                         "addicted"               => 3573,
                         "addiction"              => 3562,
                         "addictions"             => 17713,
                         "addictive"              => 7182,
                         "addicts"                => 7181,
                         "addled"                 => 15512,
                         "address"                => 1031,
                         "adebisi"                => 4096,
                         "adenoids"               => 19144,
                         "adhesive"               => 10142,
                         "adieu"                  => 9634,
                         "adios"                  => 4178,
                         "adirondacks"            => 19143,
                         "adjourn"                => 7671,
                         "adjourned"              => 3853,
                         "adjust"                 => 2942,
                         "adjuster"               => 17712,
                         "adjusting"              => 4519,
                         "adjustment"             => 3974,
                         "adjustments"            => 5590,
                         "adlai"                  => 11863,
                         "administer"             => 6406,
                         "admirable"              => 4838,
                         "admirably"              => 13345,
                         "admiration"             => 6257,
                         "admire"                 => 1780,
                         "admired"                => 3973,
                         "admirer"                => 4837,
                         "admirers"               => 11862,
                         "admires"                => 10141,
                         "admiring"               => 5310,
                         "admissible"             => 9633,
                         "admit"                  => 546,
                         "admittance"             => 11443,
                         "admittedly"             => 7828,
                         "admitting"              => 2837,
                         "admonish"               => 15511,
                         "admonished"             => 15510,
                         "admonition"             => 19142,
                         "adolescence"            => 8109,
                         "adolescent"             => 4477,
                         "adopt"                  => 2805,
                         "adoption"               => 2468,
                         "adoptions"              => 17711,
                         "adoptive"               => 7180,
                         "adorable"               => 2031,
                         "adoration"              => 11442,
                         "adore"                  => 2804,
                         "adored"                 => 5181,
                         "adores"                 => 3605,
                         "adoring"                => 8265,
                         "adrenal"                => 13921,
                         "adrenaline"             => 5135,
                         "adrenals"               => 16497,
                         "adrift"                 => 9632,
                         "adstream"               => 13344,
                         "adultery"               => 6591,
                         "advantage"              => 1121,
                         "adventure"              => 1910,
                         "adventurous"            => 7179,
                         "adversaries"            => 11861,
                         "adversary"              => 7421,
                         "adversity"              => 8995,
                         "advertise"              => 6590,
                         "advertises"             => 19141,
                         "advice"                 => 738,
                         "advil"                  => 16496,
                         "advisable"              => 10433,
                         "advise"                 => 2552,
                         "advisement"             => 9198,
                         "advising"               => 6589,
                         "aerobics"               => 6115,
                         "aerosol"                => 14666,
                         "affair"                 => 1217,
                         "affect"                 => 1771,
                         "affection"              => 2792,
                         "affectionate"           => 6752,
                         "affections"             => 6256,
                         "affects"                => 3057,
                         "affidavit"              => 6958,
                         "affidavits"             => 15509,
                         "affirm"                 => 12318,
                         "affirmative"            => 5134,
                         "affleck"                => 9881,
                         "affliction"             => 9631,
                         "afford"                 => 1062,
                         "affront"                => 12317,
                         "affronte"               => 16495,
                         "afloat"                 => 8592,
                         "afoot"                  => 8780,
                         "aforethought"           => 19140,
                         "afraid"                 => 304,
                         "afterglow"              => 16494,
                         "afterlife"              => 6957,
                         "afternoon"              => 755,
                         "afternoons"             => 5875,
                         "aftershave"             => 9630,
                         "aftertaste"             => 17710,
                         "afterthought"           => 12316,
                         "again"                  => 110,
                         "agamemnon"              => 7298,
                         "ageless"                => 12765,
                         "agenda"                 => 1795,
                         "agendas"                => 7827,
                         "agent"                  => 807,
                         "aggravate"              => 11067,
                         "aggravated"             => 5819,
                         "aggravating"            => 14665,
                         "aggravation"            => 8779,
                         "aggressive"             => 2862,
                         "aggressor"              => 8994,
                         "aggrhh"                 => 17709,
                         "agides"                 => 17708,
                         "agitate"                => 14664,
                         "agitated"               => 4573,
                         "agitator"               => 13920,
                         "agitators"              => 19139,
                         "ago"                    => 297,
                         "agonized"               => 14663,
                         "agonizing"              => 7670,
                         "agony"                  => 3604,
                         "agoraphobia"            => 17707,
                         "agrabah"                => 15508,
                         "agree"                  => 625,
                         "agreeable"              => 8264,
                         "agreed"                 => 919,
                         "agreeing"               => 3585,
                         "ahaha"                  => 19138,
                         "ahead"                  => 381,
                         "ahem"                   => 1016,
                         "ahhh"                   => 2319,
                         "ahhhh"                  => 4359,
                         "ahhhhh"                 => 7297,
                         "ahhhhhh"                => 8591,
                         "ahhhhhhh"               => 13919,
                         "ahhhhhhhh"              => 13918,
                         "ahhhhhhhhh"             => 13917,
                         "ahold"                  => 3157,
                         "aidan"                  => 1406,
                         "aides"                  => 5266,
                         "aiding"                 => 5707,
                         "aids"                   => 2227,
                         "aiight"                 => 13343,
                         "ailment"                => 16493,
                         "aimin"                  => 16492,
                         "aimless"                => 14662,
                         "aimlessly"              => 10734,
                         "ain't"                  => 429,
                         "ainsley"                => 5093,
                         "airbags"                => 13916,
                         "airfare"                => 13915,
                         "airhead"                => 7826,
                         "airlifted"              => 15507,
                         "airlock"                => 14661,
                         "airplanes"              => 6658,
                         "airspace"               => 7420,
                         "airstrip"               => 7669,
                         "airtight"               => 6588,
                         "airwaves"               => 10733,
                         "airway"                 => 10140,
                         "aisle"                  => 1900,
                         "aitoro"                 => 2154,
                         "akashic"                => 12764,
                         "akimbo"                 => 17706,
                         "alabaster"              => 15506,
                         "alaikum"                => 17705,
                         "alameida"               => 11066,
                         "alannis"                => 13914,
                         "alarm"                  => 1418,
                         "alarmed"                => 5508,
                         "alarming"               => 7987,
                         "alarmist"               => 13342,
                         "alarms"                 => 4639,
                         "alas"                   => 4875,
                         "alastor"                => 19137,
                         "albatross"              => 8263,
                         "albie"                  => 13341,
                         "alcante"                => 10432,
                         "alcazar"                => 1070,
                         "alcerro"                => 19136,
                         "alcohol"                => 1733,
                         "alcoholic"              => 3099,
                         "alcoholics"             => 7825,
                         "alcove"                 => 15505,
                         "aleck"                  => 12763,
                         "aleikuum"               => 9197,
                         "alert"                  => 2065,
                         "alerted"                => 6193,
                         "alerting"               => 12315,
                         "alexandros"             => 17704,
                         "algerians"              => 19135,
                         "alias"                  => 4799,
                         "aliases"                => 8108,
                         "alibi"                  => 2961,
                         "alibis"                 => 10139,
                         "alien"                  => 1637,
                         "alienate"               => 5706,
                         "alienated"              => 7296,
                         "alienating"             => 8107,
                         "alight"                 => 16491,
                         "alike"                  => 2036,
                         "alimony"                => 5753,
                         "alistair"               => 2253,
                         "alive"                  => 423,
                         "all"                    => 24,
                         "allahu"                 => 16490,
                         "allegiances"            => 19134,
                         "alleluia"               => 14660,
                         "allenby"                => 9389,
                         "allenwood"              => 19133,
                         "allergic"               => 2341,
                         "allergies"              => 4391,
                         "allergist"              => 17703,
                         "allergy"                => 4836,
                         "alleys"                 => 8412,
                         "alleyway"               => 9880,
                         "alligators"             => 11441,
                         "alliteration"           => 19132,
                         "allora"                 => 19131,
                         "allowance"              => 3852,
                         "allowances"             => 9879,
                         "allright"               => 3133,
                         "allspice"               => 13913,
                         "alluring"               => 11860,
                         "allus"                  => 17702,
                         "ally"                   => 2428,
                         "almighty"               => 3422,
                         "almonds"                => 7070,
                         "almost"                 => 354,
                         "alone"                  => 226,
                         "alonna"                 => 12762,
                         "aloof"                  => 9878,
                         "alotta"                 => 12314,
                         "aloud"                  => 6587,
                         "alouette"               => 19130,
                         "alpaca"                 => 17701,
                         "alpena"                 => 19129,
                         "alphabetize"            => 17700,
                         "alphabetized"           => 19128,
                         "already"                => 204,
                         "alright"                => 341,
                         "alrighty"               => 5931,
                         "alriiight"              => 19127,
                         "altar"                  => 2541,
                         "altercation"            => 8993,
                         "altering"               => 5874,
                         "alternapalooza"         => 17699,
                         "alternator"             => 15504,
                         "alters"                 => 8262,
                         "altogether"             => 3348,
                         "altruism"               => 17698,
                         "altruistic"             => 12313,
                         "alvah"                  => 17697,
                         "always"                 => 136,
                         "amalio"                 => 19126,
                         "amara"                  => 17696,
                         "amaretto"               => 16489,
                         "amaze"                  => 4983,
                         "amazed"                 => 3088,
                         "amazement"              => 13912,
                         "amazes"                 => 7540,
                         "amazing"                => 527,
                         "amazingly"              => 4874,
                         "amberg"                 => 11859,
                         "ambiance"               => 11440,
                         "ambience"               => 12761,
                         "ambition"               => 3622,
                         "ambitious"              => 3821,
                         "ambivalence"            => 19125,
                         "ambulance"              => 1526,
                         "ambulances"             => 10138,
                         "ambush"                 => 4476,
                         "ambushed"               => 6192,
                         "amen"                   => 1902,
                         "amenable"               => 13911,
                         "amends"                 => 4025,
                         "americano"              => 17695,
                         "amiable"                => 16488,
                         "amicable"               => 11858,
                         "amish"                  => 7539,
                         "amiss"                  => 10137,
                         "ammo"                   => 4203,
                         "amnesia"                => 2607,
                         "amnesiac"               => 17694,
                         "amnio"                  => 8106,
                         "amniocentesis"          => 17693,
                         "amniotic"               => 12760,
                         "amoral"                 => 8778,
                         "amorous"                => 11439,
                         "ampata"                 => 9388,
                         "amped"                  => 11857,
                         "amphetamines"           => 15503,
                         "ampicillin"             => 15502,
                         "ample"                  => 6255,
                         "amply"                  => 15501,
                         "ampule"                 => 11065,
                         "amputate"               => 12312,
                         "amputation"             => 14659,
                         "amscray"                => 19124,
                         "amuck"                  => 17692,
                         "amulet"                 => 3561,
                         "amulets"                => 13340,
                         "amuse"                  => 5873,
                         "amused"                 => 5705,
                         "amusement"              => 4798,
                         "amuses"                 => 11856,
                         "amusing"                => 2540,
                         "amway"                  => 17691,
                         "anachronism"            => 16487,
                         "anacott"                => 12759,
                         "anaesthetic"            => 11438,
                         "anago"                  => 10732,
                         "anagram"                => 14658,
                         "analogy"                => 7069,
                         "analyze"                => 3851,
                         "analyzing"              => 6049,
                         "anaphylactic"           => 19123,
                         "anatomically"           => 16486,
                         "anchorman"              => 13910,
                         "anchovies"              => 11064,
                         "andale"                 => 17690,
                         "andersons"              => 14657,
                         "andie"                  => 1752,
                         "andolini"               => 17689,
                         "androscoggin"           => 17688,
                         "anecdote"               => 8777,
                         "anemia"                 => 5650,
                         "anemic"                 => 10731,
                         "anesthesia"             => 5872,
                         "anesthesiologist"       => 13339,
                         "anesthesiology"         => 16485,
                         "anesthetic"             => 8992,
                         "anesthetics"            => 19122,
                         "anesthetist"            => 17687,
                         "aneurysm"               => 6956,
                         "anger"                  => 1325,
                         "angina"                 => 10136,
                         "angio"                  => 15500,
                         "angiogram"              => 11437,
                         "angioplasty"            => 15499,
                         "angleman"               => 17686,
                         "angling"                => 8991,
                         "anglos"                 => 17685,
                         "angora"                 => 12758,
                         "angrier"                => 6751,
                         "angry"                  => 601,
                         "angst"                  => 6405,
                         "anguish"                => 6485,
                         "anguished"              => 15498,
                         "animosity"              => 6855,
                         "anini"                  => 14656,
                         "anise"                  => 11436,
                         "ankle"                  => 2606,
                         "ankles"                 => 4760,
                         "annihilate"             => 11435,
                         "anniversaries"          => 9629,
                         "announce"               => 2436,
                         "announcement"           => 2272,
                         "annoy"                  => 4914,
                         "annoyance"              => 10730,
                         "annoyances"             => 16484,
                         "annoyed"                => 4835,
                         "annoying"               => 1827,
                         "annoyingly"             => 12311,
                         "annoys"                 => 11063,
                         "annul"                  => 11855,
                         "annulled"               => 4390,
                         "annulment"              => 1908,
                         "annyong"                => 13909,
                         "anoint"                 => 15497,
                         "anointed"               => 7068,
                         "anomaly"                => 7668,
                         "anonymity"              => 8261,
                         "anonymous"              => 2458,
                         "anonymously"            => 9628,
                         "anorexia"               => 14655,
                         "anorexic"               => 15496,
                         "ansel"                  => 11854,
                         "anspaugh"               => 19121,
                         "answer"                 => 356,
                         "answered"               => 1603,
                         "answering"              => 1651,
                         "answers"                => 978,
                         "antacid"                => 11853,
                         "antagonistic"           => 12757,
                         "antagonize"             => 8990,
                         "antagonizing"           => 14654,
                         "antar"                  => 17684,
                         "antibiotic"             => 6955,
                         "antibiotics"            => 3725,
                         "antibodies"             => 6854,
                         "antichrist"             => 15495,
                         "anticipate"             => 4913,
                         "anticipating"           => 7824,
                         "anticipation"           => 5407,
                         "anticlimactic"          => 17683,
                         "antics"                 => 7067,
                         "antidepressants"        => 12310,
                         "antidote"               => 3850,
                         "antihistamine"          => 13338,
                         "antihistamines"         => 16483,
                         "antin"                  => 19120,
                         "antiquated"             => 10431,
                         "antique"                => 3362,
                         "antiques"               => 5092,
                         "antiquing"              => 12309,
                         "antiseptic"             => 9196,
                         "antisocial"             => 14653,
                         "antivenin"              => 15494,
                         "antlers"                => 9877,
                         "ants"                   => 4071,
                         "antsy"                  => 8105,
                         "anvil"                  => 12308,
                         "anwar"                  => 6048,
                         "anxieties"              => 17682,
                         "anxiety"                => 3337,
                         "anxious"                => 1668,
                         "anxiously"              => 12756,
                         "any"                    => 95,
                         "anyanka"                => 10729,
                         "anybody"                => 340,
                         "anybody'd"              => 17681,
                         "anyhoo"                 => 10430,
                         "anyhow"                 => 2385,
                         "anymore"                => 288,
                         "anyone"                 => 265,
                         "anyplace"               => 3930,
                         "anythin"                => 9627,
                         "anything"               => 92,
                         "anythng"                => 15493,
                         "anytime"                => 1231,
                         "anyway"                 => 273,
                         "anyways"                => 2457,
                         "anywhere"               => 478,
                         "aorta"                  => 9387,
                         "apart"                  => 676,
                         "apartment"              => 573,
                         "apathetic"              => 17680,
                         "aphrodisiac"            => 8411,
                         "apiece"                 => 5589,
                         "aplastic"               => 6750,
                         "apocalypse"             => 5355,
                         "apologetic"             => 13337,
                         "apologies"              => 2728,
                         "apologise"              => 4245,
                         "apologising"            => 13908,
                         "apologize"              => 756,
                         "apologized"             => 2797,
                         "apologizes"             => 10429,
                         "apologizing"            => 2941,
                         "apology"                => 1324,
                         "apophis"                => 3894,
                         "apostrophe"             => 11852,
                         "apothecary"             => 9195,
                         "appalled"               => 5930,
                         "appalling"              => 5453,
                         "apparently"             => 775,
                         "apparition"             => 12755,
                         "appealing"              => 4095,
                         "appease"                => 8410,
                         "appeased"               => 19119,
                         "appendage"              => 11851,
                         "appendectomy"           => 13336,
                         "appendicitis"           => 12754,
                         "appendix"               => 7066,
                         "apperantly"             => 8590,
                         "appetit"                => 13335,
                         "appetite"               => 2379,
                         "appetites"              => 10135,
                         "appetizer"              => 6191,
                         "appetizers"             => 7065,
                         "appetizing"             => 14652,
                         "applaud"                => 5452,
                         "applauding"             => 12307,
                         "applause"               => 4218,
                         "applejack"              => 11062,
                         "appliance"              => 8104,
                         "appointment"            => 1145,
                         "appointments"           => 3421,
                         "appraise"               => 19118,
                         "appraised"              => 9876,
                         "appraiser"              => 17679,
                         "appreciate"             => 519,
                         "appreciated"            => 2985,
                         "appreciates"            => 3541,
                         "appreciating"           => 9875,
                         "appreciation"           => 3322,
                         "appreciative"           => 6954,
                         "apprehend"              => 8776,
                         "apprehended"            => 6484,
                         "apprehension"           => 12306,
                         "apprehensive"           => 15492,
                         "apprised"               => 15491,
                         "approaching"            => 3465,
                         "appropriate"            => 1758,
                         "approve"                => 1996,
                         "approves"               => 9194,
                         "apricots"               => 13907,
                         "apron"                  => 4518,
                         "aprons"                 => 15490,
                         "apropos"                => 15489,
                         "aptitude"               => 7538,
                         "aptly"                  => 14651,
                         "arachnids"              => 14650,
                         "arachtoids"             => 15488,
                         "arbitrator"             => 8989,
                         "archenemy"              => 19117,
                         "archway"                => 13906,
                         "aren't"                 => 290,
                         "argh"                   => 4358,
                         "argon"                  => 5507,
                         "argue"                  => 1410,
                         "arguillo"               => 13905,
                         "arguing"                => 1822,
                         "argument"               => 1455,
                         "argumentative"          => 12753,
                         "aright"                 => 19116,
                         "arintero"               => 17678,
                         "arlyn"                  => 9193,
                         "armadillo"              => 9874,
                         "armbrust"               => 10728,
                         "armchair"               => 14649,
                         "arming"                 => 11434,
                         "armoire"                => 9626,
                         "armpit"                 => 9625,
                         "armpits"                => 11433,
                         "arms"                   => 812,
                         "arnie"                  => 5133,
                         "arnon"                  => 12305,
                         "aroma"                  => 8103,
                         "aromatherapy"           => 9624,
                         "aroun"                  => 11432,
                         "around"                 => 130,
                         "arouse"                 => 11061,
                         "aroused"                => 6853,
                         "arousing"               => 8988,
                         "arquillians"            => 19115,
                         "arraigned"              => 8260,
                         "arraignment"            => 4389,
                         "arrange"                => 1907,
                         "arrangements"           => 1794,
                         "arranging"              => 5871,
                         "arrest"                 => 847,
                         "arrested"               => 993,
                         "arresting"              => 3464,
                         "arrhythmia"             => 8987,
                         "arrive"                 => 2120,
                         "arrivederci"            => 13334,
                         "arrogance"              => 5091,
                         "arrogant"               => 2615,
                         "arroway"                => 7178,
                         "arrowhead"              => 11850,
                         "arroz"                  => 16482,
                         "arsenic"                => 8589,
                         "arses"                  => 17677,
                         "arson"                  => 2691,
                         "arsonist"               => 5180,
                         "artemus"                => 17676,
                         "arteries"               => 7667,
                         "artery"                 => 4158,
                         "artful"                 => 11431,
                         "artichoke"              => 11849,
                         "artichokes"             => 19114,
                         "articulate"             => 7295,
                         "artifact"               => 7419,
                         "artoo"                  => 5451,
                         "artsy"                  => 11430,
                         "arugula"                => 16481,
                         "arvin"                  => 4954,
                         "aryan"                  => 6404,
                         "aryans"                 => 12304,
                         "asalaam"                => 11060,
                         "asap"                   => 3478,
                         "asbestos"               => 6657,
                         "ascenscion"             => 12752,
                         "ascension"              => 5997,
                         "ascertain"              => 9386,
                         "aschen"                 => 8259,
                         "ashamed"                => 1365,
                         "ashes"                  => 2398,
                         "ashtray"                => 5354,
                         "ashtrays"               => 12303,
                         "aside"                  => 1209,
                         "asinine"                => 11059,
                         "ask"                    => 185,
                         "asked"                  => 325,
                         "askin"                  => 4202,
                         "asking"                 => 411,
                         "asks"                   => 1824,
                         "asleep"                 => 951,
                         "asparagus"              => 8775,
                         "asphyxiation"           => 12302,
                         "aspirin"                => 2633,
                         "aspirins"               => 12301,
                         "ass"                    => 465,
                         "assailant"              => 8409,
                         "assaulted"              => 4475,
                         "assaulting"             => 8102,
                         "assed"                  => 5704,
                         "assemble"               => 6114,
                         "assertive"              => 10727,
                         "assertiveness"          => 19113,
                         "asses"                  => 2723,
                         "assign"                 => 5090,
                         "assigning"              => 8774,
                         "assignment"             => 1553,
                         "assignments"            => 4070,
                         "assoc"                  => 14648,
                         "associating"            => 11848,
                         "assorted"               => 10134,
                         "assume"                 => 950,
                         "assuming"               => 1593,
                         "assumptions"            => 4834,
                         "assurance"              => 5649,
                         "assurances"             => 8258,
                         "assure"                 => 1532,
                         "assured"                => 2660,
                         "assuredly"              => 13333,
                         "assures"                => 8773,
                         "assuring"               => 12300,
                         "astaire"                => 13332,
                         "asthmatic"              => 14647,
                         "astonish"               => 17675,
                         "astonished"             => 10133,
                         "astonishing"            => 6953,
                         "astonishment"           => 16480,
                         "astound"                => 12299,
                         "astounded"              => 17674,
                         "astounding"             => 8101,
                         "astray"                 => 8408,
                         "astronaut"              => 5648,
                         "astronauts"             => 5752,
                         "astroturf"              => 19112,
                         "astute"                 => 7177,
                         "asunder"                => 12298,
                         "asystole"               => 19111,
                         "atcha"                  => 16479,
                         "atchoo"                 => 14646,
                         "athame"                 => 12297,
                         "atheists"               => 13331,
                         "athos"                  => 8588,
                         "ativan"                 => 12296,
                         "atley"                  => 14645,
                         "atone"                  => 9192,
                         "atreus"                 => 17673,
                         "atrocious"              => 12295,
                         "atrocity"               => 14644,
                         "atrophied"              => 19110,
                         "atrophy"                => 14643,
                         "atropine"               => 10726,
                         "attaboy"                => 6952,
                         "attach"                 => 5929,
                         "attachments"            => 10428,
                         "attacker"               => 6749,
                         "attagirl"               => 19109,
                         "atten"                  => 16478,
                         "attendant"              => 4982,
                         "attendants"             => 6951,
                         "attention"              => 660,
                         "attentions"             => 12294,
                         "attentive"              => 6852,
                         "attest"                 => 10427,
                         "attic"                  => 1737,
                         "attics"                 => 17672,
                         "attired"                => 19108,
                         "attitude"               => 1120,
                         "attorney"               => 820,
                         "attorneys"              => 3396,
                         "attracted"              => 1722,
                         "attractive"             => 1409,
                         "attuned"                => 13330,
                         "aubyn"                  => 19107,
                         "auction"                => 2374,
                         "auctioneer"             => 16477,
                         "auctioning"             => 15487,
                         "audacity"               => 7823,
                         "audiotape"              => 16476,
                         "audited"                => 11058,
                         "audition"               => 2043,
                         "auditioning"            => 5703,
                         "auditions"              => 4572,
                         "aught"                  => 19106,
                         "augie"                  => 13904,
                         "augustino"              => 14642,
                         "aunt"                   => 674,
                         "auntie"                 => 4177,
                         "aunties"                => 11847,
                         "aunts"                  => 2871,
                         "aunty"                  => 17671,
                         "auras"                  => 13329,
                         "auster"                 => 8257,
                         "austero"                => 17670,
                         "authentic"              => 4388,
                         "authenticate"           => 19105,
                         "authoritah"             => 15486,
                         "authorization"          => 4571,
                         "authorize"              => 6113,
                         "authorizes"             => 17669,
                         "autograph"              => 3056,
                         "autographed"            => 6950,
                         "autographs"             => 7986,
                         "automatics"             => 19104,
                         "autopilot"              => 9385,
                         "autopsies"              => 11846,
                         "autopsy"                => 3004,
                         "avanya"                 => 4157,
                         "avenge"                 => 6483,
                         "avenged"                => 11845,
                         "avenging"               => 9623,
                         "averse"                 => 16475,
                         "aversion"               => 10132,
                         "avert"                  => 9191,
                         "averted"                => 9873,
                         "aviary"                 => 17668,
                         "aviva"                  => 7666,
                         "avoid"                  => 1273,
                         "avoiding"               => 1991,
                         "await"                  => 6851,
                         "awaiting"               => 5089,
                         "awaits"                 => 4474,
                         "awake"                  => 1249,
                         "awaken"                 => 8407,
                         "awakened"               => 6656,
                         "awakes"                 => 19103,
                         "aware"                  => 987,
                         "away"                   => 120,
                         "aways"                  => 19102,
                         "awful"                  => 768,
                         "awfully"                => 1581,
                         "awhile"                 => 1492,
                         "awkward"                => 1626,
                         "awkwardly"              => 13328,
                         "awkwardness"            => 10426,
                         "awning"                 => 13903,
                         "awoke"                  => 11429,
                         "awright"                => 3830,
                         "awww"                   => 3494,
                         "awwwk"                  => 19101,
                         "awwww"                  => 8772,
                         "awwwww"                 => 17667,
                         "azkaban"                => 17666,
                         "aztreonam"              => 15485,
                         "b'fore"                 => 19100,
                         "baaad"                  => 19099,
                         "baako"                  => 15484,
                         "babak"                  => 10425,
                         "babble"                 => 6850,
                         "babbling"               => 3370,
                         "babies"                 => 1094,
                         "babish"                 => 10725,
                         "baboons"                => 16474,
                         "baby"                   => 165,
                         "baby'd"                 => 19098,
                         "babying"                => 17665,
                         "babysat"                => 16473,
                         "babysit"                => 5996,
                         "babysitter"             => 3025,
                         "babysitters"            => 10131,
                         "babysitting"            => 3953,
                         "bacarra"                => 11844,
                         "baccarat"               => 13902,
                         "bachelorette"           => 6190,
                         "bachelors"              => 8771,
                         "back"                   => 56,
                         "backdraft"              => 14641,
                         "backers"                => 9622,
                         "backfire"               => 4517,
                         "backfired"              => 4516,
                         "backfires"              => 10424,
                         "backfiring"             => 11843,
                         "backgammon"             => 15483,
                         "backhand"               => 12751,
                         "backin"                 => 17664,
                         "backlog"                => 17663,
                         "backpack"               => 3584,
                         "backpacking"            => 8986,
                         "backpacks"              => 12293,
                         "backroom"               => 16472,
                         "backs"                  => 2682,
                         "backseat"               => 5219,
                         "backside"               => 6482,
                         "backslide"              => 19097,
                         "backstabber"            => 13901,
                         "backstabbing"           => 7418,
                         "backstage"              => 3603,
                         "backstreet"             => 13327,
                         "backtrack"              => 14640,
                         "backup"                 => 1806,
                         "backups"                => 11057,
                         "backwards"              => 2163,
                         "backwater"              => 14639,
                         "backyard"               => 3261,
                         "bactine"                => 15482,
                         "bad"                    => 153,
                         "badda"                  => 15481,
                         "badder"                 => 15480,
                         "badenweiler"            => 12750,
                         "badge"                  => 1754,
                         "badgered"               => 13326,
                         "badgering"              => 5406,
                         "badges"                 => 6849,
                         "badly"                  => 1188,
                         "badmouth"               => 9621,
                         "badmouthing"            => 9384,
                         "badness"                => 11428,
                         "baerly"                 => 17662,
                         "baffled"                => 10423,
                         "baffles"                => 16471,
                         "baffling"               => 15479,
                         "bagel"                  => 4570,
                         "baggage"                => 3075,
                         "bagged"                 => 6655,
                         "bagging"                => 8256,
                         "baggoli"                => 11427,
                         "baggy"                  => 10130,
                         "bagman"                 => 16470,
                         "bags"                   => 1448,
                         "bahamas"                => 4608,
                         "bail"                   => 1327,
                         "bailed"                 => 3074,
                         "bailiff"                => 5702,
                         "bailiffs"               => 19096,
                         "bailing"                => 4094,
                         "bailout"                => 13900,
                         "bails"                  => 13325,
                         "bait"                   => 2285,
                         "baited"                 => 12749,
                         "baiting"                => 7417,
                         "bake"                   => 2950,
                         "baked"                  => 2796,
                         "bakery"                 => 4357,
                         "bakes"                  => 12292,
                         "baking"                 => 4050,
                         "baklava"                => 10422,
                         "bakshi"                 => 13324,
                         "balance"                => 1870,
                         "balcony"                => 2421,
                         "bald"                   => 2507,
                         "balding"                => 10421,
                         "baldness"               => 10129,
                         "balled"                 => 12748,
                         "ballerina"              => 7665,
                         "ballgame"               => 7416,
                         "ballistic"              => 3849,
                         "ballistics"             => 7176,
                         "ballpark"               => 6047,
                         "ballplayer"             => 8255,
                         "ballplayers"            => 16469,
                         "ballpoint"              => 15478,
                         "ballroom"               => 4833,
                         "ballsy"                 => 15477,
                         "balmoral"               => 13323,
                         "balmy"                  => 9620,
                         "baloney"                => 5353,
                         "balraj"                 => 7822,
                         "balsom"                 => 3227,
                         "baltar"                 => 16468,
                         "balthazar"              => 13322,
                         "baltus"                 => 13899,
                         "bambang"                => 16467,
                         "bamboozled"             => 10420,
                         "banal"                  => 12291,
                         "banality"               => 16466,
                         "bandage"                => 5088,
                         "bandaged"               => 17661,
                         "bandages"               => 4638,
                         "bandanna"               => 14638,
                         "bandwagon"              => 11842,
                         "banek"                  => 15476,
                         "banged"                 => 5056,
                         "bangin"                 => 13898,
                         "banging"                => 3477,
                         "bangler"                => 16465,
                         "bangles"                => 16464,
                         "bania"                  => 8587,
                         "banish"                 => 6848,
                         "banished"               => 5506,
                         "bankbooks"              => 10724,
                         "bankroll"               => 8586,
                         "bankrolled"             => 15475,
                         "bankrolling"            => 17660,
                         "bankrupt"               => 4420,
                         "bankrupted"             => 19095,
                         "banky"                  => 10128,
                         "bannish"                => 15474,
                         "banquet"                => 4912,
                         "banter"                 => 6333,
                         "banya"                  => 13321,
                         "baptism"                => 5019,
                         "baptize"                => 13320,
                         "baptized"               => 5647,
                         "bar"                    => 664,
                         "baracus"                => 12290,
                         "barbarians"             => 8985,
                         "barbaric"               => 7821,
                         "barbas"                 => 8984,
                         "barbatus"               => 19094,
                         "barbecue"               => 2711,
                         "barbecued"              => 11841,
                         "barbecues"              => 11840,
                         "barbecuing"             => 14637,
                         "barbella"               => 17659,
                         "barbeque"               => 13897,
                         "barbers"                => 19093,
                         "barbershop"             => 6403,
                         "barboni"                => 13896,
                         "barbrady"               => 4797,
                         "barbs"                  => 19092,
                         "barch"                  => 14636,
                         "barcode"                => 6847,
                         "barcodes"               => 14635,
                         "bare"                   => 2435,
                         "bared"                  => 12289,
                         "barely"                 => 1011,
                         "baretta"                => 16463,
                         "barfed"                 => 11056,
                         "barfing"                => 15473,
                         "bargain"                => 2004,
                         "bargained"              => 5870,
                         "bargaining"             => 4674,
                         "bargains"               => 9872,
                         "barge"                  => 3205,
                         "barged"                 => 5555,
                         "barging"                => 4324,
                         "bark"                   => 3643,
                         "barked"                 => 16462,
                         "barkeep"                => 8406,
                         "barkin"                 => 16461,
                         "barking"                => 4217,
                         "barmaid"                => 12288,
                         "barn"                   => 1783,
                         "barnacle"               => 16460,
                         "barneys"                => 19091,
                         "barnyard"               => 11055,
                         "barometer"              => 12747,
                         "barrel"                 => 2812,
                         "barreled"               => 13895,
                         "barreling"              => 13319,
                         "barren"                 => 7537,
                         "barrenger"              => 8770,
                         "barricade"              => 11426,
                         "barricaded"             => 12746,
                         "barricades"             => 11839,
                         "barring"                => 6654,
                         "barrington"             => 3286,
                         "barringtons"            => 19090,
                         "barroom"                => 16459,
                         "barrytown"              => 19089,
                         "bars"                   => 1437,
                         "barstool"               => 11838,
                         "bartender"              => 2195,
                         "bartenders"             => 9871,
                         "bartending"             => 10723,
                         "bartlet"                => 2722,
                         "barto"                  => 4673,
                         "barts"                  => 10722,
                         "barzini"                => 11054,
                         "baseballs"              => 17658,
                         "baseless"               => 15472,
                         "basement"               => 1373,
                         "basements"              => 16458,
                         "baser"                  => 17657,
                         "bashed"                 => 10419,
                         "bashing"                => 7664,
                         "basically"              => 1257,
                         "basics"                 => 4953,
                         "basing"                 => 9190,
                         "basketballs"            => 16457,
                         "baskets"                => 6748,
                         "basking"                => 11053,
                         "basquiat"               => 12745,
                         "bassinet"               => 11052,
                         "bastards"               => 2070,
                         "baste"                  => 12744,
                         "bastille"               => 11837,
                         "batak"                  => 17656,
                         "batch"                  => 3420,
                         "bath"                   => 1471,
                         "bathe"                  => 6846,
                         "bathed"                 => 6845,
                         "bathes"                 => 17655,
                         "bathing"                => 3321,
                         "bathrobe"               => 6112,
                         "bathrobes"              => 16456,
                         "bathroom"               => 885,
                         "bathrooms"              => 5087,
                         "baths"                  => 5646,
                         "bathtub"                => 4156,
                         "batmobile"              => 14634,
                         "batter"                 => 5818,
                         "battered"               => 7294,
                         "batteries"              => 3125,
                         "battering"              => 12743,
                         "battleground"           => 16455,
                         "battling"               => 5405,
                         "bauble"                 => 16454,
                         "baubles"                => 16453,
                         "baudelaire"             => 9870,
                         "baudelaires"            => 13894,
                         "baudouin"               => 19088,
                         "bauers"                 => 7293,
                         "bawdy"                  => 13318,
                         "bawling"                => 10721,
                         "baxworth"               => 15471,
                         "bayberry"               => 10418,
                         "bazillion"              => 19087,
                         "be"                     => 18,
                         "beached"                => 14633,
                         "beachfront"             => 17654,
                         "beacon"                 => 2539,
                         "beaded"                 => 16452,
                         "beads"                  => 5404,
                         "beady"                  => 9869,
                         "beakers"                => 19086,
                         "beamed"                 => 11836,
                         "beaming"                => 11425,
                         "beans"                  => 2136,
                         "beanstalk"              => 9868,
                         "bearable"               => 7985,
                         "bearded"                => 8769,
                         "beards"                 => 8983,
                         "bearer"                 => 5450,
                         "bearings"               => 7536,
                         "beastly"                => 17653,
                         "beasts"                 => 6481,
                         "beat"                   => 650,
                         "beatin"                 => 8982,
                         "beating"                => 1579,
                         "beatings"               => 10417,
                         "beatnik"                => 11424,
                         "beats"                  => 1846,
                         "beattle"                => 15470,
                         "beaucoup"               => 8405,
                         "beaudine"               => 17652,
                         "beaujolais"             => 15469,
                         "beaute"                 => 17651,
                         "beauties"               => 7292,
                         "beautiful"              => 299,
                         "beautifully"            => 3463,
                         "beaverhausen"           => 19085,
                         "becau"                  => 19084,
                         "because"                => 67,
                         "beckoning"              => 17650,
                         "beckons"                => 16451,
                         "beckworth"              => 10127,
                         "becuase"                => 12287,
                         "bed"                    => 371,
                         "bedbugs"                => 12286,
                         "bedded"                 => 13893,
                         "bedding"                => 9619,
                         "beddy"                  => 15468,
                         "bedevere"               => 16450,
                         "bedpan"                 => 8768,
                         "bedpans"                => 11051,
                         "bedpost"                => 13892,
                         "bedridden"              => 16449,
                         "bedroom"                => 954,
                         "bedrooms"               => 4201,
                         "beds"                   => 3347,
                         "bedsheets"              => 17649,
                         "bedside"                => 3952,
                         "bedspread"              => 13317,
                         "bedtime"                => 3098,
                         "beechwood"              => 19083,
                         "beef"                   => 1931,
                         "beefed"                 => 16448,
                         "beefs"                  => 19082,
                         "beelzebub"              => 16447,
                         "beenie"                 => 19081,
                         "beens"                  => 13316,
                         "beep"                   => 3034,
                         "beeped"                 => 7984,
                         "beeper"                 => 5018,
                         "beepers"                => 16446,
                         "beeping"                => 9867,
                         "beeps"                  => 10720,
                         "bees"                   => 4024,
                         "beeswax"                => 11423,
                         "beethoven"              => 4981,
                         "befall"                 => 11422,
                         "befitting"              => 16445,
                         "beforehand"             => 6844,
                         "befriend"               => 13891,
                         "begat"                  => 12742,
                         "begbie"                 => 11835,
                         "begets"                 => 16444,
                         "beggar"                 => 11834,
                         "beggars"                => 8585,
                         "begged"                 => 2015,
                         "beggin"                 => 11421,
                         "begging"                => 1474,
                         "begin"                  => 863,
                         "begining"               => 19080,
                         "beginnin"               => 19079,
                         "begone"                 => 17648,
                         "begrudge"               => 10126,
                         "behave"                 => 2053,
                         "behaved"                => 4244,
                         "behaves"                => 9618,
                         "behaving"               => 3929,
                         "behavior"               => 1192,
                         "beheading"              => 11833,
                         "behind"                 => 379,
                         "behinds"                => 17647,
                         "behold"                 => 3434,
                         "beholden"               => 14632,
                         "behoove"                => 13890,
                         "behooves"               => 15467,
                         "behrani"                => 9617,
                         "behrle"                 => 19078,
                         "beige"                  => 6949,
                         "beikoku"                => 13315,
                         "bein"                   => 3097,
                         "beings"                 => 2836,
                         "bela"                   => 3928,
                         "belabor"                => 15466,
                         "belated"                => 13314,
                         "belching"               => 14631,
                         "beleaguered"            => 19077,
                         "belie"                  => 19076,
                         "believable"             => 4515,
                         "believe"                => 121,
                         "believer"               => 4873,
                         "believes"               => 1561,
                         "believing"              => 1709,
                         "belittle"               => 10719,
                         "belittling"             => 17646,
                         "belive"                 => 13313,
                         "bellboy"                => 8404,
                         "bellboys"               => 17645,
                         "bellerophon"            => 11050,
                         "bellhop"                => 9866,
                         "bellhops"               => 19075,
                         "bellied"                => 9616,
                         "bellies"                => 10125,
                         "belligerent"            => 11420,
                         "belloq"                 => 16443,
                         "bellowing"              => 14630,
                         "bells"                  => 2577,
                         "belly"                  => 2390,
                         "bellyaching"            => 19074,
                         "bellybutton"            => 15465,
                         "belong"                 => 930,
                         "belongings"             => 4796,
                         "belongs"                => 1288,
                         "beloved"                => 2340,
                         "belt"                   => 1718,
                         "belted"                 => 11419,
                         "belthazor"              => 3395,
                         "belts"                  => 4569,
                         "belus"                  => 16442,
                         "belushi"                => 17644,
                         "belvedere"              => 10124,
                         "bembe"                  => 19073,
                         "benatar"                => 15464,
                         "bench"                  => 2179,
                         "benched"                => 15463,
                         "benching"               => 19072,
                         "benchley"               => 19071,
                         "bend"                   => 2314,
                         "bended"                 => 12741,
                         "bendiga"                => 17643,
                         "bending"                => 5179,
                         "bends"                  => 7535,
                         "bendy"                  => 13312,
                         "beneath"                => 2356,
                         "benefactor"             => 7415,
                         "beneficiary"            => 9189,
                         "benefit"                => 1511,
                         "benegas"                => 17642,
                         "benes"                  => 5132,
                         "benet"                  => 10123,
                         "benevolence"            => 15462,
                         "benevolent"             => 7534,
                         "benign"                 => 5588,
                         "benjamins"              => 15461,
                         "bennetts"               => 6747,
                         "bent"                   => 2348,
                         "bentonville"            => 19070,
                         "bequeath"               => 13889,
                         "berate"                 => 13311,
                         "berating"               => 13310,
                         "bereaved"               => 14629,
                         "bereavement"            => 19069,
                         "bereft"                 => 13309,
                         "berenson"               => 16441,
                         "beret"                  => 8584,
                         "berkshires"             => 15460,
                         "berlini"                => 8981,
                         "berluti"                => 8583,
                         "bermuda"                => 1835,
                         "bernece"                => 19068,
                         "bernheim"               => 17641,
                         "berries"                => 4832,
                         "berrisford"             => 13308,
                         "beryllium"              => 11832,
                         "beseech"                => 7820,
                         "beside"                 => 2014,
                         "besides"                => 522,
                         "besmirch"               => 19067,
                         "besotted"               => 17640,
                         "bested"                 => 11831,
                         "bestest"                => 11418,
                         "bestow"                 => 11049,
                         "bet"                    => 427,
                         "betadine"               => 16440,
                         "betas"                  => 13888,
                         "betaseron"              => 19066,
                         "betcha"                 => 4129,
                         "bethie"                 => 6948,
                         "bethy"                  => 6653,
                         "betray"                 => 2104,
                         "betrayal"               => 2940,
                         "betrayals"              => 11048,
                         "betrayed"               => 1538,
                         "betrayer"               => 10718,
                         "betraying"              => 4093,
                         "betrays"                => 11830,
                         "bets"                   => 3320,
                         "better"                 => 117,
                         "better'n"               => 9615,
                         "betterton"              => 10717,
                         "bettin"                 => 15459,
                         "betting"                => 3096,
                         "beususe"                => 19065,
                         "beverage"               => 4952,
                         "beware"                 => 3692,
                         "bewildered"             => 13887,
                         "bewitched"              => 7533,
                         "beyond"                 => 1002,
                         "bfast"                  => 15458,
                         "bfmid"                  => 15457,
                         "bhamra"                 => 12740,
                         "bialy"                  => 12739,
                         "bialystock"             => 7663,
                         "bianchinni"             => 16439,
                         "biased"                 => 7819,
                         "bibles"                 => 7818,
                         "bicentennial"           => 8980,
                         "bicep"                  => 14628,
                         "bicker"                 => 13307,
                         "bickering"              => 6480,
                         "bicuspids"              => 19064,
                         "bidder"                 => 5449,
                         "bidding"                => 3451,
                         "bidet"                  => 17639,
                         "biding"                 => 11047,
                         "biebe"                  => 11046,
                         "big"                    => 142,
                         "big'uns"                => 17638,
                         "bigamist"               => 11045,
                         "bigamy"                 => 7983,
                         "bigboote"               => 13886,
                         "bigger"                 => 961,
                         "biggest"                => 1026,
                         "bigglesworth"           => 19063,
                         "biggly"                 => 16438,
                         "bigot"                  => 11417,
                         "bigoted"                => 14627,
                         "bigotry"                => 12738,
                         "bijan"                  => 14626,
                         "bijou"                  => 7532,
                         "bike"                   => 1311,
                         "bikes"                  => 4735,
                         "bikinis"                => 8100,
                         "bilge"                  => 19062,
                         "bilked"                 => 17637,
                         "billable"               => 13885,
                         "billboards"             => 10416,
                         "billing"                => 5928,
                         "billionaire"            => 6254,
                         "billionaires"           => 13306,
                         "billions"               => 4419,
                         "biloxi"                 => 16437,
                         "biltmore"               => 17636,
                         "bimbos"                 => 11044,
                         "bimmel"                 => 16436,
                         "bind"                   => 4269,
                         "binge"                  => 7175,
                         "bings"                  => 15456,
                         "binks"                  => 9614,
                         "binoculars"             => 6189,
                         "binturong"              => 13884,
                         "biocyte"                => 11829,
                         "biodegradable"          => 17635,
                         "bioethics"              => 14625,
                         "biogenetics"            => 19061,
                         "biological"             => 1810,
                         "biologically"           => 7817,
                         "biometric"              => 14624,
                         "biopsy"                 => 4447,
                         "bipartisan"             => 11043,
                         "bipartisanship"         => 17634,
                         "bippy"                  => 19060,
                         "birdbrain"              => 17633,
                         "birdseed"               => 16435,
                         "birdson"                => 15455,
                         "birkhead"               => 10122,
                         "birthday"               => 626,
                         "birthdays"              => 4911,
                         "birthing"               => 8099,
                         "birthmark"              => 11416,
                         "birthright"             => 6253,
                         "biscotti"               => 8254,
                         "biscuits"               => 5309,
                         "bisque"                 => 10415,
                         "bistro"                 => 7531,
                         "bit"                    => 316,
                         "bitchin"                => 6332,
                         "bitching"               => 7530,
                         "bite"                   => 1051,
                         "biter"                  => 14623,
                         "bites"                  => 3361,
                         "biting"                 => 3724,
                         "bits"                   => 2822,
                         "bitsy"                  => 8979,
                         "bitte"                  => 19059,
                         "bitten"                 => 4418,
                         "bitter"                 => 2030,
                         "bitterness"             => 5352,
                         "bittersweet"            => 9865,
                         "bitty"                  => 5403,
                         "bizarre"                => 2062,
                         "bizarro"                => 8403,
                         "blabbed"                => 9188,
                         "blabbering"             => 17632,
                         "blabbermouth"           => 16434,
                         "blabbing"               => 7662,
                         "blabs"                  => 17631,
                         "blackballed"            => 17630,
                         "blackbeard"             => 19058,
                         "blackboard"             => 12737,
                         "blacked"                => 5817,
                         "blacken"                => 17629,
                         "blackened"              => 17628,
                         "blackest"               => 17627,
                         "blackface"              => 17626,
                         "blacking"               => 15454,
                         "blackmail"              => 1979,
                         "blackmailed"            => 3873,
                         "blackmailer"            => 6843,
                         "blackmailing"           => 2984,
                         "blackness"              => 11042,
                         "blackouts"              => 10414,
                         "bladder"                => 5017,
                         "bladders"               => 19057,
                         "blading"                => 16433,
                         "blah"                   => 1227,
                         "blainetologists"        => 16432,
                         "blame"                  => 570,
                         "blamed"                 => 2705,
                         "blameless"              => 8402,
                         "blames"                 => 3242,
                         "blaming"                => 1694,
                         "blanket"                => 1954,
                         "blankets"               => 3572,
                         "blankie"                => 12285,
                         "blankly"                => 19056,
                         "blanky"                 => 13883,
                         "blaring"                => 11041,
                         "blase"                  => 13305,
                         "blasphemous"            => 15453,
                         "blasphemy"              => 8978,
                         "blast"                  => 1830,
                         "blasted"                => 5351,
                         "blasting"               => 6586,
                         "blatant"                => 6652,
                         "blatantly"              => 12284,
                         "blather"                => 19055,
                         "blathering"             => 15452,
                         "blayne"                 => 12283,
                         "blazes"                 => 8401,
                         "blazing"                => 7816,
                         "bleached"               => 8767,
                         "bleachers"              => 8766,
                         "bleaching"              => 16431,
                         "bleak"                  => 5816,
                         "blech"                  => 14622,
                         "bleed"                  => 2678,
                         "bleeder"                => 10413,
                         "bleedin"                => 9187,
                         "bleeding"               => 1341,
                         "bleeds"                 => 6479,
                         "bleep"                  => 10412,
                         "bleeth"                 => 17625,
                         "blemish"                => 16430,
                         "blend"                  => 3571,
                         "bless"                  => 1605,
                         "blessings"              => 3691,
                         "blew"                   => 1069,
                         "blight"                 => 10716,
                         "blimey"                 => 11040,
                         "blimp"                  => 10411,
                         "blind"                  => 1100,
                         "blinded"                => 4910,
                         "blinders"               => 6331,
                         "blindfold"              => 5927,
                         "blindfolded"            => 8253,
                         "blinding"               => 5402,
                         "blindly"                => 6478,
                         "blindness"              => 7815,
                         "blinds"                 => 6477,
                         "blindsided"             => 7661,
                         "bling"                  => 7291,
                         "blink"                  => 3690,
                         "blinked"                => 7290,
                         "blinking"               => 5308,
                         "blinks"                 => 15451,
                         "blintzes"               => 13882,
                         "blips"                  => 16429,
                         "blissful"               => 11415,
                         "blissfully"             => 13304,
                         "blisters"               => 12736,
                         "blithely"               => 19054,
                         "blithering"             => 15450,
                         "bloat"                  => 17624,
                         "bloated"                => 6842,
                         "blockage"               => 11828,
                         "blockbusters"           => 19053,
                         "blocked"                => 2954,
                         "blockhead"              => 19052,
                         "blocking"               => 3570,
                         "blokes"                 => 8582,
                         "blond"                  => 2677,
                         "blood"                  => 428,
                         "bloodbath"              => 9864,
                         "blooded"                => 3689,
                         "bloodhound"             => 11414,
                         "bloodhounds"            => 14621,
                         "bloodied"               => 15449,
                         "bloodless"              => 12282,
                         "bloodline"              => 13303,
                         "bloodshed"              => 7660,
                         "bloodshot"              => 19051,
                         "bloodstained"           => 17623,
                         "bloodstains"            => 14620,
                         "bloodstream"            => 7982,
                         "bloodsucker"            => 10715,
                         "bloodsuckers"           => 17622,
                         "bloodsucking"           => 8765,
                         "bloodthirsty"           => 13881,
                         "bloodwork"              => 15448,
                         "bloody"                 => 1148,
                         "bloomers"               => 14619,
                         "blooming"               => 10714,
                         "blossomed"              => 15447,
                         "blossoming"             => 14618,
                         "blossoms"               => 10713,
                         "blotchy"                => 15446,
                         "blotter"                => 16428,
                         "blouse"                 => 3848,
                         "blouses"                => 17621,
                         "blow"                   => 692,
                         "blowback"               => 17620,
                         "blowed"                 => 15445,
                         "blowhard"               => 12735,
                         "blowin"                 => 8252,
                         "blowing"                => 1687,
                         "blown"                  => 1667,
                         "blowout"                => 7814,
                         "blows"                  => 2028,
                         "blowtorch"              => 16427,
                         "blowup"                 => 11413,
                         "blubbering"             => 7981,
                         "bludgeoned"             => 16426,
                         "bluebells"              => 19050,
                         "blueberries"            => 7980,
                         "blueberry"              => 4514,
                         "bluepoint"              => 7064,
                         "blueprint"              => 9186,
                         "blueprints"             => 5926,
                         "bluer"                  => 15444,
                         "bluest"                 => 19049,
                         "bluey"                  => 17619,
                         "bluff"                  => 3124,
                         "bluffing"               => 3095,
                         "blunder"                => 11827,
                         "blundering"             => 15443,
                         "blunders"               => 11826,
                         "bluntly"                => 14617,
                         "bluntman"               => 8400,
                         "blurb"                  => 11412,
                         "blurred"                => 10121,
                         "blurry"                 => 5995,
                         "blurt"                  => 6841,
                         "blurted"                => 8098,
                         "blurting"               => 11411,
                         "blush"                  => 4872,
                         "blushing"               => 4323,
                         "bluster"                => 13302,
                         "bluth"                  => 6746,
                         "bluuch"                 => 15442,
                         "boarded"                => 6111,
                         "boarding"               => 1995,
                         "boardinghouse"          => 15441,
                         "boardroom"              => 7813,
                         "boardwalk"              => 6476,
                         "boast"                  => 10410,
                         "boat"                   => 760,
                         "boathouse"              => 4699,
                         "boatload"               => 11039,
                         "bobbing"                => 10120,
                         "bobka"                  => 10409,
                         "bobunk"                 => 14616,
                         "bodega"                 => 8977,
                         "bodes"                  => 14615,
                         "bodhi"                  => 11825,
                         "bodily"                 => 5751,
                         "bodyguard"              => 3336,
                         "bodyguards"             => 5350,
                         "bogas"                  => 15440,
                         "bogeyman"               => 11410,
                         "bogged"                 => 13880,
                         "boggles"                => 16425,
                         "boggling"               => 10119,
                         "bogus"                  => 3055,
                         "bogyman"                => 13879,
                         "boil"                   => 3762,
                         "boiled"                 => 5994,
                         "boilerplate"            => 17618,
                         "boiling"                => 5086,
                         "boils"                  => 6188,
                         "boink"                  => 19048,
                         "boinked"                => 19047,
                         "bolder"                 => 16424,
                         "bolie"                  => 6046,
                         "bollo"                  => 19046,
                         "bolted"                 => 7174,
                         "bolting"                => 17617,
                         "bolts"                  => 5645,
                         "bomb"                   => 1136,
                         "bombarding"             => 19045,
                         "bombed"                 => 5644,
                         "bombosity"              => 17616,
                         "bombshell"              => 6252,
                         "bonbon"                 => 11038,
                         "bonbons"                => 14614,
                         "bonded"                 => 4607,
                         "bonding"                => 3016,
                         "bondsman"               => 16423,
                         "bone"                   => 1320,
                         "boned"                  => 8764,
                         "boneless"               => 19044,
                         "bonfire"                => 6840,
                         "boning"                 => 12734,
                         "bonnet"                 => 8581,
                         "bonsoir"                => 10408,
                         "bontecou"               => 8399,
                         "booby"                  => 5265,
                         "boogety"                => 10712,
                         "boogey"                 => 15439,
                         "boogeyman"              => 15438,
                         "boogida"                => 16422,
                         "booing"                 => 17615,
                         "booked"                 => 1880,
                         "bookends"               => 19043,
                         "bookies"                => 14613,
                         "booking"                => 5218,
                         "bookish"                => 15437,
                         "bookkeeper"             => 13301,
                         "bookkeeping"            => 13878,
                         "booklets"               => 15436,
                         "bookshelf"              => 16421,
                         "bookshelves"            => 19042,
                         "bookstore"              => 3761,
                         "bookstores"             => 9863,
                         "boom"                   => 1680,
                         "boomerang"              => 8976,
                         "boomhauer"              => 8251,
                         "booming"                => 9862,
                         "boonies"                => 15435,
                         "boooo"                  => 15434,
                         "boorish"                => 12281,
                         "boosh"                  => 14612,
                         "boost"                  => 3661,
                         "boosters"               => 11824,
                         "boosts"                 => 19041,
                         "boot"                   => 2596,
                         "booted"                 => 6402,
                         "booths"                 => 7812,
                         "bootlegs"               => 17614,
                         "booze"                  => 2298,
                         "boozing"                => 11823,
                         "bopping"                => 17613,
                         "boragora"               => 4568,
                         "borans"                 => 19040,
                         "bordello"               => 16420,
                         "borderline"             => 7289,
                         "bore"                   => 3024,
                         "borealis"               => 10407,
                         "bored"                  => 1540,
                         "boredom"                => 4637,
                         "bores"                  => 9383,
                         "borgnine"               => 17612,
                         "boring"                 => 1181,
                         "borrow"                 => 1316,
                         "borrowed"               => 2141,
                         "borrowing"              => 5055,
                         "bosom"                  => 6187,
                         "bosoms"                 => 17611,
                         "bosomy"                 => 19039,
                         "boss"                   => 745,
                         "bossa"                  => 16419,
                         "bossed"                 => 19038,
                         "bosses"                 => 4023,
                         "bossing"                => 10406,
                         "bossy"                  => 5264,
                         "botch"                  => 14611,
                         "botched"                => 6330,
                         "bother"                 => 733,
                         "bothered"               => 1975,
                         "botherin"               => 13877,
                         "bothering"              => 1353,
                         "bothers"                => 2237,
                         "botox"                  => 11822,
                         "botrelle"               => 11037,
                         "botticelli"             => 13876,
                         "bottle"                 => 1001,
                         "bottled"                => 4606,
                         "bottles"                => 2531,
                         "bottom"                 => 882,
                         "bottomed"               => 16418,
                         "bottomless"             => 8580,
                         "botulism"               => 12280,
                         "boudoir"                => 9613,
                         "bought"                 => 706,
                         "bounced"                => 5349,
                         "bouncers"               => 13875,
                         "bounces"                => 9612,
                         "bouncin"                => 17610,
                         "bouncing"               => 4005,
                         "bouncy"                 => 7979,
                         "bound"                  => 1675,
                         "boundless"              => 14610,
                         "bountiful"              => 17609,
                         "bouquet"                => 3560,
                         "bouquets"               => 11821,
                         "bourbon"                => 3910,
                         "bout"                   => 1137,
                         "boutique"               => 3285,
                         "boutonniere"            => 19037,
                         "boutros"                => 11409,
                         "bovary"                 => 13300,
                         "bowel"                  => 5554,
                         "bowels"                 => 7063,
                         "bowing"                 => 8763,
                         "bowline"                => 15433,
                         "box"                    => 683,
                         "boxed"                  => 7978,
                         "boxes"                  => 1933,
                         "boy"                    => 223,
                         "boycotting"             => 13874,
                         "boyfriend"              => 623,
                         "boyfriends"             => 3073,
                         "boyish"                 => 14609,
                         "boys"                   => 472,
                         "boys'd"                 => 19036,
                         "boys'll"                => 19035,
                         "boys're"                => 19034,
                         "boysenberry"            => 15432,
                         "bozos"                  => 8398,
                         "bra'tac"                => 9185,
                         "bracebridge"            => 12733,
                         "bracelet"               => 2116,
                         "bracelets"              => 7062,
                         "braces"                 => 5178,
                         "bracing"                => 12279,
                         "brackley"               => 11820,
                         "bradlee"                => 19033,
                         "bradys"                 => 8762,
                         "bradywood"              => 16417,
                         "brag"                   => 4268,
                         "braggart"               => 19032,
                         "bragged"                => 11408,
                         "braggin"                => 16416,
                         "bragging"               => 4473,
                         "brags"                  => 16415,
                         "braid"                  => 7977,
                         "braided"                => 13299,
                         "braiding"               => 16414,
                         "braids"                 => 13873,
                         "brained"                => 8397,
                         "brainer"                => 6045,
                         "brainiac"               => 11036,
                         "brainiest"              => 19031,
                         "brainless"              => 9382,
                         "brains"                 => 1615,
                         "brainstorm"             => 7173,
                         "brainstorming"          => 10405,
                         "brainwash"              => 11035,
                         "brainwashed"            => 5131,
                         "brainwashing"           => 8761,
                         "brainwaves"             => 19030,
                         "brainy"                 => 9861,
                         "braised"                => 14608,
                         "brakes"                 => 3510,
                         "brana"                  => 17608,
                         "brandies"               => 19029,
                         "brania"                 => 16413,
                         "brash"                  => 6585,
                         "braslow"                => 12278,
                         "brass"                  => 2771,
                         "brassiere"              => 11034,
                         "brassieres"             => 15431,
                         "brat"                   => 2488,
                         "brats"                  => 5925,
                         "bratty"                 => 14607,
                         "bratwurst"              => 16412,
                         "brava"                  => 7061,
                         "bravado"                => 10711,
                         "brave"                  => 1222,
                         "braved"                 => 19028,
                         "bravely"                => 11819,
                         "bravenet"               => 19027,
                         "braver"                 => 10118,
                         "bravest"                => 6186,
                         "brawl"                  => 6401,
                         "brawling"               => 14606,
                         "brays"                  => 15430,
                         "brazen"                 => 8760,
                         "breach"                 => 3642,
                         "breached"               => 8097,
                         "bread"                  => 1650,
                         "breadstick"             => 19026,
                         "breadwinner"            => 17607,
                         "break"                  => 326,
                         "breakable"              => 19025,
                         "breakdown"              => 2506,
                         "breakdowns"             => 12732,
                         "breakfast"              => 766,
                         "breakfasts"             => 9184,
                         "breakin"                => 6584,
                         "breaking"               => 944,
                         "breaks"                 => 1623,
                         "breakthroughs"          => 10710,
                         "breakup"                => 3723,
                         "breakups"               => 16411,
                         "brean"                  => 17606,
                         "breasted"               => 10404,
                         "breath"                 => 963,
                         "breathable"             => 15429,
                         "breathalyzer"           => 16410,
                         "breathe"                => 848,
                         "breathed"               => 7811,
                         "breather"               => 5177,
                         "breathes"               => 7659,
                         "breathin"               => 12277,
                         "breathing"              => 1214,
                         "breathless"             => 10403,
                         "breaths"                => 4294,
                         "breathtaking"           => 5815,
                         "brecher"                => 12731,
                         "breeher"                => 19024,
                         "breezes"                => 9611,
                         "breezing"               => 19023,
                         "brendell"               => 14605,
                         "brewed"                 => 10402,
                         "brewin"                 => 17605,
                         "brews"                  => 12276,
                         "brewskies"              => 16409,
                         "brewskis"               => 17604,
                         "briar"                  => 15428,
                         "briault"                => 8579,
                         "bribe"                  => 2568,
                         "bribed"                 => 5085,
                         "bribery"                => 7172,
                         "bribes"                 => 6475,
                         "bribing"                => 7060,
                         "bricked"                => 19022,
                         "bridal"                 => 3951,
                         "bride"                  => 1105,
                         "bridegroom"             => 13298,
                         "brides"                 => 6947,
                         "bridesmaid"             => 4216,
                         "bridesmaids"            => 5084,
                         "briefcase"              => 2522,
                         "briefcases"             => 19021,
                         "briefed"                => 6185,
                         "briefing"               => 3123,
                         "briefings"              => 16408,
                         "brighten"               => 7288,
                         "brighter"               => 4909,
                         "brightest"              => 4980,
                         "brilliance"             => 6583,
                         "brilliant"              => 1109,
                         "brilliantly"            => 7810,
                         "brimming"               => 13872,
                         "brimstone"              => 9381,
                         "bring"                  => 279,
                         "bringer"                => 14604,
                         "bringin"                => 8250,
                         "bringing"               => 881,
                         "brings"                 => 1174,
                         "brioche"                => 15427,
                         "brisk"                  => 9610,
                         "brisket"                => 13297,
                         "briskly"                => 19020,
                         "briss"                  => 15426,
                         "brit"                   => 4293,
                         "britches"               => 6946,
                         "brits"                  => 9609,
                         "brittle"                => 8096,
                         "broached"               => 17603,
                         "broaden"                => 9380,
                         "broads"                 => 7658,
                         "brobich"                => 14603,
                         "broccoli"               => 5924,
                         "brochure"               => 4672,
                         "brochures"              => 6329,
                         "brockovich"             => 10709,
                         "broda"                  => 15425,
                         "brodski"                => 11033,
                         "broflovski"             => 7287,
                         "brogna"                 => 11407,
                         "broiled"                => 15424,
                         "broiler"                => 19019,
                         "broke"                  => 555,
                         "broken"                 => 737,
                         "brokenhearted"          => 12730,
                         "brokers"                => 9379,
                         "brolin"                 => 16407,
                         "brolly"                 => 17602,
                         "bromden"                => 17601,
                         "bromly"                 => 16406,
                         "bronchial"              => 19018,
                         "bronchitis"             => 17600,
                         "bronck"                 => 13296,
                         "bronzed"                => 15423,
                         "bronzing"               => 19017,
                         "brooch"                 => 7529,
                         "brood"                  => 6651,
                         "brooding"               => 6839,
                         "broody"                 => 16405,
                         "brookline"              => 15422,
                         "brookside"              => 11032,
                         "brooms"                 => 12275,
                         "broomstick"             => 8396,
                         "broomsticks"            => 16404,
                         "broth"                  => 10117,
                         "brotha"                 => 13295,
                         "brothel"                => 8975,
                         "brother"                => 295,
                         "brotherly"              => 6945,
                         "brought"                => 402,
                         "brouhaha"               => 19016,
                         "browbeat"               => 12729,
                         "browbeating"            => 16403,
                         "brownies"               => 4951,
                         "brownout"               => 19015,
                         "brownstone"             => 11818,
                         "browse"                 => 10708,
                         "browsing"               => 10116,
                         "brrrrr"                 => 19014,
                         "bruenell"               => 8395,
                         "bruise"                 => 4092,
                         "bruised"                => 4267,
                         "bruises"                => 3509,
                         "bruising"               => 7171,
                         "brulee"                 => 9608,
                         "brumby"                 => 13294,
                         "brummel"                => 12274,
                         "brunch"                 => 4215,
                         "brundle"                => 7286,
                         "brunettes"              => 13293,
                         "brung"                  => 12728,
                         "bruschetta"             => 16402,
                         "brush"                  => 2109,
                         "brushed"                => 5505,
                         "brushes"                => 7170,
                         "brushing"               => 5643,
                         "brusque"                => 17599,
                         "brussel"                => 13292,
                         "brutal"                 => 2896,
                         "brutality"              => 6110,
                         "brutally"               => 6109,
                         "brute"                  => 6328,
                         "brutish"                => 17598,
                         "bubbe"                  => 11817,
                         "bubbies"                => 19013,
                         "bubbling"               => 9378,
                         "bubbly"                 => 5016,
                         "bubut"                  => 19012,
                         "buchanans"              => 13871,
                         "buckaroo"               => 4200,
                         "buckets"                => 7809,
                         "bucking"                => 9607,
                         "bucklands"              => 7059,
                         "buckle"                 => 3972,
                         "buckled"                => 11816,
                         "buckling"               => 16401,
                         "bucko"                  => 10115,
                         "bucks"                  => 809,
                         "bucyk"                  => 16400,
                         "buddies"                => 2296,
                         "budge"                  => 4759,
                         "budged"                 => 14602,
                         "budging"                => 12727,
                         "budington"              => 13870,
                         "bueller"                => 9860,
                         "buenas"                 => 15421,
                         "buff"                   => 2999,
                         "buffay"                 => 7528,
                         "buffed"                 => 17597,
                         "buffets"                => 17596,
                         "buffoon"                => 11406,
                         "buffoons"               => 15420,
                         "buffs"                  => 16399,
                         "buffy"                  => 713,
                         "buffybot"               => 19011,
                         "bugged"                 => 4004,
                         "buggered"               => 13291,
                         "buggers"                => 9859,
                         "buggin"                 => 11031,
                         "bugging"                => 2690,
                         "bugler"                 => 17595,
                         "bugs"                   => 2013,
                         "buildin"                => 14601,
                         "bukatari"               => 14600,
                         "bulb"                   => 4472,
                         "bulbs"                  => 7058,
                         "bulging"                => 8249,
                         "bulimia"                => 14599,
                         "bulimic"                => 12726,
                         "buljanoff"              => 9377,
                         "bulky"                  => 13290,
                         "bullcrap"               => 11030,
                         "bulldoze"               => 19010,
                         "bulldozer"              => 9858,
                         "bulldozers"             => 10707,
                         "bulletin"               => 4003,
                         "bulletproof"            => 6582,
                         "bullets"                => 2135,
                         "bullheaded"             => 16398,
                         "bullied"                => 7808,
                         "bullies"                => 7976,
                         "bullshitting"           => 10401,
                         "bullwinkle"             => 12273,
                         "bully"                  => 3156,
                         "bumbling"               => 13289,
                         "bummed"                 => 3744,
                         "bummers"                => 19009,
                         "bumming"                => 12272,
                         "bump"                   => 2230,
                         "bumped"                 => 3044,
                         "bumping"                => 6474,
                         "bumpkins"               => 19008,
                         "bumps"                  => 4513,
                         "bumpy"                  => 5130,
                         "bumstead"               => 10114,
                         "buncha"                 => 10706,
                         "bundle"                 => 4111,
                         "bundt"                  => 9376,
                         "bundys"                 => 9857,
                         "bungchow"               => 17594,
                         "bungled"                => 19007,
                         "bunion"                 => 12725,
                         "bunions"                => 16397,
                         "bunk"                   => 4417,
                         "bunkhouse"              => 17593,
                         "bunking"                => 12271,
                         "bunks"                  => 10705,
                         "buns"                   => 3743,
                         "bunsen"                 => 14598,
                         "buona"                  => 16396,
                         "burbs"                  => 16395,
                         "burdened"               => 8394,
                         "burdens"                => 10704,
                         "burdon"                 => 10400,
                         "bureaucrat"             => 15419,
                         "bureaucrats"            => 11815,
                         "burgel"                 => 11405,
                         "burgers"                => 3072,
                         "burglar"                => 4831,
                         "burglaries"             => 16394,
                         "burglars"               => 9183,
                         "burglary"               => 5129,
                         "burgomeister"           => 17592,
                         "buries"                 => 11404,
                         "burlap"                 => 15418,
                         "burn"                   => 1030,
                         "burned"                 => 1296,
                         "burners"                => 13869,
                         "burnin"                 => 12270,
                         "burning"                => 1162,
                         "burnt"                  => 2922,
                         "burping"                => 10703,
                         "burps"                  => 17591,
                         "burritos"               => 7285,
                         "burro"                  => 12269,
                         "burst"                  => 2291,
                         "bursting"               => 5176,
                         "bury"                   => 1885,
                         "burying"                => 4734,
                         "busboy"                 => 6745,
                         "busboys"                => 11814,
                         "bushes"                 => 3742,
                         "bushy"                  => 13868,
                         "busier"                 => 11029,
                         "businesswoman"          => 6650,
                         "businesswomen"          => 19006,
                         "busload"                => 16393,
                         "busmalis"               => 10702,
                         "busses"                 => 17590,
                         "bussing"                => 12724,
                         "bust"                   => 1416,
                         "busted"                 => 1546,
                         "bustier"                => 15417,
                         "bustin"                 => 8248,
                         "busting"                => 2998,
                         "busts"                  => 11028,
                         "busy"                   => 531,
                         "busybody"               => 12723,
                         "busywork"               => 17589,
                         "but"                    => 23,
                         "butabi"                 => 10701,
                         "butai"                  => 19005,
                         "butchered"              => 11813,
                         "butchers"               => 11812,
                         "butlers"                => 12722,
                         "buts"                   => 3847,
                         "butt"                   => 913,
                         "butted"                 => 11403,
                         "butterball"             => 15416,
                         "buttered"               => 9375,
                         "butterfingers"          => 14597,
                         "butterflies"            => 4795,
                         "buttering"              => 11402,
                         "buttermilk"             => 14596,
                         "butters"                => 2261,
                         "butterscotch"           => 11027,
                         "buttholes"              => 17588,
                         "butting"                => 5993,
                         "buttle"                 => 8393,
                         "button"                 => 1487,
                         "buttoned"               => 11401,
                         "buttoning"              => 16392,
                         "buxley"                 => 13288,
                         "buy"                    => 438,
                         "buyer"                  => 4199,
                         "buyers"                 => 4950,
                         "buyin"                  => 7975,
                         "buying"                 => 1115,
                         "buys"                   => 2997,
                         "buzz"                   => 1732,
                         "buzzards"               => 19004,
                         "buzzed"                 => 10113,
                         "buzzes"                 => 16391,
                         "buzzing"                => 4733,
                         "bye"                    => 267,
                         "bygones"                => 4732,
                         "bylaws"                 => 7414,
                         "byline"                 => 15415,
                         "bystander"              => 7169,
                         "bystanders"             => 11400,
                         "c'est"                  => 6184,
                         "c'mere"                 => 3722,
                         "c'mon"                  => 781,
                         "cabdriver"              => 19003,
                         "cabeza"                 => 19002,
                         "cabin"                  => 1377,
                         "cabinets"               => 6838,
                         "cabot"                  => 2811,
                         "cachet"                 => 19001,
                         "cackle"                 => 16390,
                         "cackling"               => 11399,
                         "cacophony"              => 16389,
                         "cadavers"               => 16388,
                         "caddie"                 => 13287,
                         "caddies"                => 17587,
                         "cadillacs"              => 19000,
                         "cadmium"                => 10112,
                         "cafeteria"              => 2412,
                         "caffeinated"            => 16387,
                         "caffeine"               => 3385,
                         "cage"                   => 2078,
                         "caged"                  => 8247,
                         "cages"                  => 6183,
                         "cagey"                  => 13286,
                         "cahoots"                => 6944,
                         "cain't"                 => 12268,
                         "cake"                   => 926,
                         "cakes"                  => 3241,
                         "cakewalk"               => 13285,
                         "calamari"               => 9606,
                         "calamine"               => 14595,
                         "calamitous"             => 18999,
                         "calculating"            => 6473,
                         "calculator"             => 8095,
                         "caldecott"              => 18998,
                         "caldy"                  => 15414,
                         "calfskin"               => 17586,
                         "caliber"                => 4908,
                         "calibrated"             => 14594,
                         "calisthenics"           => 13867,
                         "calitri"                => 15413,
                         "call"                   => 114,
                         "callar"                 => 16386,
                         "callate"                => 16385,
                         "callback"               => 14593,
                         "caller"                 => 2704,
                         "callers"                => 7657,
                         "callin"                 => 4322,
                         "calling"                => 491,
                         "callous"                => 6943,
                         "callously"              => 17585,
                         "calls"                  => 662,
                         "calluses"               => 13866,
                         "calm"                   => 566,
                         "calmed"                 => 4758,
                         "calmer"                 => 8759,
                         "calming"                => 7284,
                         "calmly"                 => 4871,
                         "calms"                  => 7413,
                         "calorie"                => 11398,
                         "calories"               => 5814,
                         "calrissian"             => 12721,
                         "calves"                 => 8246,
                         "calzone"                => 8974,
                         "calzones"               => 15412,
                         "camaraderie"            => 17584,
                         "cambias"                => 4155,
                         "camcorder"              => 11397,
                         "came"                   => 179,
                         "camembert"              => 11811,
                         "camera"                 => 957,
                         "cameraman"              => 7057,
                         "cameras"                => 1978,
                         "camogli"                => 11810,
                         "camped"                 => 6744,
                         "campers"                => 7974,
                         "campfire"               => 7283,
                         "campin"                 => 16384,
                         "camping"                => 2791,
                         "campsite"               => 9182,
                         "camry"                  => 15411,
                         "can"                    => 37,
                         "can't"                  => 57,
                         "canape"                 => 18997,
                         "canasta"                => 12267,
                         "cancel"                 => 1460,
                         "canceled"               => 2305,
                         "canceling"              => 4794,
                         "cancellations"          => 16383,
                         "cancelling"             => 9181,
                         "cancels"                => 10111,
                         "candaules"              => 18996,
                         "candid"                 => 5175,
                         "candidly"               => 17583,
                         "candied"                => 13865,
                         "candlelight"            => 6108,
                         "candlelit"              => 15410,
                         "candles"                => 1674,
                         "candlestick"            => 15409,
                         "candlesticks"           => 12266,
                         "candlewell"             => 13284,
                         "candor"                 => 11026,
                         "cane"                   => 3602,
                         "canin"                  => 9856,
                         "canines"                => 18995,
                         "canister"               => 9374,
                         "canisters"              => 15408,
                         "canned"                 => 4154,
                         "cannery"                => 7168,
                         "cannibals"              => 11025,
                         "cannoli"                => 11809,
                         "cannolis"               => 11808,
                         "cannot"                 => 505,
                         "cans"                   => 3178,
                         "cantaloupe"             => 9180,
                         "canvass"                => 15407,
                         "canvassing"             => 14592,
                         "cap'n"                  => 7973,
                         "capable"                => 1140,
                         "capades"                => 10700,
                         "caped"                  => 14591,
                         "capelli"                => 11807,
                         "caper"                  => 8245,
                         "capeside"               => 2485,
                         "capiche"                => 13283,
                         "capillaries"            => 17582,
                         "capisce"                => 9179,
                         "capitalistic"           => 17581,
                         "capitalize"             => 10399,
                         "cappuccino"             => 3559,
                         "cappuccinos"            => 13864,
                         "cappucino"              => 13282,
                         "cappy"                  => 14590,
                         "caprica"                => 11806,
                         "capricious"             => 17580,
                         "capsize"                => 13281,
                         "capsules"               => 10398,
                         "capt'n"                 => 16382,
                         "captioning"             => 13280,
                         "captivated"             => 16381,
                         "captivating"            => 12720,
                         "captive"                => 4243,
                         "capulet"                => 16380,
                         "capulets"               => 18994,
                         "car"                    => 233,
                         "caramels"               => 14589,
                         "carano"                 => 10397,
                         "carasco"                => 9178,
                         "carat"                  => 8758,
                         "carats"                 => 12719,
                         "caravaggio"             => 12718,
                         "carbs"                  => 10699,
                         "carbuncle"              => 18993,
                         "carburetor"             => 7656,
                         "carcinogens"            => 16379,
                         "card"                   => 718,
                         "cardboard"              => 5217,
                         "carded"                 => 14588,
                         "cardiac"                => 3705,
                         "cardio"                 => 10698,
                         "cardiogram"             => 18992,
                         "cardiologist"           => 6400,
                         "cardiology"             => 12265,
                         "cards"                  => 1055,
                         "care"                   => 152,
                         "cared"                  => 1287,
                         "careening"              => 17579,
                         "careful"                => 592,
                         "carefully"              => 1711,
                         "caregiver"              => 12264,
                         "careless"               => 3741,
                         "carelessly"             => 17578,
                         "carelessness"           => 10697,
                         "cares"                  => 832,
                         "caress"                 => 11396,
                         "caressing"              => 17577,
                         "caribou"                => 6399,
                         "caring"                 => 1673,
                         "caritas"                => 12263,
                         "carjack"                => 15406,
                         "carjacking"             => 12262,
                         "carly"                  => 400,
                         "carnal"                 => 9855,
                         "carnations"             => 13863,
                         "carnie"                 => 18991,
                         "carnivore"              => 16378,
                         "carny"                  => 14587,
                         "carob"                  => 17576,
                         "carolers"               => 18990,
                         "caroling"               => 12261,
                         "carolling"              => 18989,
                         "carols"                 => 9373,
                         "carotid"                => 11024,
                         "carousel"               => 7412,
                         "carpal"                 => 13862,
                         "carpe"                  => 7972,
                         "carpenters"             => 9854,
                         "carpentry"              => 12260,
                         "carpeted"               => 17575,
                         "carpeting"              => 11023,
                         "carples"                => 14586,
                         "carpool"                => 10696,
                         "carrear"                => 18988,
                         "carrey"                 => 13861,
                         "carriage"               => 3204,
                         "carry"                  => 940,
                         "carryin"                => 11022,
                         "carrying"               => 1098,
                         "cart"                   => 2888,
                         "carted"                 => 11021,
                         "cartel"                 => 6398,
                         "carting"                => 18987,
                         "cartmanland"            => 14585,
                         "carton"                 => 5083,
                         "cartons"                => 8244,
                         "cartouche"              => 16377,
                         "cartwheel"              => 17574,
                         "cartwheels"             => 9372,
                         "carve"                  => 4605,
                         "carvel"                 => 18986,
                         "carvers"                => 10695,
                         "carves"                 => 17573,
                         "carving"                => 5992,
                         "casbah"                 => 6942,
                         "cascade"                => 2484,
                         "case"                   => 280,
                         "cased"                  => 18985,
                         "caseload"               => 15405,
                         "cashed"                 => 5923,
                         "cashews"                => 16376,
                         "cashier"                => 6397,
                         "cashing"                => 8757,
                         "cashmere"               => 4870,
                         "casing"                 => 8094,
                         "casings"                => 11805,
                         "casinos"                => 6743,
                         "casitas"                => 18984,
                         "casket"                 => 3721,
                         "caskets"                => 8973,
                         "caspar"                 => 6581,
                         "cassadine"              => 1934,
                         "cassadines"             => 4471,
                         "casserole"              => 5448,
                         "cassio"                 => 16375,
                         "cassiopeia"             => 17572,
                         "castell"                => 12259,
                         "castrated"              => 16374,
                         "casual"                 => 2538,
                         "casually"               => 6044,
                         "cataclysmic"            => 18983,
                         "catacombs"              => 9605,
                         "cataloging"             => 16373,
                         "catalogs"               => 9853,
                         "catalogues"             => 9371,
                         "cataloguing"            => 14584,
                         "catapult"               => 12717,
                         "cataracts"              => 10396,
                         "catastrophe"            => 6251,
                         "catatonic"              => 7807,
                         "catch"                  => 535,
                         "catches"                => 3260,
                         "catchin"                => 11395,
                         "catching"               => 2003,
                         "catchy"                 => 6396,
                         "categorically"          => 10395,
                         "catered"                => 9604,
                         "caterer"                => 4757,
                         "caterers"               => 6327,
                         "caterine"               => 17571,
                         "catering"               => 3893,
                         "caterwauling"           => 18982,
                         "catharsis"              => 11394,
                         "cathartic"              => 15404,
                         "catheter"               => 11804,
                         "catskills"              => 10694,
                         "catsup"                 => 13279,
                         "catting"                => 17570,
                         "caucasian"              => 6043,
                         "caught"                 => 569,
                         "cauldron"               => 7806,
                         "cauldwell"              => 17569,
                         "cauliflower"            => 11393,
                         "cause"                  => 255,
                         "cauterized"             => 17568,
                         "caution"                => 3583,
                         "cautionary"             => 12258,
                         "cautious"               => 3780,
                         "cautiously"             => 12257,
                         "cavalcade"              => 16372,
                         "cave"                   => 1669,
                         "caveat"                 => 14583,
                         "caved"                  => 6580,
                         "cavemen"                => 17567,
                         "cavern"                 => 5991,
                         "caviar"                 => 3660,
                         "caving"                 => 9603,
                         "cavorting"              => 17566,
                         "caymans"                => 11803,
                         "ccedil"                 => 17565,
                         "cease"                  => 3621,
                         "ceases"                 => 9177,
                         "cedars"                 => 4907,
                         "ceecee"                 => 17564,
                         "ceiling"                => 2669,
                         "celebrate"              => 1108,
                         "celebrating"            => 1913,
                         "celebration"            => 1919,
                         "celebratory"            => 9852,
                         "celery"                 => 7282,
                         "celibacy"               => 11020,
                         "celibate"               => 12256,
                         "cell"                   => 735,
                         "cellar"                 => 3276,
                         "cellblock"              => 9602,
                         "celled"                 => 16371,
                         "cellmate"               => 10110,
                         "cellmates"              => 15403,
                         "cellophane"             => 14582,
                         "cellulite"              => 16370,
                         "cemetary"               => 18981,
                         "censure"                => 12716,
                         "censured"               => 18980,
                         "centerfold"             => 17563,
                         "centerpieces"           => 17562,
                         "centimeter"             => 11802,
                         "cents"                  => 1906,
                         "cereal"                 => 3113,
                         "cerebellum"             => 17561,
                         "cerebrum"               => 18979,
                         "ceremony"               => 1307,
                         "cerreno"                => 18978,
                         "certainaly"             => 10109,
                         "certainly"              => 470,
                         "certainties"            => 18977,
                         "certainty"              => 6182,
                         "certifiable"            => 6326,
                         "certifiably"            => 16369,
                         "certs"                  => 18976,
                         "cervix"                 => 13860,
                         "cesspool"               => 8972,
                         "cetera"                 => 5701,
                         "chadway"                => 16368,
                         "chaff"                  => 18975,
                         "chafing"                => 11019,
                         "chagrined"              => 18974,
                         "chained"                => 4292,
                         "chainsaws"              => 12715,
                         "chair"                  => 980,
                         "chairs"                 => 2447,
                         "chakras"                => 14581,
                         "chalet"                 => 15402,
                         "chalk"                  => 3558,
                         "chalkboard"             => 11801,
                         "chalked"                => 16367,
                         "chambermaid"            => 14580,
                         "chamdo"                 => 18973,
                         "chamomile"              => 8093,
                         "champagne"              => 1071,
                         "chance"                 => 262,
                         "chances"                => 1177,
                         "chandelier"             => 7655,
                         "chandeliers"            => 18972,
                         "chandlers"              => 14579,
                         "change"                 => 287,
                         "changed"                => 467,
                         "changin"                => 13278,
                         "changing"               => 1269,
                         "channeled"              => 15401,
                         "channeling"             => 9176,
                         "channing"               => 7411,
                         "channukah"              => 17560,
                         "chant"                  => 6472,
                         "chanteuse"              => 18971,
                         "chanting"               => 6325,
                         "chanukah"               => 10108,
                         "chaperon"               => 7056,
                         "chaperone"              => 5401,
                         "chaperoned"             => 17559,
                         "chaperones"             => 10394,
                         "chaperoning"            => 8243,
                         "chapil"                 => 16366,
                         "chapped"                => 11800,
                         "chaps"                  => 8756,
                         "charade"                => 3557,
                         "charades"               => 6324,
                         "chardonnay"             => 7281,
                         "charge"                 => 758,
                         "charges"                => 890,
                         "chargin"                => 18970,
                         "charging"               => 3087,
                         "chariot"                => 7805,
                         "charlatan"              => 10393,
                         "charm"                  => 1676,
                         "charmer"                => 7804,
                         "charming"               => 1408,
                         "charmingly"             => 13277,
                         "charms"                 => 3740,
                         "charnier"               => 16365,
                         "charo"                  => 16364,
                         "charred"                => 11018,
                         "chartreuse"             => 16363,
                         "chased"                 => 2851,
                         "chases"                 => 8242,
                         "chasin"                 => 11799,
                         "chasing"                => 1559,
                         "chasm"                  => 16362,
                         "chaste"                 => 9601,
                         "chat"                   => 1453,
                         "chats"                  => 9175,
                         "chatted"                => 11392,
                         "chatter"                => 6395,
                         "chatterbox"             => 17558,
                         "chattering"             => 13859,
                         "chatting"               => 4198,
                         "chatty"                 => 8092,
                         "chauffeur"              => 4002,
                         "chauvinist"             => 14578,
                         "chauvinistic"           => 16361,
                         "cheap"                  => 1260,
                         "cheapen"                => 12714,
                         "cheaper"                => 4321,
                         "cheapest"               => 11391,
                         "cheat"                  => 1990,
                         "cheated"                => 2086,
                         "cheaters"               => 12255,
                         "cheatin"                => 9600,
                         "cheating"               => 1622,
                         "cheats"                 => 5700,
                         "check"                  => 286,
                         "checkbook"              => 4869,
                         "checked"                => 861,
                         "checkered"              => 10392,
                         "checkin"                => 8971,
                         "checking"               => 1065,
                         "checklist"              => 14577,
                         "checkmate"              => 7410,
                         "checkout"               => 7971,
                         "checkpoint"             => 9174,
                         "checks"                 => 2023,
                         "checkup"                => 4636,
                         "checkups"               => 12254,
                         "cheeco"                 => 14576,
                         "cheekbones"             => 8392,
                         "cheep"                  => 12253,
                         "cheer"                  => 1572,
                         "cheered"                => 8391,
                         "cheerful"               => 4949,
                         "cheering"               => 4110,
                         "cheerleader"            => 3226,
                         "cheerleaders"           => 4320,
                         "cheerleading"           => 4868,
                         "cheery"                 => 5587,
                         "cheeseburger"           => 4830,
                         "cheeseburgers"          => 7280,
                         "cheesecake"             => 6181,
                         "cheesed"                => 17557,
                         "cheesie"                => 16360,
                         "cheesy"                 => 3312,
                         "chef"                   => 1392,
                         "chefs"                  => 8755,
                         "chem"                   => 4867,
                         "chemo"                  => 5015,
                         "chenille"               => 8091,
                         "chenowith"              => 13276,
                         "cheque"                 => 3829,
                         "cheques"                => 9173,
                         "cherished"              => 6250,
                         "chessboard"             => 18969,
                         "chessler"               => 11390,
                         "chest"                  => 1294,
                         "chested"                => 14575,
                         "chesterton"             => 10391,
                         "chestnuts"              => 8578,
                         "chests"                 => 12713,
                         "cheswick"               => 11389,
                         "chevron"                => 5400,
                         "chewed"                 => 5447,
                         "chewin"                 => 18968,
                         "chewing"                => 3674,
                         "chews"                  => 9599,
                         "chianti"                => 12252,
                         "chick"                  => 1442,
                         "chicka"                 => 13858,
                         "chickadee"              => 18967,
                         "chickened"              => 7970,
                         "chickening"             => 13275,
                         "chickenpox"             => 18966,
                         "chickenshit"            => 8970,
                         "chickie"                => 8241,
                         "chiffon"                => 15400,
                         "chigliak"               => 16359,
                         "chigorin"               => 12251,
                         "child"                  => 360,
                         "childbirth"             => 6649,
                         "childhoods"             => 13274,
                         "childish"               => 3704,
                         "childlike"              => 13273,
                         "chili"                  => 2551,
                         "chill"                  => 1614,
                         "chilled"                => 7409,
                         "chilling"               => 7055,
                         "chills"                 => 6249,
                         "chillun"                => 17556,
                         "chime"                  => 11388,
                         "chimes"                 => 9598,
                         "chimney"                => 5307,
                         "chimp"                  => 5869,
                         "chimpanzee"             => 12712,
                         "chimps"                 => 12250,
                         "chinatown"              => 4387,
                         "chingachgook"           => 18965,
                         "chink"                  => 10693,
                         "chinks"                 => 18964,
                         "chinnery"               => 9851,
                         "chinpoko"               => 11017,
                         "chinpokomon"            => 5750,
                         "chins"                  => 11387,
                         "chip"                   => 1607,
                         "chipped"                => 5642,
                         "chippie"                => 14574,
                         "chipping"               => 12711,
                         "chips"                  => 1930,
                         "chiropractor"           => 7803,
                         "chirp"                  => 18963,
                         "chirping"               => 11798,
                         "chirpy"                 => 18962,
                         "chiseled"               => 13857,
                         "chiseling"              => 18961,
                         "chitchat"               => 6648,
                         "chivalrous"             => 11016,
                         "chivalry"               => 9370,
                         "chlamydia"              => 16358,
                         "chloe"                  => 715,
                         "chloroform"             => 14573,
                         "chloroformed"           => 17555,
                         "chock"                  => 9369,
                         "chocolate"              => 1170,
                         "chocolates"             => 4242,
                         "chocolatey"             => 16357,
                         "choice"                 => 477,
                         "choices"                => 1502,
                         "choirboy"               => 16356,
                         "choke"                  => 2983,
                         "choked"                 => 4866,
                         "choker"                 => 15399,
                         "chokes"                 => 13272,
                         "choking"                => 3739,
                         "choksondik"             => 8577,
                         "cholesterol"            => 5922,
                         "cholinesterase"         => 16355,
                         "chomp"                  => 11386,
                         "chompers"               => 18960,
                         "chomping"               => 12249,
                         "choo"                   => 4069,
                         "choos"                  => 17554,
                         "choose"                 => 910,
                         "choosers"               => 15398,
                         "chooses"                => 4635,
                         "choosing"               => 2930,
                         "choosy"                 => 12248,
                         "chop"                   => 2101,
                         "chopec"                 => 11385,
                         "chopped"                => 3950,
                         "chopping"               => 6837,
                         "chops"                  => 3540,
                         "chopsticks"             => 8754,
                         "choque"                 => 18959,
                         "chore"                  => 8576,
                         "chores"                 => 4319,
                         "chose"                  => 1335,
                         "chrissake"              => 6836,
                         "chrissakes"             => 6835,
                         "christening"            => 3720,
                         "christmas"              => 444,
                         "christmases"            => 8390,
                         "christmassy"            => 14572,
                         "christmastime"          => 7279,
                         "christmasy"             => 14571,
                         "christsakes"            => 18958,
                         "chromic"                => 17553,
                         "chromium"               => 9597,
                         "chronically"            => 18957,
                         "chronisters"            => 17552,
                         "chucked"                => 13271,
                         "chucking"               => 13856,
                         "chuckle"                => 7278,
                         "chugga"                 => 11797,
                         "chugging"               => 18956,
                         "chulak"                 => 6042,
                         "chumash"                => 11015,
                         "chummy"                 => 6647,
                         "chump"                  => 4829,
                         "chumps"                 => 16354,
                         "chums"                  => 11014,
                         "chunk"                  => 3493,
                         "chunks"                 => 8240,
                         "chunnel"                => 16353,
                         "chuppah"                => 8575,
                         "churn"                  => 11796,
                         "churning"               => 9368,
                         "chute"                  => 5749,
                         "chutes"                 => 13270,
                         "chutzpah"               => 13855,
                         "ciao"                   => 3394,
                         "cider"                  => 4671,
                         "cienega"                => 14570,
                         "cigar"                  => 2562,
                         "cigarette"              => 1984,
                         "cigarettes"             => 2252,
                         "cilantro"               => 13854,
                         "cimmeria"               => 13853,
                         "cinch"                  => 9850,
                         "cinnabar"               => 16352,
                         "circled"                => 7654,
                         "circles"                => 2710,
                         "circling"               => 4793,
                         "circuited"              => 17551,
                         "circulate"              => 10390,
                         "circulatory"            => 17550,
                         "circumcised"            => 13852,
                         "circumcision"           => 10107,
                         "circumference"          => 8574,
                         "circumstance"           => 5446,
                         "circumstances"          => 1239,
                         "circumstantial"         => 5306,
                         "circus"                 => 2042,
                         "cirque"                 => 9367,
                         "cirrhosis"              => 10692,
                         "cissy"                  => 15397,
                         "citywide"               => 17549,
                         "civilised"              => 13851,
                         "civility"               => 10691,
                         "civilization"           => 3267,
                         "civilized"              => 3659,
                         "civvies"                => 17548,
                         "clader"                 => 9172,
                         "clairvoyant"            => 10389,
                         "clam"                   => 4670,
                         "clammed"                => 18955,
                         "clammy"                 => 10690,
                         "clamoring"              => 11795,
                         "clamp"                  => 4153,
                         "clamped"                => 12247,
                         "clamping"               => 17547,
                         "clamps"                 => 9849,
                         "clams"                  => 5054,
                         "clang"                  => 15396,
                         "clanging"               => 17546,
                         "clanking"               => 17545,
                         "clapped"                => 16351,
                         "clapping"               => 8573,
                         "clarification"          => 8239,
                         "clarify"                => 4318,
                         "clarifying"             => 16350,
                         "clarithromycin"         => 14569,
                         "clarity"                => 5504,
                         "clashing"               => 17544,
                         "clasp"                  => 8753,
                         "classier"               => 11013,
                         "classifieds"            => 10689,
                         "classless"              => 17543,
                         "classmates"             => 6107,
                         "classy"                 => 3086,
                         "claus"                  => 2542,
                         "claustrophobia"         => 11794,
                         "claustrophobic"         => 6742,
                         "clavicle"               => 17542,
                         "claw"                   => 4152,
                         "clawed"                 => 12246,
                         "clawing"                => 9596,
                         "claws"                  => 3949,
                         "claymores"              => 18954,
                         "clean"                  => 575,
                         "cleaned"                => 1741,
                         "cleaner"                => 3225,
                         "cleaners"               => 3556,
                         "cleanest"               => 12710,
                         "cleanin"                => 13850,
                         "cleaning"               => 1400,
                         "cleanliness"            => 11384,
                         "cleans"                 => 5921,
                         "cleanse"                => 8389,
                         "cleansed"               => 11383,
                         "cleanser"               => 10106,
                         "cleanses"               => 18953,
                         "cleansing"              => 6180,
                         "cleanup"                => 7802,
                         "clear"                  => 413,
                         "clearance"              => 3335,
                         "cleared"                => 1671,
                         "clearer"                => 4266,
                         "clearing"               => 3284,
                         "clearly"                => 1107,
                         "clears"                 => 5014,
                         "cleats"                 => 16349,
                         "cleavage"               => 7167,
                         "clein"                  => 18952,
                         "clemency"               => 10388,
                         "clemenza"               => 10105,
                         "clemonds"               => 14568,
                         "clench"                 => 18951,
                         "clenched"               => 13849,
                         "clerk"                  => 2586,
                         "clerks"                 => 5503,
                         "cleve"                  => 16348,
                         "clever"                 => 1589,
                         "cleverly"               => 11382,
                         "cleverness"             => 18950,
                         "cliche"                 => 7653,
                         "clicked"                => 5920,
                         "clicking"               => 8752,
                         "clicks"                 => 7652,
                         "client"                 => 974,
                         "clientele"              => 5868,
                         "clients"                => 1769,
                         "cliffhanger"            => 15395,
                         "cliffside"              => 13269,
                         "climb"                  => 1948,
                         "climbed"                => 3892,
                         "climbing"               => 3015,
                         "clincher"               => 18949,
                         "clinches"               => 18948,
                         "cling"                  => 5399,
                         "clinging"               => 4865,
                         "clings"                 => 17541,
                         "clingy"                 => 8388,
                         "clinic"                 => 1537,
                         "clinically"             => 8969,
                         "clip"                   => 3014,
                         "clipboard"              => 10104,
                         "clipped"                => 6106,
                         "clipping"               => 10103,
                         "clippings"              => 6323,
                         "cloak"                  => 5445,
                         "cloaked"                => 13848,
                         "clobber"                => 14567,
                         "clobbered"              => 10102,
                         "clock"                  => 1263,
                         "clocked"                => 6322,
                         "clocking"               => 17540,
                         "clocks"                 => 5174,
                         "clockwork"              => 6834,
                         "clods"                  => 17539,
                         "clogged"                => 7054,
                         "clogging"               => 8751,
                         "clogs"                  => 8090,
                         "cloistered"             => 16347,
                         "clone"                  => 4906,
                         "cloned"                 => 11793,
                         "cloning"                => 9366,
                         "clooney"                => 10688,
                         "close"                  => 329,
                         "closeness"              => 7408,
                         "closer"                 => 865,
                         "closes"                 => 4022,
                         "closest"                => 2505,
                         "closet"                 => 1193,
                         "closeted"               => 16346,
                         "closets"                => 5867,
                         "closing"                => 1639,
                         "clothe"                 => 17538,
                         "clothed"                => 8968,
                         "clothes"                => 653,
                         "clothesline"            => 18947,
                         "cloths"                 => 17537,
                         "clots"                  => 8238,
                         "clotted"                => 18946,
                         "clotting"               => 12709,
                         "clouded"                => 8750,
                         "clouding"               => 9848,
                         "clout"                  => 10687,
                         "cloven"                 => 17536,
                         "cloves"                 => 17535,
                         "clown"                  => 1832,
                         "clownfish"              => 13847,
                         "clowning"               => 15394,
                         "clubbed"                => 15393,
                         "clubbing"               => 9595,
                         "clubhouse"              => 5173,
                         "clucking"               => 17534,
                         "clue"                   => 1143,
                         "clued"                  => 9171,
                         "clueless"               => 3450,
                         "clues"                  => 2881,
                         "cluett"                 => 11381,
                         "clump"                  => 15392,
                         "clumsily"               => 17533,
                         "clumsiness"             => 18945,
                         "clumsy"                 => 4241,
                         "clung"                  => 12708,
                         "clunk"                  => 18944,
                         "clunker"                => 18943,
                         "clunkers"               => 17532,
                         "clunky"                 => 13846,
                         "clutched"               => 16345,
                         "clutches"               => 6941,
                         "clutching"              => 9170,
                         "cluttered"              => 13845,
                         "cluttering"             => 18942,
                         "clydesdale"             => 18941,
                         "coals"                  => 7277,
                         "coaster"                => 4109,
                         "coasters"               => 10101,
                         "coastguard"             => 9365,
                         "coasting"               => 18940,
                         "coat"                   => 1106,
                         "coattails"              => 11792,
                         "coaxing"                => 13268,
                         "cobblepot"              => 7969,
                         "cobbler"                => 7407,
                         "cobwebs"                => 8749,
                         "cockamamie"             => 10100,
                         "cocked"                 => 7651,
                         "cockeyed"               => 14566,
                         "cockfight"              => 13844,
                         "cockles"                => 16344,
                         "cockney"                => 16343,
                         "cockroach"              => 5641,
                         "cockroaches"            => 7053,
                         "cocksuckers"            => 11791,
                         "cocksucking"            => 16342,
                         "cocktail"               => 2242,
                         "cocktails"              => 4512,
                         "cocky"                  => 4265,
                         "cocoa"                  => 3673,
                         "coconuts"               => 7052,
                         "cocoon"                 => 7166,
                         "coddle"                 => 11790,
                         "coddled"                => 13843,
                         "coddling"               => 15391,
                         "coded"                  => 7276,
                         "codependent"            => 16341,
                         "codicil"                => 18939,
                         "coeds"                  => 16340,
                         "coerce"                 => 11012,
                         "coerced"                => 8237,
                         "coercion"               => 10387,
                         "coexist"                => 13267,
                         "cofell"                 => 8387,
                         "coffeehouse"            => 2939,
                         "coffers"                => 16339,
                         "coffins"                => 6179,
                         "cognac"                 => 6321,
                         "cognizant"              => 17531,
                         "cohaagen"               => 9169,
                         "coiffure"               => 16338,
                         "coincidence"            => 1459,
                         "coincidences"           => 5348,
                         "coincidental"           => 8748,
                         "coitus"                 => 18938,
                         "cokes"                  => 7527,
                         "cokey"                  => 17530,
                         "colada"                 => 10686,
                         "coladas"                => 10685,
                         "colchicine"             => 15390,
                         "cold"                   => 495,
                         "colder"                 => 6320,
                         "coldly"                 => 16337,
                         "coldness"               => 18937,
                         "colds"                  => 12245,
                         "coleslaw"               => 8967,
                         "colic"                  => 11789,
                         "colitis"                => 16336,
                         "collage"                => 6471,
                         "collapsed"              => 2914,
                         "collapsing"             => 7650,
                         "collar"                 => 2510,
                         "collarbone"             => 16335,
                         "collared"               => 14565,
                         "collars"                => 8089,
                         "collateral"             => 6470,
                         "colleague"              => 3393,
                         "collect"                => 1935,
                         "collide"                => 10684,
                         "colling"                => 13266,
                         "collingswood"           => 18936,
                         "collusion"              => 14564,
                         "colonel"                => 903,
                         "colonnade"              => 5699,
                         "colonoscopy"            => 15389,
                         "colorful"               => 4669,
                         "coloring"               => 6319,
                         "colossal"               => 5502,
                         "colosseum"              => 13265,
                         "columnists"             => 15388,
                         "com'on"                 => 16334,
                         "coma"                   => 1506,
                         "comanches"              => 13264,
                         "comas"                  => 12244,
                         "comatose"               => 8572,
                         "comb"                   => 3927,
                         "combative"              => 13263,
                         "combed"                 => 9847,
                         "combing"                => 8386,
                         "combo"                  => 5698,
                         "combust"                => 12243,
                         "combusted"              => 18935,
                         "combustible"            => 18934,
                         "come"                   => 50,
                         "comebacks"              => 16333,
                         "comely"                 => 13842,
                         "comers"                 => 18933,
                         "comes"                  => 348,
                         "cometh"                 => 14563,
                         "comeuppance"            => 13262,
                         "comfort"                => 1337,
                         "comfortable"            => 859,
                         "comfortably"            => 6646,
                         "comforted"              => 6741,
                         "comforter"              => 13261,
                         "comforting"             => 2668,
                         "comforts"               => 8236,
                         "comfy"                  => 3641,
                         "comin"                  => 1602,
                         "coming"                 => 187,
                         "comings"                => 14562,
                         "comm"                   => 4634,
                         "comma"                  => 8966,
                         "commandeered"           => 13841,
                         "commandment"            => 7275,
                         "commandments"           => 8747,
                         "comme"                  => 13260,
                         "commence"               => 6041,
                         "commend"                => 9364,
                         "commendable"            => 10683,
                         "commendatore"           => 16332,
                         "commensurate"           => 15387,
                         "comment"                => 1842,
                         "commercialism"          => 17529,
                         "commie"                 => 7801,
                         "commies"                => 12242,
                         "comming"                => 15386,
                         "commiserate"            => 13259,
                         "commish"                => 10386,
                         "commit"                 => 1552,
                         "commited"               => 13258,
                         "commitment"             => 1524,
                         "committed"              => 1302,
                         "committing"             => 3476,
                         "committment"            => 13840,
                         "commode"                => 15385,
                         "commodus"               => 14561,
                         "commoner"               => 12241,
                         "commotion"              => 6040,
                         "communicate"            => 2689,
                         "communicating"          => 4176,
                         "communicator"           => 10682,
                         "communing"              => 15384,
                         "communique"             => 10099,
                         "commute"                => 8571,
                         "compactor"              => 17528,
                         "compadre"               => 11011,
                         "companionship"          => 6579,
                         "compare"                => 2236,
                         "comparing"              => 4264,
                         "compartment"            => 5748,
                         "compartments"           => 8385,
                         "compassion"             => 2411,
                         "compassionate"          => 3601,
                         "compel"                 => 11788,
                         "compelled"              => 4633,
                         "compelling"             => 5082,
                         "compels"                => 15383,
                         "compensated"            => 7406,
                         "compensating"           => 13839,
                         "competent"              => 4356,
                         "compiegne"              => 14560,
                         "complacency"            => 16331,
                         "complacent"             => 15382,
                         "complain"               => 2271,
                         "complainin"             => 15381,
                         "complaining"            => 2096,
                         "complains"              => 10681,
                         "complaint"              => 2953,
                         "completely"             => 468,
                         "complexion"             => 7405,
                         "complicate"             => 5501,
                         "complicated"            => 1023,
                         "complicates"            => 10098,
                         "complicating"           => 11010,
                         "complication"           => 6039,
                         "complications"          => 2780,
                         "complicit"              => 14559,
                         "compliment"             => 2069,
                         "complimentary"          => 6394,
                         "complimented"           => 9168,
                         "complimenting"          => 9594,
                         "compliments"            => 3433,
                         "compost"                => 11380,
                         "composure"              => 11787,
                         "comprehend"             => 6105,
                         "comprehending"          => 16330,
                         "comprehension"          => 7800,
                         "comprende"              => 8965,
                         "comprendo"              => 18932,
                         "compress"               => 9846,
                         "compressions"           => 11009,
                         "compromise"             => 2241,
                         "compromised"            => 3177,
                         "compromises"            => 8964,
                         "compromising"           => 5128,
                         "compulsion"             => 10385,
                         "compulsive"             => 5127,
                         "compulsively"           => 15380,
                         "comrade"                => 4470,
                         "comrades"               => 6393,
                         "conceal"                => 6833,
                         "concealed"              => 5747,
                         "concealer"              => 17527,
                         "concealing"             => 10097,
                         "concealment"            => 15379,
                         "concede"                => 6038,
                         "conceited"              => 8570,
                         "conceivable"            => 7968,
                         "conceivably"            => 15378,
                         "conceive"               => 4905,
                         "conceiving"             => 15377,
                         "concentrate"            => 1360,
                         "concentrating"          => 4668,
                         "concern"                => 1068,
                         "concerned"              => 648,
                         "conch"                  => 13838,
                         "concierge"              => 6940,
                         "conclusions"            => 2518,
                         "conclusive"             => 5919,
                         "conclusively"           => 12707,
                         "concoct"                => 13837,
                         "concocted"              => 8963,
                         "concocting"             => 16329,
                         "concoction"             => 10384,
                         "concur"                 => 7967,
                         "concussion"             => 3508,
                         "concussions"            => 18931,
                         "condemn"                => 5500,
                         "condemning"             => 8569,
                         "condescend"             => 13836,
                         "condescending"          => 5918,
                         "condiment"              => 16328,
                         "condiments"             => 14558,
                         "condition"              => 922,
                         "conditioner"            => 5013,
                         "conditioners"           => 18930,
                         "conditioning"           => 4049,
                         "condo"                  => 2835,
                         "condolence"             => 14557,
                         "condolences"            => 4469,
                         "condoms"                => 3411,
                         "condone"                => 6178,
                         "condoned"               => 18929,
                         "condoning"              => 12240,
                         "condos"                 => 10383,
                         "conduit"                => 9845,
                         "cones"                  => 7274,
                         "confab"                 => 14556,
                         "confess"                => 1599,
                         "confessed"              => 2097,
                         "confessing"             => 4091,
                         "confession"             => 1446,
                         "confessional"           => 7273,
                         "confetti"               => 11786,
                         "confidant"              => 8568,
                         "confidante"             => 11008,
                         "confide"                => 3779,
                         "confided"               => 5126,
                         "confidence"             => 1493,
                         "confidences"            => 15376,
                         "confident"              => 1946,
                         "confidential"           => 2870,
                         "confidentiality"        => 3909,
                         "confidentially"         => 13257,
                         "confides"               => 13256,
                         "confiding"              => 8384,
                         "confine"                => 10096,
                         "confines"               => 9844,
                         "confining"              => 15375,
                         "confirm"                => 2138,
                         "confirmation"           => 3539,
                         "confirming"             => 6177,
                         "confirms"               => 4698,
                         "confiscate"             => 9843,
                         "confiscating"           => 18928,
                         "confit"                 => 18927,
                         "conflicted"             => 7799,
                         "confound"               => 18926,
                         "confounded"             => 13835,
                         "confront"               => 2611,
                         "confrontational"        => 14555,
                         "confronted"             => 3846,
                         "confronting"            => 7649,
                         "confuse"                => 3555,
                         "confused"               => 995,
                         "confuses"               => 9842,
                         "confusing"              => 2057,
                         "conga"                  => 14554,
                         "congenial"              => 17526,
                         "congeniality"           => 10680,
                         "congrats"               => 6578,
                         "congratulate"           => 2698,
                         "congratulated"          => 11007,
                         "congratulating"         => 7526,
                         "congratulations"        => 778,
                         "congressman"            => 3311,
                         "congressmen"            => 9593,
                         "congresswoman"          => 8962,
                         "conjoined"              => 13834,
                         "conjugal"               => 7272,
                         "conjure"                => 5216,
                         "conjured"               => 8088,
                         "conjures"               => 17525,
                         "conjuring"              => 7525,
                         "conked"                 => 10095,
                         "connection"             => 1072,
                         "conned"                 => 5347,
                         "conning"                => 5990,
                         "conniption"             => 16327,
                         "conniving"              => 5012,
                         "connoisseur"            => 11785,
                         "conquer"                => 4317,
                         "conquering"             => 8383,
                         "conquers"               => 10679,
                         "consarn"                => 13255,
                         "conscience"             => 1649,
                         "conscientious"          => 8087,
                         "conscious"              => 2427,
                         "consciously"            => 7524,
                         "consciousness"          => 2858,
                         "consensual"             => 11379,
                         "consented"              => 10678,
                         "consenting"             => 10677,
                         "consequences"           => 1717,
                         "conserve"               => 8086,
                         "consider"               => 815,
                         "considerate"            => 3891,
                         "consideration"          => 2857,
                         "considering"            => 1161,
                         "consigliere"            => 12239,
                         "consolation"            => 3369,
                         "consoled"               => 13254,
                         "consoling"              => 11784,
                         "consorting"             => 13253,
                         "conspiracies"           => 12238,
                         "conspiracy"             => 2331,
                         "conspirator"            => 11783,
                         "conspire"               => 10676,
                         "conspired"              => 5989,
                         "conspiring"             => 5586,
                         "constable"              => 2041,
                         "constantly"             => 2194,
                         "constellations"         => 9592,
                         "constipated"            => 13833,
                         "constipation"           => 15374,
                         "constrictor"            => 18925,
                         "constructive"           => 5746,
                         "construed"              => 10382,
                         "consulate"              => 4021,
                         "consult"                => 3071,
                         "consults"               => 17524,
                         "consumed"               => 3908,
                         "consumes"               => 10675,
                         "consummate"             => 6577,
                         "consummated"            => 10381,
                         "contact"                => 899,
                         "contacted"              => 2779,
                         "contacting"             => 5866,
                         "contacts"               => 2638,
                         "contagious"             => 4108,
                         "containment"            => 6392,
                         "contaminate"            => 10380,
                         "contaminated"           => 5988,
                         "contaminating"          => 16326,
                         "contemplate"            => 7966,
                         "contemplating"          => 7051,
                         "contempt"               => 3176,
                         "contemptible"           => 13832,
                         "contented"              => 18924,
                         "contentment"            => 11378,
                         "contesting"             => 8085,
                         "contingencies"          => 16325,
                         "contingency"            => 6176,
                         "continuance"            => 8382,
                         "contraband"             => 7648,
                         "contraceptives"         => 16324,
                         "contraction"            => 6175,
                         "contractions"           => 4604,
                         "contradict"             => 8567,
                         "contradicting"          => 15373,
                         "contraire"              => 7523,
                         "contraption"            => 10674,
                         "contrary"               => 2339,
                         "contrite"               => 18923,
                         "contrition"             => 13831,
                         "controlling"            => 2752,
                         "contusion"              => 11782,
                         "contusions"             => 11781,
                         "conundrum"              => 9167,
                         "convene"                => 8961,
                         "convenes"               => 16323,
                         "convenience"            => 3600,
                         "convenient"             => 2149,
                         "conveniently"           => 4545,
                         "conversation"           => 695,
                         "conversational"         => 12706,
                         "conversationalist"      => 13252,
                         "conversations"          => 2856,
                         "conversing"             => 14553,
                         "convertible"            => 4151,
                         "convertibles"           => 13251,
                         "conveyor"               => 11780,
                         "convict"                => 3145,
                         "convicted"              => 1965,
                         "conviction"             => 3043,
                         "convictions"            => 5125,
                         "convince"               => 973,
                         "convinced"              => 1088,
                         "convincing"             => 2225,
                         "convoluted"             => 14552,
                         "convulsing"             => 17523,
                         "convulsions"            => 14551,
                         "cooing"                 => 12237,
                         "cookbook"               => 8746,
                         "cookbooks"              => 18922,
                         "cooked"                 => 2352,
                         "cookin"                 => 6576,
                         "cooking"                => 1486,
                         "cool"                   => 357,
                         "coolers"                => 10379,
                         "coolest"                => 3419,
                         "coolin"                 => 18921,
                         "coolly"                 => 18920,
                         "cools"                  => 10094,
                         "coop"                   => 4263,
                         "cooped"                 => 4948,
                         "cooperate"              => 2392,
                         "cooperating"            => 5305,
                         "coordsize"              => 17522,
                         "cooties"                => 10673,
                         "copacetic"              => 17521,
                         "copernicus"             => 13830,
                         "copied"                 => 4979,
                         "copier"                 => 12236,
                         "copilot"                => 12235,
                         "coping"                 => 6248,
                         "copiously"              => 16322,
                         "copped"                 => 9363,
                         "copperfield"            => 10672,
                         "copperhead"             => 17520,
                         "copperpot"              => 17519,
                         "coppers"                => 12234,
                         "copping"                => 11779,
                         "cops"                   => 710,
                         "cops'll"                => 14550,
                         "copy"                   => 1014,
                         "copycat"                => 8566,
                         "cord"                   => 3346,
                         "corday"                 => 13829,
                         "cordesh"                => 12705,
                         "cordial"                => 7798,
                         "cordially"              => 14549,
                         "cordless"               => 10093,
                         "cordoned"               => 18919,
                         "cords"                  => 7965,
                         "corduroy"               => 11006,
                         "cordy"                  => 3296,
                         "coriander"              => 16321,
                         "corinthos"              => 1172,
                         "corkmaster"             => 10671,
                         "corks"                  => 18918,
                         "corkscrew"              => 8745,
                         "corky"                  => 2256,
                         "corn"                   => 2129,
                         "cornball"               => 11377,
                         "cornea"                 => 13828,
                         "corned"                 => 7964,
                         "corner"                 => 1041,
                         "cornered"               => 4978,
                         "cornering"              => 18917,
                         "corners"                => 3217,
                         "cornfield"              => 12233,
                         "cornflakes"             => 17518,
                         "cornucopia"             => 18916,
                         "cornwallis"             => 8744,
                         "corny"                  => 4416,
                         "coronary"               => 6575,
                         "coroner"                => 4090,
                         "coroners"               => 17517,
                         "corporal"               => 2913,
                         "corporeal"              => 18915,
                         "corpse"                 => 2880,
                         "corpses"                => 5346,
                         "correct"                => 1142,
                         "corrected"              => 5011,
                         "correcting"             => 10670,
                         "correction"             => 4947,
                         "correctly"              => 2952,
                         "corroborate"            => 7404,
                         "corroboration"          => 17516,
                         "corrosive"              => 14548,
                         "corrupt"                => 4214,
                         "corrupted"              => 7165,
                         "corrupting"             => 11778,
                         "corry"                  => 6104,
                         "corsage"                => 7271,
                         "cortlandt"              => 2850,
                         "corvis"                 => 9362,
                         "corwins"                => 16320,
                         "cosign"                 => 17515,
                         "coslaw"                 => 18914,
                         "cosmetic"               => 5987,
                         "cosmetics"              => 2757,
                         "cosmically"             => 17514,
                         "costanza"               => 3042,
                         "costing"                => 5172,
                         "costume"                => 1761,
                         "costumes"               => 3094,
                         "cotillion"              => 7270,
                         "cotswolds"              => 13250,
                         "cottage"                => 2091,
                         "couches"                => 13827,
                         "cough"                  => 2715,
                         "coughed"                => 9166,
                         "coughing"               => 6574,
                         "coughs"                 => 18913,
                         "could"                  => 63,
                         "could'a"                => 10092,
                         "could've"               => 780,
                         "coulda"                 => 2921,
                         "couldn"                 => 10669,
                         "couldn't"               => 216,
                         "couldn't've"            => 16319,
                         "councilman"             => 9165,
                         "councilor"              => 9841,
                         "counsel"                => 1967,
                         "counseled"              => 13826,
                         "counseling"             => 2973,
                         "counselling"            => 11376,
                         "counsellor"             => 7522,
                         "counselor"              => 1751,
                         "counselors"             => 6939,
                         "count"                  => 622,
                         "countdown"              => 4828,
                         "countenance"            => 17513,
                         "counterfeit"            => 5917,
                         "counterfeiting"         => 11777,
                         "counterintelligence"    => 14547,
                         "countermission"         => 13249,
                         "counteroffer"           => 11776,
                         "counterproductive"      => 7963,
                         "countin"                => 11375,
                         "counting"               => 1397,
                         "countless"              => 5215,
                         "countrymen"             => 12232,
                         "coupla"                 => 5499,
                         "couple"                 => 317,
                         "couple'a"               => 18912,
                         "coupon"                 => 5214,
                         "coupons"                => 6740,
                         "courage"                => 1720,
                         "courageous"             => 4020,
                         "couric"                 => 12704,
                         "courier"                => 5640,
                         "couriers"               => 13248,
                         "course"                 => 172,
                         "coursing"               => 10378,
                         "courted"                => 11374,
                         "courteous"              => 8235,
                         "courtesy"               => 2703,
                         "courthouse"             => 2790,
                         "courting"               => 7797,
                         "courtroom"              => 2056,
                         "courtrooms"             => 17512,
                         "courtship"              => 8960,
                         "courtside"              => 11775,
                         "cousin"                 => 1015,
                         "coven"                  => 6938,
                         "coveralls"              => 18911,
                         "coverin"                => 17511,
                         "covertly"               => 14546,
                         "coverup"                => 11373,
                         "covet"                  => 8743,
                         "coveting"               => 13247,
                         "cowardice"              => 8742,
                         "cowardly"               => 6174,
                         "cowards"                => 6645,
                         "cowed"                  => 15372,
                         "cower"                  => 13246,
                         "cowering"               => 12703,
                         "coworker"               => 16318,
                         "coworkers"              => 9840,
                         "cows"                   => 2576,
                         "cozy"                   => 2495,
                         "cozying"                => 11005,
                         "crab"                   => 3492,
                         "crabgrass"              => 18910,
                         "crabs"                  => 6173,
                         "crack"                  => 1352,
                         "cracked"                => 2426,
                         "crackerjack"            => 13245,
                         "crackers"               => 3799,
                         "crackheads"             => 16317,
                         "crackin"                => 14545,
                         "cracking"               => 3432,
                         "crackle"                => 14544,
                         "crackling"              => 11774,
                         "crackpot"               => 7796,
                         "cracks"                 => 3890,
                         "cradle"                 => 5213,
                         "craftsmanship"          => 10091,
                         "crammed"                => 8565,
                         "cramming"               => 12702,
                         "cramp"                  => 4415,
                         "cramped"                => 5865,
                         "cramping"               => 6832,
                         "cranberries"            => 9361,
                         "cranberry"              => 4731,
                         "crane"                  => 486,
                         "cranes"                 => 2567,
                         "cranium"                => 12701,
                         "crank"                  => 3334,
                         "cranked"                => 9839,
                         "cranking"               => 11372,
                         "cranks"                 => 18909,
                         "cranky"                 => 3333,
                         "cranny"                 => 15371,
                         "cranwell"               => 17510,
                         "crap"                   => 928,
                         "crapped"                => 10377,
                         "crapping"               => 15370,
                         "crappy"                 => 3491,
                         "craps"                  => 7164,
                         "crash"                  => 1176,
                         "crashdown"              => 5639,
                         "crashed"                => 2367,
                         "crashers"               => 17509,
                         "crashes"                => 5697,
                         "crashing"               => 2778,
                         "crate"                  => 4355,
                         "crated"                 => 16316,
                         "crates"                 => 6644,
                         "crave"                  => 5745,
                         "craves"                 => 11004,
                         "cravings"               => 9838,
                         "crawl"                  => 1964,
                         "crawled"                => 4291,
                         "crawlers"               => 16315,
                         "crawlin"                => 16314,
                         "crawling"               => 2521,
                         "crawls"                 => 10668,
                         "crawly"                 => 16313,
                         "crayons"                => 8959,
                         "craze"                  => 10667,
                         "crazed"                 => 4107,
                         "crazier"                => 4827,
                         "crazies"                => 9164,
                         "craziest"               => 5345,
                         "craziness"              => 5304,
                         "crazy"                  => 302,
                         "creak"                  => 16312,
                         "creaky"                 => 18908,
                         "cream"                  => 969,
                         "creamed"                => 6831,
                         "creaming"               => 15369,
                         "creams"                 => 14543,
                         "crease"                 => 11003,
                         "creased"                => 18907,
                         "creases"                => 18906,
                         "creations"              => 2810,
                         "creatively"             => 15368,
                         "creature"               => 1834,
                         "creatures"              => 2644,
                         "credence"               => 11371,
                         "credentials"            => 3948,
                         "credenza"               => 16311,
                         "credibility"            => 3947,
                         "credible"               => 6247,
                         "credit"                 => 914,
                         "credo"                  => 11773,
                         "creeds"                 => 16310,
                         "creep"                  => 1813,
                         "creeped"                => 8958,
                         "creepiest"              => 14542,
                         "creepin"                => 16309,
                         "creeping"               => 5344,
                         "creepo"                 => 18905,
                         "creeps"                 => 2789,
                         "creepy"                 => 1888,
                         "cregg"                  => 6172,
                         "cremate"                => 13825,
                         "cremated"               => 5303,
                         "cremation"              => 11370,
                         "crematorium"            => 10090,
                         "creme"                  => 8234,
                         "crepe"                  => 8564,
                         "crepes"                 => 12231,
                         "crept"                  => 10666,
                         "crescendo"              => 13824,
                         "crescentis"             => 17508,
                         "creswood"               => 18904,
                         "cretins"                => 13244,
                         "crevasse"               => 18903,
                         "crewman"                => 16308,
                         "crib"                   => 3203,
                         "cribs"                  => 16307,
                         "crickets"               => 9163,
                         "cried"                  => 2219,
                         "crier"                  => 10665,
                         "cries"                  => 3462,
                         "crikey"                 => 12230,
                         "crilly"                 => 16306,
                         "crime"                  => 719,
                         "crimes"                 => 1969,
                         "criminal"               => 1158,
                         "criminalistics"         => 15367,
                         "criminally"             => 6391,
                         "criminals"              => 2451,
                         "criminy"                => 17507,
                         "crimp"                  => 11772,
                         "cringe"                 => 11771,
                         "crinkle"                => 13823,
                         "cripes"                 => 13243,
                         "cripple"                => 5124,
                         "crippled"               => 5010,
                         "cripples"               => 16305,
                         "crippling"              => 9360,
                         "crips"                  => 9591,
                         "cris"                   => 1901,
                         "crisper"                => 14541,
                         "crispina"               => 7795,
                         "crisps"                 => 16304,
                         "crissake"               => 18902,
                         "cristian"               => 612,
                         "cristobel"              => 3224,
                         "criticise"              => 14540,
                         "criticize"              => 4904,
                         "croak"                  => 10376,
                         "croaked"                => 14539,
                         "croaks"                 => 14538,
                         "crock"                  => 4150,
                         "crocodile"              => 6318,
                         "croissant"              => 9837,
                         "croissants"             => 10089,
                         "cronies"                => 11002,
                         "cronkite"               => 11369,
                         "cronus"                 => 8381,
                         "cronyn"                 => 15366,
                         "crooked"                => 4544,
                         "croon"                  => 18901,
                         "cropped"                => 17506,
                         "croquet"                => 11770,
                         "crossbow"               => 6171,
                         "crosscheck"             => 18900,
                         "crossed"                => 1438,
                         "crossfire"              => 6390,
                         "crosshairs"             => 15365,
                         "crosswalk"              => 13822,
                         "crossword"              => 6103,
                         "crotch"                 => 6573,
                         "crouched"               => 16303,
                         "crouching"              => 12700,
                         "croupier"               => 10375,
                         "croutons"               => 17505,
                         "crowd"                  => 1457,
                         "crowded"                => 3013,
                         "crowding"               => 8563,
                         "crowed"                 => 17504,
                         "crowing"                => 17503,
                         "crowning"               => 10664,
                         "crows"                  => 6739,
                         "cruces"                 => 13821,
                         "crucified"              => 8957,
                         "crucifix"               => 10663,
                         "crucify"                => 7647,
                         "cruddy"                 => 11769,
                         "crudely"                => 18899,
                         "cruel"                  => 1503,
                         "cruelest"               => 9359,
                         "cruelly"                => 12699,
                         "cruelty"                => 4792,
                         "cruisin"                => 15364,
                         "cruising"               => 4903,
                         "cruller"                => 13820,
                         "crumble"                => 6830,
                         "crumbled"               => 11001,
                         "crumblers"              => 18898,
                         "crumbles"               => 10088,
                         "crumbling"              => 8741,
                         "crummy"                 => 4603,
                         "crumpets"               => 12698,
                         "crumpled"               => 11000,
                         "crunched"               => 18897,
                         "crunches"               => 16302,
                         "crunching"              => 9162,
                         "crush"                  => 1525,
                         "crushed"                => 2751,
                         "crushes"                => 7646,
                         "crushing"               => 4864,
                         "crust"                  => 5444,
                         "crusts"                 => 10662,
                         "crutch"                 => 7163,
                         "crutches"               => 6643,
                         "cryin"                  => 6317,
                         "crying"                 => 929,
                         "cryogenically"          => 14537,
                         "crypt"                  => 4977,
                         "cryptic"                => 5498,
                         "cryptid"                => 18896,
                         "crypts"                 => 18895,
                         "cryss"                  => 13242,
                         "cryto"                  => 10999,
                         "cubans"                 => 4667,
                         "cubed"                  => 12229,
                         "cubes"                  => 6246,
                         "cubicle"                => 4632,
                         "cucamonga"              => 13819,
                         "cucaracha"              => 14536,
                         "cuckoo"                 => 5302,
                         "cucumbers"              => 14535,
                         "cuddle"                 => 5696,
                         "cuddled"                => 12697,
                         "cuddling"               => 9161,
                         "cuddly"                 => 7403,
                         "cuddy"                  => 5443,
                         "cuff"                   => 3266,
                         "cuffed"                 => 10374,
                         "cuffing"                => 18894,
                         "cufflink"               => 6738,
                         "cufflinks"              => 7162,
                         "cuffs"                  => 3384,
                         "cuisinart"              => 18893,
                         "culottes"               => 15363,
                         "culpa"                  => 8956,
                         "culpability"            => 18892,
                         "culpable"               => 12696,
                         "culprit"                => 9358,
                         "cultivating"            => 10998,
                         "cumin"                  => 11368,
                         "cummerbund"             => 16301,
                         "cunning"                => 5123,
                         "cupboard"               => 5916,
                         "cupboards"              => 15362,
                         "cupcakes"               => 10373,
                         "cupid"                  => 4468,
                         "cuppa"                  => 11367,
                         "cups"                   => 2960,
                         "curb"                   => 3360,
                         "curdle"                 => 18891,
                         "curdled"                => 13818,
                         "cure"                   => 1619,
                         "cured"                  => 3155,
                         "cures"                  => 8562,
                         "curfew"                 => 3872,
                         "curfews"                => 16300,
                         "curie"                  => 12228,
                         "curing"                 => 7794,
                         "curiosity"              => 2709,
                         "curiouser"              => 13817,
                         "curiousity"             => 17502,
                         "curled"                 => 6469,
                         "curlers"                => 12227,
                         "curls"                  => 9357,
                         "curly"                  => 4467,
                         "curmudgeon"             => 18890,
                         "curse"                  => 1631,
                         "cursed"                 => 2895,
                         "curses"                 => 6937,
                         "cursing"                => 6737,
                         "cursory"                => 11366,
                         "curtain"                => 2972,
                         "curtains"               => 3658,
                         "curtsy"                 => 11365,
                         "curvaceous"             => 17501,
                         "curveball"              => 16299,
                         "cushion"                => 5553,
                         "cushions"               => 7402,
                         "cushy"                  => 10372,
                         "cussing"                => 13241,
                         "custodial"              => 7962,
                         "custodian"              => 10661,
                         "custody"                => 1113,
                         "customer"               => 2061,
                         "cut"                    => 386,
                         "cutaway"                => 18889,
                         "cutbacks"               => 12695,
                         "cute"                   => 642,
                         "cuteness"               => 15361,
                         "cuter"                  => 5263,
                         "cutest"                 => 3926,
                         "cutesy"                 => 18888,
                         "cuticle"                => 17500,
                         "cuticles"               => 15360,
                         "cutie"                  => 3845,
                         "cutlery"                => 16298,
                         "cutoffs"                => 17499,
                         "cutout"                 => 16297,
                         "cuts"                   => 2364,
                         "cutters"                => 8380,
                         "cutthroat"              => 10087,
                         "cuttin"                 => 8561,
                         "cutting"                => 1507,
                         "cuvee"                  => 8955,
                         "cyanide"                => 8379,
                         "cyberdyne"              => 17498,
                         "cyberspace"             => 12694,
                         "cyclotron"              => 12693,
                         "cylon"                  => 6642,
                         "cylons"                 => 7521,
                         "cymbal"                 => 17497,
                         "cynic"                  => 8740,
                         "cynical"                => 3986,
                         "cynicism"               => 8378,
                         "cynics"                 => 18887,
                         "cytoxan"                => 16296,
                         "czechoslovakian"        => 17496,
                         "czechoslovakians"       => 15359,
                         "d'agnasti"              => 17495,
                         "d'agosta"               => 13240,
                         "d'alene"                => 17494,
                         "d'algout"               => 10997,
                         "d'amour"                => 8084,
                         "d'angelo"               => 2894,
                         "d'arcy"                 => 6572,
                         "d'argent"               => 17493,
                         "d'artagnan"             => 5864,
                         "d'astier"               => 18886,
                         "d'etre"                 => 17492,
                         "d'hoffryn"              => 18885,
                         "d'oeuvre"               => 12226,
                         "d'oeuvres"              => 5986,
                         "d'peshu"                => 18884,
                         "d'ya"                   => 3093,
                         "d'you"                  => 1884,
                         "dabble"                 => 10371,
                         "dabbled"                => 17491,
                         "dabbling"               => 17490,
                         "dachau"                 => 13816,
                         "dad"                    => 159,
                         "dad'll"                 => 12225,
                         "daddies"                => 10370,
                         "daddy"                  => 421,
                         "daddy'll"               => 17489,
                         "dads"                   => 4791,
                         "daffodils"              => 11364,
                         "daggers"                => 13815,
                         "dagon"                  => 15358,
                         "dailies"                => 10660,
                         "dainty"                 => 8954,
                         "daiquiri"               => 13239,
                         "daiquiris"              => 13814,
                         "daisies"                => 7645,
                         "dalai"                  => 6736,
                         "dalliance"              => 13238,
                         "dallying"               => 15357,
                         "dalrimple"              => 18883,
                         "damaging"               => 4631,
                         "damaskinos"             => 18882,
                         "damme"                  => 17488,
                         "damn"                   => 276,
                         "damnable"               => 13237,
                         "damnation"              => 9160,
                         "damndest"               => 14534,
                         "damned"                 => 1428,
                         "damnedest"              => 7644,
                         "damning"                => 12224,
                         "damone"                 => 8953,
                         "dampen"                 => 14533,
                         "dampened"               => 18881,
                         "dampener"               => 17487,
                         "damper"                 => 7793,
                         "damsel"                 => 6468,
                         "damsels"                => 12223,
                         "dan'l"                  => 7643,
                         "dance"                  => 517,
                         "danced"                 => 2869,
                         "dancin"                 => 6829,
                         "dancing"                => 1012,
                         "dandelions"             => 18880,
                         "dandruff"               => 11768,
                         "dandy"                  => 5009,
                         "danes"                  => 7520,
                         "dangerous"              => 712,
                         "dangerously"            => 4863,
                         "dangers"                => 5552,
                         "dangle"                 => 7269,
                         "dangled"                => 16295,
                         "dangles"                => 14532,
                         "dangling"               => 6828,
                         "danieljackson"          => 16294,
                         "danke"                  => 16293,
                         "dankova"                => 12692,
                         "danson"                 => 10086,
                         "danvers"                => 6245,
                         "daph"                   => 4567,
                         "dappy"                  => 15356,
                         "dardis"                 => 17486,
                         "dare"                   => 894,
                         "dared"                  => 6467,
                         "dares"                  => 10369,
                         "daresay"                => 14531,
                         "daring"                 => 5081,
                         "dark"                   => 669,
                         "darkened"               => 15355,
                         "darkest"                => 4566,
                         "darklighter"            => 8377,
                         "darklighters"           => 18879,
                         "darkroom"               => 10368,
                         "darks"                  => 16292,
                         "darlin"                 => 3475,
                         "darling"                => 541,
                         "darlings"               => 7519,
                         "darn"                   => 1905,
                         "darndest"               => 13236,
                         "darned"                 => 5053,
                         "darnit"                 => 16291,
                         "darsh"                  => 12222,
                         "darwinian"              => 18878,
                         "darwinism"              => 16290,
                         "daryll"                 => 11767,
                         "dash"                   => 3640,
                         "dashboard"              => 9159,
                         "dashed"                 => 10367,
                         "dashing"                => 5638,
                         "dashwood"               => 4543,
                         "dastardly"              => 13813,
                         "date"                   => 372,
                         "dateless"               => 10996,
                         "dateline"               => 13235,
                         "dater"                  => 15354,
                         "datin"                  => 18877,
                         "dating"                 => 855,
                         "daughter"               => 322,
                         "daunting"               => 12691,
                         "dauphine"               => 14530,
                         "dauthuille"             => 13812,
                         "davic"                  => 16289,
                         "davola"                 => 18876,
                         "dawdle"                 => 14529,
                         "dawdling"               => 16288,
                         "dawned"                 => 10659,
                         "dawnie"                 => 6466,
                         "dawning"                => 15353,
                         "daybreak"               => 9158,
                         "daycare"                => 8739,
                         "daydreaming"            => 7401,
                         "daydreams"              => 9356,
                         "daylight"               => 2868,
                         "daylights"              => 9157,
                         "dazzled"                => 8560,
                         "dazzling"               => 7642,
                         "deacon"                 => 998,
                         "deactivate"             => 9355,
                         "deactivated"            => 9590,
                         "dead"                   => 224,
                         "deadbeat"               => 6936,
                         "deadbeats"              => 13234,
                         "deadbolt"               => 13811,
                         "deader"                 => 10366,
                         "deadlier"               => 16287,
                         "deadline"               => 2912,
                         "deadlines"              => 6735,
                         "deadly"                 => 2667,
                         "deaf"                   => 2359,
                         "deafening"              => 15352,
                         "deal"                   => 241,
                         "dealer"                 => 2391,
                         "dealers"                => 4565,
                         "dealership"             => 6935,
                         "dealey"                 => 12221,
                         "dealin"                 => 10365,
                         "dealing"                => 988,
                         "dealings"               => 5551,
                         "dealio"                 => 10085,
                         "deals"                  => 2517,
                         "dealt"                  => 2247,
                         "deaqon"                 => 18875,
                         "dear"                   => 433,
                         "dearest"                => 2697,
                         "dearie"                 => 12690,
                         "dearly"                 => 3620,
                         "dears"                  => 10995,
                         "deathbed"               => 8559,
                         "deathly"                => 12689,
                         "deathwok"               => 11363,
                         "debacle"                => 8952,
                         "debatable"              => 12220,
                         "debating"               => 5301,
                         "debauchery"             => 9836,
                         "debilitating"           => 11362,
                         "debonair"               => 16286,
                         "debrief"                => 7641,
                         "debriefed"              => 13233,
                         "debriefing"             => 7792,
                         "debt"                   => 1915,
                         "debts"                  => 4290,
                         "debutante"              => 8951,
                         "debutantes"             => 16285,
                         "decadence"              => 15351,
                         "decadent"               => 10994,
                         "decaf"                  => 4446,
                         "decanter"               => 17485,
                         "decapitate"             => 17484,
                         "decapitated"            => 10364,
                         "decapitation"           => 16284,
                         "decaying"               => 10993,
                         "deceit"                 => 6934,
                         "deceitful"              => 5985,
                         "deceive"                => 5122,
                         "deceived"               => 5343,
                         "deceiving"              => 4756,
                         "decency"                => 3345,
                         "decent"                 => 1272,
                         "deception"              => 3310,
                         "deceptions"             => 16283,
                         "deceptive"              => 11361,
                         "deceptively"            => 16282,
                         "decibel"                => 15350,
                         "decibels"               => 16281,
                         "decide"                 => 783,
                         "decidedly"              => 9354,
                         "deciding"               => 3639,
                         "decimate"               => 13810,
                         "decipher"               => 6244,
                         "deciphered"             => 14528,
                         "deciphering"            => 16280,
                         "decision"               => 633,
                         "decisions"              => 1388,
                         "deck"                   => 1809,
                         "decked"                 => 9156,
                         "declare"                => 3003,
                         "decode"                 => 9835,
                         "decoded"                => 12219,
                         "decoder"                => 10084,
                         "decompose"              => 16279,
                         "decomposed"             => 12688,
                         "decomposing"            => 10658,
                         "decompress"             => 15349,
                         "deconstruction"         => 16278,
                         "decontamination"        => 17483,
                         "decorate"               => 4602,
                         "decorating"             => 4511,
                         "decorator"              => 6389,
                         "decorators"             => 18874,
                         "decorum"                => 9155,
                         "decoupage"              => 15348,
                         "decoy"                  => 5497,
                         "decoys"                 => 15347,
                         "decrepit"               => 14527,
                         "decruz"                 => 9353,
                         "decrypted"              => 17482,
                         "decryption"             => 15346,
                         "dedicate"               => 5212,
                         "deduce"                 => 13232,
                         "deduct"                 => 12687,
                         "deductible"             => 9154,
                         "deduction"              => 7518,
                         "deductions"             => 13231,
                         "deductive"              => 13809,
                         "deed"                   => 2750,
                         "deeds"                  => 3023,
                         "deemesa"                => 13230,
                         "deep"                   => 711,
                         "deepcore"               => 13808,
                         "deeper"                 => 2119,
                         "deepest"                => 3925,
                         "deeply"                 => 1784,
                         "deevak"                 => 13229,
                         "defaced"                => 18873,
                         "defacing"               => 16277,
                         "defective"              => 6827,
                         "defector"               => 17481,
                         "defenceless"            => 16276,
                         "defend"                 => 1479,
                         "defendant"              => 2434,
                         "defending"              => 1727,
                         "defenseless"            => 5211,
                         "defer"                  => 9589,
                         "deference"              => 14526,
                         "defiantly"              => 16275,
                         "defib"                  => 18872,
                         "defibrillator"          => 16274,
                         "defied"                 => 10657,
                         "defies"                 => 10083,
                         "defile"                 => 14525,
                         "defiled"                => 13807,
                         "definatly"              => 17480,
                         "definite"               => 3033,
                         "definitely"             => 551,
                         "deflate"                => 17479,
                         "deflated"               => 18871,
                         "deflect"                => 9588,
                         "deflecting"             => 15345,
                         "deflector"              => 14524,
                         "deflower"               => 16273,
                         "deformed"               => 9587,
                         "deformity"              => 17478,
                         "defraud"                => 16272,
                         "defrost"                => 8950,
                         "deftly"                 => 17477,
                         "defuse"                 => 8083,
                         "defused"                => 15344,
                         "defying"                => 9153,
                         "degas"                  => 14523,
                         "degaulle"               => 17476,
                         "degenerate"             => 7400,
                         "degenerates"            => 14522,
                         "degenerative"           => 12686,
                         "degrade"                => 13228,
                         "degrading"              => 7517,
                         "degrassi"               => 5550,
                         "dehydrated"             => 7050,
                         "dehydration"            => 10656,
                         "deigned"                => 16271,
                         "delacour"               => 18870,
                         "delacroix"              => 7399,
                         "delaford"               => 17475,
                         "delay"                  => 2500,
                         "delaying"               => 7516,
                         "delbruck"               => 17474,
                         "delectable"             => 10992,
                         "deliberate"             => 5496,
                         "deliberately"           => 2330,
                         "delicacies"             => 14521,
                         "delicacy"               => 8376,
                         "delicate"               => 2464,
                         "delicately"             => 8949,
                         "delicates"              => 16270,
                         "delicious"              => 1638,
                         "deliciously"            => 14520,
                         "delighted"              => 2867,
                         "delightful"             => 2938,
                         "delightfully"           => 11766,
                         "delights"               => 10082,
                         "delinquent"             => 6243,
                         "delinquents"            => 13806,
                         "delirious"              => 4630,
                         "deliriously"            => 9834,
                         "delirium"               => 13227,
                         "delish"                 => 17473,
                         "deliver"                => 1433,
                         "deliverance"            => 14519,
                         "deliveries"             => 6388,
                         "delivering"             => 3410,
                         "delivery"               => 1658,
                         "dellarte"               => 18869,
                         "delly"                  => 11765,
                         "delts"                  => 18868,
                         "delude"                 => 13226,
                         "deluded"                => 4601,
                         "deluding"               => 7268,
                         "delusion"               => 5080,
                         "delusional"             => 2920,
                         "delusions"              => 4354,
                         "delve"                  => 12685,
                         "delving"                => 16269,
                         "demanding"              => 3041,
                         "demean"                 => 17472,
                         "demeaning"              => 6734,
                         "demeanor"               => 9833,
                         "demented"               => 4946,
                         "dementia"               => 8738,
                         "demerits"               => 13225,
                         "demerol"                => 10991,
                         "demolitions"            => 17471,
                         "demon"                  => 813,
                         "demonic"                => 3283,
                         "demonology"             => 18867,
                         "demons"                 => 1348,
                         "demony"                 => 16268,
                         "demur"                  => 18866,
                         "demure"                 => 17470,
                         "deniability"            => 13805,
                         "denial"                 => 2162,
                         "denials"                => 14518,
                         "deniece"                => 16267,
                         "denies"                 => 6170,
                         "denim"                  => 9352,
                         "dennings"               => 14517,
                         "denominator"            => 9832,
                         "denominators"           => 18865,
                         "dental"                 => 3122,
                         "dented"                 => 9351,
                         "dentist"                => 2456,
                         "dentists"               => 7398,
                         "dents"                  => 15343,
                         "dentures"               => 18864,
                         "deny"                   => 1262,
                         "denying"                => 2605,
                         "deodorant"              => 6316,
                         "depend"                 => 2425,
                         "dependable"             => 6037,
                         "dependant"              => 18863,
                         "depended"               => 4945,
                         "depends"                => 1219,
                         "deplete"                => 17469,
                         "deplorable"             => 12684,
                         "deplore"                => 17468,
                         "deport"                 => 15342,
                         "depose"                 => 15341,
                         "deposing"               => 16266,
                         "deposit"                => 2530,
                         "deposition"             => 3760,
                         "depositions"            => 8375,
                         "depository"             => 8558,
                         "depraved"               => 6733,
                         "depravity"              => 13804,
                         "deprecating"            => 12683,
                         "depress"                => 12218,
                         "depressants"            => 13803,
                         "depressed"              => 1899,
                         "depressing"             => 2906,
                         "depressive"             => 9350,
                         "depressor"              => 15340,
                         "depressors"             => 18862,
                         "deprive"                => 6315,
                         "deprived"               => 5442,
                         "depriving"              => 9152,
                         "depths"                 => 4697,
                         "deputized"              => 18861,
                         "derail"                 => 8737,
                         "derailed"               => 9586,
                         "derailing"              => 18860,
                         "deranged"               => 5300,
                         "derevko"                => 6314,
                         "derision"               => 18859,
                         "dermatologist"          => 8948,
                         "derogatory"             => 10081,
                         "deron"                  => 11360,
                         "derriere"               => 11359,
                         "derris"                 => 17467,
                         "describe"               => 1768,
                         "desdemona"              => 7791,
                         "desecrate"              => 16265,
                         "desecrated"             => 17466,
                         "desecration"            => 18858,
                         "deserted"               => 3032,
                         "deserter"               => 11358,
                         "deserting"              => 9151,
                         "desertion"              => 13802,
                         "deserve"                => 640,
                         "deserved"               => 1777,
                         "deserves"               => 1146,
                         "deserving"              => 6826,
                         "desi"                   => 4755,
                         "desires"                => 3778,
                         "desist"                 => 11357,
                         "desk"                   => 972,
                         "desks"                  => 7397,
                         "desolate"               => 13224,
                         "desolation"             => 14516,
                         "despair"                => 3798,
                         "desperate"              => 1056,
                         "desperately"            => 2212,
                         "desperation"            => 4564,
                         "despicable"             => 3638,
                         "despise"                => 3121,
                         "despised"               => 8082,
                         "despises"               => 5441,
                         "despising"              => 15339,
                         "despondent"             => 18857,
                         "dessaline"              => 12682,
                         "dessert"                => 1634,
                         "desserts"               => 5813,
                         "destabilize"            => 16264,
                         "destined"               => 3319,
                         "destinies"              => 9349,
                         "destroy"                => 808,
                         "destroying"             => 2329,
                         "destroys"               => 5440,
                         "destruct"               => 4826,
                         "destructing"            => 13223,
                         "destructive"            => 2803,
                         "destructs"              => 17465,
                         "detach"                 => 13222,
                         "detail"                 => 1636,
                         "details"                => 1038,
                         "detain"                 => 8374,
                         "detaining"              => 18856,
                         "detective"              => 763,
                         "detectives"             => 2659,
                         "detector"               => 3418,
                         "detectors"              => 6825,
                         "detente"                => 17464,
                         "detention"              => 2937,
                         "detergent"              => 7790,
                         "deteriorate"            => 9348,
                         "deterrent"              => 10655,
                         "detest"                 => 7267,
                         "detestable"             => 18855,
                         "detests"                => 18854,
                         "detonate"               => 6732,
                         "detonates"              => 18853,
                         "detonating"             => 15338,
                         "detonation"             => 7640,
                         "detonator"              => 6036,
                         "detonators"             => 11356,
                         "detour"                 => 5695,
                         "detours"                => 17463,
                         "detox"                  => 9831,
                         "detoxing"               => 17462,
                         "detract"                => 17461,
                         "detriment"              => 13801,
                         "deuces"                 => 8233,
                         "devane"                 => 2610,
                         "devastate"              => 8373,
                         "devastated"             => 2133,
                         "devastating"            => 4316,
                         "devastatingly"          => 16263,
                         "devastation"            => 8947,
                         "deveraux"               => 3907,
                         "deviants"               => 18852,
                         "deviate"                => 13800,
                         "deviated"               => 10990,
                         "deviled"                => 10989,
                         "devilishly"             => 17460,
                         "devious"                => 4825,
                         "devise"                 => 11355,
                         "devising"               => 13799,
                         "devola"                 => 14515,
                         "devote"                 => 5984,
                         "devoting"               => 12681,
                         "devotion"               => 3637,
                         "devour"                 => 8736,
                         "devoured"               => 11354,
                         "devouring"              => 13221,
                         "devours"                => 17459,
                         "diabetic"               => 6387,
                         "diabetics"              => 18851,
                         "diabolical"             => 6102,
                         "diagnose"               => 8081,
                         "diagnosing"             => 14514,
                         "diagnosis"              => 3154,
                         "diagnostician"          => 17458,
                         "dialed"                 => 5983,
                         "dialing"                => 7161,
                         "dialysis"               => 11764,
                         "diapers"                => 3255,
                         "diaphragm"              => 8232,
                         "diaphragms"             => 16262,
                         "diarrhea"               => 8080,
                         "diary"                  => 2095,
                         "diathesis"              => 18850,
                         "diatribe"               => 13798,
                         "diatribes"              => 18849,
                         "diazepam"               => 10080,
                         "dibbs"                  => 8557,
                         "dicaprio"               => 12217,
                         "dice"                   => 3582,
                         "diced"                  => 13220,
                         "dicey"                  => 7961,
                         "dicing"                 => 14513,
                         "dickensian"             => 16261,
                         "dicking"                => 15337,
                         "dickwad"                => 18848,
                         "dictate"                => 4510,
                         "dictates"               => 10079,
                         "dictating"              => 11353,
                         "dictation"              => 11763,
                         "dictators"              => 17457,
                         "dictatorships"          => 17456,
                         "did"                    => 47,
                         "diddling"               => 17455,
                         "diddly"                 => 10078,
                         "didja"                  => 13219,
                         "didn"                   => 4089,
                         "didn't"                 => 64,
                         "didnt"                  => 10988,
                         "didya"                  => 18847,
                         "die"                    => 345,
                         "dief"                   => 4754,
                         "diefenbaker"            => 3971,
                         "diello"                 => 17454,
                         "dies"                   => 1347,
                         "diet"                   => 2128,
                         "dieting"                => 11352,
                         "difference"             => 703,
                         "differently"            => 1807,
                         "difficult"              => 727,
                         "digest"                 => 4730,
                         "digested"               => 15336,
                         "digesting"              => 17453,
                         "digestion"              => 10987,
                         "diggin"                 => 9150,
                         "digging"                => 1887,
                         "diggory"                => 14512,
                         "digitalis"              => 14511,
                         "dignan"                 => 5171,
                         "dignified"              => 6933,
                         "dignify"                => 7639,
                         "dignity"                => 2246,
                         "digress"                => 11351,
                         "digs"                   => 4790,
                         "dilate"                 => 14510,
                         "dilated"                => 7789,
                         "dilation"               => 16260,
                         "dilemma"                => 4106,
                         "dilettante"             => 16259,
                         "diligence"              => 13218,
                         "diligent"               => 12216,
                         "diligently"             => 16258,
                         "dilly"                  => 11762,
                         "dilucca"                => 3889,
                         "dime"                   => 2132,
                         "dimension"              => 3012,
                         "dimera"                 => 1686,
                         "dimeras"                => 3985,
                         "dimes"                  => 8372,
                         "diminish"               => 8231,
                         "dimly"                  => 17452,
                         "dimmed"                 => 14509,
                         "dimming"                => 16257,
                         "dimmy"                  => 13797,
                         "dimoxinil"              => 13796,
                         "dimpled"                => 18846,
                         "dimwitted"              => 13795,
                         "dined"                  => 12215,
                         "diner"                  => 1826,
                         "diners"                 => 10077,
                         "dinged"                 => 15335,
                         "dinghy"                 => 13794,
                         "dings"                  => 11761,
                         "dingy"                  => 11350,
                         "dining"                 => 2313,
                         "dinka"                  => 17451,
                         "dinks"                  => 18845,
                         "dinky"                  => 8230,
                         "dinner"                 => 351,
                         "dinners"                => 3392,
                         "dinnertime"             => 8946,
                         "dinning"                => 16256,
                         "dinosaurs"              => 4542,
                         "diorama"                => 14508,
                         "diperna"                => 12214,
                         "diphtheria"             => 18844,
                         "dipped"                 => 6932,
                         "dipping"                => 5299,
                         "dippy"                  => 14507,
                         "dire"                   => 4753,
                         "directions"             => 2433,
                         "dirt"                   => 1424,
                         "dirtier"                => 13793,
                         "dirtiest"               => 18843,
                         "dirty"                  => 909,
                         "disable"                => 7049,
                         "disagree"               => 2188,
                         "disagreeable"           => 13792,
                         "disagreeing"            => 10986,
                         "disagreement"           => 4976,
                         "disagrees"              => 8371,
                         "disappear"              => 1277,
                         "disappearance"          => 2905,
                         "disappearances"         => 8229,
                         "disappeared"            => 1208,
                         "disappearing"           => 3295,
                         "disappears"             => 3507,
                         "disappoint"             => 1963,
                         "disappointed"           => 1240,
                         "disappointing"          => 4149,
                         "disappointment"         => 2834,
                         "disappointments"        => 6931,
                         "disappoints"            => 15334,
                         "disapprove"             => 6386,
                         "disapproves"            => 12213,
                         "disapproving"           => 13217,
                         "disarm"                 => 7266,
                         "disarmed"               => 12212,
                         "disarming"              => 12680,
                         "disarray"               => 8945,
                         "disaster"               => 1436,
                         "disastrous"             => 4944,
                         "disavowed"              => 14506,
                         "disbarred"              => 7960,
                         "disbelief"              => 10985,
                         "discerning"             => 15333,
                         "discharging"            => 13791,
                         "disciplined"            => 8556,
                         "disciplining"           => 15332,
                         "disclosure"             => 5915,
                         "discoloration"          => 10076,
                         "discolored"             => 18842,
                         "discomfort"             => 6035,
                         "disconcerting"          => 9347,
                         "disconnect"             => 7396,
                         "disconnected"           => 4541,
                         "discontinue"            => 11760,
                         "discord"                => 13216,
                         "discotheque"            => 18841,
                         "discount"               => 3332,
                         "discounting"            => 17450,
                         "discourage"             => 6385,
                         "discouraged"            => 6242,
                         "discouraging"           => 9585,
                         "discourteous"           => 18840,
                         "discredit"              => 7160,
                         "discreet"               => 3888,
                         "discreetly"             => 10363,
                         "discrepancies"          => 10984,
                         "discrepancy"            => 8735,
                         "discretion"             => 4353,
                         "discriminating"         => 11759,
                         "discuss"                => 802,
                         "discussed"              => 1894,
                         "discussing"             => 1776,
                         "discussion"             => 1536,
                         "disdain"                => 10654,
                         "diseased"               => 8079,
                         "disengage"              => 9584,
                         "disengaged"             => 14505,
                         "disfigured"             => 8555,
                         "disfiguring"            => 16255,
                         "disgrace"               => 3759,
                         "disgraced"              => 10983,
                         "disgraceful"            => 9346,
                         "disgruntled"            => 6241,
                         "disguise"               => 3359,
                         "disguised"              => 5744,
                         "disguises"              => 9149,
                         "disgust"                => 4824,
                         "disgusted"              => 5052,
                         "disgusting"             => 1431,
                         "disgustingly"           => 13215,
                         "disgusts"               => 9830,
                         "dish"                   => 2153,
                         "disheartening"          => 18839,
                         "dishes"                 => 2520,
                         "disheveled"             => 16254,
                         "dishing"                => 14504,
                         "dishonest"              => 4789,
                         "dishonesty"             => 9583,
                         "dishonor"               => 7959,
                         "dishonorable"           => 11758,
                         "dishonored"             => 14503,
                         "dishwalla"              => 14502,
                         "dishwasher"             => 5121,
                         "dishwashing"            => 15331,
                         "disillusioned"          => 7958,
                         "disillusionment"        => 18838,
                         "disinfect"              => 18837,
                         "disinfectant"           => 11349,
                         "disinformation"         => 17449,
                         "disingenuous"           => 16253,
                         "disinherit"             => 17448,
                         "disinherited"           => 12211,
                         "disintegrate"           => 10362,
                         "disintegrated"          => 12679,
                         "disintegrating"         => 14501,
                         "disinterested"          => 13790,
                         "disks"                  => 6465,
                         "dislike"                => 4600,
                         "dislikes"               => 9582,
                         "disliking"              => 14500,
                         "dislocated"             => 8734,
                         "dislodge"               => 17447,
                         "dislodged"              => 17446,
                         "disloyal"               => 7395,
                         "disloyalty"             => 13789,
                         "dismal"                 => 8944,
                         "dismantle"              => 6824,
                         "dismember"              => 18836,
                         "dismemberment"          => 18835,
                         "dismiss"                => 3719,
                         "dismissing"             => 10982,
                         "dismissive"             => 16252,
                         "dismount"               => 12210,
                         "disneyland"             => 7048,
                         "disneyworld"            => 16251,
                         "disobey"                => 8228,
                         "disobeyed"              => 7047,
                         "disobeying"             => 11348,
                         "disorderly"             => 9829,
                         "disorganized"           => 13214,
                         "disorientation"         => 12678,
                         "disoriented"            => 5637,
                         "disorienting"           => 16250,
                         "disown"                 => 12209,
                         "disowned"               => 15330,
                         "disparage"              => 14499,
                         "disparaging"            => 12677,
                         "dispatch"               => 4466,
                         "dispatcher"             => 10075,
                         "dispense"               => 7394,
                         "dispenser"              => 7788,
                         "dispensers"             => 16249,
                         "dispensing"             => 10074,
                         "displace"               => 13213,
                         "displeased"             => 12208,
                         "displeasure"            => 10653,
                         "disposable"             => 6930,
                         "disposal"               => 3383,
                         "dispose"                => 4788,
                         "disposing"              => 12676,
                         "disposition"            => 6929,
                         "disprove"               => 11347,
                         "disputing"              => 10652,
                         "disqualify"             => 15329,
                         "disraeli"               => 15328,
                         "disregard"              => 5398,
                         "disrespect"             => 3522,
                         "disrespected"           => 11346,
                         "disrespectful"          => 6169,
                         "disrespecting"          => 13212,
                         "disrupt"                => 5298,
                         "disrupting"             => 8370,
                         "disrupts"               => 18834,
                         "dissect"                => 7787,
                         "dissected"              => 12675,
                         "dissecting"             => 14498,
                         "dissection"             => 12674,
                         "dissed"                 => 8943,
                         "disservice"             => 17445,
                         "dissimilar"             => 14497,
                         "dissing"                => 7786,
                         "dissipate"              => 15327,
                         "dissociative"           => 9345,
                         "dissolve"               => 6384,
                         "dissuade"               => 13211,
                         "distancing"             => 16248,
                         "distaste"               => 17444,
                         "distasteful"            => 10651,
                         "distended"              => 15326,
                         "distinctly"             => 6168,
                         "distort"                => 12207,
                         "distract"               => 2516,
                         "distracted"             => 2038,
                         "distracting"            => 3797,
                         "distraction"            => 2887,
                         "distractions"           => 4540,
                         "distracts"              => 13788,
                         "distraught"             => 4787,
                         "distress"               => 2951,
                         "distressed"             => 8227,
                         "distressing"            => 10361,
                         "distrust"               => 10360,
                         "distrustful"            => 18833,
                         "disturb"                => 2515,
                         "disturbance"            => 4943,
                         "disturbed"              => 2494,
                         "disturbing"             => 2514,
                         "disturbs"               => 9828,
                         "ditch"                  => 2304,
                         "ditched"                => 4414,
                         "ditching"               => 5863,
                         "ditsy"                  => 17443,
                         "ditto"                  => 4902,
                         "ditty"                  => 11757,
                         "ditzy"                  => 14496,
                         "diuretic"               => 18832,
                         "diuretics"              => 18831,
                         "dive"                   => 2293,
                         "diversify"              => 13787,
                         "diversion"              => 3924,
                         "diversionary"           => 16247,
                         "diversions"             => 15325,
                         "divert"                 => 7159,
                         "diverting"              => 13210,
                         "dives"                  => 8733,
                         "divest"                 => 18830,
                         "divining"               => 18829,
                         "divola"                 => 17442,
                         "divorce"                => 862,
                         "divorced"               => 1596,
                         "divorcee"               => 11345,
                         "divorces"               => 6731,
                         "divorcing"              => 5170,
                         "divulge"                => 9344,
                         "divulged"               => 16246,
                         "divvy"                  => 13209,
                         "dizziness"              => 6823,
                         "dizzy"                  => 2550,
                         "dizzying"               => 17441,
                         "dmitri"                 => 7158,
                         "do"                     => 17,
                         "doable"                 => 9581,
                         "dobermans"              => 17440,
                         "dobisch"                => 11344,
                         "dobler"                 => 16245,
                         "docile"                 => 13786,
                         "dock"                   => 2727,
                         "docket"                 => 13785,
                         "docking"                => 7957,
                         "docks"                  => 2643,
                         "doctored"               => 7046,
                         "doctoring"              => 14495,
                         "doctors"                => 964,
                         "dodgeball"              => 8732,
                         "dodged"                 => 7045,
                         "dodging"                => 5743,
                         "dodgy"                  => 11756,
                         "doers"                  => 13784,
                         "does"                   => 128,
                         "doesn"                  => 6928,
                         "doesn't"                => 113,
                         "doesnt"                 => 16244,
                         "dog"                    => 542,
                         "dogcatcher"             => 14494,
                         "dogged"                 => 11755,
                         "dogging"                => 9580,
                         "doily"                  => 13208,
                         "doin"                   => 982,
                         "doing"                  => 99,
                         "doings"                 => 14493,
                         "dokey"                  => 4862,
                         "dokie"                  => 12206,
                         "dokos"                  => 17439,
                         "doling"                 => 10073,
                         "doll"                   => 1301,
                         "dollars"                => 558,
                         "dolled"                 => 10650,
                         "dollhouse"              => 10981,
                         "dollop"                 => 16243,
                         "dolls"                  => 3144,
                         "domesticity"            => 16242,
                         "domicile"               => 17438,
                         "dominatrix"             => 13783,
                         "domineering"            => 14492,
                         "dominoes"               => 15324,
                         "don't"                  => 14,
                         "don'tcha"               => 14491,
                         "don'ts"                 => 11343,
                         "donate"                 => 3796,
                         "donating"               => 6641,
                         "donation"               => 3358,
                         "doncha"                 => 17437,
                         "donde"                  => 10359,
                         "done"                   => 170,
                         "doneghy"                => 18828,
                         "dongs"                  => 11754,
                         "donkeys"                => 10358,
                         "donnatella"             => 17436,
                         "donor"                  => 2157,
                         "donot"                  => 11753,
                         "donovon"                => 9148,
                         "donowitz"               => 15323,
                         "dont"                   => 4861,
                         "dontcha"                => 18827,
                         "donut"                  => 4509,
                         "doodling"               => 14490,
                         "doofy"                  => 9827,
                         "doohickey"              => 17435,
                         "doohicky"               => 18826,
                         "doom"                   => 3461,
                         "doomed"                 => 2467,
                         "door"                   => 328,
                         "doorbell"               => 4386,
                         "doork"                  => 5694,
                         "doorknobs"              => 17434,
                         "doorman"                => 3887,
                         "doormat"                => 8554,
                         "doornail"               => 11752,
                         "doors"                  => 1318,
                         "doorstep"               => 3538,
                         "doorway"                => 4197,
                         "doorways"               => 9343,
                         "doose"                  => 9826,
                         "doozy"                  => 10357,
                         "dope"                   => 3002,
                         "doped"                  => 9579,
                         "dopes"                  => 18825,
                         "dopey"                  => 6927,
                         "doppelganger"           => 18824,
                         "doree"                  => 9147,
                         "doren"                  => 4289,
                         "dork"                   => 3554,
                         "dorkface"               => 17433,
                         "dorks"                  => 9342,
                         "dorky"                  => 7157,
                         "dorleen"                => 12205,
                         "dorm"                   => 2312,
                         "dorma"                  => 13207,
                         "dorms"                  => 7515,
                         "dorsia"                 => 11751,
                         "dory"                   => 4508,
                         "dosage"                 => 5297,
                         "dosages"                => 18823,
                         "dose"                   => 3153,
                         "dosed"                  => 12204,
                         "dossier"                => 8078,
                         "dostoyevsky"            => 14489,
                         "dotes"                  => 17432,
                         "doting"                 => 9825,
                         "dots"                   => 4288,
                         "dotted"                 => 8226,
                         "doublemeat"             => 10072,
                         "doubly"                 => 10356,
                         "doubt"                  => 707,
                         "doubted"                => 3309,
                         "doubtful"               => 6822,
                         "doubting"               => 4445,
                         "doubts"                 => 1968,
                         "douchebag"              => 14488,
                         "douggie"                => 14487,
                         "dough"                  => 2809,
                         "doughnut"               => 4240,
                         "doughnuts"              => 3923,
                         "doused"                 => 12203,
                         "doves"                  => 6383,
                         "dovey"                  => 10355,
                         "down"                   => 87,
                         "downers"                => 13782,
                         "downloaded"             => 7044,
                         "downloading"            => 9341,
                         "downplay"               => 13781,
                         "downpour"               => 18822,
                         "downright"              => 4729,
                         "downriver"              => 16241,
                         "downside"               => 6382,
                         "downsize"               => 18821,
                         "downsizing"             => 15322,
                         "downstairs"             => 1082,
                         "downtime"               => 9340,
                         "downtrodden"            => 12202,
                         "downy"                  => 18820,
                         "dowser"                 => 8553,
                         "dozed"                  => 7156,
                         "dozen"                  => 1630,
                         "dozens"                 => 3553,
                         "dozer"                  => 6313,
                         "dozing"                 => 17431,
                         "drafty"                 => 10980,
                         "drag"                   => 1187,
                         "dragged"                => 1782,
                         "draggin"                => 15321,
                         "dragging"               => 2351,
                         "dragline"               => 13780,
                         "drags"                  => 7393,
                         "drainpipe"              => 17430,
                         "dramamine"              => 14486,
                         "dramatics"              => 13779,
                         "drang"                  => 17429,
                         "drank"                  => 2338,
                         "drape"                  => 12201,
                         "draped"                 => 8369,
                         "drapes"                 => 5495,
                         "drastic"                => 4262,
                         "drawback"               => 11342,
                         "drawbacks"              => 9824,
                         "drawbridge"             => 14485,
                         "drawer"                 => 2000,
                         "drawers"                => 4315,
                         "drawstring"             => 17428,
                         "drazen"                 => 4539,
                         "drazens"                => 18819,
                         "drazi"                  => 9578,
                         "dread"                  => 5549,
                         "dreaded"                => 6571,
                         "dreadful"               => 3537,
                         "dreadfully"             => 13778,
                         "dreading"               => 7155,
                         "dream"                  => 506,
                         "dreamboat"              => 15320,
                         "dreamed"                => 1618,
                         "dreamin"                => 9823,
                         "dreaming"               => 1606,
                         "dreamless"              => 17427,
                         "dreamt"                 => 3581,
                         "dreamy"                 => 7043,
                         "dreary"                 => 7042,
                         "dreck"                  => 15319,
                         "dredge"                 => 8077,
                         "dredged"                => 11750,
                         "dredging"               => 11341,
                         "dregs"                  => 15318,
                         "dreidel"                => 4507,
                         "drell"                  => 7956,
                         "drenched"               => 9577,
                         "dress"                  => 643,
                         "dressed"                => 934,
                         "dresser"                => 4001,
                         "dresses"                => 2200,
                         "dressing"               => 2251,
                         "dressy"                 => 13206,
                         "drexl"                  => 11340,
                         "drey'auc"               => 16240,
                         "dreyfuss"               => 10354,
                         "dribbles"               => 18818,
                         "dribbling"              => 12200,
                         "dried"                  => 3132,
                         "drier"                  => 8076,
                         "dries"                  => 10979,
                         "drift"                  => 3536,
                         "drifted"                => 6640,
                         "drifting"               => 4629,
                         "drifts"                 => 14484,
                         "driftwood"              => 15317,
                         "drill"                  => 2270,
                         "drills"                 => 9339,
                         "drink"                  => 418,
                         "drinkers"               => 13205,
                         "drinkin"                => 5693,
                         "drinking"               => 942,
                         "drinks"                 => 1300,
                         "drinky"                 => 14483,
                         "drip"                   => 4175,
                         "dripped"                => 18817,
                         "dripping"               => 4901,
                         "drippy"                 => 17426,
                         "drips"                  => 18816,
                         "drive"                  => 500,
                         "drivel"                 => 8942,
                         "drives"                 => 2168,
                         "driveway"               => 3031,
                         "driveways"              => 17425,
                         "drivin"                 => 5210,
                         "driving"                => 770,
                         "droid"                  => 14482,
                         "droids"                 => 18815,
                         "drokken"                => 8075,
                         "droll"                  => 10353,
                         "drones"                 => 9146,
                         "drool"                  => 4900,
                         "drooled"                => 17424,
                         "drooling"               => 4128,
                         "drools"                 => 16239,
                         "droop"                  => 18814,
                         "drop"                   => 504,
                         "dropout"                => 11749,
                         "dropped"                => 912,
                         "dropper"                => 15316,
                         "droppin"                => 16238,
                         "dropping"               => 1571,
                         "droppings"              => 10649,
                         "drops"                  => 2549,
                         "drossos"                => 17423,
                         "drove"                  => 1286,
                         "droves"                 => 16237,
                         "drown"                  => 2721,
                         "drowned"                => 2770,
                         "drowning"               => 2637,
                         "drowns"                 => 14481,
                         "drowsy"                 => 9145,
                         "drudge"                 => 18813,
                         "drue"                   => 4752,
                         "drug"                   => 830,
                         "drugged"                => 2575,
                         "druggie"                => 13777,
                         "drugging"               => 6312,
                         "druggist"               => 17422,
                         "drugs"                  => 858,
                         "drugstore"              => 5296,
                         "drumlin"                => 14480,
                         "drummed"                => 13204,
                         "drumstick"              => 15315,
                         "drumsticks"             => 12673,
                         "drunk"                  => 819,
                         "drunkard"               => 18812,
                         "drunken"                => 3040,
                         "drunkenness"            => 14479,
                         "drunker"                => 13776,
                         "drunks"                 => 5862,
                         "druthers"               => 17421,
                         "dryer"                  => 3672,
                         "dryers"                 => 11339,
                         "drying"                 => 6101,
                         "dubious"                => 7955,
                         "duchaisne"              => 18811,
                         "duchamp"                => 14478,
                         "ducked"                 => 8731,
                         "ducking"                => 6639,
                         "duct"                   => 4314,
                         "ducts"                  => 9144,
                         "duddy"                  => 14477,
                         "dude"                   => 594,
                         "dudes"                  => 3357,
                         "dudleys"                => 17420,
                         "dueling"                => 12199,
                         "duesouth"               => 13775,
                         "duffel"                 => 8225,
                         "duffle"                 => 12672,
                         "dufus"                  => 14476,
                         "dugout"                 => 10071,
                         "dugray"                 => 18810,
                         "duisberg"               => 13203,
                         "dulcet"                 => 16236,
                         "dulcinea"               => 9822,
                         "dull"                   => 2355,
                         "dullard"                => 17419,
                         "dulled"                 => 15314,
                         "dulles"                 => 7785,
                         "dullest"                => 11748,
                         "dulli"                  => 15313,
                         "dullness"               => 15312,
                         "duloc"                  => 13202,
                         "dumb"                   => 1043,
                         "dumbasses"              => 13201,
                         "dumber"                 => 6100,
                         "dumbest"                => 5120,
                         "dumbledore"             => 14475,
                         "dumbo"                  => 4628,
                         "dumbshit"               => 13200,
                         "dumdum"                 => 17418,
                         "dummkopf"               => 18809,
                         "dummy"                  => 3120,
                         "dump"                   => 1199,
                         "dumped"                 => 1349,
                         "dumper"                 => 7954,
                         "dumping"                => 2959,
                         "dumpling"               => 10648,
                         "dumplings"              => 10978,
                         "dumps"                  => 4148,
                         "dumpster"               => 4068,
                         "dumpsters"              => 13199,
                         "dumpty"                 => 14474,
                         "duncans"                => 16235,
                         "dunked"                 => 17417,
                         "dunking"                => 17416,
                         "dunks"                  => 15311,
                         "dunno"                  => 1760,
                         "dunois"                 => 17415,
                         "dunville"               => 10070,
                         "dunwitty"               => 11747,
                         "duped"                  => 7784,
                         "duper"                  => 13774,
                         "duplex"                 => 11338,
                         "duplicate"              => 5494,
                         "duplicitous"            => 14473,
                         "dupres"                 => 8552,
                         "duress"                 => 8551,
                         "durned"                 => 17414,
                         "durslar"                => 17413,
                         "dussander"              => 11746,
                         "dust"                   => 1648,
                         "dusted"                 => 7638,
                         "dusting"                => 6638,
                         "dutiful"                => 10977,
                         "duty"                   => 1087,
                         "duvet"                  => 16234,
                         "duwayne"                => 10352,
                         "dweeb"                  => 10976,
                         "dwell"                  => 4067,
                         "dweller"                => 17412,
                         "dwells"                 => 16233,
                         "dyeing"                 => 16232,
                         "dying"                  => 776,
                         "dysfunctional"          => 4899,
                         "dyslexia"               => 14472,
                         "dyslexic"               => 13773,
                         "eager"                  => 2466,
                         "eagerly"                => 10069,
                         "eally"                  => 16231,
                         "eardrum"                => 14471,
                         "earful"                 => 7783,
                         "earlobe"                => 13198,
                         "earlobes"               => 16230,
                         "earmarks"               => 17411,
                         "earmuffs"               => 13772,
                         "earn"                   => 2240,
                         "earphones"              => 17410,
                         "earpiece"               => 13197,
                         "earplugs"               => 8368,
                         "earring"                => 4506,
                         "earrings"               => 2911,
                         "ears"                   => 1267,
                         "earshot"                => 15310,
                         "earthlings"             => 10068,
                         "earthly"                => 7637,
                         "earthy"                 => 16229,
                         "ease"                   => 1812,
                         "easel"                  => 12671,
                         "easely"                 => 17409,
                         "eases"                  => 13196,
                         "easier"                 => 853,
                         "easiest"                => 3599,
                         "easing"                 => 10351,
                         "easterland"             => 12198,
                         "easy"                   => 331,
                         "easygoing"              => 15309,
                         "eat"                    => 391,
                         "eaten"                  => 1840,
                         "eater"                  => 4898,
                         "eaters"                 => 8367,
                         "eatin"                  => 4666,
                         "eating"                 => 844,
                         "eats"                   => 2323,
                         "eavesdrop"              => 5812,
                         "eavesdropped"           => 18808,
                         "eavesdropping"          => 3922,
                         "ebola"                  => 9821,
                         "eccentric"              => 5742,
                         "eccentricities"         => 15308,
                         "echelon"                => 6464,
                         "echinacea"              => 13195,
                         "ecirc"                  => 17408,
                         "ecklie"                 => 9576,
                         "ecstasy"                => 5169,
                         "ecstatic"               => 5168,
                         "ectopic"                => 17407,
                         "ectoplasm"              => 18807,
                         "eczema"                 => 16228,
                         "edema"                  => 10647,
                         "edgy"                   => 4088,
                         "eecom"                  => 16227,
                         "eerie"                  => 7782,
                         "eerily"                 => 16226,
                         "effacing"               => 18806,
                         "effecting"              => 16225,
                         "effeminate"             => 15307,
                         "effortless"             => 17406,
                         "egging"                 => 18805,
                         "eggnog"                 => 6570,
                         "eggroll"                => 13771,
                         "eggs"                   => 1441,
                         "eggshell"               => 13194,
                         "eggshells"              => 10350,
                         "egocentric"             => 11745,
                         "egomaniac"              => 9143,
                         "egomaniacal"            => 18804,
                         "egotistical"            => 7636,
                         "egotitis"               => 16224,
                         "egregious"              => 10349,
                         "ehrlichman"             => 12197,
                         "eiffel"                 => 7781,
                         "eighteen"               => 1883,
                         "eighths"                => 14470,
                         "eighties"               => 5585,
                         "eights"                 => 10067,
                         "eighty"                 => 1803,
                         "eigth"                  => 13193,
                         "eirie"                  => 16223,
                         "either"                 => 319,
                         "ejaculate"              => 15306,
                         "eject"                  => 10646,
                         "eking"                  => 18803,
                         "eladio"                 => 12196,
                         "elated"                 => 16222,
                         "elbow"                  => 3946,
                         "elbows"                 => 5493,
                         "elders"                 => 2600,
                         "electrician"            => 7635,
                         "electricians"           => 18802,
                         "electrocute"            => 13192,
                         "electrocuted"           => 6637,
                         "electrolytes"           => 11337,
                         "electroshock"           => 12670,
                         "elegance"               => 8074,
                         "elegant"                => 3945,
                         "elephants"              => 4599,
                         "elevate"                => 8941,
                         "elevates"               => 15305,
                         "elevator"               => 1303,
                         "elevators"              => 4696,
                         "eleven"                 => 1529,
                         "eliminate"              => 3112,
                         "eling"                  => 16221,
                         "elitist"                => 8073,
                         "elixir"                 => 11336,
                         "ellenor"                => 3688,
                         "ellsberg"               => 9820,
                         "elope"                  => 4000,
                         "eloped"                 => 5636,
                         "elopement"              => 9338,
                         "eloping"                => 5167,
                         "eloquent"               => 9142,
                         "eloquently"             => 10645,
                         "else"                   => 168,
                         "elsinore"               => 9575,
                         "elspeth"                => 13191,
                         "elster"                 => 11335,
                         "elude"                  => 13190,
                         "eluded"                 => 10644,
                         "eludes"                 => 16220,
                         "elusive"                => 7265,
                         "elves"                  => 4942,
                         "emailed"                => 13770,
                         "emanates"               => 18801,
                         "emancipated"            => 15304,
                         "emasculating"           => 14469,
                         "embalmed"               => 16219,
                         "embalming"              => 13189,
                         "embarass"               => 13188,
                         "embarassed"             => 13187,
                         "embarassing"            => 10975,
                         "embark"                 => 7953,
                         "embarrass"              => 2537,
                         "embarrassed"            => 1413,
                         "embarrasses"            => 12669,
                         "embarrassing"           => 1447,
                         "embarrassingly"         => 16218,
                         "embarrassment"          => 3506,
                         "embarressed"            => 16217,
                         "ember"                  => 15303,
                         "embers"                 => 14468,
                         "embezzle"               => 18800,
                         "embezzled"              => 9141,
                         "embezzlement"           => 8224,
                         "embezzler"              => 16216,
                         "embezzling"             => 11334,
                         "embittered"             => 17405,
                         "embodiment"             => 9819,
                         "embolism"               => 9574,
                         "embrace"                => 3216,
                         "embracing"              => 8550,
                         "embryos"                => 9818,
                         "emdash"                 => 8549,
                         "emeralds"               => 15302,
                         "emergencies"            => 5342,
                         "emergency"              => 911,
                         "eminence"               => 10066,
                         "eminently"              => 16215,
                         "emissary"               => 9573,
                         "emmys"                  => 16214,
                         "emotion"                => 2777,
                         "emotional"              => 1386,
                         "emotionally"            => 2264,
                         "emotions"               => 1923,
                         "empath"                 => 10643,
                         "empathetic"             => 13769,
                         "empathic"               => 18799,
                         "empathize"              => 9817,
                         "empathy"                => 6730,
                         "emphatic"               => 15301,
                         "emphatically"           => 12668,
                         "emphysema"              => 14467,
                         "employee"               => 2115,
                         "emporium"               => 10348,
                         "emptied"                => 7041,
                         "emptiness"              => 6311,
                         "emptive"                => 16213,
                         "empty"                  => 985,
                         "emptying"               => 10974,
                         "emulating"              => 17404,
                         "enamored"               => 11744,
                         "encephalitis"           => 11333,
                         "enchant"                => 11743,
                         "enchante"               => 13186,
                         "enchanted"              => 5079,
                         "enchanting"             => 6821,
                         "enchantment"            => 2260,
                         "enchantress"            => 9337,
                         "enchilada"              => 9572,
                         "encino"                 => 18798,
                         "enclose"                => 14466,
                         "encouragement"          => 4505,
                         "encouraging"            => 3070,
                         "encrusted"              => 18797,
                         "encrypted"              => 8548,
                         "encyclopedias"          => 17403,
                         "endanger"               => 6099,
                         "endangering"            => 8730,
                         "endangerment"           => 7154,
                         "endear"                 => 18796,
                         "endearing"              => 8366,
                         "endearment"             => 13768,
                         "endeavor"               => 6569,
                         "endings"                => 5439,
                         "endive"                 => 17402,
                         "endless"                => 3143,
                         "endlessly"              => 7264,
                         "endor"                  => 12667,
                         "endorphins"             => 16212,
                         "endorse"                => 7040,
                         "ends"                   => 1198,
                         "endure"                 => 4287,
                         "enema"                  => 10642,
                         "enemies"                => 1745,
                         "energized"              => 11332,
                         "enfants"                => 17401,
                         "engaged"                => 1183,
                         "engagement"             => 1384,
                         "englishman"             => 6636,
                         "engrossed"              => 15300,
                         "engrossing"             => 16211,
                         "enhancer"               => 18795,
                         "enjoy"                  => 646,
                         "enjoyable"              => 6098,
                         "enjoyed"                => 1721,
                         "enjoying"               => 1476,
                         "enjoyment"              => 7952,
                         "enjoys"                 => 4563,
                         "enlighten"              => 4213,
                         "enlightened"            => 5982,
                         "enlightening"           => 9571,
                         "enlist"                 => 7392,
                         "ennui"                  => 11331,
                         "enormity"               => 17400,
                         "enormous"               => 2513,
                         "enormously"             => 8547,
                         "enough"                 => 176,
                         "enquire"                => 13767,
                         "enquirer"               => 7263,
                         "enquiries"              => 17399,
                         "enrage"                 => 18794,
                         "enriching"              => 18793,
                         "ensconced"              => 12195,
                         "ensenada"               => 18792,
                         "enslave"                => 15299,
                         "ensue"                  => 10641,
                         "entail"                 => 12666,
                         "entails"                => 9140,
                         "entanglements"          => 15298,
                         "entendre"               => 16210,
                         "enterprises"            => 2833,
                         "enterprising"           => 12665,
                         "entertain"              => 3535,
                         "entertained"            => 5584,
                         "entertaining"           => 3202,
                         "enthralled"             => 18791,
                         "enthused"               => 16209,
                         "enthusiasm"             => 3254,
                         "enthusiastic"           => 4313,
                         "entice"                 => 10065,
                         "enticed"                => 16208,
                         "enticing"               => 9336,
                         "entire"                 => 562,
                         "entitle"                => 17398,
                         "entitles"               => 10064,
                         "entourage"              => 8072,
                         "entrails"               => 10347,
                         "entrap"                 => 14465,
                         "entrapment"             => 6034,
                         "entree"                 => 12194,
                         "entrees"                => 13766,
                         "entrust"                => 11330,
                         "entwined"               => 12193,
                         "envelope"               => 2473,
                         "envelopes"              => 6381,
                         "envied"                 => 11742,
                         "envious"                => 6926,
                         "envy"                   => 2720,
                         "enzo"                   => 2688,
                         "epcot"                  => 18790,
                         "ephram"                 => 1823,
                         "ephrum"                 => 15297,
                         "epidural"               => 13185,
                         "epileptic"              => 10346,
                         "epinephrine"            => 10063,
                         "epiphany"               => 6240,
                         "epithelials"            => 15296,
                         "epitome"                => 14464,
                         "epizootics"             => 15295,
                         "epoxy"                  => 16207,
                         "equalizer"              => 13765,
                         "equals"                 => 3718,
                         "equate"                 => 13764,
                         "equivalency"            => 13763,
                         "erase"                  => 2604,
                         "erased"                 => 3598,
                         "erasers"                => 10973,
                         "erases"                 => 15294,
                         "erasing"                => 7780,
                         "erlich"                 => 14463,
                         "ernswiler"              => 18789,
                         "eroding"                => 18788,
                         "erogenous"              => 13184,
                         "errand"                 => 3240,
                         "errands"                => 3201,
                         "errant"                 => 11741,
                         "erratic"                => 5861,
                         "erratically"            => 18787,
                         "erred"                  => 17397,
                         "errrr"                  => 18786,
                         "erupt"                  => 10345,
                         "escalate"               => 9335,
                         "escalating"             => 10062,
                         "escalator"              => 8940,
                         "escapade"               => 10972,
                         "escapades"              => 16206,
                         "escape"                 => 1025,
                         "escaped"                => 1567,
                         "escapee"                => 15293,
                         "escaping"               => 4413,
                         "escargot"               => 15292,
                         "escorts"                => 8365,
                         "escrow"                 => 9816,
                         "eskimos"                => 9570,
                         "esmail"                 => 18785,
                         "esmerelda"              => 16205,
                         "esophageal"             => 13762,
                         "esophagus"              => 12664,
                         "especially"             => 520,
                         "espressos"              => 18784,
                         "essay"                  => 2795,
                         "essence"                => 3152,
                         "essentials"             => 9569,
                         "estamos"                => 17396,
                         "estas"                  => 10971,
                         "esteem"                 => 2929,
                         "esteemed"               => 7391,
                         "estoy"                  => 16204,
                         "estranged"              => 6925,
                         "estrangement"           => 14462,
                         "estrogen"               => 9139,
                         "etcetera"               => 8364,
                         "etched"                 => 8729,
                         "eternally"              => 6239,
                         "ether"                  => 7634,
                         "ethic"                  => 8223,
                         "ethically"              => 10640,
                         "ethics"                 => 2788,
                         "ethros"                 => 11329,
                         "etins"                  => 13761,
                         "etiquette"              => 5438,
                         "eubie"                  => 14461,
                         "eulogy"                 => 6167,
                         "eunuch"                 => 10970,
                         "euphemism"              => 8071,
                         "euphemisms"             => 17395,
                         "euphoric"               => 17394,
                         "eurotrash"              => 14460,
                         "evacuate"               => 5341,
                         "evacuating"             => 11740,
                         "evading"                => 9815,
                         "evander"                => 17393,
                         "evaporate"              => 10344,
                         "evaporated"             => 15291,
                         "evasion"                => 9334,
                         "evasions"               => 18783,
                         "evasive"                => 7039,
                         "even"                   => 96,
                         "evenin"                 => 10639,
                         "evening"                => 560,
                         "eventful"               => 12663,
                         "eventuality"            => 17392,
                         "ever"                   => 118,
                         "ever'body"              => 9568,
                         "ever'thing"             => 14459,
                         "everbody"               => 15290,
                         "everglades"             => 10969,
                         "everlasting"            => 5981,
                         "everthing"              => 17391,
                         "everwood"               => 3999,
                         "every"                  => 175,
                         "everybody"              => 315,
                         "everybody'd"            => 18782,
                         "everyday"               => 1886,
                         "everyone"               => 312,
                         "everything"             => 123,
                         "everything'll"          => 10638,
                         "everything's"           => 682,
                         "everytime"              => 5397,
                         "everywhere"             => 1034,
                         "evian"                  => 13760,
                         "evict"                  => 8546,
                         "evicted"                => 5548,
                         "evidence"               => 641,
                         "evidentiary"            => 14458,
                         "evidently"              => 3175,
                         "evil"                   => 550,
                         "evils"                  => 6568,
                         "eviscerate"             => 16203,
                         "eviscerated"            => 13183,
                         "ewwww"                  => 13182,
                         "exacerbate"             => 17390,
                         "exact"                  => 1278,
                         "exacting"               => 18781,
                         "exactly"                => 217,
                         "exaggerate"             => 5980,
                         "exaggerating"           => 3921,
                         "exaggeration"           => 7390,
                         "exalted"                => 12662,
                         "exam"                   => 2148,
                         "examine"                => 2566,
                         "examiner"               => 5635,
                         "examining"              => 5119,
                         "exasperated"            => 16202,
                         "exasperating"           => 18780,
                         "exceedingly"            => 10343,
                         "excellency"             => 5914,
                         "excellent"              => 880,
                         "excels"                 => 18779,
                         "except"                 => 514,
                         "excepted"               => 12192,
                         "excercise"              => 15289,
                         "excercises"             => 13759,
                         "exchanging"             => 7389,
                         "excited"                => 873,
                         "excitement"             => 2384,
                         "excites"                => 10637,
                         "exciting"               => 1134,
                         "exclamation"            => 7779,
                         "excrement"              => 13758,
                         "excruciating"           => 6097,
                         "excruciatingly"         => 14457,
                         "exculpatory"            => 17389,
                         "excuse"                 => 227,
                         "excused"                => 4627,
                         "excuses"                => 1853,
                         "excusez"                => 13757,
                         "excusing"               => 12191,
                         "execs"                  => 17388,
                         "execute"                => 4019,
                         "executioner"            => 8363,
                         "exemplary"              => 8362,
                         "exercise"               => 1878,
                         "exercising"             => 5913,
                         "exert"                  => 9333,
                         "exerting"               => 15288,
                         "exertion"               => 15287,
                         "exfoliate"              => 18778,
                         "exhale"                 => 11328,
                         "exhausted"              => 1708,
                         "exhausting"             => 5396,
                         "exhaustion"             => 6567,
                         "exhausts"               => 18777,
                         "exhilarated"            => 15286,
                         "exhilarating"           => 7951,
                         "exhilaration"           => 18776,
                         "exhumation"             => 18775,
                         "exhume"                 => 16201,
                         "existential"            => 7514,
                         "existentialist"         => 17387,
                         "exit"                   => 2090,
                         "exits"                  => 4538,
                         "exonerate"              => 8545,
                         "exonerated"             => 7633,
                         "exorbitant"             => 15285,
                         "exorcise"               => 17386,
                         "exorcism"               => 7038,
                         "exorcist"               => 11327,
                         "expect"                 => 528,
                         "expectant"              => 13756,
                         "expectations"           => 2561,
                         "expectin"               => 14456,
                         "expecting"              => 997,
                         "expects"                => 3318,
                         "expedient"              => 13181,
                         "expedite"               => 10061,
                         "expedited"              => 17385,
                         "expel"                  => 8728,
                         "expelling"              => 15284,
                         "expendable"             => 7513,
                         "expense"                => 2574,
                         "expenses"               => 3391,
                         "expensive"              => 1396,
                         "experiencing"           => 3490,
                         "experimenting"          => 6820,
                         "expert"                 => 1510,
                         "expiration"             => 7778,
                         "expire"                 => 9567,
                         "expires"                => 10342,
                         "explain"                => 469,
                         "explaining"             => 2463,
                         "explains"               => 2049,
                         "explanation"            => 1225,
                         "explanations"           => 4465,
                         "explanatory"            => 10968,
                         "expletive"              => 14455,
                         "explode"                => 2420,
                         "exploded"               => 3795,
                         "explodes"               => 5741,
                         "exploding"              => 5860,
                         "exploit"                => 5209,
                         "exploiting"             => 7037,
                         "exploratory"            => 10967,
                         "explore"                => 2776,
                         "explosion"              => 1986,
                         "explosions"             => 6819,
                         "explosives"             => 3844,
                         "expose"                 => 2295,
                         "exposer"                => 9814,
                         "exposing"               => 4941,
                         "expresso"               => 14454,
                         "expunged"               => 15283,
                         "exquisite"              => 3521,
                         "exquisitely"            => 17384,
                         "extenuating"            => 9138,
                         "exterminate"            => 10636,
                         "exterminated"           => 16200,
                         "exterminating"          => 18774,
                         "exterminator"           => 5740,
                         "exterminators"          => 13755,
                         "extinguish"             => 15282,
                         "extinguisher"           => 8727,
                         "extort"                 => 10060,
                         "extorted"               => 18773,
                         "extorting"              => 18772,
                         "extortion"              => 4728,
                         "extortionist"           => 17383,
                         "extra"                  => 834,
                         "extracurricular"        => 6729,
                         "extracurriculars"       => 15281,
                         "extradite"              => 15280,
                         "extradited"             => 10341,
                         "extradition"            => 6463,
                         "extramarital"           => 16199,
                         "extraordinaire"         => 11739,
                         "extraordinarily"        => 8939,
                         "extraordinary"          => 2284,
                         "extras"                 => 5979,
                         "extraterrestrial"       => 8938,
                         "extraterrestrials"      => 15279,
                         "extravagant"            => 8937,
                         "extravaganza"           => 10966,
                         "extremely"              => 1394,
                         "extremists"             => 11326,
                         "extremities"            => 10340,
                         "extricate"              => 12661,
                         "exxon"                  => 15278,
                         "eye"                    => 554,
                         "eyeballin"              => 17382,
                         "eyeballs"               => 4147,
                         "eyebrow"                => 7632,
                         "eyebrows"               => 4562,
                         "eyed"                   => 2636,
                         "eyeful"                 => 16198,
                         "eyeglasses"             => 14453,
                         "eyeing"                 => 10059,
                         "eyelash"                => 7262,
                         "eyelashes"              => 7261,
                         "eyelid"                 => 14452,
                         "eyelids"                => 8936,
                         "eyeliner"               => 10339,
                         "eyepatch"               => 15277,
                         "eyes"                   => 358,
                         "eyesight"               => 6818,
                         "eyesore"                => 13180,
                         "eyewitness"             => 3253,
                         "eyewitnesses"           => 7512,
                         "eyghon"                 => 12660,
                         "faberge"                => 18771,
                         "fabled"                 => 17381,
                         "fabricate"              => 12659,
                         "fabricating"            => 13754,
                         "fabulous"               => 1317,
                         "fabulously"             => 13179,
                         "face"                   => 252,
                         "facedown"               => 17380,
                         "faceless"               => 8726,
                         "faceman"                => 12190,
                         "faces"                  => 1512,
                         "facetious"              => 15276,
                         "facials"                => 10635,
                         "fact"                   => 301,
                         "factoid"                => 17379,
                         "factored"               => 14451,
                         "factoring"              => 16197,
                         "facts"                  => 1236,
                         "fade"                   => 3597,
                         "faded"                  => 5811,
                         "fades"                  => 7777,
                         "fading"                 => 5118,
                         "faggots"                => 8544,
                         "faggy"                  => 18770,
                         "fahrenheit"             => 10965,
                         "fail"                   => 1535,
                         "failings"               => 15275,
                         "faint"                  => 2949,
                         "fainted"                => 3131,
                         "fainter"                => 15274,
                         "faintest"               => 8935,
                         "fainting"               => 7631,
                         "fair"                   => 568,
                         "faire"                  => 10964,
                         "fairer"                 => 15273,
                         "fairest"                => 8934,
                         "fairies"                => 7388,
                         "fairly"                 => 2118,
                         "fairness"               => 5912,
                         "fairservice"            => 17378,
                         "fairwinds"              => 3944,
                         "fairy"                  => 1701,
                         "fairytale"              => 17377,
                         "faithful"               => 2743,
                         "faithfully"             => 9332,
                         "faithfulness"           => 16196,
                         "faithless"              => 15272,
                         "fake"                   => 1131,
                         "faked"                  => 3275,
                         "faker"                  => 9566,
                         "fakes"                  => 9565,
                         "faking"                 => 2358,
                         "falafel"                => 13178,
                         "fall"                   => 538,
                         "fallback"               => 10634,
                         "fallible"               => 16195,
                         "falling"                => 1009,
                         "fallopian"              => 15271,
                         "fallow"                 => 11738,
                         "false"                  => 1578,
                         "falsified"              => 13753,
                         "falsify"                => 15270,
                         "faltered"               => 18769,
                         "fambly"                 => 13752,
                         "familiar"               => 1135,
                         "familiarize"            => 10963,
                         "familiars"              => 13177,
                         "famished"               => 7776,
                         "fanatical"              => 14450,
                         "fanaticism"             => 18768,
                         "fanatics"               => 12189,
                         "fancied"                => 11325,
                         "fancier"                => 14449,
                         "fancies"                => 9564,
                         "fanciful"               => 10962,
                         "fancy"                  => 1285,
                         "fangs"                  => 4504,
                         "fantabulous"            => 15269,
                         "fantasies"              => 3022,
                         "fantasize"              => 7775,
                         "fantasized"             => 8933,
                         "fantasizing"            => 6728,
                         "fantastic"              => 1213,
                         "fantastically"          => 13176,
                         "fantasyland"            => 18767,
                         "fanucci"                => 13175,
                         "far"                    => 334,
                         "faraway"                => 11324,
                         "farbman"                => 12658,
                         "farce"                  => 5859,
                         "fare"                   => 3717,
                         "farewell"               => 3657,
                         "farewells"              => 18766,
                         "farfel"                 => 13751,
                         "farfetched"             => 10961,
                         "farkus"                 => 16194,
                         "farmin"                 => 17376,
                         "farquaad"               => 11323,
                         "farragut"               => 10633,
                         "farrouhk"               => 17375,
                         "farted"                 => 8543,
                         "farther"                => 3596,
                         "farthest"               => 9813,
                         "farts"                  => 7511,
                         "fascinate"              => 15268,
                         "fascinated"             => 4598,
                         "fascinates"             => 13750,
                         "fascinating"            => 1792,
                         "fascination"            => 8361,
                         "fashionably"            => 10632,
                         "fashioned"              => 2226,
                         "fashions"               => 4897,
                         "fast"                   => 496,
                         "fasten"                 => 5858,
                         "fastened"               => 10960,
                         "fatal"                  => 3142,
                         "fatale"                 => 16193,
                         "fate"                   => 1359,
                         "fateful"                => 9563,
                         "fates"                  => 10338,
                         "father"                 => 167,
                         "fathered"               => 6238,
                         "fatherhood"             => 8932,
                         "fathering"              => 17374,
                         "fatherless"             => 14448,
                         "fatherly"               => 8222,
                         "fathers"                => 2383,
                         "fathom"                 => 6566,
                         "fathoms"                => 14447,
                         "fatigued"               => 14446,
                         "fatigues"               => 13174,
                         "fatso"                  => 8931,
                         "fatten"                 => 12188,
                         "fattening"              => 11737,
                         "fatter"                 => 9331,
                         "fattest"                => 11736,
                         "faucet"                 => 6924,
                         "faucets"                => 18765,
                         "fault"                  => 436,
                         "faults"                 => 4751,
                         "faulty"                 => 6727,
                         "faunia"                 => 16192,
                         "favell"                 => 11735,
                         "favor"                  => 572,
                         "favore"                 => 17373,
                         "favorite"               => 730,
                         "favorites"              => 3595,
                         "favoritism"             => 12187,
                         "favors"                 => 2548,
                         "favourite"              => 2322,
                         "favours"                => 10058,
                         "fawkes"                 => 13749,
                         "fawning"                => 11322,
                         "faxed"                  => 4727,
                         "faxes"                  => 8725,
                         "faxing"                 => 14445,
                         "fe'nos"                 => 10057,
                         "fear"                   => 870,
                         "fears"                  => 2363,
                         "feasting"               => 17372,
                         "feathered"              => 9562,
                         "feathering"             => 18764,
                         "feces"                  => 12186,
                         "feckless"               => 18763,
                         "federales"              => 13748,
                         "fedex"                  => 7387,
                         "fedorchuk"              => 18762,
                         "feds"                   => 2235,
                         "feeble"                 => 6817,
                         "feed"                   => 1182,
                         "feedin"                 => 17371,
                         "feeding"                => 2048,
                         "feedings"               => 10631,
                         "feeds"                  => 4444,
                         "feel"                   => 122,
                         "feelers"                => 15267,
                         "feelin"                 => 3356,
                         "feeling"                => 321,
                         "feelings"               => 501,
                         "feels"                  => 552,
                         "feeny"                  => 6033,
                         "feet"                   => 631,
                         "feign"                  => 16191,
                         "feigning"               => 14444,
                         "feisty"                 => 5340,
                         "feldberg"               => 16190,
                         "felicity"               => 4503,
                         "fell"                   => 654,
                         "fella"                  => 1744,
                         "fellah"                 => 11321,
                         "fellahs"                => 15266,
                         "fellas"                 => 1789,
                         "felling"                => 16189,
                         "felon"                  => 3594,
                         "felonies"               => 12185,
                         "felonious"              => 12184,
                         "felons"                 => 8070,
                         "felony"                 => 2982,
                         "felt"                   => 416,
                         "feminine"               => 4146,
                         "femme"                  => 8930,
                         "femoral"                => 13747,
                         "femur"                  => 13173,
                         "fence"                  => 2173,
                         "fenceline"              => 13172,
                         "fences"                 => 5339,
                         "fending"                => 15265,
                         "fenelon"                => 18761,
                         "fenmore"                => 5857,
                         "fennyman"               => 12183,
                         "fentanyl"               => 18760,
                         "ferment"                => 15264,
                         "ferocious"              => 9561,
                         "ferragamo"              => 6816,
                         "ferrars"                => 6726,
                         "ferrie"                 => 7153,
                         "ferrini"                => 17370,
                         "fertility"              => 5166,
                         "fertilize"              => 15263,
                         "fertilizer"             => 8542,
                         "fervor"                 => 18759,
                         "fest"                   => 4286,
                         "festering"              => 12657,
                         "festive"                => 4561,
                         "festivities"            => 5338,
                         "festivus"               => 8541,
                         "fetal"                  => 6032,
                         "fetch"                  => 3011,
                         "fetched"                => 6096,
                         "fetching"               => 9330,
                         "fettes"                 => 5547,
                         "fetus"                  => 6166,
                         "fetuses"                => 10337,
                         "fever"                  => 1586,
                         "feverish"               => 11734,
                         "fevers"                 => 14443,
                         "few"                    => 258,
                         "fezzik"                 => 10959,
                         "fhloston"               => 13171,
                         "fianc"                  => 13746,
                         "fiance"                 => 3174,
                         "fiancee"                => 2821,
                         "fiasco"                 => 4665,
                         "fibber"                 => 17369,
                         "fibbing"                => 18758,
                         "fickle"                 => 7774,
                         "ficus"                  => 12656,
                         "fiddling"               => 12182,
                         "fiderer"                => 16188,
                         "fidgeting"              => 14442,
                         "fiefdom"                => 18757,
                         "fieldstone"             => 17368,
                         "fiend"                  => 5008,
                         "fiendish"               => 15262,
                         "fiends"                 => 10056,
                         "fiercest"               => 18756,
                         "fiery"                  => 5911,
                         "fifteen"                => 1020,
                         "fifties"                => 5437,
                         "fiftieth"               => 11320,
                         "fifty"                  => 803,
                         "figger"                 => 10336,
                         "figgered"               => 10958,
                         "fight"                  => 384,
                         "fightin"                => 5692,
                         "fighting"               => 726,
                         "fights"                 => 2321,
                         "figuratively"           => 7152,
                         "figure"                 => 414,
                         "figured"                => 596,
                         "figurehead"             => 15261,
                         "figuring"               => 2919,
                         "file"                   => 945,
                         "files"                  => 1310,
                         "filet"                  => 9137,
                         "filibuster"             => 13170,
                         "filing"                 => 2855,
                         "filipov"                => 16187,
                         "filko"                  => 17367,
                         "fill"                   => 958,
                         "filled"                 => 1275,
                         "fillet"                 => 13745,
                         "fillets"                => 18755,
                         "fillin"                 => 16186,
                         "filling"                => 2089,
                         "fillings"               => 12181,
                         "fills"                  => 4443,
                         "filth"                  => 4087,
                         "filthy"                 => 2113,
                         "finagle"                => 17366,
                         "finald"                 => 13744,
                         "finality"               => 18754,
                         "finalize"               => 8069,
                         "finalizing"             => 16185,
                         "finally"                => 396,
                         "financials"             => 18753,
                         "finchley"               => 7510,
                         "finchy"                 => 15260,
                         "find"                   => 108,
                         "finders"                => 11319,
                         "findin"                 => 18752,
                         "finding"                => 892,
                         "finds"                  => 860,
                         "fine"                   => 125,
                         "finelli"                => 17365,
                         "finer"                  => 4786,
                         "finesse"                => 7151,
                         "finessed"               => 18751,
                         "finest"                 => 1950,
                         "finetti"                => 17364,
                         "fingerbang"             => 16184,
                         "fingered"               => 8221,
                         "fingering"              => 13743,
                         "fingernail"             => 7950,
                         "fingernails"            => 4048,
                         "fingerpaint"            => 13169,
                         "fingerpainting"         => 18750,
                         "fingerprint"            => 5395,
                         "fingerprinted"          => 13742,
                         "fingerprinting"         => 13741,
                         "fingerprints"           => 2259,
                         "fingers"                => 1223,
                         "fingertips"             => 5739,
                         "finish"                 => 635,
                         "finito"                 => 10957,
                         "fireballs"              => 12180,
                         "firebug"                => 18749,
                         "firecracker"            => 10956,
                         "firecrackers"           => 10335,
                         "fired"                  => 879,
                         "firefight"              => 13168,
                         "fireflies"              => 10630,
                         "firehouse"              => 11318,
                         "firelight"              => 16183,
                         "firemen"                => 5051,
                         "fireplace"              => 3505,
                         "fireplaces"             => 11733,
                         "firepower"              => 6565,
                         "fireproof"              => 18748,
                         "fires"                  => 2702,
                         "firewater"              => 16182,
                         "firewood"               => 8068,
                         "fireworks"              => 2769,
                         "firing"                 => 2372,
                         "firmer"                 => 18747,
                         "firstborn"              => 6923,
                         "firsthand"              => 5007,
                         "fishbowl"               => 14441,
                         "fished"                 => 8067,
                         "fishies"                => 18746,
                         "fishsticks"             => 17363,
                         "fist"                   => 3064,
                         "fisted"                 => 13167,
                         "fistfight"              => 12179,
                         "fistful"                => 16181,
                         "fists"                  => 5436,
                         "fits"                   => 1893,
                         "fittest"                => 12178,
                         "fitting"                => 2971,
                         "fitty"                  => 10055,
                         "fitzgeralds"            => 11317,
                         "fitzwallace"            => 7630,
                         "fitzy"                  => 17362,
                         "fiver"                  => 17361,
                         "fives"                  => 9136,
                         "fix"                    => 657,
                         "fixable"                => 16180,
                         "fixated"                => 7629,
                         "fixating"               => 15259,
                         "fixation"               => 7773,
                         "fixed"                  => 1329,
                         "fixer"                  => 10955,
                         "fixes"                  => 7036,
                         "fixin"                  => 8540,
                         "fixing"                 => 2614,
                         "fixings"                => 16179,
                         "fizzled"                => 12655,
                         "flabby"                 => 14440,
                         "flagged"                => 8929,
                         "flagging"               => 17360,
                         "flagpole"               => 9329,
                         "flail"                  => 17359,
                         "flailing"               => 11316,
                         "flair"                  => 6237,
                         "flaked"                 => 10629,
                         "flakes"                 => 6236,
                         "flaky"                  => 8220,
                         "flame"                  => 2904,
                         "flaming"                => 5546,
                         "flammable"              => 8219,
                         "flannel"                => 5810,
                         "flapjacks"              => 12654,
                         "flapped"                => 18745,
                         "flapping"               => 6922,
                         "flare"                  => 4860,
                         "flared"                 => 11732,
                         "flares"                 => 7772,
                         "flaring"                => 15258,
                         "flashbang"              => 18744,
                         "flashdance"             => 17358,
                         "flashed"                => 6165,
                         "flashes"                => 3828,
                         "flashing"               => 4239,
                         "flashlight"             => 3687,
                         "flashlights"            => 9135,
                         "flashy"                 => 5545,
                         "flask"                  => 6380,
                         "flatbed"                => 13166,
                         "flatfoot"               => 13740,
                         "flatlined"              => 17357,
                         "flatten"                => 9812,
                         "flatter"                => 4066,
                         "flattered"              => 2318,
                         "flatterer"              => 15257,
                         "flattering"             => 3390,
                         "flatters"               => 18743,
                         "flattery"               => 5738,
                         "flatulence"             => 17356,
                         "flatware"               => 17355,
                         "flaubert"               => 17354,
                         "flaun"                  => 11731,
                         "flaunt"                 => 6635,
                         "flaunting"              => 7628,
                         "flavor"                 => 3906,
                         "flavored"               => 8218,
                         "flavors"                => 7771,
                         "flaw"                   => 3905,
                         "flawed"                 => 6310,
                         "flawless"               => 6164,
                         "flawlessly"             => 18742,
                         "flaws"                  => 5544,
                         "flayed"                 => 18741,
                         "flea"                   => 4065,
                         "fleabag"                => 16178,
                         "fleas"                  => 5337,
                         "flecks"                 => 17353,
                         "fledermaus"             => 18740,
                         "fledged"                => 7386,
                         "fleece"                 => 13165,
                         "fleeting"               => 6163,
                         "fleischman"             => 2970,
                         "flemmer"                => 14439,
                         "flenders"               => 16177,
                         "flesh"                  => 1574,
                         "flew"                   => 1898,
                         "flexing"                => 15256,
                         "flicked"                => 16176,
                         "flicker"                => 8539,
                         "flickering"             => 10334,
                         "flicking"               => 12177,
                         "flier"                  => 7035,
                         "fliers"                 => 7509,
                         "flies"                  => 2595,
                         "flighty"                => 12653,
                         "flimsy"                 => 7627,
                         "flinch"                 => 8538,
                         "flinched"               => 9811,
                         "flinching"              => 17352,
                         "fling"                  => 3111,
                         "flinging"               => 12176,
                         "flings"                 => 13739,
                         "flintstones"            => 18739,
                         "flip"                   => 1966,
                         "flipped"                => 3504,
                         "flippers"               => 10628,
                         "flipping"               => 4064,
                         "flips"                  => 6634,
                         "flirt"                  => 3716,
                         "flirtation"             => 9810,
                         "flirtatious"            => 15255,
                         "flirted"                => 7949,
                         "flirting"               => 2529,
                         "flirts"                 => 13738,
                         "flitting"               => 14438,
                         "float"                  => 3215,
                         "floater"                => 12175,
                         "floatin"                => 13737,
                         "floating"               => 2472,
                         "floats"                 => 5910,
                         "flock"                  => 5050,
                         "flogged"                => 16175,
                         "flogging"               => 11730,
                         "floodgates"             => 16174,
                         "floor"                  => 680,
                         "floorboard"             => 17351,
                         "floorboards"            => 10627,
                         "floored"                => 12652,
                         "floorshow"              => 17350,
                         "floozy"                 => 8066,
                         "flophouse"              => 13736,
                         "flopped"                => 17349,
                         "flopping"               => 16173,
                         "flops"                  => 10954,
                         "floris"                 => 9560,
                         "florist"                => 5006,
                         "florists"               => 17348,
                         "floss"                  => 4412,
                         "flossing"               => 11315,
                         "flotation"              => 16172,
                         "floundering"            => 15254,
                         "flowery"                => 13735,
                         "fluffed"                => 18738,
                         "fluffing"               => 15253,
                         "fluids"                 => 4411,
                         "fluke"                  => 5336,
                         "flung"                  => 8537,
                         "flunk"                  => 5909,
                         "flunked"                => 6309,
                         "flunkies"               => 13164,
                         "flunking"               => 7626,
                         "flunky"                 => 10333,
                         "flurries"               => 18737,
                         "flush"                  => 2910,
                         "flushed"                => 4410,
                         "flushes"                => 14437,
                         "flustered"              => 8536,
                         "flutter"                => 9328,
                         "fluttering"             => 15252,
                         "flyin"                  => 7948,
                         "flying"                 => 1099,
                         "foam"                   => 4047,
                         "foaming"                => 11314,
                         "foamy"                  => 11729,
                         "focker"                 => 7625,
                         "focking"                => 18736,
                         "focussing"              => 18735,
                         "fodder"                 => 11728,
                         "fogged"                 => 11727,
                         "foggiest"               => 10332,
                         "foggy"                  => 10054,
                         "foibles"                => 13163,
                         "foiled"                 => 11313,
                         "foisting"               => 18734,
                         "fold"                   => 2687,
                         "folder"                 => 5737,
                         "folders"                => 10053,
                         "folding"                => 4896,
                         "folks"                  => 968,
                         "folksy"                 => 15251,
                         "follicle"               => 16171,
                         "follicles"              => 13734,
                         "follow"                 => 600,
                         "followin"               => 16170,
                         "followup"               => 10331,
                         "folly"                  => 9134,
                         "fomin"                  => 16169,
                         "fond"                   => 2255,
                         "fonder"                 => 11312,
                         "fondest"                => 16168,
                         "fondle"                 => 15250,
                         "fondled"                => 15249,
                         "fondling"               => 15248,
                         "fondly"                 => 9809,
                         "fondness"               => 9559,
                         "fondue"                 => 8535,
                         "fonics"                 => 14436,
                         "food"                   => 498,
                         "fool"                   => 785,
                         "fooled"                 => 2027,
                         "foolhardy"              => 16167,
                         "foolin"                 => 8724,
                         "fooling"                => 2560,
                         "foolish"                => 2068,
                         "foolishly"              => 9558,
                         "foolishness"            => 8928,
                         "foolproof"              => 5736,
                         "fools"                  => 2735,
                         "foosball"               => 8065,
                         "foot"                   => 888,
                         "foothold"               => 12174,
                         "footing"                => 5691,
                         "footloose"              => 9808,
                         "footnote"               => 10953,
                         "footprints"             => 5335,
                         "footsies"               => 17347,
                         "footsteps"              => 3984,
                         "footstool"              => 18733,
                         "footwear"               => 9133,
                         "footwork"               => 12173,
                         "forbid"                 => 2432,
                         "forbidden"              => 3449,
                         "forbids"                => 12172,
                         "forceful"               => 8217,
                         "forceps"                => 11726,
                         "fordson"                => 14435,
                         "foreal"                 => 17346,
                         "forearm"                => 10952,
                         "forearms"               => 14434,
                         "foreclose"              => 14433,
                         "foreclosed"             => 17345,
                         "forefathers"            => 11311,
                         "forego"                 => 12651,
                         "foregone"               => 12650,
                         "forehead"               => 2861,
                         "foreigner"              => 10052,
                         "forensic"               => 4312,
                         "forensics"              => 2573,
                         "foresaw"                => 15247,
                         "foresee"                => 8360,
                         "foreseeable"            => 7770,
                         "foreseen"               => 9807,
                         "foresight"              => 15246,
                         "forethought"            => 18732,
                         "foretold"               => 10626,
                         "forewarned"             => 14432,
                         "forfeit"                => 6235,
                         "forfeits"               => 17344,
                         "forgave"                => 3636,
                         "forge"                  => 5005,
                         "forged"                 => 4750,
                         "forger"                 => 16166,
                         "forgery"                => 5735,
                         "forget"                 => 253,
                         "forgetful"              => 11310,
                         "forgets"                => 4063,
                         "forgettable"            => 15245,
                         "forgettin"              => 13733,
                         "forgetting"             => 1750,
                         "forging"                => 8534,
                         "forgive"                => 606,
                         "forgiven"               => 2347,
                         "forgiveness"            => 2234,
                         "forgives"               => 7769,
                         "forgiving"              => 3239,
                         "forgo"                  => 15244,
                         "forgot"                 => 585,
                         "forgotten"              => 1144,
                         "fork"                   => 2650,
                         "forked"                 => 13162,
                         "forks"                  => 6095,
                         "formaldehyde"           => 10330,
                         "formalities"            => 10051,
                         "formality"              => 4695,
                         "fornicating"            => 18731,
                         "fornication"            => 18730,
                         "forrester"              => 1111,
                         "forresters"             => 4127,
                         "forsake"                => 17343,
                         "forsaking"              => 7768,
                         "forsley"                => 12171,
                         "forth"                  => 1879,
                         "forthcoming"            => 5435,
                         "forthright"             => 10951,
                         "forthwith"              => 15243,
                         "forties"                => 7947,
                         "fortieth"               => 13161,
                         "fortitude"              => 11309,
                         "fortuitous"             => 11725,
                         "fortunate"              => 2969,
                         "fortunately"            => 2559,
                         "fortune"                => 1282,
                         "fortuneteller"          => 10329,
                         "forty"                  => 960,
                         "forward"                => 784,
                         "forwarded"              => 8216,
                         "forwarding"             => 6725,
                         "fossilized"             => 17342,
                         "foul"                   => 2354,
                         "fouled"                 => 10625,
                         "fountainhead"           => 15242,
                         "fours"                  => 6724,
                         "foursome"               => 12170,
                         "fourteen"               => 1912,
                         "fourty"                 => 17341,
                         "foxbooks"               => 13160,
                         "foxhole"                => 10624,
                         "foxholes"               => 17340,
                         "foyer"                  => 5978,
                         "fracture"               => 5049,
                         "fractured"              => 5634,
                         "fragile"                => 2572,
                         "fragrance"              => 7508,
                         "fragrances"             => 13732,
                         "fraid"                  => 5633,
                         "fraidy"                 => 17339,
                         "frail"                  => 8215,
                         "frailty"                => 16165,
                         "fraiser"                => 10050,
                         "fraizh"                 => 6633,
                         "framed"                 => 3200,
                         "framers"                => 18729,
                         "framing"                => 5809,
                         "francs"                 => 6308,
                         "frankenstein"           => 3820,
                         "frankly"                => 1259,
                         "frannie"                => 6031,
                         "frantic"                => 6462,
                         "frantically"            => 13159,
                         "fras"                   => 3703,
                         "frasier"                => 577,
                         "frat"                   => 3871,
                         "fraternity"             => 3671,
                         "fraternization"         => 18728,
                         "fraternizing"           => 10328,
                         "fraud"                  => 2108,
                         "frauds"                 => 15241,
                         "fraught"                => 13158,
                         "fraulein"               => 10327,
                         "frayed"                 => 11308,
                         "fraziers"               => 17338,
                         "frazzled"               => 10326,
                         "freak"                  => 966,
                         "freakazoid"             => 18727,
                         "freaked"                => 1473,
                         "freakin"                => 2981,
                         "freaking"               => 1710,
                         "freakish"               => 10950,
                         "freakishly"             => 14431,
                         "freckle"                => 10949,
                         "freckling"              => 15240,
                         "freddo"                 => 8359,
                         "frederika"              => 15239,
                         "fredo"                  => 6564,
                         "fredrica"               => 17337,
                         "freebies"               => 14430,
                         "freeing"                => 6723,
                         "freelancer"             => 8533,
                         "freelancing"            => 18726,
                         "freeloader"             => 16164,
                         "freeloading"            => 18725,
                         "frees"                  => 10325,
                         "freewald"               => 16163,
                         "freeways"               => 11307,
                         "freeze"                 => 1304,
                         "freezer"                => 3331,
                         "freezers"               => 17336,
                         "freezes"                => 6234,
                         "freezin"                => 16162,
                         "freezing"               => 1662,
                         "frenchies"              => 17335,
                         "frenchmen"              => 12169,
                         "frenzy"                 => 5977,
                         "freon"                  => 12649,
                         "frere"                  => 13731,
                         "fresh"                  => 904,
                         "freshen"                => 3382,
                         "freshener"              => 11724,
                         "freshening"             => 13157,
                         "freshest"               => 17334,
                         "freshly"                => 6307,
                         "freshman"               => 2719,
                         "freshmen"               => 5856,
                         "freshness"              => 13156,
                         "fretting"               => 17333,
                         "freud"                  => 4352,
                         "freudian"               => 8927,
                         "frickin"                => 6233,
                         "fricking"               => 15238,
                         "fridays"                => 7034,
                         "fridge"                 => 2337,
                         "fried"                  => 2283,
                         "friend"                 => 203,
                         "friendless"             => 12648,
                         "friendlier"             => 10948,
                         "friendliest"            => 18724,
                         "friendly"               => 1427,
                         "friends"                => 246,
                         "friendship"             => 1250,
                         "friendships"            => 6563,
                         "fries"                  => 1957,
                         "friggin"                => 4895,
                         "frigging"               => 7385,
                         "frighten"               => 3619,
                         "frightened"             => 1684,
                         "frightening"            => 2787,
                         "frighteningly"          => 14429,
                         "frightens"              => 6921,
                         "frightful"              => 11723,
                         "frightfully"            => 18723,
                         "frills"                 => 16161,
                         "frilly"                 => 9806,
                         "fritters"               => 18722,
                         "frivolous"              => 6722,
                         "frizzies"               => 18721,
                         "frizzy"                 => 13155,
                         "fro'tak"                => 13730,
                         "frobisher"              => 8926,
                         "frock"                  => 9805,
                         "frolic"                 => 11306,
                         "frolicking"             => 9804,
                         "fromberge"              => 18720,
                         "fromby"                 => 12168,
                         "fronkonsteen"           => 16160,
                         "front"                  => 408,
                         "fronting"               => 8723,
                         "froot"                  => 18719,
                         "frostbite"              => 10324,
                         "frosted"                => 9327,
                         "frosting"               => 8214,
                         "frothy"                 => 13729,
                         "froufrou"               => 18718,
                         "frown"                  => 5394,
                         "frowned"                => 14428,
                         "frowning"               => 13728,
                         "frowns"                 => 14427,
                         "froze"                  => 4018,
                         "frozen"                 => 1756,
                         "frugal"                 => 15237,
                         "fruit"                  => 1697,
                         "fruitcake"              => 5690,
                         "fruitful"               => 10947,
                         "fruitless"              => 12647,
                         "frumpy"                 => 13727,
                         "frustrated"             => 2686,
                         "frustrates"             => 18717,
                         "frustrating"            => 2996,
                         "frustration"            => 4385,
                         "frustrations"           => 9803,
                         "frutt"                  => 8925,
                         "frying"                 => 6562,
                         "fuchsia"                => 17332,
                         "fuck're"                => 17331,
                         "fucka"                  => 16159,
                         "fuckeen"                => 18716,
                         "fuckin"                 => 924,
                         "fucks"                  => 3758,
                         "fuckwad"                => 17330,
                         "fuddy"                  => 13726,
                         "fudged"                 => 17329,
                         "fudging"                => 18715,
                         "fugimotto"              => 18714,
                         "fugitive"               => 3330,
                         "fugitives"              => 7767,
                         "fugue"                  => 9132,
                         "fuhrer"                 => 8722,
                         "fukes"                  => 12167,
                         "fukienese"              => 13154,
                         "fulfill"                => 3686,
                         "fulfilled"              => 4975,
                         "fulfilling"             => 5078,
                         "fulfillment"            => 7766,
                         "fulfills"               => 14426,
                         "fulla"                  => 11722,
                         "fullest"                => 7260,
                         "fumbling"               => 17328,
                         "fumes"                  => 5734,
                         "fumigated"              => 12646,
                         "fumigating"             => 17327,
                         "fumigation"             => 16158,
                         "fun"                    => 307,
                         "fundamentals"           => 9802,
                         "fundraiser"             => 3886,
                         "funeral"                => 1160,
                         "funerals"               => 6094,
                         "funkytown"              => 18713,
                         "funnier"                => 5262,
                         "funnies"                => 18712,
                         "funniest"               => 4894,
                         "funny"                  => 352,
                         "furies"                 => 14425,
                         "furious"                => 1989,
                         "furiously"              => 15236,
                         "furnace"                => 5492,
                         "furnish"                => 14424,
                         "furniture"              => 1953,
                         "furrowed"               => 18711,
                         "furthest"               => 8213,
                         "furtive"                => 16157,
                         "furtwangler"            => 6162,
                         "fury"                   => 4502,
                         "fuse"                   => 3870,
                         "fuses"                  => 13153,
                         "fusilli"                => 15235,
                         "fusionlips"             => 15234,
                         "fuss"                   => 2849,
                         "fussing"                => 6161,
                         "fussy"                  => 6815,
                         "futile"                 => 7033,
                         "futility"               => 12645,
                         "futon"                  => 11721,
                         "futterman"              => 12644,
                         "future"                 => 479,
                         "futures"                => 5583,
                         "fyarl"                  => 14423,
                         "g'day"                  => 14422,
                         "g'head"                 => 17326,
                         "g'night"                => 7624,
                         "gaaah"                  => 16156,
                         "gabbing"                => 11720,
                         "gabby"                  => 3274,
                         "gabe"                   => 4726,
                         "gablyczyck"             => 17325,
                         "gachnar"                => 15233,
                         "gadda"                  => 18710,
                         "gadgets"                => 9801,
                         "gaffe"                  => 14421,
                         "gaggle"                 => 10623,
                         "gainful"                => 13152,
                         "gainfully"              => 15232,
                         "gairwyn"                => 12643,
                         "galactica"              => 7032,
                         "galgenstein"            => 14420,
                         "gallbladder"            => 16155,
                         "galley"                 => 9557,
                         "galling"                => 18709,
                         "gallivanting"           => 15231,
                         "gallon"                 => 5582,
                         "gallons"                => 5295,
                         "galloping"              => 12642,
                         "gallows"                => 11719,
                         "galls"                  => 13725,
                         "galoshes"               => 15230,
                         "galvanized"             => 16154,
                         "gambled"                => 9800,
                         "gamblers"               => 13724,
                         "gambling"               => 2756,
                         "gamesphere"             => 9131,
                         "gammy"                  => 9130,
                         "gamut"                  => 15229,
                         "gandarium"              => 15228,
                         "gander"                 => 7031,
                         "gandhiji"               => 16153,
                         "gang"                   => 1528,
                         "gangbusters"            => 13723,
                         "ganged"                 => 12166,
                         "ganging"                => 7623,
                         "gangland"               => 18708,
                         "gangly"                 => 18707,
                         "gangrene"               => 10946,
                         "gangs"                  => 5393,
                         "gangsters"              => 6721,
                         "gangway"                => 15227,
                         "gangy"                  => 18706,
                         "gantu"                  => 18705,
                         "ganz"                   => 4501,
                         "ganza"                  => 5808,
                         "gaping"                 => 10049,
                         "garage"                 => 1346,
                         "garas"                  => 18704,
                         "garba"                  => 17324,
                         "garbage"                => 1264,
                         "garbled"                => 14419,
                         "garbo"                  => 11718,
                         "garcon"                 => 11717,
                         "gardener"               => 4126,
                         "gardeners"              => 13151,
                         "gardenias"              => 11716,
                         "gardening"              => 5976,
                         "gardino"                => 10945,
                         "garfunkel"              => 15226,
                         "gargantuan"             => 15225,
                         "gargle"                 => 14418,
                         "gargling"               => 16152,
                         "gargoyles"              => 11715,
                         "garish"                 => 18703,
                         "garlic"                 => 3344,
                         "garnish"                => 12641,
                         "garretts"               => 17323,
                         "garroway"               => 13722,
                         "garshaw"                => 15224,
                         "garters"                => 18702,
                         "gasbag"                 => 18701,
                         "gasket"                 => 6920,
                         "gaslight"               => 18700,
                         "gaslighting"            => 17322,
                         "gasoline"               => 3970,
                         "gasped"                 => 17321,
                         "gasping"                => 11305,
                         "gassed"                 => 10622,
                         "gasses"                 => 12640,
                         "gassy"                  => 16151,
                         "gastro"                 => 18699,
                         "gate"                   => 1450,
                         "gatehouse"              => 8064,
                         "gatekeeper"             => 11714,
                         "gather"                 => 1977,
                         "gaudy"                  => 13150,
                         "gauging"                => 18698,
                         "gauze"                  => 6720,
                         "gave"                   => 300,
                         "gavel"                  => 10944,
                         "gawking"                => 12165,
                         "gayest"                 => 18697,
                         "gayness"                => 17320,
                         "gazebo"                 => 5261,
                         "gazed"                  => 16150,
                         "gazelles"               => 14417,
                         "gazillion"              => 9129,
                         "gazillionth"            => 18696,
                         "gazing"                 => 9556,
                         "gazpacho"               => 16149,
                         "gazzo"                  => 14416,
                         "gear"                   => 2217,
                         "gearshift"              => 17319,
                         "geek"                   => 2786,
                         "geeks"                  => 4749,
                         "geeky"                  => 8721,
                         "geese"                  => 7259,
                         "geez"                   => 1877,
                         "geeze"                  => 15223,
                         "geezers"                => 15222,
                         "geishas"                => 17318,
                         "gekko"                  => 5632,
                         "gelatin"                => 12164,
                         "gelato"                 => 17317,
                         "gelbman"                => 18695,
                         "gellar"                 => 8924,
                         "gellers"                => 15221,
                         "geminon"                => 12639,
                         "gemme"                  => 16148,
                         "gendarme"               => 18694,
                         "generator"              => 3843,
                         "generosity"             => 4238,
                         "generous"               => 1468,
                         "generously"             => 8720,
                         "genetically"            => 4351,
                         "genitals"               => 9128,
                         "geniuses"               => 5689,
                         "gennero"                => 16147,
                         "genoa"                  => 2216,
                         "gente"                  => 18693,
                         "gentle"                 => 2074,
                         "gentleman"              => 1505,
                         "gentlemanly"            => 12163,
                         "gentlemen"              => 720,
                         "gentler"                => 8719,
                         "gently"                 => 3192,
                         "gents"                  => 6232,
                         "genuine"                => 2625,
                         "genuinely"              => 4409,
                         "georgio"                => 18692,
                         "georgy"                 => 14415,
                         "geosynchronous"         => 18691,
                         "geraniums"              => 13721,
                         "gerbils"                => 18690,
                         "geriatric"              => 11713,
                         "geriatrics"             => 18689,
                         "geritol"                => 10621,
                         "germane"                => 14414,
                         "germs"                  => 4237,
                         "gerome"                 => 8212,
                         "gershwin"               => 9326,
                         "gestapo"                => 6814,
                         "gestating"              => 17316,
                         "gesture"                => 2193,
                         "gestures"               => 6461,
                         "gesundheit"             => 9555,
                         "get"                    => 30,
                         "get'em"                 => 11712,
                         "getaway"                => 3431,
                         "getcha"                 => 9554,
                         "gether"                 => 18688,
                         "gets"                   => 324,
                         "getter"                 => 10620,
                         "gettin"                 => 1498,
                         "getting"                => 156,
                         "getup"                  => 8211,
                         "ghali"                  => 18687,
                         "ghastly"                => 8718,
                         "ghettos"                => 18686,
                         "ghora"                  => 17315,
                         "ghostbusters"           => 14413,
                         "ghosts"                 => 2547,
                         "ghoul"                  => 5975,
                         "ghoulish"               => 18685,
                         "ghouls"                 => 9325,
                         "giambetti"              => 18684,
                         "gianelli"               => 13720,
                         "giant"                  => 1565,
                         "gibarian"               => 12638,
                         "gibberish"              => 8717,
                         "giblets"                => 15220,
                         "giddy"                  => 5688,
                         "gift"                   => 666,
                         "gifted"                 => 3983,
                         "gifts"                  => 1625,
                         "gigantic"               => 4940,
                         "gigantor"               => 11711,
                         "gigglepuss"             => 17314,
                         "giggling"               => 7384,
                         "giggly"                 => 18683,
                         "gilardi"                => 12637,
                         "gilbey"                 => 17313,
                         "gilmores"               => 13719,
                         "gimbal"                 => 15219,
                         "gimme"                  => 1357,
                         "gimmee"                 => 16146,
                         "gimmick"                => 10048,
                         "gimmicks"               => 18682,
                         "gimmie"                 => 16145,
                         "gingerbread"            => 7383,
                         "gingham"                => 14412,
                         "ginza"                  => 16144,
                         "giorno"                 => 10619,
                         "giraffes"               => 17312,
                         "girl"                   => 201,
                         "girlfriend"             => 679,
                         "girlfriends"            => 2666,
                         "girlish"                => 9324,
                         "girlscout"              => 17311,
                         "girly"                  => 6379,
                         "girth"                  => 15218,
                         "gittes"                 => 4785,
                         "give"                   => 101,
                         "giveaway"               => 8210,
                         "giver"                  => 6632,
                         "givers"                 => 16143,
                         "gives"                  => 824,
                         "giveth"                 => 14411,
                         "givin"                  => 4597,
                         "giving"                 => 454,
                         "gizzard"                => 12636,
                         "glad"                   => 311,
                         "glades"                 => 11710,
                         "gladly"                 => 3110,
                         "glamor"                 => 18681,
                         "glamorama"              => 14410,
                         "glamorous"              => 4350,
                         "glance"                 => 4823,
                         "glanced"                => 10323,
                         "glances"                => 8209,
                         "glancing"               => 13718,
                         "glands"                 => 6631,
                         "glare"                  => 7150,
                         "glares"                 => 16142,
                         "glaring"                => 10943,
                         "glasses"                => 1376,
                         "glassware"              => 18680,
                         "glassy"                 => 15217,
                         "glaucoma"               => 17310,
                         "glazed"                 => 5908,
                         "gleam"                  => 11709,
                         "gleaming"               => 15216,
                         "glengarry"              => 18679,
                         "glenville"              => 17309,
                         "glimmer"                => 8716,
                         "glimpse"                => 4017,
                         "glimpsed"               => 17308,
                         "glimpses"               => 13717,
                         "glint"                  => 15215,
                         "glistening"             => 10047,
                         "glitch"                 => 4784,
                         "glitches"               => 11304,
                         "glittering"             => 15214,
                         "glitz"                  => 13716,
                         "gloat"                  => 4086,
                         "gloating"               => 6030,
                         "globes"                 => 10618,
                         "globetrotters"          => 17307,
                         "gloom"                  => 6306,
                         "gloomy"                 => 6561,
                         "glorificus"             => 12635,
                         "glorified"              => 7622,
                         "glorious"               => 2820,
                         "gloriously"             => 18678,
                         "gloss"                  => 6029,
                         "glove"                  => 2832,
                         "gloves"                 => 1960,
                         "glow"                   => 2307,
                         "glowed"                 => 13715,
                         "glowing"                => 3842,
                         "glows"                  => 10046,
                         "glowy"                  => 17306,
                         "glscripts"              => 13149,
                         "glue"                   => 2893,
                         "glued"                  => 5077,
                         "glues"                  => 18677,
                         "gluing"                 => 16141,
                         "glutes"                 => 17305,
                         "glutton"                => 8715,
                         "gluttony"               => 10617,
                         "glycerin"               => 17304,
                         "gnats"                  => 16140,
                         "gnawing"                => 10322,
                         "gnome"                  => 7946,
                         "gnomes"                 => 8923,
                         "go"                     => 43,
                         "goa'uld"                => 1876,
                         "goa'ulds"               => 5687,
                         "goaded"                 => 14409,
                         "goading"                => 10942,
                         "goatee"                 => 8922,
                         "gobble"                 => 8063,
                         "gobbledegook"           => 18676,
                         "gobbledygook"           => 18675,
                         "gobbles"                => 7507,
                         "goblet"                 => 10616,
                         "goblins"                => 11708,
                         "god"                    => 105,
                         "godammit"               => 10321,
                         "godamn"                 => 17303,
                         "godawful"               => 17302,
                         "goddam"                 => 3151,
                         "goddamit"               => 8532,
                         "goddammit"              => 3869,
                         "goddamn"                => 1000,
                         "goddamned"              => 3618,
                         "goddamnit"              => 3010,
                         "goddaughter"            => 16139,
                         "godforsaken"            => 5733,
                         "godless"                => 9323,
                         "godliness"              => 17301,
                         "godly"                  => 18674,
                         "godmother"              => 4893,
                         "godorsky"               => 13148,
                         "godparents"             => 10045,
                         "gods"                   => 2250,
                         "godsake"                => 16138,
                         "godsakes"               => 14408,
                         "godsend"                => 7506,
                         "godson"                 => 7149,
                         "goebbels"               => 8358,
                         "goes"                   => 393,
                         "goeth"                  => 12162,
                         "gofer"                  => 16137,
                         "goggle"                 => 15213,
                         "goggles"                => 6813,
                         "goin"                   => 854,
                         "going"                  => 33,
                         "goingo"                 => 18673,
                         "goiter"                 => 7382,
                         "goldenrod"              => 18672,
                         "goldilocks"             => 6378,
                         "goldmuff"               => 18671,
                         "golitsyn"               => 16136,
                         "golly"                  => 4626,
                         "gondola"                => 11303,
                         "gondorff"               => 13147,
                         "gone"                   => 243,
                         "goner"                  => 5974,
                         "goners"                 => 16135,
                         "gonna"                  => 74,
                         "gonorrhea"              => 6160,
                         "gooble"                 => 16134,
                         "good"                   => 51,
                         "goodbye"                => 921,
                         "goodbyes"               => 7258,
                         "gooder"                 => 9799,
                         "gooders"                => 12161,
                         "goodes"                 => 15212,
                         "goodies"                => 5581,
                         "goodly"                 => 17300,
                         "goodness"               => 1036,
                         "goodnight"              => 1595,
                         "goodspeed"              => 6460,
                         "goodwill"               => 5855,
                         "goody"                  => 2785,
                         "gooey"                  => 6560,
                         "goofed"                 => 13714,
                         "goofing"                => 7148,
                         "googly"                 => 18670,
                         "gooks"                  => 14407,
                         "goona"                  => 17299,
                         "gooney"                 => 18669,
                         "goons"                  => 4261,
                         "goood"                  => 14406,
                         "gooood"                 => 14405,
                         "goopy"                  => 17298,
                         "goosebumps"             => 11302,
                         "goosed"                 => 13713,
                         "gorak"                  => 10320,
                         "gordie"                 => 4442,
                         "gordievsky"             => 13146,
                         "goren"                  => 10615,
                         "gorgeous"               => 1195,
                         "gorignak"               => 13712,
                         "gorillas"               => 9322,
                         "gorky"                  => 9553,
                         "gosh"                   => 838,
                         "gossamer"               => 9798,
                         "gossip"                 => 2755,
                         "gossiping"              => 8921,
                         "gossips"                => 16133,
                         "got"                    => 46,
                         "gotta"                  => 225,
                         "gotten"                 => 614,
                         "gouged"                 => 11707,
                         "gouging"                => 18668,
                         "goulash"                => 17297,
                         "gourmet"                => 4725,
                         "governess"              => 8357,
                         "gown"                   => 2446,
                         "gowns"                  => 5580,
                         "grab"                   => 801,
                         "grabbed"                => 1766,
                         "grabbin"                => 15211,
                         "grabbing"               => 3520,
                         "grabby"                 => 12634,
                         "grabs"                  => 3685,
                         "graceful"               => 6459,
                         "gracefully"             => 7505,
                         "graceland"              => 12160,
                         "graces"                 => 6719,
                         "gracias"                => 4441,
                         "gracing"                => 16132,
                         "gracious"               => 3238,
                         "graciously"             => 7765,
                         "grad"                   => 4384,
                         "grader"                 => 6377,
                         "graders"                => 4822,
                         "grading"                => 7504,
                         "gradski"                => 16131,
                         "graft"                  => 9797,
                         "grafted"                => 14404,
                         "grafts"                 => 13145,
                         "grail"                  => 5807,
                         "grainy"                 => 18667,
                         "gram"                   => 3580,
                         "grampa"                 => 3738,
                         "grams"                  => 1707,
                         "gran"                   => 3593,
                         "grandbaby"              => 16130,
                         "grandchild"             => 4408,
                         "grandchildren"          => 3191,
                         "granddad"               => 3409,
                         "granddaddy"             => 10614,
                         "granddaughter"          => 2419,
                         "granddaughters"         => 11706,
                         "grander"                => 13144,
                         "grandest"               => 14403,
                         "grandeur"               => 10319,
                         "grandfather"            => 1122,
                         "grandfathers"           => 16129,
                         "grandiose"              => 14402,
                         "grandkid"               => 18666,
                         "grandkids"              => 7503,
                         "grandma"                => 1124,
                         "grandmama"              => 9321,
                         "grandmother"            => 1130,
                         "grandmothers"           => 13143,
                         "grandpa"                => 1500,
                         "grandparent"            => 11705,
                         "grandparents"           => 3448,
                         "grandson"               => 2156,
                         "grandstanding"          => 10044,
                         "granilith"              => 7502,
                         "granma"                 => 16128,
                         "granola"                => 10613,
                         "grape"                  => 4212,
                         "grapefruit"             => 5260,
                         "grapevine"              => 7945,
                         "grasp"                  => 3489,
                         "grasped"                => 11704,
                         "grasping"               => 7621,
                         "grasshopper"            => 8062,
                         "grasshoppers"           => 14401,
                         "grata"                  => 13711,
                         "grated"                 => 17296,
                         "grateful"               => 1028,
                         "gratification"          => 10318,
                         "gratified"              => 17295,
                         "gratifying"             => 8356,
                         "grating"                => 14400,
                         "gratitude"              => 2742,
                         "gratuitous"             => 8714,
                         "gratuity"               => 16127,
                         "grave"                  => 1621,
                         "gravedigger"            => 14399,
                         "gravesite"              => 16126,
                         "gravest"                => 17294,
                         "graveyard"              => 3982,
                         "graveyards"             => 18665,
                         "gravy"                  => 3579,
                         "graynamore"             => 15210,
                         "grazed"                 => 10317,
                         "grazie"                 => 6093,
                         "graziella"              => 6812,
                         "greaseball"             => 16125,
                         "greased"                => 8531,
                         "greasing"               => 18664,
                         "greasy"                 => 4260,
                         "great"                  => 116,
                         "greatness"              => 4625,
                         "greed"                  => 3998,
                         "greedy"                 => 3164,
                         "greenbacks"             => 14398,
                         "greenlee"               => 613,
                         "greet"                  => 3578,
                         "greeting"               => 3577,
                         "greetings"              => 3943,
                         "greets"                 => 13142,
                         "greevey"                => 18663,
                         "greevy"                 => 10043,
                         "grenade"                => 4349,
                         "gretch"                 => 18662,
                         "gretel"                 => 2749,
                         "greystone"              => 12159,
                         "gribbit"                => 12158,
                         "gribbs"                 => 10042,
                         "griddle"                => 12157,
                         "grief"                  => 1654,
                         "griet"                  => 7620,
                         "grievance"              => 12156,
                         "grieve"                 => 4383,
                         "grieved"                => 13710,
                         "grieving"               => 3109,
                         "grievous"               => 9796,
                         "griff"                  => 5543,
                         "grift"                  => 13141,
                         "grifters"               => 18661,
                         "grill"                  => 2879,
                         "grilled"                => 4694,
                         "grilling"               => 5907,
                         "grills"                 => 15209,
                         "grimlocks"              => 13140,
                         "grimoir"                => 12155,
                         "grind"                  => 4259,
                         "grinding"               => 6458,
                         "grinds"                 => 18660,
                         "grindstone"             => 12154,
                         "grinning"               => 7257,
                         "grins"                  => 16124,
                         "grip"                   => 2229,
                         "gripe"                  => 8355,
                         "gripes"                 => 18659,
                         "griping"                => 17293,
                         "gripping"               => 12633,
                         "grips"                  => 8920,
                         "grisly"                 => 8713,
                         "griss"                  => 13709,
                         "gristle"                => 15208,
                         "grits"                  => 12632,
                         "gritty"                 => 9795,
                         "groan"                  => 14397,
                         "groaning"               => 15207,
                         "grocer"                 => 12631,
                         "groceries"              => 4174,
                         "grocery"                => 3381,
                         "grodin"                 => 18658,
                         "groggy"                 => 7381,
                         "groin"                  => 6559,
                         "groom"                  => 2192,
                         "groomed"                => 7764,
                         "groomer"                => 18657,
                         "grooming"               => 6558,
                         "groomsmen"              => 17292,
                         "groosalug"              => 7030,
                         "grope"                  => 12630,
                         "groped"                 => 16123,
                         "groping"                => 7147,
                         "groppi"                 => 18656,
                         "grosses"                => 17291,
                         "grossie"                => 16122,
                         "grossly"                => 12629,
                         "grotesque"              => 6718,
                         "grotto"                 => 9320,
                         "grouchy"                => 8712,
                         "grounded"               => 2504,
                         "groundhog"              => 7256,
                         "grounding"              => 8919,
                         "groundless"             => 15206,
                         "groundskeeper"          => 12153,
                         "groundwork"             => 6717,
                         "groupie"                => 6457,
                         "groupies"               => 7380,
                         "grovel"                 => 6811,
                         "groveling"              => 7029,
                         "grovelling"             => 14396,
                         "grow"                   => 925,
                         "growed"                 => 14395,
                         "growin"                 => 11703,
                         "growl"                  => 5906,
                         "growling"               => 9552,
                         "grown"                  => 1129,
                         "grownup"                => 5076,
                         "grownups"               => 5542,
                         "grrrr"                  => 10316,
                         "grrrrrr"                => 17290,
                         "grubbing"               => 10315,
                         "grubby"                 => 10612,
                         "grubs"                  => 16121,
                         "grudge"                 => 3030,
                         "grudges"                => 7501,
                         "grudging"               => 17289,
                         "gruel"                  => 17288,
                         "grueling"               => 10041,
                         "gruesome"               => 7146,
                         "gruff"                  => 13708,
                         "grumbling"              => 13139,
                         "grump"                  => 14394,
                         "grunemann"              => 8208,
                         "grungy"                 => 10941,
                         "grunick"                => 18655,
                         "grunther"               => 18654,
                         "grunting"               => 10040,
                         "gruntmaster"            => 16120,
                         "gstaad"                 => 13707,
                         "guacamole"              => 6810,
                         "guapo"                  => 10611,
                         "guarantee"              => 1293,
                         "guaranteed"             => 3119,
                         "guaranteeing"           => 12152,
                         "guarantees"             => 3757,
                         "guard"                  => 923,
                         "guarded"                => 4382,
                         "guardianship"           => 10610,
                         "guarding"               => 4724,
                         "guardrail"              => 18653,
                         "guards"                 => 1659,
                         "guava"                  => 18652,
                         "guerillas"              => 18651,
                         "guess"                  => 151,
                         "guessed"                => 2629,
                         "guesses"                => 5117,
                         "guessing"               => 1855,
                         "guest"                  => 992,
                         "guesthouse"             => 8918,
                         "guests"                 => 1509,
                         "guidebook"              => 13706,
                         "guilder"                => 12151,
                         "guillotine"             => 8917,
                         "guilt"                  => 1368,
                         "guilted"                => 17287,
                         "guiltier"               => 13705,
                         "guilty"                 => 724,
                         "guinevere"              => 10940,
                         "guittierez"             => 7255,
                         "gulag"                  => 12150,
                         "gullible"               => 4892,
                         "gulls"                  => 9794,
                         "gumbel"                 => 18650,
                         "gummi"                  => 15205,
                         "gummy"                  => 13704,
                         "gumption"               => 16119,
                         "gun"                    => 515,
                         "gundersons"             => 16118,
                         "gunfire"                => 5491,
                         "gunman"                 => 6305,
                         "gunna"                  => 7763,
                         "gunned"                 => 6557,
                         "gunpoint"               => 5806,
                         "gunshot"                => 3552,
                         "gunshots"               => 7379,
                         "gunsights"              => 12628,
                         "gurgling"               => 17286,
                         "gushie"                 => 8530,
                         "gushing"                => 8529,
                         "gushy"                  => 17285,
                         "gusta"                  => 17284,
                         "gusto"                  => 10314,
                         "guten"                  => 13703,
                         "gutiurrez"              => 11301,
                         "gutless"                => 10313,
                         "guts"                   => 1370,
                         "gutsy"                  => 10039,
                         "gutted"                 => 9793,
                         "gutter"                 => 3684,
                         "gutters"                => 7145,
                         "guttersnipe"            => 14393,
                         "gutting"                => 15204,
                         "guy"                    => 134,
                         "guy'd"                  => 14392,
                         "guy'll"                 => 18649,
                         "guys"                   => 139,
                         "guys'd"                 => 14391,
                         "guys'll"                => 9792,
                         "guys're"                => 16117,
                         "guzzling"               => 10939,
                         "gwennie"                => 10938,
                         "gyges"                  => 16116,
                         "gynaecologist"          => 12149,
                         "gynecologist"           => 7254,
                         "gypped"                 => 18648,
                         "gypsies"                => 6809,
                         "gyroscope"              => 14390,
                         "h'yah"                  => 17283,
                         "haaaa"                  => 17282,
                         "haaaaa"                 => 15203,
                         "haagen"                 => 15202,
                         "haberdashery"           => 18647,
                         "habit"                  => 1833,
                         "habits"                 => 3069,
                         "habitual"               => 13702,
                         "habla"                  => 14389,
                         "hacene"                 => 16115,
                         "hacer"                  => 13138,
                         "hacks"                  => 6630,
                         "hacksaw"                => 9127,
                         "hacky"                  => 17281,
                         "hadda"                  => 9791,
                         "hades"                  => 5732,
                         "hadn't"                 => 667,
                         "hafta"                  => 8061,
                         "haggle"                 => 10038,
                         "haggling"               => 12148,
                         "hagitha"                => 14388,
                         "haha"                   => 4500,
                         "hahaha"                 => 5973,
                         "hahahaha"               => 9790,
                         "hahahahaha"             => 13137,
                         "haiku"                  => 10037,
                         "hail"                   => 3190,
                         "hair"                   => 475,
                         "hairbrush"              => 8711,
                         "haircut"                => 2794,
                         "haircuts"               => 9126,
                         "hairdo"                 => 8060,
                         "hairdresser"            => 6159,
                         "hairdressers"           => 17280,
                         "haired"                 => 3885,
                         "hairless"               => 10937,
                         "hairline"               => 8354,
                         "hairnet"                => 17279,
                         "hairs"                  => 3430,
                         "hairspray"              => 11300,
                         "hairstyle"              => 9789,
                         "hairstyles"             => 15201,
                         "haise"                  => 12627,
                         "haklar"                 => 12626,
                         "hakuna"                 => 10312,
                         "haladki"                => 10036,
                         "halberstam"             => 17278,
                         "haldeman"               => 6304,
                         "haldol"                 => 12147,
                         "haleh"                  => 17277,
                         "halfrek"                => 16114,
                         "halfway"                => 1974,
                         "halitosis"              => 18646,
                         "halkein"                => 17276,
                         "hallelujah"             => 3670,
                         "halliwell"              => 2676,
                         "halliwells"             => 12625,
                         "hallor"                 => 18645,
                         "hallowed"               => 7500,
                         "halloween"              => 1516,
                         "hallows"                => 13701,
                         "hallucinate"            => 12146,
                         "hallucinating"          => 4560,
                         "hallucination"          => 7378,
                         "hallucinations"         => 6376,
                         "hallucinogen"           => 18644,
                         "hallway"                => 1973,
                         "hallways"               => 7377,
                         "halothane"              => 15200,
                         "halstrom"               => 13136,
                         "hamburger"              => 3576,
                         "hamburgers"             => 5334,
                         "hammered"               => 6303,
                         "hammering"              => 6716,
                         "hamptons"               => 6092,
                         "hamsters"               => 8710,
                         "hamunaptra"             => 10035,
                         "hand"                   => 330,
                         "handbasket"             => 16113,
                         "handcuffed"             => 6808,
                         "handcuffs"              => 3199,
                         "handed"                 => 1577,
                         "handedly"               => 5631,
                         "handful"                => 3503,
                         "handgun"                => 7376,
                         "handguns"               => 12145,
                         "handi"                  => 16112,
                         "handicapped"            => 4783,
                         "handing"                => 2958,
                         "handiwork"              => 9551,
                         "handkerchief"           => 7253,
                         "handle"                 => 451,
                         "handlebars"             => 14387,
                         "handled"                => 1545,
                         "handles"                => 4196,
                         "handling"               => 1839,
                         "handmade"               => 9550,
                         "handoff"                => 18643,
                         "handout"                => 8207,
                         "handouts"               => 10936,
                         "handprint"              => 11299,
                         "handrail"               => 18642,
                         "hands"                  => 376,
                         "handshake"              => 4693,
                         "handsome"               => 1229,
                         "handsomely"             => 12624,
                         "handsomer"              => 13700,
                         "handsomest"             => 10935,
                         "handstand"              => 18641,
                         "handwriting"            => 3130,
                         "hanen"                  => 13699,
                         "hang"                   => 446,
                         "hangers"                => 10311,
                         "hangin"                 => 4236,
                         "hanging"                => 771,
                         "hangnail"               => 18640,
                         "hangout"                => 10934,
                         "hangouts"               => 17275,
                         "hangover"               => 5048,
                         "hangovers"              => 16111,
                         "hangs"                  => 3355,
                         "hankering"              => 10310,
                         "hankey"                 => 3997,
                         "hankie"                 => 12623,
                         "hanky"                  => 7144,
                         "hansom"                 => 18639,
                         "hanta"                  => 18638,
                         "hanukkah"               => 7028,
                         "hapless"                => 13698,
                         "happen"                 => 220,
                         "happend"                => 14386,
                         "happened"               => 144,
                         "happenin"               => 7619,
                         "happening"              => 532,
                         "happenings"             => 12622,
                         "happens"                => 426,
                         "happier"                => 1548,
                         "happiest"               => 2167,
                         "happily"                => 1775,
                         "happiness"              => 1074,
                         "happy"                  => 198,
                         "harass"                 => 4085,
                         "harassed"               => 7027,
                         "harassing"              => 3141,
                         "harassment"             => 2892,
                         "harboring"              => 8059,
                         "harbouring"             => 17274,
                         "harbucks"               => 12144,
                         "harcesis"               => 17273,
                         "hard"                   => 230,
                         "hardened"               => 8528,
                         "hardens"                => 17272,
                         "harder"                 => 1164,
                         "hardest"                => 2585,
                         "hardheaded"             => 14385,
                         "hardly"                 => 895,
                         "hardship"               => 7143,
                         "hardwired"              => 15199,
                         "hardworking"            => 9125,
                         "harebrained"            => 13697,
                         "harem"                  => 11298,
                         "harlin"                 => 6158,
                         "harlot"                 => 15198,
                         "harm"                   => 1281,
                         "harmed"                 => 5854,
                         "harming"                => 7375,
                         "harmless"               => 2685,
                         "harmony"                => 1138,
                         "harmsway"               => 7142,
                         "harnessed"              => 16110,
                         "harpies"                => 13135,
                         "harping"                => 7944,
                         "harpoons"               => 17271,
                         "harpy"                  => 8058,
                         "harrassment"            => 13134,
                         "harridan"               => 17270,
                         "harrowing"              => 16109,
                         "harsh"                  => 2317,
                         "harshly"                => 8206,
                         "hartmans"               => 7943,
                         "harts"                  => 9124,
                         "harvey'll"              => 18637,
                         "hasenfuss"              => 10309,
                         "hasn't"                 => 524,
                         "hassle"                 => 3617,
                         "hassled"                => 9123,
                         "hassles"                => 9788,
                         "hassling"               => 5294,
                         "hasta"                  => 7026,
                         "haste"                  => 7141,
                         "hasten"                 => 17269,
                         "hatched"                => 7942,
                         "hatches"                => 13696,
                         "hatchet"                => 4440,
                         "hatching"               => 9319,
                         "hate"                   => 296,
                         "hated"                  => 1077,
                         "hateful"                => 4195,
                         "hates"                  => 1103,
                         "hathor"                 => 9318,
                         "hating"                 => 2642,
                         "hatred"                 => 2878,
                         "hats"                   => 2802,
                         "hatsue"                 => 15197,
                         "haughty"                => 12621,
                         "haul"                   => 2594,
                         "hauled"                 => 5853,
                         "haulin"                 => 18636,
                         "hauling"                => 5805,
                         "hauls"                  => 17268,
                         "haunt"                  => 3237,
                         "haunted"                => 3054,
                         "haunting"               => 5392,
                         "haunts"                 => 6028,
                         "have"                   => 12,
                         "haven't"                => 211,
                         "haveo"                  => 17267,
                         "havesham"               => 10308,
                         "havin"                  => 3068,
                         "having"                 => 218,
                         "havoc"                  => 3920,
                         "havta"                  => 18635,
                         "hawkland"               => 18634,
                         "hayloft"                => 12143,
                         "hayseed"                => 17266,
                         "haystack"               => 7499,
                         "haywire"                => 8709,
                         "hazing"                 => 11297,
                         "he'd"                   => 549,
                         "he'll"                  => 388,
                         "he's"                   => 62,
                         "head"                   => 247,
                         "headache"               => 1749,
                         "headaches"              => 3214,
                         "headband"               => 13133,
                         "headboard"              => 11296,
                         "headdress"              => 13695,
                         "headed"                 => 1184,
                         "headfirst"              => 15196,
                         "headgear"               => 11295,
                         "headhunter"             => 9122,
                         "headin"                 => 7498,
                         "heading"                => 1298,
                         "headlight"              => 14384,
                         "headlights"             => 5905,
                         "headline"               => 4464,
                         "headlines"              => 4499,
                         "headlock"               => 16108,
                         "headlong"               => 18633,
                         "headmistress"           => 14383,
                         "headphones"             => 6715,
                         "headpiece"              => 17265,
                         "heads"                  => 1067,
                         "headset"                => 10609,
                         "headsets"               => 18632,
                         "headstart"              => 18631,
                         "headstone"              => 12142,
                         "headstrong"             => 9549,
                         "headway"                => 7941,
                         "heal"                   => 1726,
                         "healed"                 => 3488,
                         "healer"                 => 6556,
                         "healers"                => 18630,
                         "healing"                => 2483,
                         "heals"                  => 5904,
                         "healthier"              => 6302,
                         "healthiest"             => 8708,
                         "healthilizer"           => 15195,
                         "healthy"                => 1180,
                         "heap"                   => 4821,
                         "heaped"                 => 18629,
                         "heaping"                => 15194,
                         "hear"                   => 164,
                         "heard"                  => 212,
                         "hearin"                 => 13132,
                         "hearing"                => 795,
                         "hears"                  => 2199,
                         "hearsay"                => 8057,
                         "hearse"                 => 8527,
                         "hearst"                 => 5434,
                         "heart"                  => 269,
                         "heartache"              => 3884,
                         "heartbeat"              => 2609,
                         "heartbeats"             => 18628,
                         "heartbreak"             => 5391,
                         "heartbreaker"           => 6629,
                         "heartbreaking"          => 6807,
                         "heartbroken"            => 5004,
                         "heartburn"              => 7762,
                         "hearted"                => 3756,
                         "heartfelt"              => 6157,
                         "hearth"                 => 9787,
                         "heartless"              => 3702,
                         "heartsick"              => 13694,
                         "heartstrings"           => 14382,
                         "heartthrob"             => 17264,
                         "heartwarming"           => 7940,
                         "hearty"                 => 6091,
                         "heat"                   => 1169,
                         "heathcliff"             => 11294,
                         "heathen"                => 13131,
                         "heathens"               => 17263,
                         "heatshield"             => 17262,
                         "heave"                  => 5116,
                         "heaved"                 => 16107,
                         "heavenly"               => 4105,
                         "heavens"                => 2558,
                         "heaving"                => 11293,
                         "heavyset"               => 17261,
                         "hebbing"                => 16106,
                         "hebrews"                => 16105,
                         "heckle"                 => 15193,
                         "heckled"                => 17260,
                         "heckles"                => 8353,
                         "heckling"               => 17259,
                         "hectic"                 => 5390,
                         "hecuba"                 => 6555,
                         "hedda"                  => 18627,
                         "heddy"                  => 8352,
                         "hedging"                => 17258,
                         "hedriks"                => 14381,
                         "heebie"                 => 10307,
                         "heeey"                  => 18626,
                         "heel"                   => 3408,
                         "heels"                  => 2357,
                         "heeyy"                  => 13130,
                         "hefty"                  => 6919,
                         "heheh"                  => 8205,
                         "hehehe"                 => 12620,
                         "heheheh"                => 17257,
                         "heheheheh"              => 18625,
                         "heheheheheh"            => 17256,
                         "hehey"                  => 14380,
                         "heifer"                 => 16104,
                         "heigh"                  => 8916,
                         "heighten"               => 17255,
                         "heightened"             => 6554,
                         "heimlich"               => 10034,
                         "heinie"                 => 11702,
                         "heinous"                => 7140,
                         "heirloom"               => 7139,
                         "heirlooms"              => 13693,
                         "heist"                  => 6231,
                         "helicopter"             => 2371,
                         "helipad"                => 16103,
                         "hell"                   => 178,
                         "hell'd"                 => 11701,
                         "hell're"                => 17254,
                         "hella"                  => 8707,
                         "hellhole"               => 5579,
                         "hellhound"              => 18624,
                         "hellish"                => 8204,
                         "hellmouth"              => 5972,
                         "hellooo"                => 9786,
                         "helloooo"               => 13692,
                         "hellstrom"              => 12141,
                         "helluva"                => 4125,
                         "helmets"                => 7138,
                         "helmsley"               => 18623,
                         "help"                   => 103,
                         "helped"                 => 743,
                         "helpers"                => 10608,
                         "helpful"                => 1896,
                         "helpin"                 => 9317,
                         "helping"                => 672,
                         "helpless"               => 2047,
                         "helplessly"             => 13129,
                         "helplessness"           => 18622,
                         "helpmann"               => 12619,
                         "helps"                  => 1435,
                         "hematoma"               => 9548,
                         "hemery"                 => 18621,
                         "hemline"                => 18620,
                         "hemlines"               => 18619,
                         "hemoglobin"             => 11700,
                         "hemolytic"              => 16102,
                         "hemorrhage"             => 9316,
                         "hemorrhaging"           => 7497,
                         "hemorrhoid"             => 8706,
                         "hemorrhoids"            => 9121,
                         "henchman"               => 13691,
                         "hendler"                => 12140,
                         "henhouse"               => 16101,
                         "hennifer"               => 18618,
                         "hennigans"              => 16100,
                         "henny"                  => 16099,
                         "henslowe"               => 12139,
                         "heparin"                => 9785,
                         "hepatitis"              => 5115,
                         "heppleman"              => 17253,
                         "herbal"                 => 4235,
                         "herbalist"              => 14379,
                         "herbs"                  => 5389,
                         "here"                   => 31,
                         "here's"                 => 455,
                         "hereafter"              => 12618,
                         "hereby"                 => 3273,
                         "herein"                 => 15192,
                         "heretofore"             => 14378,
                         "hergott"                => 16098,
                         "hermano"                => 8203,
                         "hermaphrodite"          => 18617,
                         "hermey"                 => 16097,
                         "herndorff"              => 13128,
                         "hernia"                 => 7374,
                         "hernias"                => 17252,
                         "herniated"              => 18616,
                         "hero"                   => 1042,
                         "heroic"                 => 3819,
                         "heroics"                => 8915,
                         "heroin"                 => 3067,
                         "herpes"                 => 7025,
                         "herrero"                => 13127,
                         "hers"                   => 1497,
                         "herself"                => 637,
                         "hershe"                 => 16096,
                         "heru'ur"                => 17251,
                         "hesitant"               => 10933,
                         "hesitate"               => 3368,
                         "hesitated"              => 6714,
                         "hesitates"              => 13126,
                         "hesitating"             => 8351,
                         "hesitation"             => 5388,
                         "hessian"                => 12138,
                         "hetero"                 => 12137,
                         "heterosexual"           => 6553,
                         "hetson"                 => 12136,
                         "heurh"                  => 18615,
                         "hewwo"                  => 16095,
                         "hexavalent"             => 16094,
                         "hexes"                  => 17250,
                         "hexton"                 => 15191,
                         "hey"                    => 61,
                         "heyyy"                  => 10932,
                         "hibernating"            => 13690,
                         "hiccups"                => 8526,
                         "hide"                   => 762,
                         "hideaway"               => 8350,
                         "hideous"                => 3092,
                         "hideously"              => 11292,
                         "hides"                  => 5541,
                         "hidin"                  => 12617,
                         "hiding"                 => 875,
                         "hieroglyphics"          => 14377,
                         "hieroglyphs"            => 15190,
                         "highlighters"           => 17249,
                         "highness"               => 2726,
                         "hightail"               => 11699,
                         "hightailed"             => 14376,
                         "hijack"                 => 10033,
                         "hijacked"               => 9784,
                         "hijinks"                => 13125,
                         "hike"                   => 2775,
                         "hiked"                  => 12135,
                         "hiker"                  => 11698,
                         "hikes"                  => 14375,
                         "hikita"                 => 14374,
                         "hilarious"              => 3777,
                         "hilarity"               => 18614,
                         "hildie"                 => 15189,
                         "hillbillies"            => 18613,
                         "hillbilly"              => 7939,
                         "hillnigger"             => 16093,
                         "him"                    => 44,
                         "hindquarters"           => 14373,
                         "hindsight"              => 10306,
                         "hinge"                  => 10032,
                         "hinges"                 => 6806,
                         "hinks"                  => 5578,
                         "hinky"                  => 17248,
                         "hint"                   => 1952,
                         "hinting"                => 8349,
                         "hints"                  => 5003,
                         "hippest"                => 18612,
                         "hippies"                => 6552,
                         "hippity"                => 15188,
                         "hippocratic"            => 14372,
                         "hippopotamus"           => 12134,
                         "hippy"                  => 9783,
                         "hips"                   => 4062,
                         "hire"                   => 1189,
                         "hired"                  => 1066,
                         "hires"                  => 6713,
                         "hiring"                 => 2641,
                         "hirohito"               => 14371,
                         "hiromitsu"              => 12616,
                         "hirschmuller"           => 10607,
                         "hissed"                 => 16092,
                         "hisself"                => 10931,
                         "hisses"                 => 18611,
                         "hissing"                => 12615,
                         "hissy"                  => 9782,
                         "histamine"              => 14370,
                         "histrionics"            => 14369,
                         "hit"                    => 349,
                         "hitch"                  => 3715,
                         "hitched"                => 5047,
                         "hitchhike"              => 13689,
                         "hitchhiker"             => 11291,
                         "hitchhikers"            => 16091,
                         "hitchhiking"            => 9120,
                         "hitching"               => 11697,
                         "hither"                 => 9781,
                         "hittin"                 => 7496,
                         "hitting"                => 1415,
                         "hives"                  => 5387,
                         "hiya"                   => 2980,
                         "hmm"                    => 197,
                         "hmmm"                   => 1891,
                         "hmmmm"                  => 6918,
                         "hmmmmm"                 => 18610,
                         "hmmph"                  => 13688,
                         "hoarding"               => 11696,
                         "hoarse"                 => 17247,
                         "hoaxes"                 => 18609,
                         "hobbies"                => 6156,
                         "hobbits"                => 18608,
                         "hobble"                 => 17246,
                         "hobbling"               => 17245,
                         "hobby"                  => 2968,
                         "hobnob"                 => 14368,
                         "hobnobbing"             => 14367,
                         "hoboes"                 => 17244,
                         "hoboken"                => 7938,
                         "hockley"                => 12614,
                         "hocks"                  => 18607,
                         "hocus"                  => 9119,
                         "hoedown"                => 17243,
                         "hoffa"                  => 9780,
                         "hogging"                => 8056,
                         "hogwallop"              => 18606,
                         "hogwash"                => 12613,
                         "hoist"                  => 11695,
                         "hoisting"               => 18605,
                         "hoity"                  => 13124,
                         "hokey"                  => 9118,
                         "hold"                   => 237,
                         "holdin"                 => 5731,
                         "holding"                => 661,
                         "holdup"                 => 6712,
                         "hole"                   => 1046,
                         "holed"                  => 5208,
                         "holes"                  => 2172,
                         "holidays"               => 1670,
                         "holier"                 => 7137,
                         "holies"                 => 18604,
                         "holiest"                => 15187,
                         "holiness"               => 6301,
                         "holing"                 => 18603,
                         "hollandaise"            => 13123,
                         "hollerin"               => 17242,
                         "hollering"              => 10305,
                         "hollers"                => 17241,
                         "holling"                => 4692,
                         "hollow"                 => 2211,
                         "hollowed"               => 12612,
                         "hologram"               => 9117,
                         "holster"                => 7761,
                         "holy"                   => 1086,
                         "hombres"                => 17240,
                         "homebake"               => 18602,
                         "homebody"               => 18601,
                         "homeboys"               => 13122,
                         "homecoming"             => 2995,
                         "homegirl"               => 15186,
                         "homeless"               => 2210,
                         "homemaker"              => 10606,
                         "homeopathic"            => 16090,
                         "homeroom"               => 7373,
                         "homesick"               => 5386,
                         "homework"               => 1458,
                         "homewrecker"            => 17239,
                         "homey"                  => 5002,
                         "homicidal"              => 4939,
                         "homicide"               => 2370,
                         "homicides"              => 8525,
                         "homie"                  => 10930,
                         "homily"                 => 16089,
                         "homing"                 => 6628,
                         "homo"                   => 4061,
                         "homos"                  => 10929,
                         "homosexual"             => 4060,
                         "homosexuals"            => 7372,
                         "honcho"                 => 10031,
                         "honed"                  => 11694,
                         "honest"                 => 553,
                         "honestly"               => 886,
                         "honesty"                => 1798,
                         "honey"                  => 213,
                         "honeymoon"              => 1326,
                         "honeymooners"           => 16088,
                         "honeymooning"           => 11693,
                         "honeymoons"             => 17238,
                         "honeysuckle"            => 15185,
                         "honing"                 => 14366,
                         "honkin"                 => 17237,
                         "honking"                => 9315,
                         "honks"                  => 16087,
                         "honky"                  => 11290,
                         "honor"                  => 543,
                         "honorable"              => 2503,
                         "honorably"              => 15184,
                         "honored"                => 2147,
                         "honoring"               => 5730,
                         "honto"                  => 17236,
                         "hooded"                 => 12133,
                         "hoodlum"                => 9314,
                         "hoodlums"               => 11289,
                         "hoods"                  => 10030,
                         "hoodwinked"             => 15183,
                         "hooey"                  => 10029,
                         "hook"                   => 1152,
                         "hooked"                 => 1748,
                         "hooking"                => 4498,
                         "hooky"                  => 6805,
                         "hooligans"              => 10928,
                         "hoooo"                  => 13121,
                         "hooray"                 => 3519,
                         "hoosegow"               => 16086,
                         "hoot"                   => 4691,
                         "hootchie"               => 16085,
                         "hootenanny"             => 16084,
                         "hooves"                 => 10927,
                         "hope"                   => 195,
                         "hoped"                  => 1788,
                         "hopefully"              => 1463,
                         "hopeless"               => 2362,
                         "hopelessly"             => 6375,
                         "hopelessness"           => 15182,
                         "hopes"                  => 1563,
                         "hopin"                  => 8055,
                         "hoping"                 => 615,
                         "hopped"                 => 5385,
                         "hopping"                => 5001,
                         "hopsfield"              => 17235,
                         "hordes"                 => 11288,
                         "horizons"               => 8524,
                         "hormonal"               => 7937,
                         "hormone"                => 5433,
                         "hormones"               => 3189,
                         "horns"                  => 4145,
                         "horoscope"              => 8348,
                         "horoscopes"             => 15181,
                         "horrace"                => 17234,
                         "horrendous"             => 6155,
                         "horrible"               => 767,
                         "horribly"               => 4559,
                         "horrid"                 => 8054,
                         "horrific"               => 6456,
                         "horrified"              => 5630,
                         "horrifying"             => 6090,
                         "horrors"                => 6804,
                         "hors"                   => 4820,
                         "horseback"              => 6230,
                         "horsehair"              => 18600,
                         "horseradish"            => 12611,
                         "horseshit"              => 8705,
                         "horsies"                => 12610,
                         "horsing"                => 12132,
                         "horsting"               => 13120,
                         "hose"                   => 2967,
                         "hosed"                  => 15180,
                         "hosers"                 => 18599,
                         "hoses"                  => 10605,
                         "hosing"                 => 18598,
                         "hospitable"             => 10604,
                         "hospital"               => 339,
                         "hospitality"            => 5432,
                         "hostage"                => 2178,
                         "hostages"               => 3066,
                         "hostess"                => 3904,
                         "hostile"                => 2536,
                         "hostiles"               => 10926,
                         "hostility"              => 3868,
                         "hosty"                  => 16083,
                         "hot"                    => 415,
                         "hotbed"                 => 18597,
                         "hotcakes"               => 16082,
                         "hotel"                  => 645,
                         "hothead"                => 10925,
                         "hotheaded"              => 17233,
                         "hothouse"               => 16081,
                         "hotline"                => 5804,
                         "hots"                   => 4497,
                         "hotspots"               => 17232,
                         "hotter"                 => 4285,
                         "hottest"                => 3236,
                         "hotwire"                => 17231,
                         "houmfort"               => 10924,
                         "hound"                  => 4059,
                         "hounded"                => 10304,
                         "hounding"               => 5971,
                         "houngan"                => 15179,
                         "hour"                   => 439,
                         "hourglass"              => 3367,
                         "hours"                  => 374,
                         "housebroken"            => 17230,
                         "housecleaning"          => 16080,
                         "houseguest"             => 7371,
                         "housekeeper"            => 4046,
                         "housekeeping"           => 6374,
                         "housewarming"           => 8523,
                         "housework"              => 9779,
                         "hovel"                  => 13687,
                         "hovercraft"             => 15178,
                         "hoverdrone"             => 13686,
                         "hovering"               => 4284,
                         "how"                    => 45,
                         "how'd"                  => 761,
                         "how'll"                 => 17229,
                         "how'm"                  => 10028,
                         "how're"                 => 2599,
                         "how's"                  => 420,
                         "how've"                 => 6089,
                         "howbout"                => 17228,
                         "howdy"                  => 2665,
                         "howling"                => 7024,
                         "howya"                  => 17227,
                         "hoynes"                 => 4664,
                         "hsing"                  => 11287,
                         "hubald"                 => 17226,
                         "hubba"                  => 9778,
                         "hubbub"                 => 15177,
                         "hubby"                  => 4859,
                         "hubcaps"                => 17225,
                         "hubris"                 => 15176,
                         "huckabees"              => 7495,
                         "huckleberry"            => 7760,
                         "huckster"               => 18596,
                         "huddle"                 => 6154,
                         "huddled"                => 8522,
                         "huddling"               => 14365,
                         "huevos"                 => 10027,
                         "huffed"                 => 15175,
                         "huffing"                => 16079,
                         "huffy"                  => 12609,
                         "huge"                   => 765,
                         "hugest"                 => 13685,
                         "hugged"                 => 5729,
                         "huggers"                => 18595,
                         "huggin"                 => 16078,
                         "hugging"                => 4173,
                         "huggy"                  => 18594,
                         "huh"                    => 140,
                         "huhuh"                  => 11286,
                         "hulking"                => 17224,
                         "hullo"                  => 13119,
                         "humanity"               => 2886,
                         "humanly"                => 6300,
                         "humbled"                => 9116,
                         "humbling"               => 16077,
                         "humbly"                 => 8914,
                         "humdinger"              => 16076,
                         "humidifier"             => 18593,
                         "humidor"                => 16075,
                         "humiliate"              => 3091,
                         "humiliated"             => 2632,
                         "humiliates"             => 18592,
                         "humiliating"            => 2624,
                         "humiliation"            => 2979,
                         "humiliations"           => 13684,
                         "humility"               => 5293,
                         "hummed"                 => 18591,
                         "humming"                => 6027,
                         "hummm"                  => 17223,
                         "hummus"                 => 10923,
                         "humongous"              => 9313,
                         "humons"                 => 16074,
                         "humor"                  => 1562,
                         "humored"                => 18590,
                         "humoring"               => 11692,
                         "humorless"              => 13683,
                         "humour"                 => 4258,
                         "hump"                   => 4663,
                         "humpback"               => 18589,
                         "humped"                 => 11285,
                         "humperdinck"            => 9777,
                         "humph"                  => 17222,
                         "humping"                => 7618,
                         "humps"                  => 16073,
                         "humus"                  => 17221,
                         "humvee"                 => 14364,
                         "hunch"                  => 2768,
                         "hunchback"              => 13118,
                         "hunched"                => 15174,
                         "hunches"                => 10922,
                         "hundred"                => 466,
                         "hundredth"              => 7252,
                         "hunger"                 => 3575,
                         "hungover"               => 13682,
                         "hungry"                 => 794,
                         "hunh"                   => 4858,
                         "hunhh"                  => 18588,
                         "hunk"                   => 3534,
                         "hunker"                 => 16072,
                         "hunks"                  => 12131,
                         "hunky"                  => 6088,
                         "hunnert"                => 12608,
                         "hunsecker"              => 7370,
                         "hunted"                 => 4596,
                         "huntin"                 => 9312,
                         "hunts"                  => 9547,
                         "hurled"                 => 9546,
                         "hurrah"                 => 7023,
                         "hurray"                 => 11284,
                         "hurried"                => 13117,
                         "hurry"                  => 630,
                         "hurrying"               => 8202,
                         "hurt"                   => 222,
                         "hurtful"                => 4819,
                         "hurtin"                 => 9115,
                         "hurting"                => 991,
                         "hurtling"               => 13116,
                         "hurts"                  => 976,
                         "husband"                => 353,
                         "husbands"               => 3407,
                         "huseni"                 => 14363,
                         "hush"                   => 2571,
                         "hushed"                 => 17220,
                         "hushpuppies"            => 18587,
                         "husks"                  => 15173,
                         "hussy"                  => 7494,
                         "hustle"                 => 4311,
                         "hustled"                => 10026,
                         "hustling"               => 10025,
                         "hutch"                  => 6229,
                         "huzzah"                 => 15172,
                         "hydrant"                => 10024,
                         "hydrate"                => 13681,
                         "hydrated"               => 15171,
                         "hydraulics"             => 15170,
                         "hydrochloric"           => 13680,
                         "hydrochloride"          => 17219,
                         "hydrolase"              => 16071,
                         "hyeah"                  => 18586,
                         "hyena"                  => 9776,
                         "hyenas"                 => 8201,
                         "hygiene"                => 5259,
                         "hygienic"               => 18585,
                         "hygienist"              => 15169,
                         "hymie"                  => 16070,
                         "hyped"                  => 10603,
                         "hyper"                  => 5629,
                         "hyperactive"            => 11691,
                         "hyperbole"              => 11283,
                         "hyperdrive"             => 8053,
                         "hyperspace"             => 15168,
                         "hyperventilate"         => 11690,
                         "hyperventilating"       => 8200,
                         "hyphen"                 => 13115,
                         "hypnosis"               => 6153,
                         "hypnotic"               => 10602,
                         "hypnotize"              => 7617,
                         "hypnotized"             => 6373,
                         "hypochondriac"          => 13114,
                         "hypocrisy"              => 6551,
                         "hypocrite"              => 3090,
                         "hypocrites"             => 9114,
                         "hypocritical"           => 6299,
                         "hypodermic"             => 11689,
                         "hypoglycemia"           => 9311,
                         "hypoglycemic"           => 14362,
                         "hypotensive"            => 17218,
                         "hypotenuse"             => 18584,
                         "hypothermia"            => 6455,
                         "hypothetical"           => 5384,
                         "hypothetically"         => 4723,
                         "hypothyroidism"         => 14361,
                         "hysterectomy"           => 10303,
                         "hysteria"               => 7616,
                         "hysteric"               => 18583,
                         "hysterical"             => 3009,
                         "hysterically"           => 15167,
                         "hysterics"              => 11688,
                         "i"                      => 2,
                         "i'd"                    => 133,
                         "i'd've"                 => 13113,
                         "i'i'm"                  => 16069,
                         "i'll"                   => 60,
                         "i'm"                    => 10,
                         "i'mma"                  => 9113,
                         "i've"                   => 79,
                         "iambic"                 => 15166,
                         "ibuprofen"              => 16068,
                         "ice"                    => 671,
                         "icebergs"               => 17217,
                         "icebox"                 => 13112,
                         "iced"                   => 3021,
                         "icicles"                => 16067,
                         "icing"                  => 6917,
                         "idea"                   => 184,
                         "idealist"               => 15165,
                         "idealistic"             => 9112,
                         "ideas"                  => 1133,
                         "idiocy"                 => 11282,
                         "idiosyncrasies"         => 17216,
                         "idiot"                  => 805,
                         "idiotic"                => 4211,
                         "idiots"                 => 2603,
                         "iditarod"               => 16066,
                         "idling"                 => 17215,
                         "idn't"                  => 18582,
                         "idolized"               => 13111,
                         "idolizes"               => 14360,
                         "idyllic"                => 13110,
                         "if"                     => 36,
                         "igloo"                  => 10302,
                         "ignite"                 => 11687,
                         "ignition"               => 5852,
                         "ignoramus"              => 13679,
                         "ignorance"              => 5333,
                         "ignorant"               => 4234,
                         "ignore"                 => 1343,
                         "ignored"                => 3173,
                         "ignores"                => 8199,
                         "ignoring"               => 2767,
                         "iguanas"                => 10601,
                         "illegal"                => 1467,
                         "illegally"              => 4782,
                         "illegals"               => 18581,
                         "illegible"              => 16065,
                         "illiterate"             => 9545,
                         "illogical"              => 13678,
                         "illuminate"             => 10600,
                         "illuminating"           => 11686,
                         "illusions"              => 5207,
                         "illustrious"            => 7369,
                         "imaginable"             => 8704,
                         "imaginary"              => 3942,
                         "imagination"            => 1747,
                         "imaginations"           => 11685,
                         "imaginative"            => 7759,
                         "imagine"                => 567,
                         "imagined"               => 1983,
                         "imagines"               => 13109,
                         "imagining"              => 2584,
                         "imbalance"              => 9544,
                         "imbecile"               => 8521,
                         "imbeciles"              => 13108,
                         "imbecilic"              => 18580,
                         "imbedded"               => 18579,
                         "imipenem"               => 17214,
                         "imitate"                => 8198,
                         "imitating"              => 10921,
                         "imitation"              => 5292,
                         "immaterial"             => 13107,
                         "immature"               => 3406,
                         "immaturity"             => 16064,
                         "immerse"                => 13106,
                         "immobile"               => 18578,
                         "immobilize"             => 15164,
                         "immodest"               => 18577,
                         "immoral"                => 4722,
                         "immortality"            => 6803,
                         "immune"                 => 3317,
                         "immunity"               => 3616,
                         "immutable"              => 15163,
                         "impale"                 => 18576,
                         "impaled"                => 13105,
                         "impart"                 => 10599,
                         "impartial"              => 6627,
                         "impasse"                => 9543,
                         "impassioned"            => 17213,
                         "impatience"             => 15162,
                         "impatient"              => 4283,
                         "impeach"                => 11281,
                         "impeached"              => 17212,
                         "impeccable"             => 4818,
                         "impediment"             => 10301,
                         "impediments"            => 16063,
                         "impeding"               => 16062,
                         "impenetrable"           => 9111,
                         "imperative"             => 4817,
                         "imperfection"           => 15161,
                         "imperfections"          => 12607,
                         "imperious"              => 18575,
                         "impersonal"             => 8520,
                         "impersonate"            => 8052,
                         "impersonated"           => 11280,
                         "impersonating"          => 5332,
                         "impersonation"          => 9775,
                         "impersonator"           => 12130,
                         "impertinent"            => 12606,
                         "impervious"             => 12605,
                         "impetuous"              => 13104,
                         "implant"                => 5686,
                         "implanted"              => 7936,
                         "implausible"            => 15160,
                         "implicate"              => 6298,
                         "implicates"             => 15159,
                         "implicating"            => 12129,
                         "implication"            => 7758,
                         "implode"                => 10023,
                         "imploding"              => 16061,
                         "implore"                => 7935,
                         "implosion"              => 14359,
                         "imply"                  => 4282,
                         "implying"               => 2877,
                         "impolite"               => 8913,
                         "important"              => 305,
                         "importante"             => 18574,
                         "importantly"            => 2831,
                         "importer"               => 11684,
                         "impose"                 => 4891,
                         "imposition"             => 8519,
                         "impossibility"          => 10598,
                         "impossible"             => 840,
                         "impossibly"             => 10920,
                         "imposter"               => 5728,
                         "impostor"               => 6550,
                         "impostors"              => 18573,
                         "impotence"              => 15158,
                         "impotent"               => 6802,
                         "impound"                => 8912,
                         "impounded"              => 13677,
                         "impractical"            => 9110,
                         "impregnable"            => 14358,
                         "impregnate"             => 14357,
                         "impregnated"            => 10919,
                         "impress"                => 2184,
                         "impressed"              => 1403,
                         "impresses"              => 14356,
                         "impressing"             => 11279,
                         "impression"             => 1449,
                         "impressionable"         => 6711,
                         "impressionists"         => 17211,
                         "impressions"            => 4721,
                         "impressive"             => 1763,
                         "impressively"           => 18572,
                         "imprinted"              => 18571,
                         "imprison"               => 18570,
                         "improbable"             => 10022,
                         "impromptu"              => 6916,
                         "improprieties"          => 18569,
                         "impropriety"            => 11683,
                         "improv"                 => 9774,
                         "improvise"              => 5685,
                         "improvising"            => 13676,
                         "imprudent"              => 18568,
                         "impudence"              => 17210,
                         "impudent"               => 15157,
                         "impulse"                => 3085,
                         "impulses"               => 5206,
                         "impulsive"              => 4045,
                         "impulsively"            => 11278,
                         "impunity"               => 15156,
                         "impure"                 => 9542,
                         "inaccuracies"           => 16060,
                         "inadequacies"           => 18567,
                         "inadequacy"             => 11682,
                         "inadmissible"           => 8347,
                         "inadvertently"          => 7493,
                         "inalienable"            => 14355,
                         "inane"                  => 9310,
                         "inanimate"              => 10021,
                         "inappropriate"          => 2408,
                         "inappropriately"        => 15155,
                         "inarticulate"           => 18566,
                         "inasmuch"               => 16059,
                         "inbound"                => 9109,
                         "inbred"                 => 12128,
                         "inbreeding"             => 17209,
                         "incacha"                => 14354,
                         "incan"                  => 12127,
                         "incantation"            => 7615,
                         "incantations"           => 10300,
                         "incapable"              => 3867,
                         "incapacitate"           => 16058,
                         "incapacitated"          => 5803,
                         "incarcerate"            => 17208,
                         "incarcerated"           => 7251,
                         "incarceration"          => 7757,
                         "incarnate"              => 9309,
                         "incas"                  => 17207,
                         "incase"                 => 16057,
                         "incendiary"             => 12126,
                         "incense"                => 9108,
                         "incensed"               => 16056,
                         "incentive"              => 4974,
                         "incessant"              => 9773,
                         "incessantly"            => 16055,
                         "incestuous"             => 17206,
                         "inch"                   => 1914,
                         "incidentally"           => 5903,
                         "incidentals"            => 18565,
                         "incinerate"             => 12125,
                         "incinerated"            => 12124,
                         "incinerator"            => 10597,
                         "incision"               => 6026,
                         "incisors"               => 14353,
                         "inclement"              => 18564,
                         "inclined"               => 4662,
                         "incoherent"             => 12604,
                         "incoherently"           => 18563,
                         "incoming"               => 3969,
                         "incommunicado"          => 13675,
                         "incomparable"           => 13674,
                         "incompetence"           => 5628,
                         "incompetent"            => 4172,
                         "incompletes"            => 18562,
                         "incomprehensible"       => 11681,
                         "inconceivable"          => 8518,
                         "inconclusive"           => 9772,
                         "inconsequential"        => 18561,
                         "inconsiderate"          => 7022,
                         "inconsolable"           => 17205,
                         "inconspicuous"          => 15154,
                         "incontrovertible"       => 18560,
                         "inconvenience"          => 4016,
                         "inconvenienced"         => 10020,
                         "inconveniencing"        => 17204,
                         "inconvenient"           => 5727,
                         "incorrigible"           => 10299,
                         "incredible"             => 817,
                         "incredibly"             => 1422,
                         "incriminate"            => 5258,
                         "incriminating"          => 4439,
                         "incrimination"          => 17203,
                         "incubator"              => 7368,
                         "incubators"             => 17202,
                         "incur"                  => 10298,
                         "incurable"              => 10019,
                         "indebted"               => 8197,
                         "indecent"               => 8703,
                         "indecision"             => 15153,
                         "indecisive"             => 14352,
                         "indeed"                 => 1268,
                         "indeedy"                => 10297,
                         "indefensible"           => 13673,
                         "indefinable"            => 18559,
                         "indefinitely"           => 4348,
                         "indelicate"             => 17201,
                         "indentation"            => 18558,
                         "indescribable"          => 12603,
                         "indescribably"          => 18557,
                         "indestructible"         => 8196,
                         "indeterminate"          => 11680,
                         "indication"             => 3683,
                         "indict"                 => 15152,
                         "indictment"             => 6372,
                         "indictments"            => 13672,
                         "indifference"           => 8911,
                         "indifferent"            => 8910,
                         "indigestion"            => 7934,
                         "indignant"              => 13671,
                         "indignation"            => 8517,
                         "indignities"            => 15151,
                         "indignity"              => 14351,
                         "indio"                  => 15150,
                         "indiscreet"             => 15149,
                         "indiscretion"           => 7021,
                         "indiscretions"          => 15148,
                         "indispensable"          => 10918,
                         "indisposed"             => 10018,
                         "indisputable"           => 18556,
                         "individuality"          => 11679,
                         "indoors"                => 7250,
                         "indubitably"            => 18555,
                         "inducement"             => 13670,
                         "indulge"                => 4558,
                         "indulged"               => 12602,
                         "indulgence"             => 10596,
                         "indulgent"              => 7020,
                         "indulging"              => 8195,
                         "industrious"            => 10595,
                         "indy"                   => 4595,
                         "inebriated"             => 14350,
                         "inedible"               => 13669,
                         "ineffectual"            => 10017,
                         "inept"                  => 7756,
                         "inequities"             => 18554,
                         "inevitability"          => 13668,
                         "inevitable"             => 2748,
                         "inevitably"             => 6152,
                         "inexcusable"            => 7367,
                         "inexperience"           => 12123,
                         "inexperienced"          => 6801,
                         "inexplicable"           => 10917,
                         "infact"                 => 18553,
                         "infallible"             => 10594,
                         "infamy"                 => 15147,
                         "infantery"              => 12601,
                         "infantile"              => 8346,
                         "infarction"             => 11277,
                         "infatuated"             => 7933,
                         "infatuation"            => 7019,
                         "infect"                 => 6915,
                         "infected"               => 2885,
                         "infecting"              => 9107,
                         "infection"              => 2418,
                         "infects"                => 15146,
                         "inferiority"            => 12122,
                         "infernal"               => 10296,
                         "infertile"              => 13103,
                         "infestation"            => 11678,
                         "infested"               => 5627,
                         "infidelities"           => 16054,
                         "infidelity"             => 6454,
                         "infierno"               => 6025,
                         "infiltrate"             => 6228,
                         "infinitum"              => 18552,
                         "infirmary"              => 5726,
                         "inflame"                => 13667,
                         "inflamed"               => 12121,
                         "inflatable"             => 9308,
                         "inflate"                => 15145,
                         "inflated"               => 9106,
                         "inflating"              => 16053,
                         "inflexible"             => 13666,
                         "inflict"                => 6549,
                         "infliction"             => 17200,
                         "info"                   => 3235,
                         "infomercial"            => 10916,
                         "inform"                 => 2866,
                         "informant"              => 4537,
                         "informants"             => 9541,
                         "informative"            => 9540,
                         "informed"               => 2249,
                         "informer"               => 11276,
                         "infra"                  => 17199,
                         "infraction"             => 11275,
                         "infringe"               => 18551,
                         "infuriate"              => 16052,
                         "infuriates"             => 17198,
                         "infuriating"            => 6710,
                         "infusing"               => 18550,
                         "ingenious"              => 7136,
                         "ingenue"                => 13665,
                         "ingenuity"              => 9771,
                         "ingest"                 => 13664,
                         "ingested"               => 8516,
                         "ingesting"              => 18549,
                         "ingrate"                => 9307,
                         "ingrates"               => 11677,
                         "ingratitude"            => 17197,
                         "ingredient"             => 5075,
                         "ingrown"                => 18548,
                         "inhalation"             => 9105,
                         "inhale"                 => 7135,
                         "inhaled"                => 8909,
                         "inhaler"                => 8908,
                         "inhaling"               => 11676,
                         "inherit"                => 4624,
                         "inheritance"            => 3794,
                         "inherits"               => 13663,
                         "inhibitions"            => 10016,
                         "inhuman"                => 7932,
                         "inhumane"               => 11675,
                         "inigo"                  => 10915,
                         "ining"                  => 18547,
                         "initials"               => 3737,
                         "inject"                 => 5257,
                         "injected"               => 4748,
                         "injecting"              => 9539,
                         "injection"              => 3776,
                         "injections"             => 7492,
                         "injector"               => 17196,
                         "injun"                  => 10593,
                         "injunction"             => 6626,
                         "injuns"                 => 14349,
                         "injure"                 => 10295,
                         "injustice"              => 4938,
                         "inkling"                => 9104,
                         "inlaid"                 => 17195,
                         "inlay"                  => 14348,
                         "inmate"                 => 4973,
                         "innards"                => 17194,
                         "innermost"              => 10592,
                         "innit"                  => 8702,
                         "innkeeper"              => 12600,
                         "innocence"              => 2860,
                         "innocencia"             => 10015,
                         "innocent"               => 747,
                         "innocently"             => 10914,
                         "innocents"              => 6024,
                         "innocuous"              => 12599,
                         "innuendo"               => 8701,
                         "innuendoes"             => 15144,
                         "inopportune"            => 15143,
                         "inquire"                => 9538,
                         "inquiries"              => 8194,
                         "inquiring"              => 9770,
                         "inquisition"            => 7134,
                         "inquisitive"            => 14347,
                         "inquisitor"             => 16051,
                         "inroads"                => 17193,
                         "insanely"               => 7018,
                         "insanity"               => 2442,
                         "insatiable"             => 6914,
                         "inscrutable"            => 17192,
                         "insect"                 => 4144,
                         "insectopia"             => 11674,
                         "insecure"               => 2583,
                         "insecurities"           => 5205,
                         "insecurity"             => 5902,
                         "inseminated"            => 16050,
                         "insemination"           => 9537,
                         "insensitive"            => 2671,
                         "insensitivity"          => 17191,
                         "inseparable"            => 7491,
                         "inside"                 => 380,
                         "insides"                => 5431,
                         "insidious"              => 8700,
                         "insight"                => 3487,
                         "insightful"             => 7490,
                         "insights"               => 6297,
                         "insignificant"          => 4972,
                         "insincere"              => 11673,
                         "insinuate"              => 9769,
                         "insinuated"             => 13662,
                         "insinuating"            => 5430,
                         "insinuations"           => 13102,
                         "insipid"                => 12120,
                         "insist"                 => 1570,
                         "insisted"               => 2152,
                         "insistent"              => 8699,
                         "insisting"              => 3841,
                         "insists"                => 4084,
                         "insolence"              => 11672,
                         "insolent"               => 7366,
                         "inspect"                => 7017,
                         "inspector"              => 1851,
                         "inspirational"          => 7489,
                         "inspire"                => 3635,
                         "inspires"               => 7249,
                         "inspiring"              => 4044,
                         "instant"                => 2187,
                         "instantaneously"        => 18546,
                         "instantly"              => 3919,
                         "instep"                 => 15142,
                         "instigate"              => 18545,
                         "instigator"             => 15141,
                         "instill"                => 15140,
                         "instilled"              => 17190,
                         "instinct"               => 2222,
                         "instinctive"            => 14346,
                         "instinctively"          => 7248,
                         "instincts"              => 1774,
                         "instruct"               => 7365,
                         "instructing"            => 11274,
                         "instructions"           => 2026,
                         "instructive"            => 14345,
                         "instyle"                => 18544,
                         "insubordinate"          => 14344,
                         "insubordination"        => 9306,
                         "insufferable"           => 6087,
                         "insulin"                => 5626,
                         "insult"                 => 2012,
                         "insulted"               => 3029,
                         "insulting"              => 2936,
                         "insults"                => 4194,
                         "insurance"              => 1284,
                         "insure"                 => 7614,
                         "insured"                => 7133,
                         "insuring"               => 17189,
                         "insurmountable"         => 12598,
                         "integrity"              => 2403,
                         "intellect"              => 5684,
                         "intellectually"         => 8193,
                         "intelligent"            => 2186,
                         "intelligently"          => 15139,
                         "intend"                 => 1364,
                         "intense"                => 1725,
                         "intensely"              => 7613,
                         "intention"              => 1716,
                         "intentional"            => 6086,
                         "intentionally"          => 3634,
                         "intentioned"            => 15138,
                         "intentions"             => 2402,
                         "intently"               => 15137,
                         "intents"                => 14343,
                         "intercede"              => 13101,
                         "intercept"              => 5074,
                         "intercepting"           => 13100,
                         "intercom"               => 7016,
                         "intercostal"            => 18543,
                         "intercranial"           => 16049,
                         "interested"             => 586,
                         "interestin"             => 17188,
                         "interesting"            => 644,
                         "interfacing"            => 17187,
                         "interfere"              => 2002,
                         "interfered"             => 5625,
                         "interference"           => 3252,
                         "interferes"             => 10294,
                         "interfering"            => 3282,
                         "interferon"             => 14342,
                         "intergalactic"          => 9768,
                         "interject"              => 17186,
                         "interloper"             => 18542,
                         "interlude"              => 10293,
                         "interminable"           => 18541,
                         "intermission"           => 7755,
                         "intern"                 => 3198,
                         "interning"              => 10591,
                         "internist"              => 16048,
                         "interns"                => 5970,
                         "internship"             => 4971,
                         "interpol"               => 5802,
                         "interpret"              => 5204,
                         "interrogate"            => 4816,
                         "interrogated"           => 6625,
                         "interrogating"          => 5624,
                         "interrogation"          => 2928,
                         "interrogations"         => 17185,
                         "interrupt"              => 1369,
                         "interrupted"            => 2675,
                         "interrupting"           => 1848,
                         "interruption"           => 4781,
                         "interruptions"          => 5490,
                         "interruptus"            => 17184,
                         "intertwined"            => 10292,
                         "interviewing"           => 4257,
                         "intestine"              => 10014,
                         "intestines"             => 7488,
                         "intimacy"               => 3793,
                         "intimate"               => 2245,
                         "intimated"              => 15136,
                         "intimately"             => 6800,
                         "intimates"              => 18540,
                         "intimidate"             => 4381,
                         "intimidated"            => 3633,
                         "intimidating"           => 5725,
                         "intolerable"            => 7754,
                         "intolerant"             => 8907,
                         "intoxicating"           => 7364,
                         "intoxication"           => 13661,
                         "intravenously"          => 17183,
                         "intricacies"            => 14341,
                         "intrigue"               => 6085,
                         "intrigued"              => 4937,
                         "intriguing"             => 4210,
                         "intro"                  => 6151,
                         "introduce"              => 1445,
                         "introductions"          => 7487,
                         "intros"                 => 17182,
                         "intrude"                => 4124,
                         "intruded"               => 17181,
                         "intruders"              => 7931,
                         "intruding"              => 5331,
                         "intrusion"              => 6913,
                         "intrusive"              => 9536,
                         "intubate"               => 8906,
                         "intubated"              => 18539,
                         "intuition"              => 5291,
                         "intuitions"             => 18538,
                         "intuitive"              => 7612,
                         "inuit"                  => 7363,
                         "inuvik"                 => 18537,
                         "invade"                 => 4780,
                         "invading"               => 5801,
                         "invalid"                => 5540,
                         "invalidate"             => 13099,
                         "invaluable"             => 7362,
                         "invent"                 => 4557,
                         "invented"               => 2431,
                         "inventing"              => 9767,
                         "inventory"              => 3474,
                         "invest"                 => 3656,
                         "investigating"          => 2407,
                         "investigation"          => 1154,
                         "investigator"           => 2994,
                         "invigorated"            => 17180,
                         "invigorating"           => 11671,
                         "invincible"             => 5203,
                         "invisibility"           => 12119,
                         "invisible"              => 2233,
                         "invitation"             => 1653,
                         "invitations"            => 3053,
                         "invite"                 => 1155,
                         "invited"                => 906,
                         "inviting"               => 2239,
                         "invitro"                => 15135,
                         "invoice"                => 10291,
                         "invoices"               => 11670,
                         "invoke"                 => 8345,
                         "invoking"               => 14340,
                         "involuntary"            => 9305,
                         "involve"                => 2350,
                         "invulnerable"           => 9535,
                         "ipecac"                 => 17179,
                         "iranoff"                => 11669,
                         "irate"                  => 9534,
                         "irked"                  => 14339,
                         "ironclad"               => 10290,
                         "ironed"                 => 13660,
                         "ironic"                 => 2382,
                         "ironies"                => 15134,
                         "ironing"                => 7611,
                         "irony"                  => 3001,
                         "irrational"             => 3460,
                         "irrationally"           => 15133,
                         "irredeemable"           => 18536,
                         "irrefutable"            => 14338,
                         "irregularity"           => 18535,
                         "irrelevant"             => 3592,
                         "irreparable"            => 10913,
                         "irreplaceable"          => 8905,
                         "irrepressible"          => 18534,
                         "irresistable"           => 16047,
                         "irresistible"           => 3866,
                         "irresponsibility"       => 13659,
                         "irresponsible"          => 2978,
                         "irresponsibly"          => 18533,
                         "irreversible"           => 9766,
                         "irrevocable"            => 14337,
                         "irrevocably"            => 15132,
                         "irrigate"               => 15131,
                         "irritability"           => 14336,
                         "irritable"              => 7361,
                         "irritate"               => 6912,
                         "irritated"              => 6453,
                         "irritates"              => 14335,
                         "irritating"             => 4661,
                         "isabela"                => 13658,
                         "isn't"                  => 135,
                         "isolate"                => 5901,
                         "issacs"                 => 13657,
                         "it"                     => 5,
                         "it'd"                   => 1084,
                         "it'll"                  => 390,
                         "it's"                   => 21,
                         "itch"                   => 4347,
                         "itches"                 => 7753,
                         "itching"                => 5290,
                         "itchy"                  => 5429,
                         "item"                   => 2215,
                         "itinerary"              => 5114,
                         "ivories"                => 12597,
                         "ixnay"                  => 14334,
                         "izzat"                  => 18532,
                         "jabbering"              => 15130,
                         "jabberjaw"              => 18531,
                         "jabbing"                => 18530,
                         "jabez"                  => 3502,
                         "jabot"                  => 2244,
                         "jackals"                => 12118,
                         "jackasses"              => 13098,
                         "jacked"                 => 6911,
                         "jackers"                => 13097,
                         "jacket"                 => 1151,
                         "jackets"                => 5073,
                         "jackhammer"             => 14333,
                         "jacking"                => 7930,
                         "jackrabbits"            => 18529,
                         "jacks"                  => 2037,
                         "jacksons"               => 12596,
                         "jacqnoud"               => 12595,
                         "jacuzzi"                => 5046,
                         "jaded"                  => 7610,
                         "jafar"                  => 7247,
                         "jaffa"                  => 3775,
                         "jagielski"              => 18528,
                         "jagoff"                 => 18527,
                         "jail"                   => 607,
                         "jailbreak"              => 13096,
                         "jailhouse"              => 7929,
                         "jails"                  => 14332,
                         "jakey"                  => 10289,
                         "jakov"                  => 8344,
                         "jakovasaur"             => 13656,
                         "jakovasaurs"            => 10912,
                         "jalopy"                 => 13095,
                         "jammed"                 => 3172,
                         "jammies"                => 8904,
                         "jamming"                => 7928,
                         "janeane"                => 14331,
                         "jango"                  => 13094,
                         "janiro"                 => 17178,
                         "janitor"                => 3447,
                         "janitorial"             => 17177,
                         "janitors"               => 13093,
                         "jankis"                 => 13092,
                         "jankle"                 => 18526,
                         "janover"                => 10911,
                         "jargon"                 => 12117,
                         "jarmel"                 => 18525,
                         "jarring"                => 15129,
                         "jaundice"               => 12116,
                         "jaunt"                  => 15128,
                         "jaunty"                 => 18524,
                         "javna"                  => 16046,
                         "jawbone"                => 17176,
                         "jawed"                  => 13091,
                         "jax"                    => 678,
                         "jaywalking"             => 11273,
                         "jazzed"                 => 7132,
                         "jealitosis"             => 18523,
                         "jealous"                => 829,
                         "jealousy"               => 2361,
                         "jeans"                  => 2993,
                         "jedediah"               => 18522,
                         "jeebies"                => 9533,
                         "jeebs"                  => 14330,
                         "jeeps"                  => 16045,
                         "jeesus"                 => 14329,
                         "jeeter"                 => 14328,
                         "jeez"                   => 1387,
                         "jeeze"                  => 14327,
                         "jeffy"                  => 11272,
                         "jellies"                => 16044,
                         "jellyfish"              => 6227,
                         "jellyman"               => 18521,
                         "jen"                    => 442,
                         "jenko"                  => 18520,
                         "jenoff"                 => 17175,
                         "jenzen"                 => 18519,
                         "jeopardize"             => 3446,
                         "jeopardized"            => 9103,
                         "jeopardizing"           => 7131,
                         "jeopardy"               => 3774,
                         "jeric"                  => 13090,
                         "jeriko"                 => 13655,
                         "jerk"                   => 1007,
                         "jerked"                 => 7130,
                         "jerking"                => 6150,
                         "jerks"                  => 3714,
                         "jerky"                  => 5045,
                         "jerries"                => 16043,
                         "jesminder"              => 10590,
                         "jessep"                 => 7927,
                         "jests"                  => 18518,
                         "jetting"                => 14326,
                         "jettison"               => 13089,
                         "jewbilee"               => 12594,
                         "jeweler"                => 8192,
                         "jewelers"               => 12593,
                         "jewelry"                => 2035,
                         "jezzie"                 => 14325,
                         "jiffy"                  => 8343,
                         "jigalong"               => 16042,
                         "jiggled"                => 18517,
                         "jiggling"               => 12592,
                         "jiggly"                 => 15127,
                         "jillefsky"              => 6910,
                         "jilted"                 => 12591,
                         "jimmied"                => 18516,
                         "jimmies"                => 13654,
                         "jimson"                 => 13088,
                         "jingling"               => 16041,
                         "jinx"                   => 3818,
                         "jinxed"                 => 9304,
                         "jinxy"                  => 7926,
                         "jitters"                => 4779,
                         "jittery"                => 8903,
                         "job"                    => 207,
                         "jobless"                => 15126,
                         "jobs"                   => 1429,
                         "jobson"                 => 16040,
                         "jock"                   => 4463,
                         "jockeys"                => 11668,
                         "jocko"                  => 18515,
                         "jocks"                  => 7129,
                         "jockstrap"              => 15125,
                         "jogger"                 => 10910,
                         "jogging"                => 5428,
                         "join"                   => 717,
                         "jointed"                => 14324,
                         "joints"                 => 5000,
                         "joists"                 => 18514,
                         "joke"                   => 729,
                         "jokes"                  => 1679,
                         "jokey"                  => 18513,
                         "jokin"                  => 10589,
                         "joking"                 => 1628,
                         "joliet"                 => 10909,
                         "jolinar"                => 7360,
                         "jolla"                  => 13087,
                         "jollies"                => 12115,
                         "jolson"                 => 17174,
                         "jondy"                  => 17173,
                         "jonesing"               => 12590,
                         "jonestown"              => 18512,
                         "jordie"                 => 17172,
                         "jordy"                  => 13653,
                         "jostled"                => 18511,
                         "jotted"                 => 16039,
                         "joust"                  => 16038,
                         "joyous"                 => 5202,
                         "judas"                  => 5900,
                         "judge"                  => 684,
                         "judgement"              => 4346,
                         "judgemental"            => 14323,
                         "judging"                => 2205,
                         "judgment"               => 1594,
                         "judgmental"             => 4594,
                         "judgments"              => 7752,
                         "juggling"               => 6149,
                         "jugular"                => 8191,
                         "juiced"                 => 10288,
                         "juices"                 => 7751,
                         "juilliard"              => 7359,
                         "jujyfruit"              => 18510,
                         "jukebox"                => 5489,
                         "julep"                  => 17171,
                         "julliard"               => 12114,
                         "julyan"                 => 15124,
                         "jumba"                  => 17170,
                         "jumbled"                => 16037,
                         "jump"                   => 843,
                         "jumped"                 => 1513,
                         "jumpin"                 => 8190,
                         "jumping"                => 1678,
                         "jumps"                  => 3473,
                         "jumpsuit"               => 10908,
                         "jumpy"                  => 4233,
                         "juncture"               => 8342,
                         "jungles"                => 11667,
                         "junjun"                 => 17169,
                         "junk"                   => 1765,
                         "junket"                 => 14322,
                         "junkies"                => 7358,
                         "junky"                  => 13652,
                         "junshi"                 => 16036,
                         "juries"                 => 10588,
                         "juror"                  => 6909,
                         "jurors"                 => 8189,
                         "jury"                   => 1221,
                         "jussy"                  => 13651,
                         "just"                   => 15,
                         "justifiable"            => 8698,
                         "justified"              => 4193,
                         "justifies"              => 6799,
                         "justify"                => 2684,
                         "justifying"             => 9765,
                         "juvenile"               => 3380,
                         "juvie"                  => 7609,
                         "kabob"                  => 17168,
                         "kacl"                   => 4310,
                         "kafelnikov"             => 17167,
                         "kaffee"                 => 7128,
                         "kafka"                  => 7486,
                         "kaggs"                  => 18509,
                         "kaitlan"                => 12113,
                         "kakistos"               => 15123,
                         "kaleidoscope"           => 11271,
                         "kalen"                  => 8902,
                         "kamal"                  => 6908,
                         "kamerev"                => 18508,
                         "kanamits"               => 16035,
                         "kapowski"               => 15122,
                         "kaput"                  => 8697,
                         "karajan"                => 18507,
                         "karak"                  => 15121,
                         "karenina"               => 16034,
                         "kareoke"                => 17166,
                         "karikos"                => 16033,
                         "karinsky"               => 5539,
                         "karlo"                  => 11270,
                         "karloff"                => 14321,
                         "karmic"                 => 9532,
                         "karnovsky"              => 13086,
                         "karras"                 => 11666,
                         "kasdan"                 => 15120,
                         "kasnoff"                => 3840,
                         "katan"                  => 8901,
                         "katarangura"            => 10287,
                         "katra"                  => 17165,
                         "katzenmoyer"            => 15119,
                         "kavorka"                => 18506,
                         "kawalsky"               => 10587,
                         "kazootie"               => 15118,
                         "kazuo"                  => 12589,
                         "keanu"                  => 12588,
                         "keats"                  => 12112,
                         "keaty"                  => 18505,
                         "kebab"                  => 14320,
                         "kechner"                => 18504,
                         "keeled"                 => 15117,
                         "keep"                   => 127,
                         "keepers"                => 7608,
                         "keepin"                 => 5577,
                         "keeping"                => 665,
                         "keeps"                  => 828,
                         "keepsake"               => 14319,
                         "keepsakes"              => 18503,
                         "kegger"                 => 10586,
                         "keggers"                => 18502,
                         "kellman"                => 11269,
                         "kembu"                  => 12587,
                         "kemosabe"               => 13650,
                         "kenaru"                 => 12111,
                         "kendo"                  => 17164,
                         "kenji"                  => 12586,
                         "kenmore"                => 15116,
                         "kennedys"               => 11268,
                         "kennel"                 => 9764,
                         "kennie"                 => 15115,
                         "kenosha"                => 13649,
                         "kenyons"                => 18501,
                         "kept"                   => 540,
                         "kerosene"               => 11665,
                         "kesher"                 => 16032,
                         "ketch"                  => 16031,
                         "ketchup"                => 3294,
                         "kettle"                 => 5201,
                         "keveral"                => 18500,
                         "kevie"                  => 18499,
                         "kevvy"                  => 6452,
                         "kewpie"                 => 17163,
                         "keycard"                => 7357,
                         "keyed"                  => 9531,
                         "keyhole"                => 10286,
                         "keymaster"              => 18498,
                         "keypad"                 => 14318,
                         "keyworth"               => 18497,
                         "khakis"                 => 12110,
                         "khasinau"               => 3682,
                         "kholi"                  => 8051,
                         "kholokov"               => 17162,
                         "khruschev"              => 8188,
                         "kibosh"                 => 10907,
                         "kick"                   => 800,
                         "kickback"               => 17161,
                         "kickbacks"              => 17160,
                         "kickball"               => 18496,
                         "kicked"                 => 1280,
                         "kickin"                 => 6709,
                         "kicking"                => 1764,
                         "kicks"                  => 2658,
                         "kicky"                  => 17159,
                         "kid"                    => 308,
                         "kid'll"                 => 17158,
                         "kiddie"                 => 8696,
                         "kiddies"                => 5899,
                         "kiddin"                 => 3713,
                         "kidding"                => 430,
                         "kiddo"                  => 2482,
                         "kidnap"                 => 2445,
                         "kidnapped"              => 1399,
                         "kidnapper"              => 4143,
                         "kidnappers"             => 5289,
                         "kidnapping"             => 1689,
                         "kidnappings"            => 9530,
                         "kidnaps"                => 11664,
                         "kidnet"                 => 17157,
                         "kidney"                 => 2493,
                         "kidneys"                => 4345,
                         "kids"                   => 284,
                         "kids'll"                => 15114,
                         "kill"                   => 229,
                         "killed"                 => 338,
                         "killin"                 => 5538,
                         "killing"                => 744,
                         "killington"             => 18495,
                         "kills"                  => 1611,
                         "kilos"                  => 5851,
                         "kilter"                 => 17156,
                         "kimbrow"                => 14317,
                         "kimono"                 => 12585,
                         "kind"                   => 148,
                         "kind'a"                 => 16030,
                         "kind've"                => 12584,
                         "kinda"                  => 610,
                         "kindergartners"         => 17155,
                         "kindest"                => 7127,
                         "kindling"               => 10585,
                         "kindly"                 => 2155,
                         "kindness"               => 2825,
                         "kinds"                  => 1358,
                         "kinkaid"                => 16029,
                         "kinkle"                 => 4890,
                         "kinks"                  => 9303,
                         "kinross"                => 16028,
                         "kinsa"                  => 13085,
                         "kiosk"                  => 11267,
                         "kiowas"                 => 18494,
                         "kippers"                => 14316,
                         "kippie"                 => 6084,
                         "kippur"                 => 8695,
                         "kiriakis"               => 3028,
                         "kirkeby"                => 13084,
                         "kiss"                   => 485,
                         "kissable"               => 17154,
                         "kissed"                 => 1090,
                         "kisser"                 => 4690,
                         "kissin"                 => 11266,
                         "kissing"                => 1076,
                         "kissy"                  => 7485,
                         "kitchen"                => 796,
                         "kitschy"                => 14315,
                         "kittridge"              => 11663,
                         "kivar"                  => 6708,
                         "kiwanis"                => 17153,
                         "klendathu"              => 16027,
                         "kleynach"               => 16026,
                         "klicks"                 => 17152,
                         "klorel"                 => 9529,
                         "klute"                  => 9763,
                         "klutz"                  => 5623,
                         "klutzy"                 => 16025,
                         "kmart"                  => 17151,
                         "knack"                  => 4889,
                         "knackety"               => 17150,
                         "knacks"                 => 18493,
                         "knapsack"               => 10285,
                         "knee"                   => 2077,
                         "kneecap"                => 15113,
                         "kneecaps"               => 8694,
                         "kneed"                  => 15112,
                         "kneel"                  => 6548,
                         "kneeling"               => 10906,
                         "knees"                  => 1613,
                         "knelt"                  => 13648,
                         "knew"                   => 191,
                         "knickety"               => 17149,
                         "knickknacks"            => 16024,
                         "knievel"                => 18492,
                         "knife"                  => 1186,
                         "knifed"                 => 15111,
                         "knitted"                => 11662,
                         "knitting"               => 5800,
                         "knives"                 => 3865,
                         "knknow"                 => 17148,
                         "knobs"                  => 11661,
                         "knock"                  => 822,
                         "knockdown"              => 15110,
                         "knocked"                => 1407,
                         "knockin"                => 8187,
                         "knocking"               => 2204,
                         "knockoff"               => 11265,
                         "knocks"                 => 4536,
                         "knot"                   => 3293,
                         "knots"                  => 4256,
                         "knotted"                => 13083,
                         "know"                   => 9,
                         "knowakowski"            => 18491,
                         "knowed"                 => 13082,
                         "knowin"                 => 9102,
                         "knowing"                => 736,
                         "knowingly"              => 7356,
                         "knows"                  => 257,
                         "knuckle"                => 7750,
                         "knucklehead"            => 13081,
                         "knuckleheads"           => 14314,
                         "kobol"                  => 13080,
                         "komako"                 => 9762,
                         "konoss"                 => 17147,
                         "kooks"                  => 16023,
                         "kooky"                  => 9101,
                         "kootchy"                => 17146,
                         "kopalski"               => 11660,
                         "kopek"                  => 18490,
                         "korben"                 => 8900,
                         "korsekov"               => 18489,
                         "kosher"                 => 5898,
                         "kosygin"                => 12109,
                         "kournikova"             => 17145,
                         "kovich"                 => 5622,
                         "kovinsky"               => 18488,
                         "kovitch"                => 17144,
                         "kowolski"               => 15109,
                         "kowtow"                 => 18487,
                         "kozinski"               => 11264,
                         "krabappel"              => 16022,
                         "kramerica"              => 18486,
                         "kraut"                  => 10013,
                         "krauts"                 => 14313,
                         "kreigel"                => 15108,
                         "krendler"               => 15107,
                         "kreskin"                => 17143,
                         "krevlorneswath"         => 12108,
                         "krinkle"                => 15106,
                         "krispy"                 => 14312,
                         "kroehner"               => 7925,
                         "kroff"                  => 14311,
                         "kross"                  => 9302,
                         "kruczynski"             => 18485,
                         "krudski"                => 7355,
                         "kryptonite"             => 10284,
                         "kuato"                  => 14310,
                         "kubelik"                => 5683,
                         "kubla"                  => 10905,
                         "kudos"                  => 7749,
                         "kumbaya"                => 10283,
                         "kundera"                => 15105,
                         "kundun"                 => 11263,
                         "kurten"                 => 13079,
                         "kurtzweil"              => 12583,
                         "kurzon"                 => 12582,
                         "kwaini"                 => 18484,
                         "kwang"                  => 7607,
                         "kynaston"               => 4888,
                         "l'amour"                => 17142,
                         "l'italien"              => 18483,
                         "labatier"               => 16021,
                         "labored"                => 17141,
                         "laboring"               => 14309,
                         "lace"                   => 4857,
                         "laced"                  => 6707,
                         "lacerated"              => 17140,
                         "laceration"             => 8899,
                         "lacerations"            => 11659,
                         "laces"                  => 12581,
                         "lachrymose"             => 18482,
                         "lackeys"                => 10282,
                         "lacquer"                => 16020,
                         "lactic"                 => 16019,
                         "lactose"                => 13647,
                         "ladder"                 => 2657,
                         "laddies"                => 17139,
                         "ladies"                 => 609,
                         "ladle"                  => 12107,
                         "ladman"                 => 15104,
                         "ladonn"                 => 16018,
                         "lads"                   => 4344,
                         "lady"                   => 441,
                         "ladyship"               => 8341,
                         "laferette"              => 10012,
                         "lafortunata"            => 18481,
                         "lagged"                 => 9528,
                         "lagoda"                 => 15103,
                         "laguardia"              => 10584,
                         "lahit"                  => 18480,
                         "lainey"                 => 9527,
                         "lakefront"              => 18479,
                         "lakeview"               => 2441,
                         "lakhi"                  => 8050,
                         "lalita"                 => 6148,
                         "laloosh"                => 11262,
                         "lamagra"                => 16017,
                         "lamaze"                 => 10904,
                         "lambeau"                => 16016,
                         "lambs"                  => 5969,
                         "lame"                   => 1652,
                         "lameness"               => 17138,
                         "lamest"                 => 10011,
                         "laminated"              => 13078,
                         "lamotta"                => 7924,
                         "lamp"                   => 2455,
                         "lamppost"               => 10583,
                         "landingham"             => 4689,
                         "landlady"               => 5383,
                         "landlord"               => 3366,
                         "landmines"              => 17137,
                         "lando"                  => 6798,
                         "landok"                 => 13077,
                         "languishing"            => 15102,
                         "lanky"                  => 17136,
                         "lanna"                  => 8049,
                         "lansbury"               => 9100,
                         "lanterns"               => 10010,
                         "lanyard"                => 17135,
                         "laparotomy"             => 14308,
                         "lapdog"                 => 11658,
                         "lapel"                  => 10582,
                         "lapels"                 => 18478,
                         "lapping"                => 12106,
                         "lapse"                  => 5682,
                         "lapsed"                 => 13076,
                         "lapses"                 => 8340,
                         "larceny"                => 8339,
                         "larch"                  => 8338,
                         "lardass"                => 9526,
                         "lardner"                => 16015,
                         "larek"                  => 10281,
                         "larraby"                => 11261,
                         "laryngitis"             => 13075,
                         "larynx"                 => 9525,
                         "lasagna"                => 7606,
                         "lasagne"                => 8898,
                         "lascivious"             => 13074,
                         "lashed"                 => 8337,
                         "lashes"                 => 8897,
                         "lashing"                => 6023,
                         "lasskopf"               => 16014,
                         "last"                   => 126,
                         "lasts"                  => 3329,
                         "laszlo"                 => 9301,
                         "latch"                  => 7246,
                         "latched"                => 12105,
                         "lately"                 => 701,
                         "lateness"               => 14307,
                         "laters"                 => 18477,
                         "latest"                 => 1566,
                         "lathe"                  => 12104,
                         "lather"                 => 10581,
                         "latinos"                => 10009,
                         "lations"                => 18476,
                         "latka"                  => 17134,
                         "latrine"                => 6547,
                         "latrines"               => 18475,
                         "latte"                  => 3171,
                         "lattes"                 => 6907,
                         "laudanum"               => 18474,
                         "laugh"                  => 868,
                         "laughable"              => 8896,
                         "laughed"                => 2389,
                         "laugher"                => 18473,
                         "laughin"                => 6451,
                         "laughing"               => 1215,
                         "laughingstock"          => 8515,
                         "laughlan"               => 13073,
                         "laughs"                 => 2718,
                         "laughter"               => 4171,
                         "launcelot"              => 10280,
                         "launder"                => 10903,
                         "laundered"              => 11657,
                         "laundering"             => 7245,
                         "laundromat"             => 7015,
                         "laundry"                => 1531,
                         "laurels"                => 14306,
                         "lavatory"               => 14305,
                         "lavery"                 => 3827,
                         "lavished"               => 17133,
                         "lawford"                => 15101,
                         "lawful"                 => 7748,
                         "lawfully"               => 5072,
                         "lawmen"                 => 16013,
                         "lawn"                   => 2410,
                         "lawndale"               => 3736,
                         "lawnmower"              => 7923,
                         "lawns"                  => 8514,
                         "lawsuit"                => 2492,
                         "lawsuits"               => 5724,
                         "lawyer"                 => 675,
                         "lawyered"               => 13646,
                         "lawyering"              => 18472,
                         "lawyers"                => 1564,
                         "laxative"               => 10580,
                         "laxatives"              => 17132,
                         "layaway"                => 13072,
                         "layin"                  => 8186,
                         "laying"                 => 2151,
                         "laynie"                 => 6797,
                         "layover"                => 14304,
                         "lazare"                 => 15100,
                         "lazarre"                => 13645,
                         "lazarro"                => 18471,
                         "lazars"                 => 18470,
                         "lazerus"                => 15099,
                         "laziness"               => 13071,
                         "lazy"                   => 2819,
                         "leadeth"                => 15098,
                         "leadin"                 => 18469,
                         "leafy"                  => 15097,
                         "leak"                   => 2254,
                         "leaked"                 => 5330,
                         "leaking"                => 4778,
                         "leaky"                  => 7244,
                         "leaned"                 => 5968,
                         "leanin"                 => 17131,
                         "leaning"                => 3417,
                         "leans"                  => 7354,
                         "leap"                   => 2440,
                         "leaping"                => 8336,
                         "leaps"                  => 8335,
                         "leapt"                  => 10579,
                         "learn"                  => 576,
                         "learned"                => 749,
                         "learner"                => 9300,
                         "learnin"                => 13644,
                         "lease"                  => 2903,
                         "leash"                  => 3755,
                         "least"                  => 289,
                         "leave"                  => 160,
                         "leavin"                 => 5537,
                         "leaving"                => 407,
                         "lecter"                 => 3968,
                         "lecture"                => 1802,
                         "lecturing"              => 5256,
                         "lederhosen"             => 16012,
                         "ledge"                  => 4192,
                         "ledgers"                => 11260,
                         "leeches"                => 6546,
                         "leering"                => 8895,
                         "leery"                  => 2557,
                         "leeway"                 => 10279,
                         "leezak"                 => 11259,
                         "lefferts"               => 11258,
                         "leftenant"              => 13070,
                         "leftover"               => 5576,
                         "leftovers"              => 4999,
                         "lefts"                  => 13069,
                         "legalities"             => 11656,
                         "legalizing"             => 16011,
                         "legally"                => 2198,
                         "legged"                 => 6371,
                         "leggo"                  => 13643,
                         "leggy"                  => 15096,
                         "legislate"              => 16010,
                         "legit"                  => 3655,
                         "legitimate"             => 2613,
                         "legitimize"             => 18468,
                         "legs"                   => 1091,
                         "legwork"                => 8693,
                         "leisurely"              => 12103,
                         "lemec"                  => 14303,
                         "lemkin"                 => 12102,
                         "lemme"                  => 2177,
                         "lemmiwinks"             => 13642,
                         "lemonlyman"             => 18467,
                         "lemony"                 => 15095,
                         "lence"                  => 18466,
                         "lend"                   => 3039,
                         "leniency"               => 8894,
                         "lenient"                => 9299,
                         "lentils"                => 16009,
                         "leotard"                => 10902,
                         "leotards"               => 17130,
                         "leper"                  => 8334,
                         "lepers"                 => 13068,
                         "lepner"                 => 15094,
                         "leprechaun"             => 7484,
                         "leprechauns"            => 9761,
                         "leprosy"                => 10008,
                         "leron"                  => 13067,
                         "lesabre"                => 13066,
                         "lesbianism"             => 18465,
                         "lesion"                 => 9298,
                         "lessee"                 => 16008,
                         "lesson"                 => 1157,
                         "lessons"                => 2040,
                         "lestercorp"             => 16007,
                         "let"                    => 84,
                         "let'em"                 => 18464,
                         "let's"                  => 112,
                         "letch"                  => 14302,
                         "letdown"                => 9524,
                         "lethal"                 => 3020,
                         "lets"                   => 1336,
                         "letter"                 => 782,
                         "letterhead"             => 13065,
                         "letterman"              => 6370,
                         "lettin"                 => 6906,
                         "letting"                => 752,
                         "lettuce"                => 4380,
                         "leukemia"               => 5575,
                         "leveled"                => 9523,
                         "levelheaded"            => 13064,
                         "leverage"               => 3445,
                         "levitate"               => 10278,
                         "levitation"             => 16006,
                         "levity"                 => 13063,
                         "levon"                  => 8692,
                         "lewen"                  => 16005,
                         "lewises"                => 14301,
                         "lexie"                  => 1119,
                         "lexter"                 => 15093,
                         "lhamo"                  => 17129,
                         "lhasa"                  => 8893,
                         "liable"                 => 4593,
                         "liaison"                => 4496,
                         "liaisons"               => 18463,
                         "liar"                   => 1053,
                         "liars"                  => 4660,
                         "libation"               => 17128,
                         "libbets"                => 10277,
                         "liberace"               => 10007,
                         "liberate"               => 9522,
                         "liberating"             => 8892,
                         "librarian"              => 4720,
                         "libris"                 => 17127,
                         "license"                => 1243,
                         "licious"                => 17126,
                         "licked"                 => 5621,
                         "lickety"                => 9760,
                         "lickin"                 => 16004,
                         "licks"                  => 8691,
                         "liddy"                  => 9759,
                         "lidocaine"              => 10276,
                         "lie"                    => 431,
                         "liebchen"               => 17125,
                         "liebkind"               => 13062,
                         "lied"                   => 699,
                         "liesl"                  => 17124,
                         "lifeblood"              => 18462,
                         "lifeguard"              => 8513,
                         "lifeguards"             => 18461,
                         "lifeless"               => 8690,
                         "lifelike"               => 11655,
                         "lifeline"               => 6226,
                         "lifer"                  => 16003,
                         "lifers"                 => 15092,
                         "lifesaver"              => 5967,
                         "lifesaving"             => 18460,
                         "lifestyles"             => 9758,
                         "lifetime"               => 1261,
                         "lifetimes"              => 8048,
                         "lift"                   => 1291,
                         "lifted"                 => 2830,
                         "lifting"                => 3839,
                         "liftoff"                => 13641,
                         "lifts"                  => 5574,
                         "ligature"               => 13640,
                         "lightbulb"              => 14300,
                         "lighten"                => 2417,
                         "lightened"              => 12580,
                         "lightening"             => 10901,
                         "lighters"               => 13061,
                         "lightheaded"            => 8512,
                         "lighthearted"           => 16002,
                         "lightly"                => 3838,
                         "lightness"              => 17123,
                         "ligourin"               => 18459,
                         "likable"                => 9521,
                         "like"                   => 34,
                         "liked"                  => 746,
                         "likeness"               => 7126,
                         "likes"                  => 725,
                         "likin"                  => 17122,
                         "liking"                 => 2696,
                         "lilac"                  => 12579,
                         "lilacs"                 => 13639,
                         "lilah"                  => 4936,
                         "lilies"                 => 7747,
                         "lilith"                 => 2854,
                         "lillienfield"           => 9520,
                         "limb"                   => 3008,
                         "limber"                 => 13638,
                         "limbo"                  => 4659,
                         "lime"                   => 4379,
                         "limelight"              => 10578,
                         "limericks"              => 14299,
                         "limes"                  => 13060,
                         "limey"                  => 12101,
                         "limitless"              => 13637,
                         "limo"                   => 1945,
                         "limos"                  => 8891,
                         "limousine"              => 4309,
                         "limousines"             => 13059,
                         "limp"                   => 4438,
                         "limping"                => 7605,
                         "limps"                  => 17121,
                         "lindenmeyer"            => 10577,
                         "linds"                  => 14298,
                         "linea"                  => 13058,
                         "lined"                  => 2876,
                         "linen"                  => 4255,
                         "linens"                 => 10576,
                         "lineswoman"             => 15091,
                         "linger"                 => 7746,
                         "lingerie"               => 3996,
                         "lingering"              => 6905,
                         "lingers"                => 12100,
                         "lingk"                  => 13636,
                         "lining"                 => 3140,
                         "linksynergy"            => 5044,
                         "linoleum"               => 13635,
                         "lipnik"                 => 7483,
                         "liposuction"            => 10275,
                         "lipped"                 => 12099,
                         "lippman"                => 7125,
                         "lippy"                  => 17120,
                         "lips"                   => 1112,
                         "lipstick"               => 2409,
                         "liquefy"                => 17119,
                         "liqueur"                => 18458,
                         "liquidate"              => 13634,
                         "liquor"                 => 2258,
                         "liquored"               => 12098,
                         "liquorice"              => 14297,
                         "lissen"                 => 16001,
                         "listen"                 => 137,
                         "listened"               => 1601,
                         "listener"               => 5113,
                         "listenin"               => 8689,
                         "listening"              => 708,
                         "listens"                => 3223,
                         "litany"                 => 13057,
                         "litback"                => 13056,
                         "literally"              => 1796,
                         "liters"                 => 9099,
                         "lithe"                  => 14296,
                         "litigator"              => 14295,
                         "litigious"              => 13633,
                         "litter"                 => 5288,
                         "litterbug"              => 14294,
                         "littered"               => 12578,
                         "littering"              => 11654,
                         "little"                 => 71,
                         "littlest"               => 11653,
                         "litvack"                => 8511,
                         "live"                   => 250,
                         "livelihood"             => 7124,
                         "liven"                  => 8890,
                         "liver"                  => 1890,
                         "livered"                => 18457,
                         "lives"                  => 397,
                         "livid"                  => 8889,
                         "livin"                  => 3883,
                         "livvie"                 => 814,
                         "lizardo"                => 12097,
                         "llanfair"               => 3754,
                         "llantano"               => 10006,
                         "llanview"               => 1558,
                         "load"                   => 1547,
                         "loaded"                 => 1867,
                         "loads"                  => 5112,
                         "loaf"                   => 4232,
                         "loafers"                => 8510,
                         "loaner"                 => 18456,
                         "loaning"                => 10900,
                         "loath"                  => 17118,
                         "loathe"                 => 5165,
                         "loathed"                => 16000,
                         "loathes"                => 11652,
                         "loathing"               => 8333,
                         "loathsome"              => 10005,
                         "lobbing"                => 18455,
                         "lobby"                  => 1875,
                         "lobotomy"               => 7123,
                         "lobsters"               => 7243,
                         "locate"                 => 2747,
                         "locating"               => 7604,
                         "locator"                => 13055,
                         "lock"                   => 946,
                         "locked"                 => 916,
                         "locker"                 => 1624,
                         "lockers"                => 6369,
                         "locket"                 => 4281,
                         "locking"                => 3701,
                         "locks"                  => 3118,
                         "locksmith"              => 8888,
                         "lockup"                 => 4719,
                         "locusts"                => 8047,
                         "lodged"                 => 6225,
                         "lodgers"                => 18454,
                         "loft"                   => 2401,
                         "lofts"                  => 18453,
                         "logged"                 => 6904,
                         "logical"                => 2535,
                         "logically"              => 6545,
                         "loincloth"              => 18452,
                         "loins"                  => 7922,
                         "loitering"              => 6903,
                         "lojack"                 => 17117,
                         "lollipops"              => 15090,
                         "lomez"                  => 17116,
                         "lompoc"                 => 14293,
                         "lone"                   => 3569,
                         "lonelier"               => 17115,
                         "loneliest"              => 17114,
                         "loneliness"             => 4123,
                         "lonely"                 => 1149,
                         "lonelyhearts"           => 15089,
                         "loner"                  => 5427,
                         "loners"                 => 15999,
                         "longed"                 => 9757,
                         "longer"                 => 557,
                         "longing"                => 4718,
                         "longs"                  => 11651,
                         "lonigan"                => 3251,
                         "lonnegan"               => 10004,
                         "loofah"                 => 15088,
                         "loogie"                 => 15998,
                         "look"                   => 53,
                         "looka"                  => 14292,
                         "looked"                 => 512,
                         "lookee"                 => 12577,
                         "lookie"                 => 8046,
                         "lookin"                 => 1620,
                         "looking"                => 188,
                         "lookit"                 => 4935,
                         "lookouts"               => 15997,
                         "looks"                  => 278,
                         "looky"                  => 5681,
                         "looming"                => 11650,
                         "loompa"                 => 11649,
                         "loonies"                => 18451,
                         "loons"                  => 15087,
                         "loony"                  => 3817,
                         "looong"                 => 18450,
                         "looove"                 => 15086,
                         "looped"                 => 13632,
                         "loophole"               => 6450,
                         "loopholes"              => 10899,
                         "loopy"                  => 9297,
                         "loora"                  => 18449,
                         "loose"                  => 1085,
                         "loosen"                 => 3234,
                         "loosened"               => 7921,
                         "loosening"              => 12576,
                         "loosing"                => 11648,
                         "lopped"                 => 17113,
                         "lopper"                 => 17112,
                         "lopsided"               => 13054,
                         "loran"                  => 12096,
                         "lorca"                  => 15996,
                         "lording"                => 15995,
                         "lordy"                  => 10575,
                         "lorelai"                => 1290,
                         "lorne"                  => 5111,
                         "lorre"                  => 18448,
                         "lorry"                  => 12575,
                         "lose"                   => 375,
                         "loses"                  => 2416,
                         "losin"                  => 6624,
                         "losing"                 => 741,
                         "loski"                  => 18447,
                         "lost"                   => 277,
                         "lot"                    => 143,
                         "lothario"               => 10274,
                         "lotion"                 => 4343,
                         "lotions"                => 14291,
                         "lots"                   => 939,
                         "lotsa"                  => 9296,
                         "lotta"                  => 3117,
                         "lotte"                  => 5536,
                         "lottery"                => 3941,
                         "lotto"                  => 11647,
                         "loud"                   => 1092,
                         "louder"                 => 2992,
                         "loudest"                => 11646,
                         "loudly"                 => 6296,
                         "loudmouth"              => 9756,
                         "lounge"                 => 2829,
                         "lounger"                => 18446,
                         "lounging"               => 10273,
                         "louse"                  => 7745,
                         "loused"                 => 18445,
                         "lousy"                  => 1238,
                         "lovable"                => 7603,
                         "lovebirds"              => 4535,
                         "loved"                  => 410,
                         "lovelier"               => 11257,
                         "lovelies"               => 12574,
                         "loveliest"              => 12095,
                         "loveliness"             => 14290,
                         "lovelorn"               => 13053,
                         "lovemaking"             => 6544,
                         "loves"                  => 474,
                         "loveseat"               => 18444,
                         "lovesick"               => 7242,
                         "lovey"                  => 7744,
                         "lovin"                  => 5329,
                         "loving"                 => 917,
                         "lovingly"               => 11645,
                         "lowers"                 => 10574,
                         "lowlife"                => 3632,
                         "lowlifes"               => 8887,
                         "lowly"                  => 6902,
                         "loyal"                  => 1730,
                         "loyalties"              => 6796,
                         "loyalty"                => 1850,
                         "lozenges"               => 13631,
                         "lubricant"              => 15085,
                         "lubricants"             => 17111,
                         "lubricated"             => 18443,
                         "lucci"                  => 15994,
                         "lucid"                  => 7920,
                         "lucite"                 => 17110,
                         "luck"                   => 481,
                         "lucked"                 => 5850,
                         "luckier"                => 9098,
                         "luckiest"               => 3981,
                         "luckily"                => 2853,
                         "lucks"                  => 18442,
                         "ludicrous"              => 4747,
                         "luego"                  => 18441,
                         "luggage"                => 2774,
                         "lugging"                => 10003,
                         "lugosi"                 => 7482,
                         "lujack"                 => 15084,
                         "lukewarm"               => 12094,
                         "lullabies"              => 14289,
                         "lullaby"                => 5535,
                         "lulled"                 => 18440,
                         "lumbar"                 => 7241,
                         "lumbering"              => 15993,
                         "lumberjack"             => 10898,
                         "lumberyard"             => 18439,
                         "lump"                   => 4083,
                         "lumpectomy"             => 15992,
                         "lumped"                 => 18438,
                         "lumps"                  => 7919,
                         "lunacy"                 => 9097,
                         "lunatic"                => 2269,
                         "lunatics"               => 7602,
                         "lunch"                  => 611,
                         "luncheon"               => 5043,
                         "lunches"                => 5287,
                         "lunching"               => 13630,
                         "lunchroom"              => 13629,
                         "lunchtime"              => 5966,
                         "lundegaard"             => 11644,
                         "lung"                   => 3354,
                         "lunge"                  => 11256,
                         "lunged"                 => 12573,
                         "lunges"                 => 18437,
                         "lungs"                  => 2462,
                         "lupus"                  => 7240,
                         "lurch"                  => 8185,
                         "lurconis"               => 15083,
                         "lure"                   => 3459,
                         "lured"                  => 4970,
                         "lureen"                 => 18436,
                         "lurid"                  => 10002,
                         "luring"                 => 8688,
                         "lurking"                => 3940,
                         "lurks"                  => 13052,
                         "lusting"                => 10897,
                         "lustrous"               => 18435,
                         "lusts"                  => 17109,
                         "lutze"                  => 12572,
                         "luxuries"               => 10272,
                         "luzhin"                 => 10896,
                         "lycra"                  => 13628,
                         "lydecker"               => 4437,
                         "lydell"                 => 13627,
                         "lydells"                => 17108,
                         "lying"                  => 476,
                         "lymph"                  => 11255,
                         "lymphoma"               => 10573,
                         "lynched"                => 15082,
                         "lynley"                 => 15081,
                         "lysistrata"             => 9519,
                         "lysol"                  => 13051,
                         "m'appelle"              => 18434,
                         "m'boy"                  => 18433,
                         "m'hidi"                 => 14288,
                         "m'honey"                => 11254,
                         "m'kay"                  => 4122,
                         "m'lady"                 => 9295,
                         "m'lord"                 => 11253,
                         "m'self"                 => 17107,
                         "ma'am"                  => 797,
                         "macadamia"              => 13050,
                         "macado"                 => 18432,
                         "macanaw"                => 17106,
                         "macaroons"              => 13626,
                         "macaws"                 => 17105,
                         "macchiato"              => 17104,
                         "macdougal"              => 17103,
                         "mache"                  => 18346,
                         "machete"                => 8184,
                         "machiavelli"            => 15080,
                         "machiavellian"          => 17102,
                         "machida"                => 14287,
                         "machinations"           => 13049,
                         "machismo"               => 15991,
                         "macho"                  => 3379,
                         "machu"                  => 18431,
                         "macinerney"             => 13048,
                         "maciver"                => 2349,
                         "mackerel"               => 10001,
                         "macking"                => 17101,
                         "maclaine"               => 8332,
                         "maclaren"               => 7353,
                         "macnamara"              => 13047,
                         "macready"               => 8045,
                         "macreedy"               => 7601,
                         "mad"                    => 513,
                         "madam"                  => 1976,
                         "madame"                 => 2818,
                         "maddening"              => 12571,
                         "madder"                 => 8044,
                         "mademoiselle"           => 5965,
                         "madly"                  => 3551,
                         "madmen"                 => 13625,
                         "madox"                  => 14286,
                         "madre"                  => 8886,
                         "madrona"                => 14285,
                         "madwoman"               => 15079,
                         "maeby"                  => 7481,
                         "maelstrom"              => 18430,
                         "magev"                  => 18429,
                         "maggots"                => 8331,
                         "magical"                => 1892,
                         "magically"              => 4534,
                         "magicians"              => 8509,
                         "magicks"                => 8330,
                         "magilla"                => 10572,
                         "magnanimous"            => 9755,
                         "magnetism"              => 11252,
                         "magnets"                => 10271,
                         "magnificence"           => 12570,
                         "magnificent"            => 2817,
                         "magnificently"          => 17100,
                         "magnified"              => 18428,
                         "magnifique"             => 14284,
                         "magnify"                => 13046,
                         "magnifying"             => 10000,
                         "magnolias"              => 18427,
                         "magnon"                 => 17099,
                         "magua"                  => 9096,
                         "mahandra"               => 18426,
                         "maharajah"              => 12093,
                         "mahogany"               => 9518,
                         "maid"                   => 1470,
                         "maids"                  => 5382,
                         "mail"                   => 874,
                         "mailbox"                => 4533,
                         "mailboxes"              => 11251,
                         "mailed"                 => 4378,
                         "mailer"                 => 8885,
                         "mailing"                => 5897,
                         "mailmen"                => 18425,
                         "mailroom"               => 8687,
                         "mails"                  => 4462,
                         "maimed"                 => 11250,
                         "maiming"                => 15990,
                         "mainframe"              => 8329,
                         "mainsail"               => 18424,
                         "maitre"                 => 7918,
                         "majesties"              => 18423,
                         "majesty"                => 2218,
                         "majorek"                => 17098,
                         "majorly"                => 9999,
                         "make"                   => 72,
                         "makeover"               => 5042,
                         "makeovers"              => 15989,
                         "makes"                  => 292,
                         "maketh"                 => 15988,
                         "makin"                  => 2741,
                         "making"                 => 271,
                         "makings"                => 11643,
                         "malahide"               => 15987,
                         "malaise"                => 18422,
                         "malakai"                => 10895,
                         "malarkey"               => 14283,
                         "malcontent"             => 18421,
                         "malevolent"             => 13624,
                         "malfeasance"            => 15986,
                         "malfunction"            => 6706,
                         "malfunctioned"          => 9754,
                         "malfunctioning"         => 13045,
                         "malfunctions"           => 15078,
                         "malicious"              => 5896,
                         "maliciously"            => 15985,
                         "malign"                 => 17097,
                         "malignant"              => 8328,
                         "malkovich"              => 3084,
                         "mall"                   => 1591,
                         "mallomars"              => 18420,
                         "malnourished"           => 17096,
                         "malpractice"            => 6901,
                         "maltin"                 => 15984,
                         "malucci"                => 10571,
                         "mama"                   => 697,
                         "mami"                   => 2801,
                         "mamma"                  => 5200,
                         "mammogram"              => 9294,
                         "man"                    => 88,
                         "man'll"                 => 15983,
                         "manage"                 => 1367,
                         "manageable"             => 9753,
                         "manatees"               => 15982,
                         "mandelbaum"             => 9752,
                         "manderley"              => 8043,
                         "maneuver"               => 5164,
                         "maneuvered"             => 12569,
                         "maneuvering"            => 8686,
                         "manger"                 => 8508,
                         "mangled"                => 9095,
                         "mangy"                  => 7600,
                         "manhandle"              => 15077,
                         "manhandled"             => 15981,
                         "manhandling"            => 18419,
                         "manhole"                => 15076,
                         "manhood"                => 5849,
                         "manhunt"                => 8507,
                         "maniacal"               => 12568,
                         "maniacs"                => 7743,
                         "manic"                  => 6147,
                         "manicure"               => 5381,
                         "manicured"              => 17095,
                         "manicures"              => 13623,
                         "manicurist"             => 9751,
                         "manifest"               => 4934,
                         "manifesting"            => 12092,
                         "manilow"                => 9293,
                         "manipulate"             => 2935,
                         "manipulated"            => 3197,
                         "manipulates"            => 11249,
                         "manipulating"           => 3753,
                         "manipulation"           => 4969,
                         "manipulations"          => 8506,
                         "manipulative"           => 3405,
                         "manipulator"            => 6705,
                         "manly"                  => 3533,
                         "mannequin"              => 8042,
                         "mannequins"             => 15075,
                         "mannered"               => 7014,
                         "manners"                => 2209,
                         "manny"                  => 3063,
                         "manpower"               => 6543,
                         "manray"                 => 9998,
                         "manse"                  => 18418,
                         "manservant"             => 18417,
                         "mansiere"               => 18416,
                         "mansion"                => 1541,
                         "manslaughter"           => 4377,
                         "mantan"                 => 5110,
                         "mantel"                 => 8685,
                         "manticore"              => 2582,
                         "mantini"                => 8884,
                         "mantumbi"               => 14282,
                         "manure"                 => 5799,
                         "manya"                  => 14281,
                         "manzelle"               => 15074,
                         "maplewood"              => 15073,
                         "mapuhe"                 => 13044,
                         "marah"                  => 1061,
                         "marbury"                => 7352,
                         "marce"                  => 8505,
                         "marchin"                => 17094,
                         "mardi"                  => 11642,
                         "margaritas"             => 6542,
                         "margate"                => 8504,
                         "marginally"             => 13043,
                         "margueritas"            => 12091,
                         "marick"                 => 15980,
                         "marijawana"             => 14280,
                         "marinara"               => 9997,
                         "marinate"               => 17093,
                         "maris"                  => 1483,
                         "marital"                => 3939,
                         "marivellas"             => 8041,
                         "marketable"             => 18415,
                         "markinson"              => 8040,
                         "marklar"                => 6224,
                         "marklars"               => 12090,
                         "markles"                => 18414,
                         "markovic"               => 10894,
                         "markovski"              => 12567,
                         "marksmanship"           => 17092,
                         "markstrom"              => 12089,
                         "marlboros"              => 17091,
                         "marlee"                 => 12566,
                         "marliston"              => 14279,
                         "marmaduke"              => 15979,
                         "marmalade"              => 11641,
                         "marone"                 => 3308,
                         "marooned"               => 15978,
                         "marriage"               => 456,
                         "marriages"              => 3501,
                         "marries"                => 4532,
                         "marrow"                 => 2875,
                         "marry"                  => 503,
                         "marrying"               => 1127,
                         "marseilles"             => 6449,
                         "marsellus"              => 7239,
                         "marshack"               => 18413,
                         "marshals"               => 9292,
                         "marshmallow"            => 7351,
                         "marshmallows"           => 5680,
                         "mart"                   => 4209,
                         "martialed"              => 17090,
                         "martians"               => 9996,
                         "martimmy"               => 7122,
                         "martimmys"              => 6795,
                         "martinis"               => 4658,
                         "martouf"                => 9995,
                         "martyr"                 => 4998,
                         "marveling"              => 15977,
                         "marvellous"             => 7742,
                         "marvelous"              => 2848,
                         "marys"                  => 10570,
                         "marzipan"               => 15072,
                         "masai"                  => 15071,
                         "masbath"                => 11248,
                         "mascara"                => 5488,
                         "mash"                   => 4556,
                         "mashed"                 => 4623,
                         "mask"                   => 2046,
                         "masked"                 => 5895,
                         "masking"                => 10270,
                         "masks"                  => 3735,
                         "masochist"              => 9994,
                         "masochistic"            => 14278,
                         "masquerade"             => 7599,
                         "masquerading"           => 7741,
                         "masry"                  => 10893,
                         "massage"                => 2100,
                         "massaged"               => 11640,
                         "massager"               => 15976,
                         "massages"               => 6623,
                         "massaging"              => 10269,
                         "masselin"               => 17089,
                         "masseur"                => 12088,
                         "masseuse"               => 8883,
                         "massimo"                => 1664,
                         "mastectomy"             => 15975,
                         "masterful"              => 14277,
                         "masterminded"           => 13042,
                         "masterpiece"            => 4657,
                         "masturbate"             => 9517,
                         "masturbated"            => 17088,
                         "masturbating"           => 11247,
                         "matata"                 => 10569,
                         "matchbook"              => 10568,
                         "matching"               => 3188,
                         "matchmaker"             => 7480,
                         "matchmaking"            => 10892,
                         "mate"                   => 1466,
                         "mateo"                  => 1340,
                         "materialistic"          => 13041,
                         "materialize"            => 13040,
                         "maternity"              => 5163,
                         "mates"                  => 3272,
                         "matey"                  => 13622,
                         "mateys"                 => 18412,
                         "math"                   => 1600,
                         "mathesar"               => 10567,
                         "matick"                 => 15070,
                         "matinee"                => 8503,
                         "mating"                 => 5109,
                         "matriarch"              => 17087,
                         "matrimonial"            => 15069,
                         "matrimony"              => 4461,
                         "matron"                 => 6368,
                         "matted"                 => 15974,
                         "matter"                 => 214,
                         "mattered"               => 3250,
                         "matters"                => 837,
                         "mattress"               => 2828,
                         "mattresses"             => 10566,
                         "matuka"                 => 7917,
                         "matured"                => 7740,
                         "matzah"                 => 17086,
                         "matzoh"                 => 15973,
                         "maui"                   => 4856,
                         "mauled"                 => 11639,
                         "mausoleum"              => 5620,
                         "mauve"                  => 18411,
                         "maxed"                  => 9094,
                         "maximillian"            => 12565,
                         "may've"                 => 18410,
                         "mayakovsky"             => 12564,
                         "mayan"                  => 9093,
                         "maybe"                  => 86,
                         "maybes"                 => 10891,
                         "maybourne"              => 7121,
                         "mayflower"              => 7598,
                         "mayflowers"             => 15068,
                         "mayol"                  => 11638,
                         "mayonnaise"             => 6622,
                         "maypole"                => 18409,
                         "mazel"                  => 9516,
                         "mbien"                  => 17085,
                         "mbwun"                  => 13039,
                         "mcarnold"               => 15972,
                         "mcats"                  => 17084,
                         "mcbeal"                 => 8502,
                         "mccarthyism"            => 18408,
                         "mcclane"                => 7916,
                         "mccovey"                => 14276,
                         "mcdunnough"             => 17083,
                         "mcgewan"                => 17082,
                         "mcgillicuddy"           => 15067,
                         "mcgruff"                => 15971,
                         "mckechnie"              => 5328,
                         "mckinnons"              => 17081,
                         "mcmurphy"               => 5162,
                         "mcnuggets"              => 18407,
                         "me"                     => 6,
                         "meager"                 => 10890,
                         "meal"                   => 1323,
                         "meals"                  => 3052,
                         "mean"                   => 58,
                         "meaner"                 => 8684,
                         "meanest"                => 8501,
                         "meanie"                 => 12087,
                         "meaningful"             => 3615,
                         "meaningless"            => 3170,
                         "meaninglessness"        => 18406,
                         "meanness"               => 15970,
                         "means"                  => 294,
                         "meant"                  => 425,
                         "meantime"               => 1356,
                         "measles"                => 8683,
                         "measly"                 => 6146,
                         "meat"                   => 1212,
                         "meatballs"              => 8183,
                         "meats"                  => 9092,
                         "meaty"                  => 13038,
                         "mebbe"                  => 10889,
                         "mecha"                  => 8039,
                         "meddle"                 => 7120,
                         "meddled"                => 17080,
                         "meddlesome"             => 13621,
                         "meddling"               => 4933,
                         "medevac"                => 13620,
                         "medically"              => 6295,
                         "medicate"               => 17079,
                         "medicated"              => 9291,
                         "medicating"             => 12086,
                         "medication"             => 1573,
                         "medications"            => 6541,
                         "medics"                 => 10565,
                         "mediocre"               => 5964,
                         "mediocrity"             => 8182,
                         "meditating"             => 12563,
                         "medivac"                => 18405,
                         "meds"                   => 3752,
                         "medulla"                => 18404,
                         "meecrob"                => 17078,
                         "meeee"                  => 18403,
                         "meems"                  => 5161,
                         "meeny"                  => 12085,
                         "meet"                   => 272,
                         "meetin"                 => 8882,
                         "meeting"                => 432,
                         "megalomaniac"           => 18402,
                         "megaphone"              => 12084,
                         "megara"                 => 18401,
                         "megaton"                => 18400,
                         "melancholy"             => 8682,
                         "melding"                => 15969,
                         "melissande"             => 11246,
                         "mellowed"               => 11637,
                         "mellowing"              => 13619,
                         "melodrama"              => 8681,
                         "melodramatic"           => 5798,
                         "melt"                   => 2918,
                         "meltdown"               => 3967,
                         "melted"                 => 4622,
                         "melting"                => 4495,
                         "melts"                  => 7479,
                         "mementos"               => 11636,
                         "memma"                  => 18399,
                         "memo"                   => 2977,
                         "memories"               => 1047,
                         "memorize"               => 4777,
                         "memorized"              => 5071,
                         "memorizing"             => 10268,
                         "memory"                 => 790,
                         "memos"                  => 8680,
                         "men'll"                 => 18398,
                         "menacing"               => 10267,
                         "menage"                 => 13618,
                         "menagerie"              => 15066,
                         "mend"                   => 4043,
                         "mended"                 => 11245,
                         "mending"                => 12083,
                         "mendola"                => 11244,
                         "menelaus"               => 9515,
                         "mengele"                => 15968,
                         "menial"                 => 9091,
                         "meningitis"             => 6367,
                         "mennihan"               => 6794,
                         "menopausal"             => 15065,
                         "menopause"              => 6793,
                         "menorah"                => 15967,
                         "mensa"                  => 13037,
                         "menstrual"              => 13617,
                         "mental"                 => 1504,
                         "mentality"              => 7238,
                         "mentally"               => 3307,
                         "mention"                => 652,
                         "mentioning"             => 4042,
                         "menu"                   => 2127,
                         "menus"                  => 5534,
                         "meow"                   => 3429,
                         "mephesto"               => 9290,
                         "mercenary"              => 7237,
                         "merchandise"            => 3816,
                         "merci"                  => 5255,
                         "merciful"               => 5723,
                         "merciless"              => 9514,
                         "mercilessly"            => 12562,
                         "merde"                  => 9993,
                         "mere"                   => 3249,
                         "merely"                 => 2099,
                         "meringue"               => 12561,
                         "merits"                 => 5797,
                         "merman"                 => 13036,
                         "merrier"                => 5848,
                         "merrily"                => 7739,
                         "mershaw"                => 17077,
                         "mertin"                 => 8679,
                         "mescal"                 => 18397,
                         "mescaline"              => 13616,
                         "mesdames"               => 18396,
                         "meself"                 => 9513,
                         "mesmerized"             => 13035,
                         "mesmerizing"            => 17076,
                         "mess"                   => 639,
                         "message"                => 583,
                         "messages"               => 1363,
                         "messed"                 => 1274,
                         "messengered"            => 9992,
                         "messes"                 => 3966,
                         "messieur"               => 15064,
                         "messin"                 => 8038,
                         "messing"                => 1714,
                         "messy"                  => 2674,
                         "met"                    => 401,
                         "metamorphosis"          => 10564,
                         "metaphor"               => 3965,
                         "metaphorically"         => 8678,
                         "metaphors"              => 8327,
                         "meteor"                 => 4015,
                         "meteors"                => 15966,
                         "methadone"              => 15063,
                         "methinks"               => 9991,
                         "methodical"             => 10888,
                         "methuselah"             => 18395,
                         "meticulous"             => 8181,
                         "metricconverter"        => 15965,
                         "mettle"                 => 15964,
                         "metzenbaum"             => 14275,
                         "meurice"                => 7478,
                         "mexicans"               => 7477,
                         "meyerling"              => 17075,
                         "michalchuk"             => 13034,
                         "microbe"                => 18394,
                         "microchip"              => 9512,
                         "microchips"             => 17074,
                         "microfilm"              => 11243,
                         "microscope"             => 5254,
                         "microwave"              => 3669,
                         "microwaves"             => 14274,
                         "middies"                => 12560,
                         "middleman"              => 11635,
                         "mideast"                => 18393,
                         "midge"                  => 5679,
                         "midgets"                => 6223,
                         "midler"                 => 9750,
                         "midlife"                => 10266,
                         "midriff"                => 18392,
                         "midst"                  => 4592,
                         "midstream"              => 18391,
                         "midterm"                => 5796,
                         "midterms"               => 7350,
                         "midwife"                => 7915,
                         "mieke"                  => 9289,
                         "mierzwiak"              => 17073,
                         "miffed"                 => 15062,
                         "miggs"                  => 15061,
                         "might"                  => 173,
                         "might've"               => 2292,
                         "mighta"                 => 11634,
                         "mightier"               => 17072,
                         "mightily"               => 18390,
                         "mightn't"               => 17071,
                         "migraine"               => 5573,
                         "migraines"              => 9749,
                         "miguelito"              => 18389,
                         "mija"                   => 4376,
                         "mijo"                   => 2766,
                         "mikkos"                 => 10887,
                         "milady"                 => 9288,
                         "mildew"                 => 11633,
                         "mildly"                 => 4591,
                         "mileage"                => 6621,
                         "milk"                   => 1196,
                         "milked"                 => 17070,
                         "milking"                => 8180,
                         "milkshake"              => 9090,
                         "milkshakes"             => 10563,
                         "milky"                  => 8037,
                         "millander"              => 13615,
                         "millaney"               => 14273,
                         "millgate"               => 15963,
                         "milligram"              => 10562,
                         "milligrams"             => 5678,
                         "millimeter"             => 5847,
                         "millionaire"            => 4436,
                         "millionaires"           => 7597,
                         "millions"               => 1633,
                         "millionth"              => 9748,
                         "millisecond"            => 17069,
                         "milltown"               => 8179,
                         "milos"                  => 9511,
                         "milquetoast"            => 18388,
                         "mimes"                  => 17068,
                         "mimosas"                => 13614,
                         "mince"                  => 11632,
                         "minced"                 => 18387,
                         "mincemeat"              => 15060,
                         "mind"                   => 174,
                         "minded"                 => 2628,
                         "mindee"                 => 17067,
                         "mindful"                => 13613,
                         "minding"                => 4254,
                         "mindless"               => 5533,
                         "mindlock"               => 12082,
                         "minds"                  => 1555,
                         "mindset"                => 13033,
                         "mindwarped"             => 18386,
                         "mine"                   => 337,
                         "minefield"              => 8326,
                         "mineshaft"              => 14272,
                         "miney"                  => 10265,
                         "mingle"                 => 4887,
                         "mingling"               => 9990,
                         "minibar"                => 11242,
                         "minimums"               => 11631,
                         "minions"                => 5722,
                         "miniscule"              => 15962,
                         "miniskirt"              => 18385,
                         "minivan"                => 10561,
                         "minnifield"             => 10886,
                         "mint"                   => 2966,
                         "mints"                  => 5108,
                         "minus"                  => 2612,
                         "minuses"                => 17066,
                         "minute"                 => 209,
                         "minutemen"              => 9510,
                         "minutes"                => 314,
                         "miracle"                => 1097,
                         "miracles"               => 2336,
                         "miraculous"             => 4717,
                         "miraculously"           => 6540,
                         "miramax"                => 10560,
                         "mirror"                 => 1380,
                         "mirrors"                => 3700,
                         "mirth"                  => 13612,
                         "misbehave"              => 10559,
                         "miscalculated"          => 11630,
                         "miscalculation"         => 12559,
                         "miscarriage"            => 4776,
                         "miscarriages"           => 18384,
                         "miscarried"             => 9747,
                         "miscarry"               => 17065,
                         "mischievous"            => 14271,
                         "miscommunication"       => 10264,
                         "misconception"          => 10885,
                         "misconceptions"         => 15961,
                         "misconstrued"           => 11629,
                         "miscreant"              => 15960,
                         "misdeeds"               => 15059,
                         "misdemeanor"            => 9746,
                         "misdemeanors"           => 12558,
                         "misdirected"            => 18383,
                         "misdirection"           => 14270,
                         "miserable"              => 1171,
                         "miserably"              => 6539,
                         "misery"                 => 1872,
                         "misfortune"             => 6538,
                         "misfortunes"            => 14269,
                         "misgivings"             => 13032,
                         "misguided"              => 4590,
                         "mishandled"             => 15959,
                         "mishap"                 => 8178,
                         "misheard"               => 15958,
                         "mishke"                 => 14268,
                         "misinformation"         => 18382,
                         "misinformed"            => 10884,
                         "misinterpret"           => 11241,
                         "misinterpretation"      => 17064,
                         "misinterpreted"         => 7236,
                         "misinterpreting"        => 12081,
                         "misjudge"               => 18381,
                         "misjudged"              => 4775,
                         "mislead"                => 8177,
                         "misled"                 => 8176,
                         "mismatched"             => 13611,
                         "misnomer"               => 15957,
                         "misogynistic"           => 12080,
                         "misplace"               => 10263,
                         "misplaced"              => 3815,
                         "misprint"               => 13610,
                         "misread"                => 7013,
                         "misreading"             => 10558,
                         "misrell"                => 15956,
                         "misrepresented"         => 14267,
                         "miss"                   => 270,
                         "missed"                 => 556,
                         "misses"                 => 2346,
                         "missin"                 => 8677,
                         "missing"                => 584,
                         "missis"                 => 15058,
                         "misspelled"             => 11628,
                         "misspent"               => 17063,
                         "misspoke"               => 11627,
                         "misstep"                => 18380,
                         "missus"                 => 5795,
                         "mistah"                 => 14266,
                         "mistake"                => 449,
                         "mistaken"               => 2060,
                         "mistakes"               => 1037,
                         "mistaking"              => 9509,
                         "mistletoe"              => 4932,
                         "mistook"                => 7119,
                         "mistreated"             => 10557,
                         "mistreating"            => 18379,
                         "mistresses"             => 17062,
                         "mistrial"               => 6448,
                         "mistrust"               => 8881,
                         "mistuh"                 => 15057,
                         "misunderstand"          => 4308,
                         "misunderstanding"       => 1999,
                         "misunderstandings"      => 6704,
                         "misunderstood"          => 2481,
                         "mitigating"             => 14265,
                         "mitosis"                => 9745,
                         "mitzvah"                => 5677,
                         "mitzvahs"               => 18378,
                         "mixer"                  => 8500,
                         "mixers"                 => 15955,
                         "mixup"                  => 13031,
                         "mmhmm"                  => 6222,
                         "mmkay"                  => 15056,
                         "mmm"                    => 656,
                         "mmmm"                   => 2734,
                         "mmmmm"                  => 5894,
                         "mmmmmm"                 => 9089,
                         "mmmmmmm"                => 18377,
                         "mo'ss"                  => 15954,
                         "moaning"                => 5619,
                         "moans"                  => 13609,
                         "mobbed"                 => 14264,
                         "mobilize"               => 9088,
                         "mobilizing"             => 18376,
                         "mobster"                => 6294,
                         "mobsters"               => 9989,
                         "mocarbies"              => 15953,
                         "mocha"                  => 5107,
                         "mocked"                 => 7349,
                         "mockery"                => 6293,
                         "mocking"                => 4307,
                         "mockingbird"            => 9988,
                         "mockolate"              => 12557,
                         "mocks"                  => 17061,
                         "mockup"                 => 18375,
                         "mocky"                  => 15055,
                         "modeling"               => 2976,
                         "moderation"             => 10883,
                         "modesty"                => 7914,
                         "modicum"                => 12556,
                         "modus"                  => 12555,
                         "mofet"                  => 18374,
                         "mogul"                  => 9744,
                         "mohair"                 => 15054,
                         "mohel"                  => 10556,
                         "mohicans"               => 17060,
                         "mohra"                  => 12554,
                         "moisturiser"            => 17059,
                         "moisturize"             => 15053,
                         "moisturizer"            => 10882,
                         "moland"                 => 18373,
                         "molars"                 => 13608,
                         "molasses"               => 10262,
                         "mold"                   => 4170,
                         "moldings"               => 15952,
                         "moldy"                  => 11240,
                         "mole"                   => 3428,
                         "molehill"               => 18372,
                         "molest"                 => 12553,
                         "molestation"            => 13607,
                         "molested"               => 7012,
                         "molester"               => 13606,
                         "molestered"             => 15951,
                         "molesting"              => 11626,
                         "moley"                  => 15052,
                         "mollem"                 => 17058,
                         "moloch"                 => 12552,
                         "molto"                  => 13030,
                         "mom"                    => 154,
                         "mom'll"                 => 13029,
                         "moment"                 => 363,
                         "momentarily"            => 5572,
                         "momentary"              => 6703,
                         "momento"                => 10881,
                         "momentous"              => 9508,
                         "moments"                => 1395,
                         "momma"                  => 3427,
                         "mommies"                => 7011,
                         "mommy"                  => 687,
                         "moms"                   => 3500,
                         "moncho"                 => 17057,
                         "mondesi"                => 12079,
                         "moneybags"              => 13028,
                         "mongers"                => 14263,
                         "mongi"                  => 15051,
                         "mongolians"             => 11239,
                         "mongoloid"              => 15950,
                         "mongorians"             => 13027,
                         "mongrel"                => 8676,
                         "monitors"               => 4435,
                         "monocle"                => 18371,
                         "monogamous"             => 12078,
                         "monogamy"               => 13605,
                         "monogrammed"            => 11625,
                         "monologue"              => 8880,
                         "monopolize"             => 18370,
                         "monopolizing"           => 10555,
                         "monotonous"             => 18369,
                         "monsieur"               => 2948,
                         "monsters"               => 2502,
                         "monstrosity"            => 9287,
                         "monstrous"              => 6900,
                         "montega"                => 3233,
                         "montel"                 => 15949,
                         "monumentally"           => 12077,
                         "mooch"                  => 12551,
                         "moocher"                => 15050,
                         "mooching"               => 18368,
                         "moochy"                 => 18367,
                         "mood"                   => 927,
                         "moodoo"                 => 17056,
                         "moods"                  => 5286,
                         "moola"                  => 15948,
                         "moonbeams"              => 13604,
                         "mooning"                => 9507,
                         "moonlighting"           => 9087,
                         "moonlit"                => 8325,
                         "moons"                  => 7235,
                         "moops"                  => 9086,
                         "moors"                  => 6702,
                         "mooseport"              => 8879,
                         "moped"                  => 12076,
                         "mopes"                  => 10261,
                         "mopey"                  => 11238,
                         "moping"                 => 5618,
                         "mopped"                 => 17055,
                         "mopping"                => 8675,
                         "moral"                  => 1895,
                         "moralistic"             => 18366,
                         "morality"               => 4688,
                         "morally"                => 4997,
                         "morals"                 => 4231,
                         "moratorium"             => 9987,
                         "morbid"                 => 5199,
                         "more'n"                 => 6221,
                         "mores"                  => 14262,
                         "morgendorffer"          => 4142,
                         "morgendorffers"         => 15947,
                         "morgue"                 => 2884,
                         "morgues"                => 13603,
                         "morlin"                 => 13026,
                         "morlocks"               => 12550,
                         "mornin"                 => 3773,
                         "morning"                => 244,
                         "mornings"               => 4555,
                         "moron"                  => 2183,
                         "moronic"                => 7913,
                         "morons"                 => 4656,
                         "morose"                 => 9986,
                         "morph"                  => 12549,
                         "morphate"               => 18365,
                         "morphed"                => 17054,
                         "morphine"               => 4342,
                         "morphing"               => 18364,
                         "morrie"                 => 10554,
                         "morsel"                 => 12548,
                         "mortal"                 => 1791,
                         "mortals"                => 3631,
                         "mortem"                 => 10260,
                         "mortgaged"              => 14261,
                         "mortician"              => 9985,
                         "mortified"              => 8036,
                         "mortifying"             => 15946,
                         "mortmain"               => 14260,
                         "mortuary"               => 7912,
                         "morty"                  => 5253,
                         "morvern"                => 10259,
                         "mosey"                  => 11237,
                         "mosquito"               => 5846,
                         "mosquitoes"             => 8035,
                         "mosquitos"              => 17053,
                         "mostro"                 => 18363,
                         "motaba"                 => 15049,
                         "motel"                  => 1705,
                         "motels"                 => 8674,
                         "mothafucka"             => 14259,
                         "mothballs"              => 11624,
                         "motherf"                => 18362,
                         "motherfucker"           => 2064,
                         "motherfuckers"          => 4886,
                         "motherfuckin"           => 10553,
                         "motherfucking"          => 6145,
                         "motherhood"             => 5571,
                         "mothering"              => 11623,
                         "motherless"             => 17052,
                         "motherly"               => 9506,
                         "mothers"                => 2161,
                         "mothership"             => 12075,
                         "motility"               => 14258,
                         "motions"                => 5285,
                         "motivate"               => 7234,
                         "motivated"              => 3668,
                         "motivates"              => 15048,
                         "motivation"             => 4141,
                         "motivator"              => 14257,
                         "motive"                 => 1858,
                         "motives"                => 3222,
                         "motorcade"              => 7738,
                         "motorcycle"             => 2224,
                         "motzah"                 => 12547,
                         "mountaineer"            => 10552,
                         "mountainside"           => 17051,
                         "mountaintop"            => 13025,
                         "mountie"                => 3221,
                         "mounties"               => 7233,
                         "mourn"                  => 4621,
                         "mourned"                => 11236,
                         "mournful"               => 18361,
                         "mourning"               => 3532,
                         "mourns"                 => 18360,
                         "mousetrap"              => 18359,
                         "mouseville"             => 15945,
                         "mousse"                 => 6701,
                         "moustache"              => 5380,
                         "mousy"                  => 11235,
                         "mouth"                  => 589,
                         "mouthed"                => 6899,
                         "mouthful"               => 8878,
                         "mouthing"               => 7118,
                         "mouthpiece"             => 8673,
                         "mouths"                 => 3458,
                         "mouthwash"              => 12546,
                         "mouthy"                 => 15047,
                         "move"                   => 264,
                         "mover"                  => 9984,
                         "movers"                 => 5794,
                         "moves"                  => 1393,
                         "movie"                  => 533,
                         "movies"                 => 967,
                         "movin"                  => 3964,
                         "moving"                 => 544,
                         "mowed"                  => 10258,
                         "mowing"                 => 8877,
                         "moxica"                 => 14256,
                         "mozzarella"             => 14255,
                         "mrs"                    => 320,
                         "much"                   => 94,
                         "muchacho"               => 12545,
                         "muchachos"              => 17050,
                         "muchas"                 => 13024,
                         "mucho"                  => 6898,
                         "mucking"                => 9743,
                         "muckraker"              => 17049,
                         "muckraking"             => 18358,
                         "mucous"                 => 13023,
                         "mucus"                  => 11622,
                         "mudda"                  => 14254,
                         "muddle"                 => 12074,
                         "muddy"                  => 5252,
                         "mudslinging"            => 18357,
                         "muerto"                 => 17048,
                         "muffet"                 => 15046,
                         "muffins"                => 3281,
                         "muffled"                => 13602,
                         "muffler"                => 11234,
                         "mugged"                 => 4253,
                         "mugger"                 => 7737,
                         "muggers"                => 11233,
                         "mugging"                => 6537,
                         "muggings"               => 15045,
                         "muggy"                  => 17047,
                         "mujeeb"                 => 18356,
                         "mukada"                 => 13601,
                         "mulan"                  => 7117,
                         "mule"                   => 4620,
                         "muley"                  => 15944,
                         "mulled"                 => 17046,
                         "mulling"                => 13600,
                         "mulroney"               => 13022,
                         "multimillion"           => 13021,
                         "multiply"               => 5487,
                         "multitasking"           => 18355,
                         "mulva"                  => 13599,
                         "mulvehill"              => 15044,
                         "mulwray"                => 4968,
                         "mumble"                 => 10257,
                         "mumbled"                => 15043,
                         "mumbling"               => 8876,
                         "mumbo"                  => 5963,
                         "mummies"                => 10256,
                         "mummified"              => 14253,
                         "mummy"                  => 2965,
                         "mumps"                  => 12073,
                         "mumsy"                  => 15943,
                         "munchies"               => 9742,
                         "munching"               => 15942,
                         "munchkins"              => 13020,
                         "mundane"                => 10255,
                         "mural"                  => 4774,
                         "murchy"                 => 18354,
                         "murder"                 => 548,
                         "murdered"               => 1224,
                         "murderer"               => 1645,
                         "murderers"              => 4014,
                         "murderess"              => 15941,
                         "murdering"              => 3734,
                         "murderous"              => 6620,
                         "murders"                => 2681,
                         "murky"                  => 12544,
                         "murmur"                 => 13598,
                         "murtaugh"               => 15940,
                         "muscled"                => 13597,
                         "muses"                  => 10880,
                         "mushrooms"              => 4967,
                         "mushu"                  => 11621,
                         "mushy"                  => 5793,
                         "musing"                 => 17045,
                         "musket"                 => 8875,
                         "musketeer"              => 15939,
                         "musketeers"             => 7736,
                         "musn't"                 => 18353,
                         "must"                   => 186,
                         "must've"                => 1132,
                         "musta"                  => 4306,
                         "mustache"               => 4855,
                         "mustafi"                => 15938,
                         "muster"                 => 6366,
                         "mustn't"                => 2902,
                         "musty"                  => 9505,
                         "mutants"                => 6536,
                         "mutate"                 => 18352,
                         "mutated"                => 8874,
                         "mutates"                => 18351,
                         "mutating"               => 17044,
                         "mutator"                => 15937,
                         "muted"                  => 14252,
                         "mutha"                  => 18350,
                         "mutherfucker"           => 18349,
                         "mutilate"               => 13596,
                         "mutilated"              => 7596,
                         "mutilating"             => 18348,
                         "mutilation"             => 10254,
                         "muttering"              => 9741,
                         "mutual"                 => 2280,
                         "muumuu"                 => 15042,
                         "muzak"                  => 15041,
                         "my"                     => 13,
                         "mycenae"                => 15040,
                         "myhnegon"               => 17043,
                         "mykonos"                => 18347,
                         "mylie"                  => 10879,
                         "myself"                 => 215,
                         "myslexia"               => 15936,
                         "mysteries"              => 4460,
                         "mysterious"             => 1860,
                         "mysteriously"           => 5486,
                         "mystery"                => 1254,
                         "mystical"               => 4459,
                         "mystified"              => 12072,
                         "mystifying"             => 17042,
                         "mystik"                 => 12071,
                         "mystique"               => 9983,
                         "mythic"                 => 13019,
                         "n'est"                  => 12070,
                         "n'n't"                  => 15039,
                         "n'sync"                 => 15935,
                         "n'yeah"                 => 17041,
                         "nabbed"                 => 9982,
                         "nabbit"                 => 13018,
                         "naboo"                  => 15934,
                         "nafta"                  => 18345,
                         "nagged"                 => 15933,
                         "nagging"                => 4655,
                         "nail"                   => 1420,
                         "nailed"                 => 2844,
                         "nailing"                => 6897,
                         "nails"                  => 2335,
                         "naivete"                => 17040,
                         "nakatomi"               => 12543,
                         "nakedness"              => 14251,
                         "namath"                 => 15932,
                         "nambla"                 => 10551,
                         "nameless"               => 7911,
                         "nametag"                => 15038,
                         "namun"                  => 12542,
                         "nanite"                 => 17039,
                         "nanites"                => 5792,
                         "nannies"                => 6700,
                         "nanny"                  => 2126,
                         "nanobot"                => 7010,
                         "nanocytes"              => 17038,
                         "nanosecond"             => 13017,
                         "nantucket"              => 10550,
                         "naphthalene"            => 17037,
                         "napkin"                 => 3814,
                         "napkins"                => 4619,
                         "nappa"                  => 7910,
                         "napped"                 => 18344,
                         "napping"                => 6699,
                         "nappy"                  => 10549,
                         "naquada"                => 12069,
                         "naquadah"               => 10548,
                         "narcissism"             => 12541,
                         "narcissist"             => 10253,
                         "narcissistic"           => 10878,
                         "narcissists"            => 18343,
                         "narco"                  => 14250,
                         "narcolepsy"             => 13595,
                         "narcotic"               => 12540,
                         "narcotics"              => 4931,
                         "narim"                  => 15931,
                         "narrowed"               => 5721,
                         "narrows"                => 8175,
                         "narwhal"                => 15037,
                         "nasal"                  => 5791,
                         "nasedo"                 => 4407,
                         "nastier"                => 14249,
                         "nastiest"               => 13594,
                         "nate"                   => 1610,
                         "natty"                  => 6792,
                         "naturally"              => 1755,
                         "natured"                => 12539,
                         "nauls"                  => 15930,
                         "nausea"                 => 4618,
                         "nauseam"                => 15929,
                         "nauseated"              => 13593,
                         "nauseating"             => 8873,
                         "nauseous"               => 4589,
                         "navasky"                => 18342,
                         "navel"                  => 9981,
                         "navigate"               => 6083,
                         "navigating"             => 10877,
                         "navour"                 => 15928,
                         "nbsp"                   => 588,
                         "ne'er"                  => 14248,
                         "neanderthal"            => 8034,
                         "neanderthals"           => 11620,
                         "nearer"                 => 9286,
                         "nearing"                => 9285,
                         "nearsighted"            => 14247,
                         "neat"                   => 1944,
                         "neatly"                 => 7909,
                         "neatness"               => 12538,
                         "neato"                  => 11232,
                         "nebbleman"              => 15036,
                         "necessarily"            => 1702,
                         "necessary"              => 1010,
                         "neck"                   => 936,
                         "necking"                => 15927,
                         "necklace"               => 2366,
                         "necklaces"              => 11231,
                         "neckline"               => 15035,
                         "necks"                  => 4996,
                         "necktie"                => 9740,
                         "necronomicon"           => 12068,
                         "necrosis"               => 10876,
                         "nedry"                  => 15926,
                         "need"                   => 73,
                         "needed"                 => 461,
                         "neediest"               => 18341,
                         "needin"                 => 17036,
                         "neediness"              => 17035,
                         "needing"                => 2232,
                         "needle"                 => 2185,
                         "needlepoint"            => 11230,
                         "needles"                => 3416,
                         "needless"               => 5570,
                         "needlessly"             => 10547,
                         "needn't"                => 4434,
                         "needra"                 => 15925,
                         "needs"                  => 336,
                         "needy"                  => 3265,
                         "neeson"                 => 11229,
                         "nefarious"              => 8672,
                         "negate"                 => 12537,
                         "negatives"              => 7735,
                         "negativity"             => 7734,
                         "neglected"              => 4121,
                         "neglectful"             => 17034,
                         "neglecting"             => 8872,
                         "negligee"               => 10875,
                         "negligence"             => 6896,
                         "negligent"              => 6895,
                         "negotiable"             => 5426,
                         "negotiate"              => 3019,
                         "negotiating"            => 4433,
                         "negotiation"            => 4930,
                         "negotiator"             => 6791,
                         "negroes"                => 6365,
                         "neighbor"               => 1866,
                         "neighborly"             => 9085,
                         "neighbors"              => 1904,
                         "neighbour"              => 6364,
                         "neither"                => 655,
                         "nekhorvich"             => 12067,
                         "nemo"                   => 4230,
                         "neonatal"               => 9084,
                         "nephew"                 => 1943,
                         "nepotism"               => 11619,
                         "nerd"                   => 3864,
                         "nerds"                  => 5160,
                         "nerdy"                  => 10546,
                         "nerve"                  => 1421,
                         "nerves"                 => 2491,
                         "nervosa"                => 7476,
                         "nervous"                => 757,
                         "nervously"              => 15034,
                         "nervousness"            => 10545,
                         "nessa"                  => 5720,
                         "nestled"                => 14246,
                         "nether"                 => 10874,
                         "netherworld"            => 18340,
                         "neuro"                  => 8499,
                         "neurological"           => 6292,
                         "neurologist"            => 7009,
                         "neuropathy"             => 18339,
                         "neuroses"               => 13016,
                         "neurosis"               => 12066,
                         "neurosurgeon"           => 8174,
                         "neurosurgery"           => 13592,
                         "neurotic"               => 4432,
                         "neutered"               => 10873,
                         "neutralize"             => 7595,
                         "neutralized"            => 10544,
                         "never"                  => 75,
                         "newborn"                => 4746,
                         "newborns"               => 13591,
                         "newest"                 => 3733,
                         "newfound"               => 7348,
                         "newlywed"               => 10252,
                         "newlyweds"              => 4588,
                         "newmans"                => 7594,
                         "newmeat"                => 17033,
                         "news"                   => 359,
                         "newscaster"             => 18338,
                         "newsflash"              => 10872,
                         "newsman"                => 15924,
                         "newspaperman"           => 18337,
                         "newsprint"              => 18336,
                         "newsroom"               => 11228,
                         "newsstand"              => 7347,
                         "newsstands"             => 13590,
                         "newsworthy"             => 14245,
                         "next"                   => 206,
                         "nibble"                 => 7593,
                         "nibblet"                => 13015,
                         "nibbling"               => 10251,
                         "nice"                   => 166,
                         "nicely"                 => 2268,
                         "nicer"                  => 2593,
                         "nicest"                 => 3196,
                         "niceties"               => 15923,
                         "nicey"                  => 10871,
                         "nicht"                  => 14244,
                         "nicked"                 => 8033,
                         "nicknames"              => 8173,
                         "nicotine"               => 6619,
                         "niece"                  => 1959,
                         "nieces"                 => 8871,
                         "nifty"                  => 7232,
                         "night"                  => 119,
                         "nightcap"               => 5845,
                         "nightclub"              => 4854,
                         "nighter"                => 6082,
                         "nighters"               => 13589,
                         "nightfall"              => 6022,
                         "nightgown"              => 5962,
                         "nightie"                => 9980,
                         "nightline"              => 15922,
                         "nightmare"              => 1173,
                         "nightmares"             => 2765,
                         "nightmarish"            => 15921,
                         "nights"                 => 1289,
                         "nightshift"             => 17032,
                         "nightstand"             => 10543,
                         "nightstick"             => 12536,
                         "nighttime"              => 7475,
                         "nighty"                 => 7231,
                         "nihilist"               => 17031,
                         "nikes"                  => 14243,
                         "nikolas"                => 956,
                         "niles"                  => 564,
                         "nilly"                  => 12535,
                         "nimbala"                => 15033,
                         "nimble"                 => 14242,
                         "niner"                  => 6894,
                         "nines"                  => 10870,
                         "nineteen"               => 2649,
                         "nineties"               => 6698,
                         "ninety"                 => 1808,
                         "ninny"                  => 10869,
                         "ninotchka"              => 5676,
                         "nipped"                 => 15032,
                         "nipping"                => 12534,
                         "nippy"                  => 12065,
                         "nitroglycerin"          => 13014,
                         "nitty"                  => 13588,
                         "nitwit"                 => 8498,
                         "nitwits"                => 18335,
                         "nixed"                  => 17030,
                         "no"                     => 11,
                         "nobler"                 => 18334,
                         "noblest"                => 14241,
                         "nobodies"               => 11618,
                         "nobody"                 => 392,
                         "nobody'd"               => 10542,
                         "nobody'll"              => 9979,
                         "noches"                 => 13587,
                         "nodded"                 => 8870,
                         "nodding"                => 7733,
                         "nodules"                => 15920,
                         "nohoho"                 => 18333,
                         "noinch"                 => 18332,
                         "noing"                  => 18331,
                         "noise"                  => 1305,
                         "noises"                 => 3187,
                         "noisy"                  => 4587,
                         "nomak"                  => 10868,
                         "nomine"                 => 17029,
                         "nomlies"                => 17028,
                         "nonchalant"             => 12064,
                         "none"                   => 499,
                         "nonexistent"            => 8869,
                         "nonfat"                 => 14240,
                         "nonissue"               => 15919,
                         "nonnegotiable"          => 10867,
                         "nonnie"                 => 15918,
                         "nonny"                  => 14239,
                         "nonono"                 => 8172,
                         "nononono"               => 12063,
                         "nonsense"               => 1683,
                         "nonsensical"            => 15031,
                         "nonspecific"            => 18330,
                         "nooch"                  => 15030,
                         "noon"                   => 2166,
                         "nooo"                   => 3108,
                         "noooo"                  => 4169,
                         "nooooo"                 => 6144,
                         "noooooo"                => 8868,
                         "nooooooo"               => 11617,
                         "noooooooo"              => 12062,
                         "noooooooooo"            => 12533,
                         "noose"                  => 5379,
                         "nope"                   => 962,
                         "norad"                  => 12061,
                         "norbu"                  => 17027,
                         "norcom"                 => 15029,
                         "normal"                 => 673,
                         "normalcy"               => 10866,
                         "norther"                => 15028,
                         "nose"                   => 825,
                         "nosebleed"              => 9739,
                         "nosebleeds"             => 12060,
                         "nosed"                  => 7230,
                         "nosedive"               => 17026,
                         "noses"                  => 3980,
                         "nosey"                  => 7908,
                         "nosing"                 => 8032,
                         "nostalgia"              => 8497,
                         "nostalgic"              => 7116,
                         "nostradamus"            => 15027,
                         "nostrand"               => 14238,
                         "nostril"                => 7907,
                         "nostrils"               => 6291,
                         "nosy"                   => 4654,
                         "not"                    => 16,
                         "notarized"              => 9978,
                         "notch"                  => 3518,
                         "notches"                => 10541,
                         "note"                   => 883,
                         "notebooks"              => 9284,
                         "notepad"                => 13013,
                         "nother"                 => 9283,
                         "nothin"                 => 1244,
                         "nothing"                => 109,
                         "nothingness"            => 9504,
                         "nothings"               => 8867,
                         "notice"                 => 777,
                         "noticed"                => 878,
                         "noticing"               => 3550,
                         "notified"               => 4406,
                         "notify"                 => 3772,
                         "notifying"              => 14237,
                         "notting"                => 13586,
                         "notwithstanding"        => 7592,
                         "nough"                  => 15917,
                         "nourish"                => 13012,
                         "nourished"              => 18329,
                         "nourishing"             => 17025,
                         "nourishment"            => 10250,
                         "novocain"               => 15916,
                         "novocaine"              => 12532,
                         "now"                    => 42,
                         "nowhere"                => 1024,
                         "noxious"                => 13011,
                         "ntozake"                => 15915,
                         "nuance"                 => 10865,
                         "nuances"                => 17024,
                         "nubbin"                 => 18328,
                         "nubile"                 => 11616,
                         "nucking"                => 18327,
                         "nudge"                  => 6290,
                         "nudie"                  => 9083,
                         "nuisance"               => 4885,
                         "nuked"                  => 17023,
                         "nukes"                  => 7229,
                         "nullification"          => 18326,
                         "nullifies"              => 18325,
                         "numb"                   => 3531,
                         "numbing"                => 7906,
                         "numbness"               => 11615,
                         "numbskull"              => 18324,
                         "numero"                 => 8496,
                         "nummy"                  => 17022,
                         "numpce"                 => 17021,
                         "nunheim"                => 13010,
                         "nuns"                   => 3792,
                         "nunur"                  => 14236,
                         "nuptial"                => 13009,
                         "nuptials"               => 8671,
                         "nurection"              => 15026,
                         "nurhachi"               => 18323,
                         "nurse"                  => 937,
                         "nursed"                 => 7732,
                         "nursemaid"              => 9738,
                         "nursery"                => 2991,
                         "nurses"                 => 1845,
                         "nurture"                => 9737,
                         "nurtured"               => 11227,
                         "nurturing"              => 6220,
                         "nutball"                => 18322,
                         "nutcase"                => 7346,
                         "nutcracker"             => 7345,
                         "nuthin"                 => 6363,
                         "nuthouse"               => 10249,
                         "nutjob"                 => 14235,
                         "nutritionist"           => 11614,
                         "nutritious"             => 10248,
                         "nuts"                   => 918,
                         "nutshell"               => 7115,
                         "nutso"                  => 10864,
                         "nutsy"                  => 18321,
                         "nuttier"                => 13008,
                         "nuttin"                 => 18320,
                         "nutty"                  => 4041,
                         "nuwanda"                => 11226,
                         "nyanyanyanyah"          => 18319,
                         "nyazian"                => 9977,
                         "nygma"                  => 13585,
                         "nymph"                  => 12531,
                         "nymphomaniac"           => 15914,
                         "nymphs"                 => 9282,
                         "nyong"                  => 15913,
                         "nyquil"                 => 18318,
                         "o'bannion"              => 17020,
                         "o'bannon"               => 17019,
                         "o'clock"                => 1048,
                         "o'connell"              => 5617,
                         "o'daniel"               => 10540,
                         "o'dwyer"                => 14234,
                         "o'gar"                  => 15025,
                         "o'hana"                 => 17018,
                         "o'hara"                 => 8324,
                         "o'hare"                 => 10539,
                         "o'henry"                => 18317,
                         "o'higgins"              => 12059,
                         "o'leary"                => 6362,
                         "o'malley"               => 5532,
                         "o'neil"                 => 5378,
                         "o'neill"                => 2279,
                         "o'reilly"               => 6143,
                         "o'reily"                => 4341,
                         "o'riley"                => 12058,
                         "o'toole"                => 9736,
                         "oakdale"                => 1233,
                         "oakie"                  => 15024,
                         "oath"                   => 2278,
                         "obeah"                  => 18316,
                         "obedient"               => 9503,
                         "obese"                  => 12057,
                         "obey"                   => 4082,
                         "obeyed"                 => 17017,
                         "obeying"                => 12056,
                         "obeys"                  => 18315,
                         "obits"                  => 12530,
                         "obituaries"             => 9502,
                         "objecting"              => 10538,
                         "objection"              => 2052,
                         "objectionable"          => 13584,
                         "objections"             => 4966,
                         "objectively"            => 9501,
                         "objectivity"            => 7474,
                         "obligated"              => 4104,
                         "obligation"             => 2695,
                         "oblige"                 => 5893,
                         "obliged"                => 4929,
                         "obliterate"             => 13583,
                         "obliterated"            => 15912,
                         "oblivious"              => 7473,
                         "obnoxious"              => 3271,
                         "obscene"                => 5425,
                         "obscenely"              => 14233,
                         "obscenities"            => 15023,
                         "observant"              => 8866,
                         "observe"                => 3353,
                         "obsess"                 => 7731,
                         "obsessed"               => 1696,
                         "obsessing"              => 3771,
                         "obsession"              => 2415,
                         "obsessions"             => 12055,
                         "obsessive"              => 4013,
                         "obsessively"            => 17016,
                         "obstacle"               => 5159,
                         "obstacles"              => 4405,
                         "obstetrical"            => 18314,
                         "obstetrician"           => 10863,
                         "obstinate"              => 11613,
                         "obstruct"               => 14232,
                         "obstructed"             => 12054,
                         "obstructing"            => 9500,
                         "obstruction"            => 4081,
                         "obtuse"                 => 12529,
                         "obvious"                => 915,
                         "obviously"              => 488,
                         "occasion"               => 1681,
                         "occult"                 => 7344,
                         "occured"                => 11612,
                         "octavius"               => 8171,
                         "ocular"                 => 14231,
                         "oddest"                 => 10537,
                         "oddly"                  => 4815,
                         "odds"                   => 1582,
                         "odious"                 => 11225,
                         "odorless"               => 15911,
                         "odour"                  => 9976,
                         "oedipal"                => 13007,
                         "of'em"                  => 15022,
                         "off"                    => 97,
                         "offbeat"                => 17015,
                         "offed"                  => 9735,
                         "offence"                => 4928,
                         "offend"                 => 3863,
                         "offended"               => 2883,
                         "offender"               => 7228,
                         "offending"              => 9082,
                         "offends"                => 8323,
                         "offense"                => 1647,
                         "offer"                  => 629,
                         "offering"               => 1494,
                         "offhand"                => 9975,
                         "officiate"              => 12528,
                         "offing"                 => 10247,
                         "ofher"                  => 18313,
                         "oftentimes"             => 11611,
                         "ofthe"                  => 18312,
                         "ogling"                 => 17014,
                         "ogres"                  => 15910,
                         "oh"                     => 26,
                         "ohashi"                 => 15021,
                         "ohhh"                   => 2011,
                         "ohhhh"                  => 4168,
                         "ohhhhh"                 => 7905,
                         "ohhhhhh"                => 15909,
                         "ohhhhhhhh"              => 17013,
                         "ohhhhhhhhh"             => 17012,
                         "ohmigod"                => 8031,
                         "oiled"                  => 9081,
                         "ointment"               => 6697,
                         "okaaay"                 => 15020,
                         "okama"                  => 10862,
                         "okay"                   => 55,
                         "okayed"                 => 13006,
                         "okey"                   => 3963,
                         "okeydoke"               => 18311,
                         "okeydokey"              => 15019,
                         "okies"                  => 17011,
                         "oktoberfest"            => 18310,
                         "olanov"                 => 7008,
                         "oldie"                  => 13582,
                         "olives"                 => 4995,
                         "omelet"                 => 5070,
                         "omelets"                => 18309,
                         "omelette"               => 6447,
                         "omelettes"              => 12527,
                         "omens"                  => 13005,
                         "omigod"                 => 6021,
                         "ominous"                => 8865,
                         "omission"               => 9974,
                         "omnipotent"             => 11224,
                         "omnis"                  => 18308,
                         "omoroca"                => 9734,
                         "onboard"                => 4252,
                         "once"                   => 242,
                         "oncologist"             => 9973,
                         "oncoming"               => 10246,
                         "one'll"                 => 8170,
                         "ones"                   => 634,
                         "oneself"                => 8495,
                         "onesie"                 => 18307,
                         "onstage"                => 7591,
                         "onto"                   => 1081,
                         "oodles"                 => 11610,
                         "ooh"                    => 450,
                         "oohhh"                  => 13581,
                         "oohhhh"                 => 15908,
                         "oompa"                  => 10536,
                         "oomph"                  => 13580,
                         "oomupwah"               => 15018,
                         "oooh"                   => 1994,
                         "ooohh"                  => 9972,
                         "ooohhh"                 => 9733,
                         "ooohhhh"                => 14230,
                         "ooooh"                  => 4375,
                         "oooohh"                 => 15017,
                         "oooohhh"                => 12526,
                         "ooooo"                  => 8169,
                         "oooooh"                 => 6446,
                         "oooooo"                 => 14229,
                         "ooooooh"                => 12525,
                         "ooooooo"                => 17010,
                         "oooooooh"               => 18306,
                         "ooooooooh"              => 14228,
                         "oooooooooh"             => 15907,
                         "ooops"                  => 13579,
                         "oops"                   => 1825,
                         "oopsy"                  => 14227,
                         "oozes"                  => 18305,
                         "oozing"                 => 7904,
                         "opener"                 => 4554,
                         "openers"                => 17009,
                         "opens"                  => 2277,
                         "operagirl"              => 18304,
                         "operandi"               => 13004,
                         "operatives"             => 6790,
                         "ophthalmologist"        => 18303,
                         "opinion"                => 1005,
                         "opinionated"            => 11609,
                         "opium"                  => 6289,
                         "opportune"              => 15906,
                         "opportunist"            => 7007,
                         "opportunity"            => 839,
                         "opposable"              => 15016,
                         "opposites"              => 7343,
                         "oppress"                => 15015,
                         "oppressed"              => 9732,
                         "oprah"                  => 4229,
                         "optimism"               => 5892,
                         "optimistic"             => 3770,
                         "option"                 => 1530,
                         "options"                => 1523,
                         "optometrist"            => 13003,
                         "or'derves"              => 18302,
                         "oracles"                => 9080,
                         "orangutan"              => 14226,
                         "orbed"                  => 8322,
                         "orbing"                 => 7006,
                         "orchestrate"            => 15014,
                         "orchestrating"          => 17008,
                         "orchids"                => 9499,
                         "ordeal"                 => 3791,
                         "ordering"               => 2499,
                         "orderlies"              => 9079,
                         "orderly"                => 4012,
                         "orders"                 => 1022,
                         "ordinarily"             => 4994,
                         "ordinary"               => 1982,
                         "ordinate"               => 13002,
                         "ordinates"              => 12524,
                         "ordover"                => 12523,
                         "oregano"                => 7227,
                         "oreos"                  => 12522,
                         "organs"                 => 3264,
                         "orgies"                 => 12521,
                         "orifice"                => 14225,
                         "originals"              => 6618,
                         "ornament"               => 6696,
                         "ornaments"              => 6893,
                         "ornery"                 => 15905,
                         "orphan"                 => 4773,
                         "orphanage"              => 4927,
                         "orphans"                => 4926,
                         "orphey"                 => 17007,
                         "orrin"                  => 14224,
                         "orson"                  => 4814,
                         "orthodontist"           => 12520,
                         "orthopedic"             => 10245,
                         "orthopedist"            => 18301,
                         "ortolani"               => 6445,
                         "orvelle"                => 7472,
                         "oshun"                  => 18300,
                         "ostentatious"           => 18299,
                         "ostracized"             => 13001,
                         "ostrich"                => 6444,
                         "otherwise"              => 872,
                         "otherworldly"           => 11608,
                         "ottos"                  => 14223,
                         "ouch"                   => 1988,
                         "ought"                  => 984,
                         "oughta"                 => 2125,
                         "oughtn't"               => 18298,
                         "oughtta"                => 6081,
                         "ouija"                  => 12053,
                         "ounce"                  => 3591,
                         "ounces"                 => 6020,
                         "our"                    => 81,
                         "ours"                   => 1218,
                         "ourselves"              => 864,
                         "out"                    => 32,
                         "out've"                 => 17006,
                         "outa"                   => 3352,
                         "outage"                 => 12052,
                         "outbid"                 => 13578,
                         "outburst"               => 6535,
                         "outbursts"              => 9731,
                         "outcast"                => 5961,
                         "outcasts"               => 11607,
                         "outdid"                 => 8670,
                         "outdo"                  => 15013,
                         "outdone"                => 6534,
                         "outdoors"               => 5284,
                         "outdoorsy"              => 15012,
                         "outed"                  => 9971,
                         "outfit"                 => 1469,
                         "outfits"                => 3882,
                         "outfoxed"               => 18297,
                         "outgrew"                => 15011,
                         "outgrow"                => 13577,
                         "outgrown"               => 7730,
                         "outhouse"               => 12051,
                         "outing"                 => 7729,
                         "outings"                => 14222,
                         "outlander"              => 17005,
                         "outlandish"             => 15010,
                         "outlast"                => 17004,
                         "outlive"                => 12519,
                         "outmaneuver"            => 18296,
                         "outnumber"              => 17003,
                         "outnumbered"            => 7226,
                         "outpouring"             => 12050,
                         "outrage"                => 5283,
                         "outraged"               => 5616,
                         "outrageous"             => 3027,
                         "outrageously"           => 15904,
                         "outrank"                => 12049,
                         "outrun"                 => 8030,
                         "outs"                   => 4080,
                         "outside"                => 445,
                         "outsiders"              => 7005,
                         "outsmart"               => 9970,
                         "outsmarted"             => 10244,
                         "outta"                  => 835,
                         "outvoted"               => 17002,
                         "outweigh"               => 11223,
                         "outweighs"              => 14221,
                         "outwit"                 => 13576,
                         "outwitted"              => 17001,
                         "ovaltine"               => 14220,
                         "ovaries"                => 9078,
                         "ovary"                  => 9730,
                         "oven"                   => 2498,
                         "ovens"                  => 9969,
                         "overachiever"           => 17000,
                         "overactive"             => 9077,
                         "overalls"               => 12048,
                         "overanxious"            => 16999,
                         "overbearing"            => 8029,
                         "overbite"               => 13575,
                         "overblown"              => 15903,
                         "overboard"              => 3486,
                         "overbooked"             => 14219,
                         "overcharge"             => 15902,
                         "overcharged"            => 18295,
                         "overcoat"               => 9968,
                         "overcome"               => 3150,
                         "overcomes"              => 18294,
                         "overcompensate"         => 18293,
                         "overcompensating"       => 13000,
                         "overconfident"          => 14218,
                         "overcooked"             => 15009,
                         "overcrowded"            => 12999,
                         "overdid"                => 12518,
                         "overdo"                 => 7114,
                         "overdoing"              => 9281,
                         "overdone"               => 12998,
                         "overdose"               => 5790,
                         "overdosed"              => 15901,
                         "overdrawn"              => 18292,
                         "overdressed"            => 8669,
                         "overdrive"              => 8864,
                         "overdue"                => 4140,
                         "overestimate"           => 15008,
                         "overestimated"          => 13574,
                         "overexcited"            => 16998,
                         "overflowing"            => 10535,
                         "overhear"               => 4687,
                         "overheard"              => 2176,
                         "overhearing"            => 5424,
                         "overheated"             => 11606,
                         "overheating"            => 15900,
                         "overjoyed"              => 8168,
                         "overload"               => 5531,
                         "overloaded"             => 9280,
                         "overlook"               => 4813,
                         "overlooked"             => 5960,
                         "overly"                 => 4280,
                         "overnight"              => 1929,
                         "overnights"             => 16997,
                         "overpaid"               => 12517,
                         "overpaying"             => 18291,
                         "overpower"              => 11222,
                         "overpowered"            => 14217,
                         "overpowering"           => 14216,
                         "overpriced"             => 8028,
                         "overprotective"         => 4404,
                         "overqualified"          => 11605,
                         "overrated"              => 5158,
                         "overreact"              => 5377,
                         "overreacted"            => 3378,
                         "overreacting"           => 2534,
                         "overreaction"           => 11604,
                         "override"               => 4374,
                         "overrides"              => 18290,
                         "overrule"               => 15007,
                         "overruled"              => 5844,
                         "overrun"                => 7728,
                         "oversensitive"          => 16996,
                         "oversexed"              => 18289,
                         "oversized"              => 8668,
                         "oversleep"              => 15899,
                         "overslept"              => 6892,
                         "overstate"              => 14215,
                         "overstating"            => 12516,
                         "overstay"               => 13573,
                         "overstayed"             => 15006,
                         "overstep"               => 11221,
                         "overstepped"            => 9967,
                         "overstepping"           => 10861,
                         "overstress"             => 16995,
                         "overtake"               => 14214,
                         "overthink"              => 15005,
                         "overthruster"           => 10243,
                         "overtime"               => 3769,
                         "overtired"              => 16994,
                         "overtures"              => 15004,
                         "overturn"               => 9966,
                         "overweight"             => 7727,
                         "overwhelm"              => 12047,
                         "overwhelmed"            => 3083,
                         "overwhelming"           => 3139,
                         "overwhelms"             => 12515,
                         "overworked"             => 6617,
                         "overwrought"            => 11603,
                         "overzealous"            => 9498,
                         "ovulating"              => 7342,
                         "ovulation"              => 14213,
                         "owatta"                 => 12997,
                         "owe"                    => 670,
                         "owed"                   => 3038,
                         "owes"                   => 2461,
                         "owning"                 => 4812,
                         "owns"                   => 1770,
                         "owwwww"                 => 18288,
                         "oxygen"                 => 2267,
                         "oysters"                => 5843,
                         "ozone"                  => 7225,
                         "paaiint"                => 15003,
                         "pacemaker"              => 8863,
                         "pacer"                  => 15002,
                         "paces"                  => 7471,
                         "pacey"                  => 877,
                         "pachyderm"              => 13572,
                         "pacified"               => 18287,
                         "pacifier"               => 10860,
                         "pacify"                 => 18286,
                         "pacing"                 => 6616,
                         "pack"                   => 989,
                         "package"                => 1414,
                         "packages"               => 4011,
                         "packed"                 => 1617,
                         "packets"                => 7470,
                         "packin"                 => 10859,
                         "packing"                => 1693,
                         "packs"                  => 4120,
                         "pact"                   => 3292,
                         "padded"                 => 6789,
                         "padding"                => 8167,
                         "paddington"             => 4531,
                         "paddles"                => 6361,
                         "paddling"               => 15898,
                         "padlock"                => 15897,
                         "padre"                  => 7469,
                         "paducci"                => 12996,
                         "paella"                 => 12995,
                         "paged"                  => 4058,
                         "pager"                  => 4208,
                         "pagers"                 => 13571,
                         "paging"                 => 5069,
                         "pagliacci"              => 11602,
                         "paid"                   => 740,
                         "pain"                   => 490,
                         "pained"                 => 12046,
                         "painful"                => 1481,
                         "painfully"              => 5068,
                         "painkillers"            => 5675,
                         "painless"               => 4925,
                         "pains"                  => 3426,
                         "paint"                  => 1190,
                         "paintballing"           => 16993,
                         "paintbrush"             => 15001,
                         "paints"                 => 7341,
                         "pajama"                 => 10858,
                         "pajamas"                => 3457,
                         "palamon"                => 15896,
                         "palantine"              => 16992,
                         "palatable"              => 18285,
                         "palate"                 => 9497,
                         "pale"                   => 2592,
                         "paleontologist"         => 12514,
                         "paleontology"           => 10534,
                         "pales"                  => 12994,
                         "paley"                  => 9729,
                         "pally"                  => 14212,
                         "palmdale"               => 18284,
                         "palmed"                 => 18283,
                         "palms"                  => 5251,
                         "palooza"                => 18282,
                         "palpable"               => 13570,
                         "palpitations"           => 16991,
                         "pals"                   => 3248,
                         "paltrow"                => 15895,
                         "paltry"                 => 13569,
                         "pamper"                 => 12045,
                         "pampered"               => 8166,
                         "pampering"              => 11220,
                         "pancakes"               => 2316,
                         "pancamo"                => 12513,
                         "pancreas"               => 9728,
                         "pandering"              => 13568,
                         "paneling"               => 18281,
                         "panes"                  => 9279,
                         "pangs"                  => 18280,
                         "panic"                  => 1496,
                         "panicked"               => 2990,
                         "panicking"              => 5327,
                         "panicky"                => 10242,
                         "panics"                 => 12512,
                         "pankot"                 => 11219,
                         "panky"                  => 9496,
                         "pantaloons"             => 16990,
                         "panting"                => 7726,
                         "pantry"                 => 6891,
                         "pants"                  => 965,
                         "paparazzi"              => 11218,
                         "papayas"                => 16989,
                         "paper"                  => 619,
                         "papered"                => 18279,
                         "paperers"               => 18278,
                         "papers"                 => 816,
                         "paperweight"            => 12044,
                         "paperwork"              => 1922,
                         "papier"                 => 15000,
                         "parachutes"             => 12993,
                         "parachuting"            => 16988,
                         "parade"                 => 2140,
                         "parading"               => 9076,
                         "paragraph"              => 5106,
                         "paragraphs"             => 11217,
                         "parakeet"               => 10241,
                         "paralegal"              => 11216,
                         "paralysis"              => 5041,
                         "paralyze"               => 12992,
                         "paralyzed"              => 3116,
                         "paralyzing"             => 13567,
                         "paramedics"             => 3732,
                         "paramour"               => 12991,
                         "paramus"                => 14999,
                         "paranoia"               => 3918,
                         "paranoid"               => 1838,
                         "paranormal"             => 6019,
                         "paraphernalia"          => 13566,
                         "paraphrasing"           => 18277,
                         "paraplegic"             => 18276,
                         "parasailing"            => 14998,
                         "parasite"               => 4530,
                         "parasites"              => 5485,
                         "paratrooper"            => 13565,
                         "parched"                => 9278,
                         "parcheesi"              => 16987,
                         "pardner"                => 7903,
                         "pardon"                 => 1191,
                         "pardoned"               => 8027,
                         "pardoning"              => 18275,
                         "pardons"                => 12511,
                         "parent"                 => 1568,
                         "parental"               => 4251,
                         "parenthood"             => 7902,
                         "parenting"              => 3979,
                         "parents"                => 417,
                         "pariah"                 => 9277,
                         "parishioner"            => 16986,
                         "parka"                  => 10240,
                         "parked"                 => 2094,
                         "parkers"                => 18274,
                         "parking"                => 1328,
                         "parkishoff"             => 18273,
                         "parlay"                 => 14211,
                         "parlez"                 => 14210,
                         "parlor"                 => 3881,
                         "parlors"                => 15894,
                         "parlour"                => 12043,
                         "parmesan"               => 8862,
                         "parole"                 => 2303,
                         "paroled"                => 8321,
                         "partake"                => 9495,
                         "parter"                 => 14209,
                         "particulars"            => 8026,
                         "partied"                => 8494,
                         "parting"                => 6142,
                         "partner"                => 931,
                         "partying"               => 3837,
                         "passable"               => 14997,
                         "passageway"             => 8493,
                         "passageways"            => 12510,
                         "passin"                 => 15893,
                         "passionate"             => 2490,
                         "passionately"           => 7224,
                         "passkey"                => 13564,
                         "passports"              => 6080,
                         "past"                   => 385,
                         "pasta"                  => 3415,
                         "paste"                  => 5842,
                         "pasted"                 => 16985,
                         "pastels"                => 12042,
                         "pasties"                => 15892,
                         "pastime"                => 8861,
                         "pastrami"               => 7223,
                         "pastries"               => 9494,
                         "pastry"                 => 5423,
                         "pasts"                  => 15891,
                         "patch"                  => 2131,
                         "patched"                => 5530,
                         "patching"               => 7901,
                         "patchouli"              => 15890,
                         "patently"               => 14996,
                         "paternity"              => 2623,
                         "pathetic"               => 1058,
                         "pathetically"           => 10239,
                         "pathological"           => 6079,
                         "pathologically"         => 15889,
                         "pathologist"            => 11601,
                         "pathos"                 => 16984,
                         "patient"                => 759,
                         "patiently"              => 9075,
                         "patio"                  => 5198,
                         "patois"                 => 16983,
                         "patrolling"             => 6018,
                         "patrolman"              => 11215,
                         "patrolmen"              => 16982,
                         "patronize"              => 5197,
                         "patronized"             => 12990,
                         "patronizing"            => 6443,
                         "patted"                 => 18272,
                         "patties"                => 13563,
                         "patting"                => 15888,
                         "pattycake"              => 16981,
                         "paulsson"               => 16980,
                         "pauper"                 => 14208,
                         "pause"                  => 4139,
                         "paused"                 => 18271,
                         "pauses"                 => 11600,
                         "pausing"                => 14207,
                         "pavarotti"              => 10857,
                         "pawing"                 => 8492,
                         "pawn"                   => 3654,
                         "pawned"                 => 14206,
                         "pawning"                => 16979,
                         "pawns"                  => 9493,
                         "pawnshop"               => 15887,
                         "paxcow"                 => 18270,
                         "pay"                    => 355,
                         "payable"                => 11599,
                         "payback"                => 2480,
                         "paycheck"               => 3377,
                         "paychecks"              => 9074,
                         "payin"                  => 6141,
                         "paying"                 => 949,
                         "payoff"                 => 4228,
                         "payoffs"                => 10533,
                         "payphone"               => 10532,
                         "payroll"                => 3530,
                         "pays"                   => 2117,
                         "pazzi"                  => 12041,
                         "pcpd"                   => 4494,
                         "peace"                  => 811,
                         "peaceful"               => 2556,
                         "peacefully"             => 6219,
                         "peacemaker"             => 15886,
                         "peaksville"             => 18269,
                         "peaky"                  => 18268,
                         "pears"                  => 9492,
                         "peas"                   => 4653,
                         "pecan"                  => 6890,
                         "pecans"                 => 16978,
                         "pecked"                 => 14995,
                         "peckers"                => 16977,
                         "peckin"                 => 18267,
                         "pecking"                => 11214,
                         "peckish"                => 10856,
                         "pecks"                  => 14994,
                         "pectorals"              => 18266,
                         "peculiar"               => 4529,
                         "pedal"                  => 5789,
                         "pedaling"               => 15885,
                         "peddle"                 => 7725,
                         "peddling"               => 8320,
                         "pedestal"               => 5250,
                         "pediatric"              => 6442,
                         "pediatrician"           => 7468,
                         "pediatrics"             => 5959,
                         "pedicure"               => 7222,
                         "pedicures"              => 16976,
                         "pedophile"              => 13562,
                         "peeing"                 => 7221,
                         "peeked"                 => 7724,
                         "peeking"                => 5615,
                         "peeks"                  => 15884,
                         "peeled"                 => 7113,
                         "peeling"                => 8860,
                         "peels"                  => 13561,
                         "peep"                   => 4119,
                         "peephole"               => 18265,
                         "peeping"                => 7340,
                         "peeps"                  => 10855,
                         "peering"                => 13560,
                         "peerless"               => 11598,
                         "peeve"                  => 18264,
                         "peeved"                 => 11597,
                         "pegged"                 => 5067,
                         "pegnoir"                => 18263,
                         "peignoir"               => 16975,
                         "peini"                  => 12040,
                         "pekar"                  => 8859,
                         "pellet"                 => 16974,
                         "pellets"                => 11596,
                         "pelting"                => 16973,
                         "pelts"                  => 12989,
                         "pelvic"                 => 8165,
                         "pelvis"                 => 9965,
                         "pembry"                 => 13559,
                         "pemmican"               => 15883,
                         "penalize"               => 16972,
                         "penance"                => 6288,
                         "penchant"               => 9964,
                         "pencils"                => 5040,
                         "pendant"                => 7004,
                         "pending"                => 4010,
                         "penell"                 => 15882,
                         "penetrate"              => 6287,
                         "penetrates"             => 18262,
                         "penetti"                => 18261,
                         "pengin"                 => 18260,
                         "penhall"                => 18259,
                         "penicillin"             => 6218,
                         "penises"                => 12039,
                         "penitentiary"           => 5674,
                         "penmanship"             => 9963,
                         "pennbrooke"             => 18258,
                         "penne"                  => 15881,
                         "pennies"                => 4993,
                         "penniless"              => 9073,
                         "pennybaker"             => 18257,
                         "pens"                   => 4403,
                         "pensione"               => 18256,
                         "pensive"                => 18255,
                         "pensky"                 => 12038,
                         "pentacle"               => 18254,
                         "pentagon"               => 3444,
                         "pentagram"              => 12988,
                         "pentameter"             => 18253,
                         "pentangeli"             => 10238,
                         "penthouse"              => 2008,
                         "penticoff"              => 12509,
                         "pentonville"            => 10531,
                         "pentothal"              => 12037,
                         "people'll"              => 11213,
                         "pepperdine"             => 13558,
                         "pepperjack"             => 16971,
                         "peppermint"             => 7112,
                         "pepperoni"              => 4745,
                         "peppy"                  => 9276,
                         "pepto"                  => 15880,
                         "pepys"                  => 13557,
                         "per'sus"                => 16970,
                         "perceive"               => 7590,
                         "percentile"             => 12036,
                         "perceptive"             => 4716,
                         "perchance"              => 11595,
                         "perched"                => 10854,
                         "percocet"               => 16969,
                         "percodan"               => 18252,
                         "percolating"            => 15879,
                         "perdido"                => 18251,
                         "peretti"                => 11212,
                         "perfect"                => 346,
                         "perfected"              => 9727,
                         "perfecting"             => 13556,
                         "perfection"             => 3425,
                         "perfectionist"          => 11211,
                         "perfectly"              => 849,
                         "perfume"                => 2640,
                         "perfumed"               => 16968,
                         "perfumes"               => 14993,
                         "perfunctory"            => 18250,
                         "perhaps"                => 536,
                         "perignon"               => 14992,
                         "peril"                  => 6286,
                         "perilous"               => 14205,
                         "perimeter"              => 3247,
                         "perimeters"             => 16967,
                         "periodontist"           => 18249,
                         "periscope"              => 12987,
                         "perish"                 => 7111,
                         "perishable"             => 16966,
                         "perjure"                => 12035,
                         "perjured"               => 13555,
                         "perjurer"               => 18248,
                         "perjury"                => 4250,
                         "perkiness"              => 18247,
                         "perks"                  => 4373,
                         "perky"                  => 5788,
                         "permalash"              => 6533,
                         "permission"             => 1313,
                         "permutat"               => 16965,
                         "peroxide"               => 10530,
                         "perpetrate"             => 15878,
                         "perpetrated"            => 8858,
                         "perpetrating"           => 18246,
                         "perpetrator"            => 6695,
                         "perpetually"            => 14204,
                         "perpetuate"             => 14203,
                         "perpetuating"           => 16964,
                         "perplexed"              => 18245,
                         "perps"                  => 12508,
                         "persecute"              => 12034,
                         "persecuted"             => 6788,
                         "persecuting"            => 11594,
                         "perservere"             => 18244,
                         "perseverance"           => 9491,
                         "persist"                => 8857,
                         "persistent"             => 4652,
                         "persnickety"            => 15877,
                         "person"                 => 266,
                         "personable"             => 10529,
                         "personality"            => 1699,
                         "personalize"            => 13554,
                         "personalized"           => 10528,
                         "personally"             => 1078,
                         "personals"              => 10853,
                         "personified"            => 13553,
                         "personify"              => 18243,
                         "perspective"            => 1947,
                         "perspiration"           => 12507,
                         "perspire"               => 18242,
                         "persuade"               => 3751,
                         "persuasion"             => 6360,
                         "persuasive"             => 4458,
                         "pertains"               => 13552,
                         "pertinent"              => 7339,
                         "perturbed"              => 16963,
                         "peruse"                 => 13551,
                         "perverse"               => 6694,
                         "perversion"             => 10852,
                         "perverted"              => 7220,
                         "perverts"               => 8667,
                         "pervs"                  => 18241,
                         "pesaram"                => 15876,
                         "peshtigo"               => 15875,
                         "pesky"                  => 5282,
                         "pessimist"              => 12506,
                         "pessimistic"            => 12033,
                         "pestering"              => 12986,
                         "pestilence"             => 12505,
                         "pesto"                  => 8491,
                         "petal"                  => 11593,
                         "petals"                 => 6359,
                         "petey"                  => 3291,
                         "petitioner"             => 15874,
                         "petitioning"            => 16962,
                         "petrak"                 => 11592,
                         "petrified"              => 6078,
                         "petronis"               => 16961,
                         "pets"                   => 3903,
                         "petticoat"              => 16960,
                         "petting"                => 7589,
                         "petulant"               => 9490,
                         "petyr"                  => 15873,
                         "pewter"                 => 16959,
                         "pfeffernuesse"          => 18240,
                         "pffft"                  => 12504,
                         "pharaohs"               => 15872,
                         "pharmaceuticals"        => 6615,
                         "pharmacist"             => 6693,
                         "pharoah"                => 11591,
                         "phasers"                => 18239,
                         "pheasants"              => 16958,
                         "pheebs"                 => 1811,
                         "phenomenal"             => 6017,
                         "phenomenally"           => 16957,
                         "pheromone"              => 18238,
                         "pheromones"             => 8025,
                         "phew"                   => 3590,
                         "philanderer"            => 18237,
                         "philandering"           => 16956,
                         "philby"                 => 15871,
                         "philipse"               => 15870,
                         "philistine"             => 14202,
                         "philistines"            => 18236,
                         "phillipe"               => 15869,
                         "phillippe"              => 8319,
                         "phlegm"                 => 9726,
                         "phobia"                 => 7900,
                         "phobias"                => 14991,
                         "phobic"                 => 16955,
                         "phoebe"                 => 616,
                         "phoebes"                => 18235,
                         "phoebs"                 => 7219,
                         "phone"                  => 274,
                         "phoned"                 => 3902,
                         "phones"                 => 1921,
                         "phoney"                 => 7899,
                         "phonies"                => 12985,
                         "phoning"                => 9275,
                         "phonse"                 => 5787,
                         "phony"                  => 2001,
                         "phooey"                 => 12984,
                         "phosphorous"            => 12503,
                         "photo"                  => 1334,
                         "photocopied"            => 14201,
                         "photocopies"            => 18234,
                         "photocopy"              => 14990,
                         "photogenic"             => 12502,
                         "photograph"             => 2479,
                         "photographer"           => 2555,
                         "photographing"          => 11590,
                         "phrased"                => 18233,
                         "physic"                 => 16954,
                         "physically"             => 2025,
                         "physicals"              => 13550,
                         "physiologically"        => 16953,
                         "physique"               => 12032,
                         "piccata"                => 14989,
                         "picchu"                 => 16952,
                         "pick"                   => 369,
                         "picked"                 => 772,
                         "pickers"                => 14200,
                         "picket"                 => 4057,
                         "picketing"              => 11589,
                         "pickin"                 => 5484,
                         "picking"                => 1226,
                         "pickings"               => 11210,
                         "pickled"                => 12501,
                         "pickpocket"             => 13549,
                         "pickpockets"            => 16951,
                         "picks"                  => 2635,
                         "picky"                  => 4772,
                         "picnic"                 => 2076,
                         "picnics"                => 8490,
                         "picon"                  => 16950,
                         "pictionary"             => 14988,
                         "picture"                => 463,
                         "pictured"               => 4138,
                         "pictures"               => 791,
                         "picturing"              => 5483,
                         "piddle"                 => 14199,
                         "piddles"                => 12500,
                         "piddling"               => 16949,
                         "piece"                  => 530,
                         "pieced"                 => 12499,
                         "piecing"                => 15868,
                         "pieeee"                 => 18232,
                         "pier"                   => 2622,
                         "pierced"                => 5039,
                         "piercings"              => 12983,
                         "pies"                   => 4617,
                         "piffle"                 => 14987,
                         "pigeons"                => 5422,
                         "piggly"                 => 16948,
                         "piggyback"              => 15867,
                         "pigheaded"              => 12031,
                         "pigmen"                 => 18231,
                         "pigs"                   => 2528,
                         "pigskin"                => 14986,
                         "pigsty"                 => 9072,
                         "pigtails"               => 8318,
                         "pilates"                => 18230,
                         "pile"                   => 2137,
                         "piled"                  => 7898,
                         "piles"                  => 7467,
                         "pileup"                 => 18229,
                         "piling"                 => 6787,
                         "pill"                   => 2112,
                         "pillage"                => 12030,
                         "pillowcase"             => 14198,
                         "pillows"                => 4118,
                         "pills"                  => 1279,
                         "pimento"                => 18228,
                         "pimped"                 => 15866,
                         "pimple"                 => 7466,
                         "pimples"                => 16947,
                         "pimply"                 => 15865,
                         "pimps"                  => 9962,
                         "pinafore"               => 16946,
                         "pinata"                 => 10850,
                         "pinback"                => 11588,
                         "pincer"                 => 18227,
                         "pinch"                  => 3389,
                         "pinched"                => 7003,
                         "pinches"                => 12029,
                         "pinching"               => 7338,
                         "pincushion"             => 15864,
                         "pine"                   => 1465,
                         "pineapples"             => 16945,
                         "pinecrest"              => 12028,
                         "pinetti"                => 12982,
                         "pinheads"               => 15863,
                         "pining"                 => 4279,
                         "pinkner"                => 18226,
                         "pinks"                  => 14985,
                         "pinkus"                 => 14984,
                         "pinned"                 => 3880,
                         "pinning"                => 8164,
                         "pinocchio"              => 7723,
                         "pinochle"               => 16944,
                         "pinot"                  => 8317,
                         "pinpoint"               => 6077,
                         "pinpointed"             => 14983,
                         "pinpoints"              => 18225,
                         "pins"                   => 4715,
                         "pinstripes"             => 18224,
                         "pint"                   => 4686,
                         "pintauro"               => 18223,
                         "pints"                  => 7588,
                         "pipe"                   => 2098,
                         "pipes"                  => 3653,
                         "piqued"                 => 12027,
                         "piranhas"               => 12498,
                         "pirated"                => 16943,
                         "pirelli"                => 8666,
                         "piss"                   => 1869,
                         "pissed"                 => 1609,
                         "pisses"                 => 6786,
                         "pissin"                 => 13548,
                         "pissy"                  => 9489,
                         "pistachio"              => 13547,
                         "pistachios"             => 16942,
                         "pitfalls"               => 12026,
                         "pithy"                  => 10851,
                         "pitied"                 => 12981,
                         "pitiful"                => 4651,
                         "pittance"               => 15862,
                         "pitting"                => 12497,
                         "pity"                   => 1490,
                         "pitying"                => 12025,
                         "pixilated"              => 12496,
                         "pizzazz"                => 18222,
                         "pizzeria"               => 9961,
                         "placate"                => 11587,
                         "place'll"               => 16941,
                         "placebos"               => 16940,
                         "placemats"              => 18221,
                         "placenta"               => 9488,
                         "plague"                 => 2934,
                         "plagues"                => 10849,
                         "plaguing"               => 15861,
                         "plaid"                  => 5482,
                         "plaids"                 => 18220,
                         "plain"                  => 1736,
                         "plainclothes"           => 14982,
                         "plainly"                => 8489,
                         "plaintiff"              => 5958,
                         "plait"                  => 11586,
                         "plan"                   => 373,
                         "plane"                  => 696,
                         "plane'arium"            => 16939,
                         "planetarium"            => 6217,
                         "planing"                => 10848,
                         "plannin"                => 12024,
                         "planning"               => 764,
                         "plans"                  => 677,
                         "plantains"              => 14197,
                         "planted"                => 2146,
                         "plasmapheresis"         => 18219,
                         "plaster"                => 5719,
                         "plastered"              => 6692,
                         "plastering"             => 18218,
                         "plastique"              => 14981,
                         "plate"                  => 1402,
                         "plateaued"              => 15860,
                         "plated"                 => 7722,
                         "platelets"              => 16938,
                         "plates"                 => 2334,
                         "platitude"              => 18217,
                         "platitudes"             => 15859,
                         "platonic"               => 6532,
                         "platonically"           => 18216,
                         "platter"                => 3813,
                         "platters"               => 12980,
                         "plausible"              => 6441,
                         "playbook"               => 16937,
                         "playground"             => 3917,
                         "playgroup"              => 18215,
                         "playin"                 => 3916,
                         "playmates"              => 14196,
                         "playpen"                => 9725,
                         "playroom"               => 11585,
                         "plaything"              => 12495,
                         "playthings"             => 14980,
                         "plea"                   => 2478,
                         "plead"                  => 2656,
                         "pleading"               => 4227,
                         "pleadings"              => 16936,
                         "pleasant"               => 1852,
                         "pleasantly"             => 9071,
                         "pleasantries"           => 7587,
                         "pleasantville"          => 9724,
                         "please"                 => 98,
                         "pleased"                => 1495,
                         "pleases"                => 4924,
                         "pleasing"               => 6785,
                         "pleasurable"            => 9960,
                         "pleasure"               => 769,
                         "pleasures"              => 5891,
                         "pleasuring"             => 15858,
                         "plebeian"               => 18214,
                         "pledge"                 => 2989,
                         "pledges"                => 8665,
                         "pledging"               => 11584,
                         "pleeease"               => 12979,
                         "pleeze"                 => 16935,
                         "plenty"                 => 833,
                         "plesac"                 => 14195,
                         "pliers"                 => 8163,
                         "plight"                 => 6889,
                         "plimpton"               => 14979,
                         "plissken"               => 6531,
                         "plotted"                => 8316,
                         "plotting"               => 3246,
                         "plowed"                 => 11583,
                         "plowing"                => 13546,
                         "pluck"                  => 7110,
                         "plucked"                => 8024,
                         "plucking"               => 14978,
                         "plug"                   => 2276,
                         "plugged"                => 5529,
                         "plugging"               => 12978,
                         "plugs"                  => 6076,
                         "pluie"                  => 14194,
                         "plumbers"               => 12023,
                         "plumbing"               => 3995,
                         "plummet"                => 12022,
                         "plummeted"              => 14977,
                         "plummeting"             => 10847,
                         "plums"                  => 12494,
                         "plunge"                 => 5528,
                         "plunged"                => 9723,
                         "plunger"                => 9722,
                         "plunging"               => 12977,
                         "plus"                   => 902,
                         "pluses"                 => 15857,
                         "plutonium"              => 6140,
                         "plying"                 => 14193,
                         "pneumonia"              => 4372,
                         "poach"                  => 14976,
                         "poached"                => 8664,
                         "poacher"                => 15856,
                         "poachers"               => 12021,
                         "poaching"               => 10527,
                         "poatia"                 => 18213,
                         "pocket"                 => 1339,
                         "pocketbook"             => 8488,
                         "pocketed"               => 14975,
                         "pocketful"              => 12976,
                         "pocketknife"            => 18212,
                         "pockets"                => 2852,
                         "poconos"                => 12975,
                         "pocus"                  => 8856,
                         "podiatrist"             => 11582,
                         "podiatry"               => 16934,
                         "podunk"                 => 12493,
                         "pointers"               => 6285,
                         "pointing"               => 2353,
                         "pointless"              => 2957,
                         "pointy"                 => 4853,
                         "poise"                  => 11209,
                         "poised"                 => 7897,
                         "poisoned"               => 3051,
                         "poisoning"              => 3404,
                         "poisonous"              => 4249,
                         "poisons"                => 10526,
                         "poitier"                => 16933,
                         "poke"                   => 4040,
                         "poked"                  => 6284,
                         "poker"                  => 1882,
                         "pokes"                  => 12974,
                         "pokin"                  => 16932,
                         "poking"                 => 4103,
                         "polack"                 => 18211,
                         "polaroids"              => 12973,
                         "polenta"                => 14192,
                         "policeman"              => 3089,
                         "policemen"              => 5527,
                         "policia"                => 15855,
                         "polished"               => 6216,
                         "polisher"               => 18210,
                         "polishing"              => 8663,
                         "polite"                 => 2022,
                         "politely"               => 5841,
                         "politeness"             => 18209,
                         "polling"                => 5249,
                         "polloi"                 => 15854,
                         "polls"                  => 3938,
                         "pollute"                => 12492,
                         "polluted"               => 9487,
                         "polluting"              => 13545,
                         "pollyanna"              => 12972,
                         "poltergeist"            => 8487,
                         "poltergeists"           => 14974,
                         "polyester"              => 6358,
                         "polygraph"              => 4992,
                         "polymerized"            => 18208,
                         "polyps"                 => 18207,
                         "pomade"                 => 18206,
                         "pomegranate"            => 10846,
                         "pomegranates"           => 14191,
                         "pompoms"                => 11208,
                         "pomponi"                => 16931,
                         "pompous"                => 4965,
                         "pondering"              => 9721,
                         "ponies"                 => 5614,
                         "ponytail"               => 8315,
                         "poodles"                => 12971,
                         "poof"                   => 3652,
                         "poofs"                  => 7465,
                         "poofy"                  => 15853,
                         "pool"                   => 1004,
                         "poolhouse"              => 8486,
                         "pooling"                => 15852,
                         "poolside"               => 14973,
                         "pooped"                 => 7896,
                         "pooping"                => 18205,
                         "poops"                  => 18204,
                         "poor"                   => 511,
                         "poorer"                 => 5840,
                         "poorhouse"              => 11581,
                         "poppa"                  => 8162,
                         "popped"                 => 2927,
                         "poppers"                => 16930,
                         "popping"                => 3351,
                         "poppins"                => 9486,
                         "poppycock"              => 16929,
                         "pops"                   => 2378,
                         "popsicle"               => 6440,
                         "popsicles"              => 12970,
                         "porch"                  => 2546,
                         "porcupine"              => 7721,
                         "pores"                  => 7337,
                         "poring"                 => 16928,
                         "pork"                   => 2926,
                         "pornographers"          => 16927,
                         "porque"                 => 14190,
                         "porridge"               => 13544,
                         "portal"                 => 3259,
                         "portals"                => 8161,
                         "portent"                => 15851,
                         "porterhouse"            => 16926,
                         "porthole"               => 18203,
                         "portkey"                => 16925,
                         "portofino"              => 4811,
                         "portokalos"             => 14972,
                         "portolano"              => 14971,
                         "pose"                   => 3232,
                         "poser"                  => 14970,
                         "poses"                  => 6784,
                         "poseur"                 => 18202,
                         "posies"                 => 16924,
                         "posing"                 => 4226,
                         "positively"             => 3149,
                         "positives"              => 14969,
                         "posse"                  => 5248,
                         "posses"                 => 16923,
                         "possessed"              => 3163,
                         "possessive"             => 5957,
                         "possibilities"          => 2444,
                         "possibility"            => 1315,
                         "possible"               => 447,
                         "possibly"               => 688,
                         "postcard"               => 4340,
                         "postcards"              => 7895,
                         "poster"                 => 2725,
                         "posterity"              => 9959,
                         "posters"                => 3790,
                         "postmark"               => 12969,
                         "postmortem"             => 11207,
                         "postop"                 => 14968,
                         "postpartum"             => 13543,
                         "postpone"               => 3082,
                         "postponed"              => 4167,
                         "postponement"           => 8160,
                         "postponing"             => 7109,
                         "posttraumatic"          => 11580,
                         "posturing"              => 9958,
                         "potatoes"               => 2477,
                         "pothole"                => 8855,
                         "potholes"               => 16922,
                         "potion"                 => 2171,
                         "potions"                => 5157,
                         "potpie"                 => 18201,
                         "potpourri"              => 14189,
                         "potshots"               => 14188,
                         "potsie"                 => 16921,
                         "potted"                 => 11579,
                         "pottersville"           => 16920,
                         "pottie"                 => 16919,
                         "potties"                => 18200,
                         "potting"                => 13542,
                         "potty"                  => 7586,
                         "potus"                  => 14967,
                         "pouch"                  => 7894,
                         "poughkeepsie"           => 9485,
                         "pounce"                 => 7585,
                         "pounced"                => 14187,
                         "pound"                  => 1925,
                         "pounding"               => 3651,
                         "pounds"                 => 1464,
                         "pour"                   => 2085,
                         "poured"                 => 3499,
                         "pouring"                => 3162,
                         "pours"                  => 8485,
                         "pouting"                => 7464,
                         "pouty"                  => 9274,
                         "povich"                 => 13541,
                         "powdered"               => 6283,
                         "powders"                => 14966,
                         "powerbar"               => 16918,
                         "powerful"               => 1128,
                         "powerless"              => 3915,
                         "powerpuff"              => 18199,
                         "powwow"                 => 9720,
                         "practicality"           => 14965,
                         "practically"            => 1141,
                         "practicing"             => 2565,
                         "practising"             => 8484,
                         "praetorians"            => 14964,
                         "pragmatist"             => 16917,
                         "praises"                => 7893,
                         "pralines"               => 16916,
                         "prancan"                => 18198,
                         "prance"                 => 8854,
                         "prancing"               => 7720,
                         "prank"                  => 3270,
                         "pranks"                 => 5956,
                         "prankster"              => 13540,
                         "prattle"                => 14186,
                         "prattling"              => 13539,
                         "pray"                   => 1207,
                         "prayed"                 => 2933,
                         "prayer"                 => 2103,
                         "prayers"                => 2275,
                         "prayin"                 => 10845,
                         "praying"                => 1857,
                         "prays"                  => 12968,
                         "preach"                 => 6215,
                         "preaching"              => 5376,
                         "preachy"                => 14963,
                         "precarious"             => 9719,
                         "precaution"             => 4493,
                         "precautionary"          => 12491,
                         "precautions"            => 4852,
                         "precedents"             => 10237,
                         "precedes"               => 9273,
                         "precinct"               => 3750,
                         "precipice"              => 16915,
                         "precisely"              => 2414,
                         "precludes"              => 13538,
                         "precocious"             => 13537,
                         "precog"                 => 14185,
                         "precogs"                => 7463,
                         "preconceived"           => 16914,
                         "preconceptions"         => 18197,
                         "precrime"               => 7108,
                         "predicament"            => 6075,
                         "predict"                => 3365,
                         "predictable"            => 3549,
                         "predisposed"            => 12490,
                         "predisposition"         => 13536,
                         "prednisone"             => 11578,
                         "preeclampsia"           => 8159,
                         "preemie"                => 18196,
                         "preempt"                => 18195,
                         "preemptive"             => 8023,
                         "prefer"                 => 1205,
                         "preferable"             => 8662,
                         "preferably"             => 4616,
                         "prefers"                => 5569,
                         "prefex"                 => 16913,
                         "pregnancies"            => 12489,
                         "pregnancy"              => 1656,
                         "pregnant"               => 590,
                         "prego"                  => 14184,
                         "prejudice"              => 5105,
                         "prejudiced"             => 7462,
                         "prejudices"             => 9718,
                         "prejudicial"            => 16912,
                         "prelim"                 => 10525,
                         "premarital"             => 12488,
                         "premature"              => 3826,
                         "prematurely"            => 7719,
                         "premed"                 => 7002,
                         "premeditated"           => 7718,
                         "premeditation"          => 9957,
                         "premonition"            => 2145,
                         "premonitions"           => 3472,
                         "prenatal"               => 6614,
                         "prenup"                 => 7336,
                         "prenuptial"             => 9272,
                         "preoccupation"          => 14183,
                         "preoccupied"            => 3548,
                         "preocupe"               => 16911,
                         "prep"                   => 2708,
                         "prepare"                => 1477,
                         "prepared"               => 1080,
                         "preparing"              => 2764,
                         "preposition"            => 18194,
                         "preposterous"           => 5421,
                         "prepped"                => 5955,
                         "preppie"                => 12020,
                         "prepping"               => 6783,
                         "preppy"                 => 11577,
                         "prerogative"            => 7001,
                         "pres"                   => 2932,
                         "preschool"              => 6530,
                         "prescribe"              => 5954,
                         "prescribed"             => 4964,
                         "prescribes"             => 16910,
                         "prescribing"            => 10524,
                         "prescription"           => 2570,
                         "prescriptions"          => 8661,
                         "presentable"            => 8314,
                         "presents"               => 1452,
                         "preservatives"          => 14962,
                         "preserver"              => 12019,
                         "preset"                 => 18193,
                         "presets"                => 16909,
                         "presidente"             => 8158,
                         "press'll"               => 16908,
                         "pressed"                => 3107,
                         "pressers"               => 18192,
                         "presses"                => 5718,
                         "pressing"               => 2816,
                         "pressure"               => 933,
                         "pressured"              => 4851,
                         "pressuring"             => 3630,
                         "presume"                => 3129,
                         "presuming"              => 11576,
                         "presumptuous"           => 5104,
                         "pretend"                => 842,
                         "pretended"              => 2476,
                         "pretending"             => 1283,
                         "pretends"               => 4991,
                         "pretense"               => 7461,
                         "pretenses"              => 6613,
                         "pretentious"            => 5156,
                         "pretrial"               => 15850,
                         "prettier"               => 3914,
                         "prettiest"              => 4586,
                         "pretty"                 => 199,
                         "pretzels"               => 5326,
                         "prevail"                => 5375,
                         "prevails"               => 14961,
                         "preventative"           => 14960,
                         "preview"                => 4248,
                         "previews"               => 9484,
                         "prevision"              => 18191,
                         "prewedding"             => 9956,
                         "preyed"                 => 15849,
                         "preying"                => 13535,
                         "preys"                  => 12018,
                         "priced"                 => 5953,
                         "priceless"              => 3836,
                         "pricey"                 => 8853,
                         "prick"                  => 3007,
                         "pricked"                => 16907,
                         "prickly"                => 10236,
                         "pricks"                 => 10235,
                         "pride"                  => 1461,
                         "prided"                 => 12967,
                         "prides"                 => 14182,
                         "pried"                  => 9955,
                         "priestess"              => 9271,
                         "primed"                 => 8852,
                         "primordial"             => 10234,
                         "primping"               => 14959,
                         "princesses"             => 8313,
                         "principled"             => 14181,
                         "print"                  => 1704,
                         "printout"               => 9270,
                         "printouts"              => 18190,
                         "prints"                 => 1820,
                         "prinze"                 => 16906,
                         "priorities"             => 2901,
                         "prioritize"             => 13534,
                         "prioritizing"           => 16905,
                         "priority"               => 1847,
                         "priors"                 => 7000,
                         "prison"                 => 659,
                         "prisoner"               => 1657,
                         "priss"                  => 11206,
                         "pristine"               => 9269,
                         "privacy"                => 1517,
                         "privates"               => 9954,
                         "privilege"              => 2489,
                         "privileged"             => 4810,
                         "privileges"             => 4207,
                         "proactive"              => 11205,
                         "prob'ly"                => 9268,
                         "probably"               => 219,
                         "probate"                => 10844,
                         "probation"              => 3062,
                         "probationary"           => 14958,
                         "probe"                  => 4650,
                         "probed"                 => 18189,
                         "probie"                 => 12017,
                         "probing"                => 9953,
                         "problem"                => 208,
                         "problema"               => 12966,
                         "problemo"               => 7892,
                         "problems"               => 547,
                         "procedure"              => 1551,
                         "proceed"                => 1956,
                         "proceeding"             => 5325,
                         "processional"           => 15848,
                         "proclaim"               => 9952,
                         "proclamations"          => 14180,
                         "proclivities"           => 16904,
                         "proclivity"             => 18188,
                         "procrastinate"          => 15847,
                         "procrastinating"        => 11204,
                         "procrastination"        => 14957,
                         "procreate"              => 16903,
                         "procreation"            => 14179,
                         "proctologist"           => 10233,
                         "procure"                => 11575,
                         "prodded"                => 10232,
                         "prodding"               => 11574,
                         "prodigal"               => 7584,
                         "productive"             => 3614,
                         "profanity"              => 13533,
                         "profess"                => 11573,
                         "professionalism"        => 9070,
                         "profound"               => 4305,
                         "profoundly"             => 8660,
                         "profusely"              => 12965,
                         "prognosis"              => 4649,
                         "programmed"             => 4056,
                         "progressing"            => 8157,
                         "projections"            => 6529,
                         "projector"              => 6139,
                         "prolong"                => 9069,
                         "prolonging"             => 14178,
                         "prom"                   => 1362,
                         "promiscuous"            => 13532,
                         "promise"                => 327,
                         "promised"               => 732,
                         "promises"               => 1801,
                         "promising"              => 2891,
                         "promos"                 => 9267,
                         "prompt"                 => 7717,
                         "prompter"               => 16902,
                         "proms"                  => 12016,
                         "pronounce"              => 3498,
                         "pronouncing"            => 14177,
                         "pronto"                 => 5247,
                         "proof"                  => 845,
                         "proofed"                => 16901,
                         "proofing"               => 10523,
                         "propane"                => 5420,
                         "propensity"             => 12964,
                         "proper"                 => 1560,
                         "properly"               => 2302,
                         "prophecies"             => 6357,
                         "prophecy"               => 4191,
                         "prophesied"             => 12963,
                         "prophylactic"           => 16900,
                         "proportioned"           => 16899,
                         "propose"                => 1797,
                         "proposing"              => 3613,
                         "proposition"            => 3186,
                         "propositioned"          => 18187,
                         "propositioning"         => 14956,
                         "propped"                => 15846,
                         "propping"               => 16898,
                         "propriety"              => 15845,
                         "props"                  => 4963,
                         "pros"                   => 4744,
                         "prosaic"                => 18186,
                         "prosciutto"             => 14955,
                         "prosecute"              => 3812,
                         "prosecuted"             => 5481,
                         "prosecuting"            => 6356,
                         "prosecution"            => 3161,
                         "prosecutorial"          => 14954,
                         "prosky"                 => 9483,
                         "prospects"              => 5246,
                         "prospectus"             => 14176,
                         "prosthetic"             => 12015,
                         "prostitute"             => 3471,
                         "protect"                => 507,
                         "protectee"              => 18185,
                         "protectin"              => 16897,
                         "protecting"             => 1220,
                         "protective"             => 2073,
                         "protector"              => 3901,
                         "protectors"             => 11203,
                         "protects"               => 4884,
                         "protestations"          => 18184,
                         "protesting"             => 6138,
                         "protestors"             => 10231,
                         "proteus"                => 1508,
                         "proud"                  => 624,
                         "prouder"                => 10230,
                         "proudest"               => 11202,
                         "proudly"                => 6612,
                         "provasik"               => 16896,
                         "prove"                  => 581,
                         "proven"                 => 2160,
                         "provenance"             => 5786,
                         "proverb"                => 13531,
                         "proverbial"             => 5952,
                         "proves"                 => 2093,
                         "proving"                => 2900,
                         "provocation"            => 8659,
                         "provocations"           => 10229,
                         "provocative"            => 6611,
                         "provoke"                => 4278,
                         "provoked"               => 5673,
                         "provoking"              => 6999,
                         "provolone"              => 15844,
                         "prowl"                  => 7716,
                         "prowling"               => 9717,
                         "proximo"                => 14175,
                         "prude"                  => 7107,
                         "prudent"                => 6282,
                         "prudes"                 => 15843,
                         "prudy"                  => 11201,
                         "prue"                   => 920,
                         "prune"                  => 7106,
                         "prunes"                 => 10843,
                         "pruning"                => 16895,
                         "prying"                 => 5951,
                         "psats"                  => 18183,
                         "pssst"                  => 11200,
                         "psst"                   => 3376,
                         "psych"                  => 2733,
                         "psyche"                 => 5103,
                         "psyched"                => 3667,
                         "psychiatric"            => 3169,
                         "psychiatrist"           => 1735,
                         "psychiatrists"          => 5526,
                         "psychiatry"             => 5672,
                         "psychic"                => 2202,
                         "psychically"            => 12487,
                         "psychics"               => 9266,
                         "psychoanalyze"          => 16894,
                         "psychobabble"           => 8658,
                         "psychodrama"            => 18182,
                         "psychologically"        => 7583,
                         "psychologist"           => 4685,
                         "psychopath"             => 4079,
                         "psychopathic"           => 10842,
                         "psychopaths"            => 16893,
                         "psychos"                => 10228,
                         "psychosis"              => 6782,
                         "psychosomatic"          => 13530,
                         "psychotherapist"        => 14953,
                         "psychotic"              => 2714,
                         "psychotics"             => 16892,
                         "pterodactyl"            => 18181,
                         "puberty"                => 5281,
                         "pubes"                  => 7105,
                         "pubescent"              => 15842,
                         "pubic"                  => 10522,
                         "publically"             => 16891,
                         "publicist"              => 7104,
                         "publicity"              => 2424,
                         "pucker"                 => 9068,
                         "puckering"              => 18180,
                         "puddings"               => 18179,
                         "puddle"                 => 4714,
                         "puddy"                  => 6528,
                         "pudgy"                  => 18178,
                         "puede"                  => 14174,
                         "puedo"                  => 14952,
                         "puff"                   => 3699,
                         "puffed"                 => 7891,
                         "puffing"                => 10841,
                         "puffs"                  => 5038,
                         "puke"                   => 3375,
                         "puked"                  => 9482,
                         "pukin"                  => 18177,
                         "puking"                 => 7890,
                         "pull"                   => 523,
                         "pulled"                 => 851,
                         "pulling"                => 1235,
                         "pullout"                => 18176,
                         "pulls"                  => 2602,
                         "pulsating"              => 13529,
                         "pulse"                  => 1677,
                         "pumbaa"                 => 9951,
                         "pummel"                 => 14951,
                         "pummeling"              => 14173,
                         "pump"                   => 2591,
                         "pumped"                 => 4117,
                         "pumpin"                 => 15841,
                         "pumping"                => 3629,
                         "pumps"                  => 4431,
                         "punch"                  => 1472,
                         "punchbowl"              => 16890,
                         "punched"                => 3258,
                         "punches"                => 4883,
                         "punching"               => 3731,
                         "punchline"              => 9481,
                         "punchy"                 => 8657,
                         "punctual"               => 8483,
                         "punctuality"            => 12014,
                         "puncture"               => 6214,
                         "punctured"              => 9067,
                         "pungent"                => 14950,
                         "punish"                 => 2007,
                         "punishable"             => 9480,
                         "punished"               => 2450,
                         "punishes"               => 11199,
                         "punishing"              => 3768,
                         "punishment"             => 1949,
                         "punitis"                => 18175,
                         "punks"                  => 5480,
                         "punters"                => 12486,
                         "punxsutawney"           => 11198,
                         "puppet"                 => 2975,
                         "puppeteer"              => 7889,
                         "puppets"                => 5245,
                         "purblind"               => 16889,
                         "pure"                   => 1419,
                         "puree"                  => 14949,
                         "pureed"                 => 18174,
                         "purely"                 => 3712,
                         "purer"                  => 14948,
                         "purest"                 => 8156,
                         "purgatory"              => 8312,
                         "purging"                => 12485,
                         "purifier"               => 18173,
                         "puritanical"            => 14947,
                         "purity"                 => 5324,
                         "purposefully"           => 10521,
                         "purposely"              => 5479,
                         "purring"                => 14172,
                         "purse"                  => 1375,
                         "purses"                 => 9479,
                         "purty"                  => 16888,
                         "purview"                => 15840,
                         "pusan"                  => 15839,
                         "push"                   => 742,
                         "pushed"                 => 1166,
                         "pushers"                => 15838,
                         "pushes"                 => 4553,
                         "pushin"                 => 11572,
                         "pushing"                => 1168,
                         "pushover"               => 6691,
                         "pushy"                  => 4166,
                         "put"                    => 129,
                         "put'em"                 => 18172,
                         "putrid"                 => 10840,
                         "puts"                   => 1411,
                         "puttanesca"             => 14946,
                         "puttin"                 => 4585,
                         "putting"                => 668,
                         "putty"                  => 7335,
                         "putumayo"               => 18171,
                         "puzzle"                 => 2701,
                         "puzzled"                => 10520,
                         "puzzles"                => 5478,
                         "puzzling"               => 12013,
                         "pygmalion"              => 15837,
                         "pygmies"                => 12012,
                         "pyjamas"                => 10227,
                         "pylea"                  => 10839,
                         "pyromaniac"             => 14945,
                         "pyrotechnics"           => 13528,
                         "qfxmjrie"               => 5037,
                         "quack"                  => 3290,
                         "quacks"                 => 12962,
                         "quadrant"               => 8482,
                         "quadrants"              => 18170,
                         "quahog"                 => 12011,
                         "quaid"                  => 5323,
                         "quail"                  => 9950,
                         "quaint"                 => 5196,
                         "quaintly"               => 18169,
                         "quaking"                => 12961,
                         "qualifies"              => 5244,
                         "qualities"              => 3081,
                         "qualms"                 => 13527,
                         "quandary"               => 10838,
                         "quantico"               => 7582,
                         "quarantine"             => 4923,
                         "quarantined"            => 12484,
                         "quarrel"                => 5950,
                         "quarreled"              => 16887,
                         "quarreling"             => 18168,
                         "quart"                  => 6610,
                         "quartered"              => 14171,
                         "quartermaine"           => 1632,
                         "quartermaines"          => 3231,
                         "quarters"               => 2454,
                         "quasimodo"              => 14944,
                         "queasy"                 => 6998,
                         "queef"                  => 13526,
                         "queer"                  => 3978,
                         "queers"                 => 11197,
                         "quelle"                 => 14943,
                         "quellek"                => 14942,
                         "queller"                => 15836,
                         "quench"                 => 18167,
                         "queremos"               => 14941,
                         "question"               => 332,
                         "questionable"           => 4809,
                         "questioned"             => 3026,
                         "questioning"            => 1781,
                         "questionnaire"          => 9066,
                         "questions"              => 487,
                         "questscape"             => 15835,
                         "quibble"                => 10519,
                         "quiche"                 => 7888,
                         "quiches"                => 18166,
                         "quick"                  => 700,
                         "quicker"                => 3138,
                         "quickest"               => 7218,
                         "quickie"                => 5613,
                         "quicksand"              => 7715,
                         "quien"                  => 16886,
                         "quiero"                 => 13525,
                         "quiet"                  => 647,
                         "quieter"                => 7714,
                         "quietly"                => 2601,
                         "quilt"                  => 5949,
                         "quilting"               => 16885,
                         "quilts"                 => 16884,
                         "quince"                 => 7887,
                         "quinine"                => 15834,
                         "quintessential"         => 14940,
                         "quints"                 => 16883,
                         "quintuplets"            => 12010,
                         "quips"                  => 14170,
                         "quirks"                 => 8481,
                         "quirky"                 => 7581,
                         "quit"                   => 774,
                         "quite"                  => 387,
                         "quits"                  => 5066,
                         "quitter"                => 6281,
                         "quitters"               => 14939,
                         "quittin"                => 14938,
                         "quitting"               => 2865,
                         "quiver"                 => 13524,
                         "quivering"              => 10226,
                         "quiz"                   => 2707,
                         "quizmaster"             => 5568,
                         "quizzes"                => 9065,
                         "quizzing"               => 14169,
                         "qumar"                  => 9716,
                         "qumari"                 => 16882,
                         "quote"                  => 2223,
                         "quoth"                  => 16881,
                         "quoting"                => 6074,
                         "raban"                  => 16880,
                         "rabartu"                => 18165,
                         "rabble"                 => 4371,
                         "rabid"                  => 6609,
                         "rabies"                 => 6439,
                         "raccoons"               => 12483,
                         "rach"                   => 2010,
                         "racist"                 => 4277,
                         "racists"                => 18164,
                         "rack"                   => 2700,
                         "racked"                 => 11571,
                         "racket"                 => 4137,
                         "racketeer"              => 14937,
                         "racketeering"           => 6997,
                         "rackets"                => 9949,
                         "racking"                => 7713,
                         "racks"                  => 8155,
                         "racquet"                => 7886,
                         "racquetball"            => 7712,
                         "radar"                  => 1354,
                         "radials"                => 18163,
                         "radiant"                => 6137,
                         "radiator"               => 6690,
                         "radioactive"            => 4808,
                         "radioed"                => 8480,
                         "radiologist"            => 13523,
                         "radiology"              => 7711,
                         "radios"                 => 7103,
                         "radishes"               => 16879,
                         "radisson"               => 16878,
                         "raditch"                => 6689,
                         "rafe"                   => 716,
                         "rafer"                  => 12960,
                         "raffi"                  => 11570,
                         "raffle"                 => 8656,
                         "raft"                   => 4116,
                         "rafters"                => 9948,
                         "rafting"                => 10837,
                         "rage"                   => 2324,
                         "rages"                  => 15833,
                         "ragged"                 => 7580,
                         "raggedy"                => 8022,
                         "ragging"                => 7710,
                         "raging"                 => 3628,
                         "raheem"                 => 16877,
                         "rahesh"                 => 18162,
                         "railing"                => 5280,
                         "railly"                 => 12009,
                         "railroaded"             => 9265,
                         "railroading"            => 11196,
                         "rain"                   => 1203,
                         "raincheck"              => 11569,
                         "raincoat"               => 10518,
                         "raindrops"              => 18161,
                         "rained"                 => 7334,
                         "raining"                => 3414,
                         "rainstorm"              => 11195,
                         "rainy"                  => 5525,
                         "raise"                  => 938,
                         "raiser"                 => 5567,
                         "raisers"                => 15832,
                         "raises"                 => 4771,
                         "raisinettes"            => 16876,
                         "raising"                => 1817,
                         "raisins"                => 5717,
                         "raison"                 => 15831,
                         "rajeski"                => 15830,
                         "raked"                  => 11568,
                         "raking"                 => 9478,
                         "ramali"                 => 7885,
                         "rambaldi"               => 3862,
                         "ramble"                 => 8851,
                         "rambling"               => 5948,
                         "ramblings"              => 12482,
                         "rambunctious"           => 13522,
                         "ramelle"                => 10225,
                         "ramifications"          => 6527,
                         "rammed"                 => 11194,
                         "ramming"                => 18160,
                         "ramoray"                => 18159,
                         "rampler"                => 14168,
                         "ramus"                  => 10224,
                         "ran"                    => 604,
                         "rance"                  => 9947,
                         "ranch"                  => 2564,
                         "rancher"                => 11193,
                         "rancheros"              => 14167,
                         "ranchers"               => 12959,
                         "ransack"                => 16875,
                         "ranting"                => 6073,
                         "rants"                  => 14936,
                         "raoul"                  => 5477,
                         "rape"                   => 2388,
                         "raped"                  => 2453,
                         "rapes"                  => 11192,
                         "raping"                 => 10836,
                         "rapist"                 => 6781,
                         "rapists"                => 14935,
                         "rappaport"              => 1864,
                         "rappaports"             => 18158,
                         "rapport"                => 9715,
                         "raquetball"             => 16874,
                         "rarest"                 => 14934,
                         "raring"                 => 12481,
                         "rascals"                => 12008,
                         "rasczak"                => 14166,
                         "rashes"                 => 15829,
                         "rashly"                 => 16873,
                         "rashum"                 => 14165,
                         "raspail"                => 14933,
                         "raspberry"              => 6888,
                         "ratatouille"            => 14164,
                         "ratched"                => 7884,
                         "rath"                   => 3168,
                         "rathole"                => 14932,
                         "ration"                 => 12480,
                         "rational"               => 2627,
                         "rationalization"        => 14163,
                         "rationalize"            => 8655,
                         "rationalizing"          => 10223,
                         "rationally"             => 5785,
                         "rats"                   => 2107,
                         "ratso"                  => 13521,
                         "ratted"                 => 5784,
                         "ratting"                => 11191,
                         "rattle"                 => 4304,
                         "rattled"                => 5243,
                         "rattles"                => 16872,
                         "rattlesnake"            => 8850,
                         "rattlesnakes"           => 16871,
                         "rattling"               => 6780,
                         "ratty"                  => 7709,
                         "ravages"                => 18157,
                         "rave"                   => 4339,
                         "raved"                  => 16870,
                         "ravell"                 => 11567,
                         "ravenous"               => 10835,
                         "ravenwood"              => 10222,
                         "raves"                  => 9477,
                         "ravine"                 => 8654,
                         "raving"                 => 4165,
                         "ravings"                => 13520,
                         "ravioli"                => 9476,
                         "ravish"                 => 14931,
                         "ravishing"              => 7217,
                         "rawdon"                 => 7579,
                         "rawdy"                  => 15828,
                         "rawley"                 => 5716,
                         "rawlston"               => 18156,
                         "rayanne"                => 14930,
                         "rayed"                  => 11566,
                         "rayne"                  => 13519,
                         "rays"                   => 3306,
                         "raysy"                  => 7460,
                         "razgul"                 => 16869,
                         "razinin"                => 14162,
                         "re'kali"                => 18155,
                         "reach"                  => 908,
                         "reachin"                => 18154,
                         "reacquaint"             => 14929,
                         "reacquainted"           => 12007,
                         "react"                  => 1837,
                         "reacted"                => 3497,
                         "reacting"               => 3825,
                         "reacts"                 => 8311,
                         "read"                   => 365,
                         "reade"                  => 4648,
                         "readin"                 => 11190,
                         "reading"                => 804,
                         "readout"                => 12479,
                         "reads"                  => 2843,
                         "ready"                  => 234,
                         "real"                   => 193,
                         "realer"                 => 18153,
                         "realise"                => 2925,
                         "realised"               => 3835,
                         "realist"                => 6355,
                         "realistic"              => 3364,
                         "realistically"          => 8479,
                         "realities"              => 6136,
                         "reality"                => 1118,
                         "realize"                => 457,
                         "realized"               => 799,
                         "realizes"               => 2732,
                         "realizing"              => 3305,
                         "really"                 => 52,
                         "realm"                  => 1938,
                         "realmedia"              => 9064,
                         "realtors"               => 14161,
                         "realy"                  => 18152,
                         "reamed"                 => 14928,
                         "reanimation"            => 14160,
                         "reapers"                => 12478,
                         "reappear"               => 11189,
                         "rearrange"              => 5524,
                         "rearranged"             => 9714,
                         "rearranging"            => 8653,
                         "rears"                  => 14927,
                         "rearview"               => 13518,
                         "reason"                 => 275,
                         "reasonable"             => 1629,
                         "reasons"                => 959,
                         "reassemble"             => 14926,
                         "reassess"               => 14159,
                         "reassessing"            => 18151,
                         "reassign"               => 13517,
                         "reassigning"            => 16868,
                         "reassignment"           => 12477,
                         "reassurance"            => 8849,
                         "reassure"               => 4457,
                         "reassured"              => 9713,
                         "reassuring"             => 4430,
                         "reattach"               => 16867,
                         "rebadow"                => 8848,
                         "rebate"                 => 12006,
                         "rebelling"              => 13516,
                         "rebellious"             => 7333,
                         "rebound"                => 3879,
                         "rebuild"                => 3789,
                         "rebuttal"               => 9063,
                         "recall"                 => 1475,
                         "recant"                 => 8847,
                         "recanted"               => 12958,
                         "recanting"              => 16866,
                         "recap"                  => 6688,
                         "recapture"              => 7459,
                         "receding"               => 12476,
                         "receipt"                => 2800,
                         "receipts"               => 4136,
                         "receptacle"             => 14158,
                         "receptionist"           => 6687,
                         "receptive"              => 6996,
                         "recess"                 => 3878,
                         "recharge"               => 8478,
                         "recheck"                => 10221,
                         "rechecked"              => 14925,
                         "recieved"               => 12005,
                         "recipe"                 => 2621,
                         "recipes"                => 5523,
                         "reciprocate"            => 9264,
                         "reciprocated"           => 18150,
                         "recital"                => 3612,
                         "recitation"             => 12004,
                         "recite"                 => 6072,
                         "reciting"               => 11188,
                         "recklessly"             => 12475,
                         "recklessness"           => 12957,
                         "reckon"                 => 3213,
                         "reckoned"               => 6526,
                         "reckoning"              => 8846,
                         "reclaim"                => 5476,
                         "reclaiming"             => 12003,
                         "recliner"               => 15827,
                         "reclining"              => 16865,
                         "recluse"                => 9475,
                         "reclusive"              => 12956,
                         "recognizance"           => 12002,
                         "recognize"              => 1179,
                         "recollect"              => 14157,
                         "recollection"           => 6438,
                         "recommend"              => 2124,
                         "recommendation"         => 3212,
                         "recommending"           => 6887,
                         "recommitted"            => 14156,
                         "reconcile"              => 5374,
                         "reconciled"             => 7102,
                         "reconciling"            => 12001,
                         "reconnect"              => 5522,
                         "reconnected"            => 13515,
                         "reconnecting"           => 10834,
                         "reconsider"             => 2784,
                         "reconsidered"           => 8477,
                         "reconsidering"          => 9263,
                         "reconstructive"         => 14155,
                         "reconvene"              => 9062,
                         "recorder"               => 3666,
                         "recount"                => 8310,
                         "recoup"                 => 18149,
                         "recourse"               => 7883,
                         "recover"                => 2191,
                         "recovering"             => 2988,
                         "recovers"               => 7882,
                         "recovery"               => 1715,
                         "recreate"               => 9061,
                         "recreating"             => 13514,
                         "recrimination"          => 16864,
                         "recriminations"         => 14924,
                         "recruiter"              => 15826,
                         "rectal"                 => 12474,
                         "rectangles"             => 18148,
                         "rectify"                => 7216,
                         "recuperate"             => 6995,
                         "recuperating"           => 6608,
                         "recuse"                 => 12000,
                         "recycles"               => 16863,
                         "redcoats"               => 18147,
                         "redecorate"             => 7881,
                         "redecorated"            => 14154,
                         "redecorating"           => 7458,
                         "redeem"                 => 5947,
                         "redeemable"             => 18146,
                         "redeeming"              => 11565,
                         "redefine"               => 13513,
                         "redemption"             => 5890,
                         "redheaded"              => 9712,
                         "redial"                 => 10833,
                         "redid"                  => 13512,
                         "redirect"               => 10220,
                         "rediscover"             => 14153,
                         "rednecks"               => 11564,
                         "redness"                => 18145,
                         "redoing"                => 9711,
                         "redundancies"           => 12473,
                         "reechard"               => 11999,
                         "reeking"                => 12955,
                         "reeks"                  => 6071,
                         "reeled"                 => 12472,
                         "reeling"                => 6525,
                         "reels"                  => 11187,
                         "reenactment"            => 9474,
                         "reeno"                  => 16862,
                         "reenter"                => 15825,
                         "reeseman"               => 18144,
                         "reevaluate"             => 13511,
                         "reexamine"              => 18143,
                         "referrals"              => 16861,
                         "referring"              => 2214,
                         "refill"                 => 3529,
                         "refilling"              => 18142,
                         "refills"                => 12954,
                         "reflection"             => 3304,
                         "reflexes"               => 7578,
                         "refocus"                => 16860,
                         "refrain"                => 6135,
                         "refresh"                => 4850,
                         "refreshed"              => 10832,
                         "refresher"              => 9710,
                         "refreshing"             => 3811,
                         "refreshingly"           => 18141,
                         "refreshment"            => 9473,
                         "refreshments"           => 7457,
                         "refrigerated"           => 12471,
                         "refrigerator"           => 2763,
                         "refrigerators"          => 15824,
                         "refuel"                 => 9709,
                         "refueled"               => 18140,
                         "refund"                 => 5475,
                         "refundable"             => 10219,
                         "refunds"                => 14152,
                         "refuse"                 => 1499,
                         "refusing"               => 3627,
                         "refute"                 => 12470,
                         "regains"                => 9708,
                         "regards"                => 3749,
                         "regenerate"             => 11186,
                         "regenerated"            => 16859,
                         "regimen"                => 10517,
                         "regret"                 => 1035,
                         "regrets"                => 2452,
                         "regrettable"            => 10831,
                         "regrettably"            => 11185,
                         "regretted"              => 4770,
                         "regretting"             => 6524,
                         "regroup"                => 6523,
                         "regurgitate"            => 12953,
                         "rehab"                  => 2554,
                         "rehabilitated"          => 10830,
                         "rehash"                 => 6437,
                         "rehashing"              => 10829,
                         "rehearsal"              => 2175,
                         "rehearse"               => 4190,
                         "rehearsed"              => 7708,
                         "rehearsing"             => 5155,
                         "reheat"                 => 15823,
                         "rehydrate"              => 18139,
                         "reiben"                 => 9707,
                         "reiber"                 => 4164,
                         "reibers"                => 11998,
                         "reimburse"              => 10516,
                         "reimbursed"             => 13510,
                         "reincarnated"           => 13509,
                         "reincarnation"          => 9946,
                         "reindeer"               => 4922,
                         "reinmar"                => 11997,
                         "reins"                  => 9945,
                         "reinstate"              => 6436,
                         "reinstating"            => 14923,
                         "reinvent"               => 11996,
                         "reinvented"             => 15822,
                         "reinventing"            => 15821,
                         "reiterate"              => 11995,
                         "reject"                 => 3211,
                         "rejecting"              => 5612,
                         "rejection"              => 3303,
                         "rejections"             => 16858,
                         "rejoice"                => 8845,
                         "rejoicing"              => 13508,
                         "rejuvenate"             => 16857,
                         "rejuvenated"            => 14922,
                         "rejuvenating"           => 14921,
                         "rekall"                 => 9472,
                         "rekindle"               => 11184,
                         "rekindled"              => 14920,
                         "rekindling"             => 18138,
                         "relapse"                => 6886,
                         "relapsing"              => 14919,
                         "relate"                 => 3050,
                         "relationship"           => 473,
                         "relationships"          => 1688,
                         "relax"                  => 578,
                         "relaxant"               => 18137,
                         "relaxants"              => 16856,
                         "relaxation"             => 6779,
                         "relaxed"                => 2740,
                         "relaxes"                => 11183,
                         "relaxing"               => 3568,
                         "relearn"                => 18136,
                         "relentless"             => 5521,
                         "relentlessly"           => 12952,
                         "reliable"               => 3137,
                         "relieve"                => 4135,
                         "relieved"               => 1729,
                         "relinquish"             => 8844,
                         "relinquishes"           => 18135,
                         "relinquishing"          => 13507,
                         "relish"                 => 7215,
                         "relive"                 => 4584,
                         "relived"                => 18134,
                         "reliving"               => 5373,
                         "rely"                   => 3210,
                         "remanded"               => 9706,
                         "remark"                 => 4039,
                         "remarkable"             => 2487,
                         "remarkably"             => 4849,
                         "remarks"                => 3681,
                         "remarried"              => 4713,
                         "remarry"                => 6778,
                         "remeber"                => 16855,
                         "remedial"               => 10218,
                         "remedied"               => 13506,
                         "remedy"                 => 5889,
                         "remem"                  => 18133,
                         "remember"               => 155,
                         "remembered"             => 1201,
                         "remembering"            => 1972,
                         "remembers"              => 2282,
                         "remind"                 => 889,
                         "reminded"               => 1920,
                         "reminder"               => 2947,
                         "reminders"              => 8021,
                         "reminding"              => 2808,
                         "reminds"                => 1519,
                         "reminisce"              => 10515,
                         "reminiscing"            => 9705,
                         "remiss"                 => 9704,
                         "remission"              => 6435,
                         "remitting"              => 16854,
                         "remodel"                => 9944,
                         "remodeling"             => 9262,
                         "remodelling"            => 12951,
                         "remoray"                => 10217,
                         "remore"                 => 16853,
                         "remorse"                => 4615,
                         "remotely"               => 3343,
                         "remove"                 => 1723,
                         "remover"                => 8154,
                         "rendez"                 => 18132,
                         "rendezvous"             => 3443,
                         "renege"                 => 14918,
                         "reneged"                => 14151,
                         "reneging"               => 12950,
                         "renegotiate"            => 10514,
                         "renegotiating"          => 18131,
                         "renew"                  => 5474,
                         "renewing"               => 11182,
                         "renoir"                 => 10216,
                         "renounce"               => 8476,
                         "renovating"             => 11994,
                         "renquist"               => 14917,
                         "rent"                   => 1200,
                         "rental"                 => 3470,
                         "rented"                 => 2527,
                         "renting"                => 4528,
                         "rents"                  => 7101,
                         "renzo"                  => 16852,
                         "reopen"                 => 6213,
                         "reorganize"             => 11993,
                         "reorganizing"           => 15820,
                         "repaid"                 => 11181,
                         "repaint"                => 14916,
                         "repainting"             => 18130,
                         "repairman"              => 7707,
                         "reparations"            => 10513,
                         "repartee"               => 16851,
                         "repay"                  => 2664,
                         "repaying"               => 14150,
                         "repays"                 => 18129,
                         "repeat"                 => 1379,
                         "repeating"              => 3374,
                         "repel"                  => 9261,
                         "repellant"              => 18128,
                         "repellent"              => 9060,
                         "repent"                 => 7880,
                         "repentant"              => 18127,
                         "repercussions"          => 5372,
                         "repetitious"            => 15819,
                         "rephrase"               => 5946,
                         "replaceable"            => 13505,
                         "replaying"              => 14915,
                         "replenish"              => 15818,
                         "replicant"              => 18126,
                         "replicating"            => 11180,
                         "replicators"            => 13504,
                         "reporter"               => 1844,
                         "reporters"              => 2815,
                         "repossess"              => 16850,
                         "reprehensible"          => 9260,
                         "repress"                => 11563,
                         "repressed"              => 5611,
                         "repressing"             => 14149,
                         "reprieve"               => 8652,
                         "reprimand"              => 13503,
                         "reprimanded"            => 12469,
                         "reproach"               => 8651,
                         "reprobate"              => 14914,
                         "reprogram"              => 15817,
                         "reprogrammed"           => 18125,
                         "reprogramming"          => 16849,
                         "reptilian"              => 11992,
                         "repugnant"              => 11179,
                         "repulse"                => 14148,
                         "repulsive"              => 5671,
                         "reputable"              => 9943,
                         "reputation"             => 1451,
                         "reputations"            => 9471,
                         "repute"                 => 15816,
                         "requesting"             => 4402,
                         "requisite"              => 11562,
                         "requisition"            => 8843,
                         "requisitions"           => 15815,
                         "reread"                 => 15814,
                         "reroute"                => 11561,
                         "rerun"                  => 9470,
                         "reruns"                 => 8153,
                         "resale"                 => 18124,
                         "reschedule"             => 3517,
                         "rescheduled"            => 8842,
                         "rescind"                => 9259,
                         "rescued"                => 2827,
                         "rescuer"                => 15813,
                         "rescuing"               => 4338,
                         "researching"            => 5473,
                         "reseda"                 => 15812,
                         "resemblance"            => 3824,
                         "resent"                 => 2717,
                         "resented"               => 8152,
                         "resentful"              => 9059,
                         "resenting"              => 10828,
                         "resentment"             => 4684,
                         "resentments"            => 16848,
                         "resents"                => 11991,
                         "reservation"            => 2397,
                         "reservations"           => 2377,
                         "reserving"              => 15811,
                         "reset"                  => 4552,
                         "resetting"              => 16847,
                         "reshoot"                => 15810,
                         "reshoots"               => 16846,
                         "residue"                => 6070,
                         "resigning"              => 6994,
                         "resilient"              => 6434,
                         "resist"                 => 1911,
                         "resisting"              => 4807,
                         "resists"                => 14147,
                         "resolve"                => 3049,
                         "resorting"              => 14146,
                         "resounding"             => 14145,
                         "resourceful"            => 4848,
                         "respect"                => 658,
                         "respectability"         => 10512,
                         "respectable"            => 3680,
                         "respected"              => 2673,
                         "respectful"             => 6522,
                         "respectfully"           => 5670,
                         "respecting"             => 5102,
                         "respects"               => 2799,
                         "respiration"            => 8309,
                         "respirations"           => 14913,
                         "respirator"             => 4990,
                         "respite"                => 14144,
                         "respond"                => 2006,
                         "responding"             => 3185,
                         "responsibilities"       => 2663,
                         "responsibility"         => 1039,
                         "responsibly"            => 10215,
                         "responsive"             => 8841,
                         "rest"                   => 306,
                         "restaurant"             => 1027,
                         "restaurateur"           => 16845,
                         "rested"                 => 5371,
                         "restful"                => 11990,
                         "resting"                => 2847,
                         "restless"               => 3962,
                         "restock"                => 18123,
                         "reston"                 => 16844,
                         "restorative"            => 16843,
                         "restores"               => 14143,
                         "restrain"               => 6433,
                         "restraining"            => 2369,
                         "restraint"              => 4225,
                         "restraints"             => 5472,
                         "restroom"               => 5370,
                         "restrooms"              => 11560,
                         "rests"                  => 4921,
                         "resumes"                => 8308,
                         "resurface"              => 14142,
                         "resurrect"              => 9703,
                         "resuscitate"            => 9469,
                         "resuscitated"           => 18122,
                         "retainer"               => 5369,
                         "retaliate"              => 5945,
                         "retaliating"            => 16842,
                         "retaliatory"            => 13502,
                         "retarded"               => 4847,
                         "retards"                => 9702,
                         "retentive"              => 14141,
                         "retest"                 => 16841,
                         "rethink"                => 3748,
                         "rethinking"             => 8151,
                         "rethought"              => 15809,
                         "retinal"                => 8150,
                         "retinas"                => 14912,
                         "reting"                 => 18121,
                         "retire"                 => 3328,
                         "retires"                => 9468,
                         "retort"                 => 14911,
                         "retrace"                => 9467,
                         "retract"                => 7577,
                         "retraction"             => 6993,
                         "retractor"              => 9701,
                         "retrial"                => 18120,
                         "retribution"            => 6134,
                         "retrieval"              => 5610,
                         "retrieve"               => 4429,
                         "retriever"              => 9942,
                         "retrieving"             => 12949,
                         "retro"                  => 5065,
                         "retrofit"               => 14910,
                         "retrograde"             => 11989,
                         "retrospect"             => 9258,
                         "reunion"                => 2290,
                         "reunions"               => 11178,
                         "reunite"                => 6777,
                         "revamp"                 => 13501,
                         "reveal"                 => 2443,
                         "revel"                  => 9700,
                         "reveling"               => 16840,
                         "revenge"                => 1204,
                         "revere"                 => 8650,
                         "reverend"               => 2067,
                         "reverently"             => 11988,
                         "reverse"                => 2075,
                         "revert"                 => 8840,
                         "reverts"                => 14909,
                         "revise"                 => 11177,
                         "revisit"                => 7456,
                         "revisiting"             => 14140,
                         "revlon"                 => 6354,
                         "revoir"                 => 6212,
                         "revoke"                 => 7879,
                         "revoked"                => 6069,
                         "revoking"               => 14908,
                         "revolting"              => 7455,
                         "revolutionize"          => 12468,
                         "revolve"                => 6016,
                         "revulsion"              => 11987,
                         "revved"                 => 9941,
                         "reward"                 => 2021,
                         "rewarding"              => 5419,
                         "rewind"                 => 5154,
                         "rewire"                 => 9940,
                         "rewired"                => 18119,
                         "rewrite"                => 4769,
                         "rewrites"               => 14907,
                         "rewriting"              => 7878,
                         "rewrote"                => 13500,
                         "reykjavik"              => 8839,
                         "rheingold"              => 14906,
                         "rhetorical"             => 6353,
                         "rheya"                  => 10827,
                         "rheza"                  => 14139,
                         "rhinestone"             => 11559,
                         "rhinestones"            => 12948,
                         "rhyme"                  => 4134,
                         "rhymed"                 => 14905,
                         "rhyming"                => 9699,
                         "rialto"                 => 11558,
                         "riana"                  => 7454,
                         "rianna"                 => 2190,
                         "ribbon"                 => 3316,
                         "ribbons"                => 6776,
                         "ribcage"                => 18118,
                         "rible"                  => 14138,
                         "ribs"                   => 2909,
                         "richardo"               => 15808,
                         "richer"                 => 3626,
                         "richest"                => 5036,
                         "rickets"                => 14137,
                         "rickety"                => 16839,
                         "rickshaw"               => 11557,
                         "riddance"               => 5322,
                         "ridding"                => 11556,
                         "riddled"                => 10214,
                         "riddles"                => 6885,
                         "ride"                   => 595,
                         "rides"                  => 2946,
                         "ridge"                  => 618,
                         "ridicule"               => 7100,
                         "ridiculed"              => 9058,
                         "ridiculous"             => 754,
                         "ridiculously"           => 7099,
                         "ridin"                  => 6133,
                         "riding"                 => 1434,
                         "riedenschneider"        => 9698,
                         "rieper"                 => 11176,
                         "riffing"                => 18117,
                         "rifkin"                 => 11175,
                         "rifling"                => 11986,
                         "rigged"                 => 3994,
                         "right"                  => 28,
                         "righteous"              => 2783,
                         "righteousness"          => 7214,
                         "rightful"               => 5035,
                         "rightfully"             => 5242,
                         "rightly"                => 8149,
                         "righto"                 => 12947,
                         "righty"                 => 3289,
                         "rigoletto"              => 15807,
                         "riled"                  => 5783,
                         "rimbaud"                => 6432,
                         "rincess"                => 16838,
                         "rinds"                  => 9466,
                         "ring"                   => 591,
                         "ringers"                => 12946,
                         "ringin"                 => 16837,
                         "ringing"                => 2311,
                         "ringleader"             => 18116,
                         "rings"                  => 1819,
                         "ringside"               => 10511,
                         "ringwald"               => 14904,
                         "rinse"                  => 5888,
                         "rinsing"                => 16836,
                         "rioja"                  => 11174,
                         "riot"                   => 2533,
                         "ripe"                   => 4712,
                         "ripped"                 => 1816,
                         "rippin"                 => 16835,
                         "ripping"                => 3388,
                         "ripples"                => 15806,
                         "rippling"               => 15805,
                         "risk"                   => 751,
                         "risked"                 => 2964,
                         "risking"                => 2956,
                         "risks"                  => 2460,
                         "risky"                  => 2501,
                         "risotto"                => 7706,
                         "ristle"                 => 11985,
                         "ristorante"             => 16834,
                         "ritalin"                => 6775,
                         "ritten"                 => 15804,
                         "rittle"                 => 16833,
                         "ritual"                 => 2639,
                         "ritualistic"            => 14903,
                         "ritzy"                  => 14902,
                         "riverbank"              => 9057,
                         "riveted"                => 13499,
                         "riveting"               => 11984,
                         "riviera"                => 5669,
                         "roaches"                => 9465,
                         "roadblock"              => 9056,
                         "roadblocks"             => 7877,
                         "roadhouse"              => 13498,
                         "roadies"                => 15803,
                         "roadshow"               => 14136,
                         "roaming"                => 5668,
                         "roar"                   => 4647,
                         "roared"                 => 18115,
                         "roaring"                => 6686,
                         "roast"                  => 2526,
                         "roasted"                => 5667,
                         "roasting"               => 8148,
                         "roasts"                 => 15802,
                         "robbed"                 => 2439,
                         "robber"                 => 5520,
                         "robberies"              => 6132,
                         "robbers"                => 5034,
                         "robbery"                => 2051,
                         "robbing"                => 4115,
                         "robe"                   => 2754,
                         "robechaux"              => 9257,
                         "robes"                  => 5101,
                         "robinsons"              => 14901,
                         "rocked"                 => 6211,
                         "rockettes"              => 18114,
                         "rocking"                => 4583,
                         "rode"                   => 2974,
                         "rohypnol"               => 15801,
                         "roldy"                  => 14135,
                         "rolfie"                 => 14900,
                         "rolfski"                => 18113,
                         "rolfsky"                => 10510,
                         "roll"                   => 907,
                         "rolled"                 => 2782,
                         "rollerblades"           => 15800,
                         "rollerblading"          => 14134,
                         "rollercoaster"          => 14899,
                         "rollers"                => 6992,
                         "rolling"                => 1635,
                         "rolls"                  => 2655,
                         "rolltop"                => 18112,
                         "romance"                => 1550,
                         "romances"               => 8649,
                         "romancing"              => 11173,
                         "romanica"               => 18111,
                         "romanovs"               => 14898,
                         "romantic"               => 857,
                         "romantically"           => 6210,
                         "romanticize"            => 16832,
                         "romantics"              => 14133,
                         "romari"                 => 18110,
                         "romper"                 => 14897,
                         "romping"                => 12467,
                         "rondall"                => 11555,
                         "rondell"                => 13497,
                         "ronee"                  => 6521,
                         "roof"                   => 1126,
                         "roofie"                 => 16831,
                         "roofies"                => 14132,
                         "rooftop"                => 7453,
                         "rooftops"               => 7576,
                         "roofy"                  => 16830,
                         "room"                   => 190,
                         "roomed"                 => 18109,
                         "roomful"                => 8475,
                         "roomie"                 => 6607,
                         "roomies"                => 9464,
                         "rooming"                => 8648,
                         "roommate"               => 1790,
                         "roommates"              => 3861,
                         "roomy"                  => 12466,
                         "roost"                  => 12465,
                         "rootie"                 => 16829,
                         "rootin"                 => 14896,
                         "rooting"                => 5241,
                         "rope"                   => 1981,
                         "roped"                  => 8020,
                         "ropes"                  => 4337,
                         "rosalita"               => 15799,
                         "rosary"                 => 9256,
                         "rosasharn"              => 13496,
                         "rosco"                  => 5321,
                         "rosebush"               => 13495,
                         "roses"                  => 2130,
                         "roshman"                => 9463,
                         "roslin"                 => 18108,
                         "rosomorf"               => 10213,
                         "rosses"                 => 12464,
                         "rosslyn"                => 12463,
                         "rostle"                 => 11983,
                         "roston"                 => 11982,
                         "rotarian"               => 18107,
                         "rotisserie"             => 16828,
                         "rotted"                 => 11554,
                         "rotting"                => 4492,
                         "rottweiler"             => 14131,
                         "rough"                  => 981,
                         "roughage"               => 16827,
                         "roughed"                => 9255,
                         "rougher"                => 12462,
                         "roughing"               => 11553,
                         "roughnecks"             => 12461,
                         "roulette"               => 8307,
                         "rounding"               => 7705,
                         "roundup"                => 9254,
                         "rousing"                => 10212,
                         "roust"                  => 13494,
                         "rousted"                => 14895,
                         "rousting"               => 18106,
                         "routine"                => 1575,
                         "roving"                 => 10211,
                         "rowboat"                => 10509,
                         "roxbury"                => 9939,
                         "roxy"                   => 1692,
                         "royally"                => 7876,
                         "royalty"                => 3937,
                         "rsquo"                  => 4038,
                         "rsvp'd"                 => 14894,
                         "rubbed"                 => 4882,
                         "rubbers"                => 16826,
                         "rubbery"                => 18105,
                         "rubbing"                => 3209,
                         "rubbish"                => 5782,
                         "rubes"                  => 15798,
                         "ruckus"                 => 7875,
                         "rudabaga"               => 14130,
                         "rude"                   => 1351,
                         "rudely"                 => 13493,
                         "rudeness"               => 11172,
                         "rudest"                 => 18104,
                         "rueland"                => 14129,
                         "ruffians"               => 15797,
                         "ruffle"                 => 11552,
                         "ruffled"                => 12460,
                         "ruijven"                => 12945,
                         "ruin"                   => 866,
                         "ruination"              => 14128,
                         "ruined"                 => 1050,
                         "ruining"                => 2088,
                         "rulebook"               => 16825,
                         "rules"                  => 748,
                         "rumba"                  => 16824,
                         "rumbling"               => 12944,
                         "rumblings"              => 12943,
                         "rummage"                => 9462,
                         "rummaging"              => 8474,
                         "rummy"                  => 8838,
                         "rumor"                  => 2208,
                         "rumors"                 => 2694,
                         "rumour"                 => 4711,
                         "rumpled"                => 16823,
                         "rumpus"                 => 11551,
                         "rumson"                 => 7704,
                         "run"                    => 263,
                         "runaround"              => 10826,
                         "runaways"               => 10825,
                         "rundown"                => 6884,
                         "runes"                  => 12942,
                         "runneth"                => 15796,
                         "runnin"                 => 3730,
                         "running"                => 412,
                         "runny"                  => 7874,
                         "ruptured"               => 6685,
                         "rushdie"                => 16822,
                         "rushed"                 => 2762,
                         "rusik"                  => 8306,
                         "russe"                  => 9461,
                         "russells"               => 10508,
                         "russians"               => 3650,
                         "rusted"                 => 10507,
                         "rusting"                => 14127,
                         "rustle"                 => 10210,
                         "rustling"               => 9938,
                         "ruthless"               => 3528,
                         "ruthlessly"             => 15795,
                         "ruttheimer"             => 18103,
                         "rutting"                => 15794,
                         "rya'c"                  => 7873,
                         "rydell"                 => 8305,
                         "rygalski"               => 14126,
                         "s'aright"               => 18102,
                         "s'cuse"                 => 15793,
                         "s'more"                 => 11171,
                         "s'mores"                => 8019,
                         "s'okay"                 => 14893,
                         "s'pose"                 => 11981,
                         "s'posed"                => 6520,
                         "sabath"                 => 18101,
                         "sabbatical"             => 8837,
                         "saberhagen"             => 7098,
                         "sabers"                 => 12941,
                         "sabotage"               => 3263,
                         "sabotaged"              => 5609,
                         "sabotaging"             => 7703,
                         "sabrini"                => 18100,
                         "sacamano"               => 16821,
                         "saccharine"             => 16820,
                         "sack"                   => 2345,
                         "sacre"                  => 16819,
                         "sacrifice"              => 1719,
                         "sacrificed"             => 3567,
                         "sacrifices"             => 3589,
                         "sacrificing"            => 5781,
                         "sacrilege"              => 11550,
                         "sacrilegious"           => 18099,
                         "saddam"                 => 4401,
                         "saddened"               => 10824,
                         "saddens"                => 14125,
                         "sadder"                 => 6431,
                         "saddest"                => 5780,
                         "saddle"                 => 3747,
                         "saddled"                => 8473,
                         "sadism"                 => 18098,
                         "sadist"                 => 8304,
                         "sadistic"               => 6352,
                         "sadly"                  => 3711,
                         "sadness"                => 3665,
                         "safe"                   => 405,
                         "safecracker"            => 18097,
                         "safehouse"              => 12940,
                         "safekeeping"            => 9460,
                         "safely"                 => 2289,
                         "safer"                  => 2373,
                         "safes"                  => 13492,
                         "safest"                 => 4582,
                         "saget"                  => 14124,
                         "sagging"                => 15792,
                         "sagittarius"            => 16818,
                         "sagman"                 => 14892,
                         "sahjhan"                => 10209,
                         "said"                   => 93,
                         "sail"                   => 2569,
                         "sailboats"              => 16817,
                         "sainted"                => 9697,
                         "sainthood"              => 14123,
                         "saintly"                => 10823,
                         "saith"                  => 16816,
                         "sake"                   => 686,
                         "sakes"                  => 1757,
                         "sakulos"                => 12939,
                         "salad"                  => 1644,
                         "salads"                 => 6883,
                         "salary"                 => 2693,
                         "salem"                  => 994,
                         "salesman"               => 2438,
                         "salesmen"               => 8647,
                         "salesperson"            => 12938,
                         "saleswoman"             => 15791,
                         "salieri"                => 9937,
                         "saline"                 => 6882,
                         "salino"                 => 18096,
                         "salish"                 => 16815,
                         "saliva"                 => 5519,
                         "salivating"             => 14122,
                         "sallow"                 => 18095,
                         "salmonella"             => 11549,
                         "salsa"                  => 4428,
                         "saltines"               => 11980,
                         "salty"                  => 5195,
                         "salud"                  => 12459,
                         "salutations"            => 14891,
                         "salute"                 => 3834,
                         "saluted"                => 16814,
                         "saluting"               => 12458,
                         "salvage"                => 3625,
                         "salvaging"              => 11548,
                         "salvy"                  => 10506,
                         "samaritan"              => 5839,
                         "sami"                   => 1123,
                         "samool"                 => 18094,
                         "sanctimonious"          => 8147,
                         "sanctity"               => 6131,
                         "sanctum"                => 10208,
                         "sand"                   => 1917,
                         "sandals"                => 6991,
                         "sandalwood"             => 14890,
                         "sandbag"                => 11979,
                         "sandbar"                => 16813,
                         "sandbox"                => 8646,
                         "sandburg"               => 1881,
                         "sanded"                 => 13491,
                         "sandeman"               => 8836,
                         "sanding"                => 15790,
                         "sandovals"              => 15789,
                         "sandpaper"              => 12457,
                         "sandstorm"              => 14889,
                         "sandwich"               => 1576,
                         "sandwiches"             => 2333,
                         "sane"                   => 2824,
                         "sanest"                 => 12937,
                         "sangria"                => 10207,
                         "sanitarium"             => 13490,
                         "sankara"                => 12936,
                         "santangel"              => 18093,
                         "santas"                 => 15788,
                         "santen"                 => 14121,
                         "santoses"               => 9253,
                         "santy"                  => 12935,
                         "sapiens"                => 11547,
                         "sapphires"              => 13489,
                         "sappy"                  => 5838,
                         "sarcasm"                => 4009,
                         "sarcastic"              => 3877,
                         "sarcoidosis"            => 16812,
                         "sarcophagus"            => 10505,
                         "sardine"                => 14888,
                         "sardines"               => 10504,
                         "sarge"                  => 3860,
                         "sark"                   => 3900,
                         "sarnia"                 => 18092,
                         "sarong"                 => 18091,
                         "sarris"                 => 7097,
                         "sartorius"              => 14120,
                         "sasquatch"              => 11978,
                         "satch"                  => 11170,
                         "satin"                  => 5518,
                         "satine"                 => 11546,
                         "satisfaction"           => 2842,
                         "satisfied"              => 1746,
                         "satisfy"                => 3566,
                         "satisfying"             => 4400,
                         "saturday"               => 1093,
                         "satyr"                  => 9055,
                         "sauce"                  => 1800,
                         "saucer"                 => 6280,
                         "saucers"                => 10822,
                         "sauces"                 => 14119,
                         "saucy"                  => 9252,
                         "saudis"                 => 15787,
                         "sauerkraut"             => 10503,
                         "saugus"                 => 11977,
                         "sauna"                  => 5779,
                         "saute"                  => 16811,
                         "savagely"               => 15786,
                         "savagery"               => 18090,
                         "savages"                => 7872,
                         "save"                   => 394,
                         "saved"                  => 694,
                         "saver"                  => 7332,
                         "saves"                  => 3746,
                         "savin"                  => 11545,
                         "saving"                 => 1075,
                         "savoir"                 => 18089,
                         "savor"                  => 6351,
                         "savored"                => 16810,
                         "savoring"               => 14887,
                         "savour"                 => 16809,
                         "savvy"                  => 5778,
                         "saw"                    => 200,
                         "sawchuk"                => 11976,
                         "sawed"                  => 14886,
                         "sawing"                 => 11544,
                         "say"                    => 68,
                         "saybrooke"              => 14885,
                         "sayeth"                 => 14884,
                         "sayin"                  => 2620,
                         "saying"                 => 205,
                         "sayonara"               => 8472,
                         "says"                   => 298,
                         "scabs"                  => 10821,
                         "scaffolding"            => 14118,
                         "scagnetti"              => 11975,
                         "scald"                  => 16808,
                         "scalding"               => 14883,
                         "scallions"              => 16807,
                         "scallop"                => 14882,
                         "scalloped"              => 18088,
                         "scallops"               => 13488,
                         "scalp"                  => 5153,
                         "scalped"                => 14881,
                         "scalpel"                => 4962,
                         "scalper"                => 12934,
                         "scalping"               => 14880,
                         "scalps"                 => 14117,
                         "scaly"                  => 14116,
                         "scam"                   => 2106,
                         "scammed"                => 8146,
                         "scamming"               => 5152,
                         "scampered"              => 15785,
                         "scamps"                 => 18087,
                         "scams"                  => 6015,
                         "scan"                   => 2581,
                         "scandalous"             => 9696,
                         "scanned"                => 9054,
                         "scanners"               => 10502,
                         "scans"                  => 7871,
                         "scapegoat"              => 8471,
                         "scar"                   => 2509,
                         "scarce"                 => 5151,
                         "scarcely"               => 10206,
                         "scare"                  => 1060,
                         "scarecrow"              => 3810,
                         "scared"                 => 462,
                         "scaredy"                => 11974,
                         "scares"                 => 2084,
                         "scarf"                  => 2413,
                         "scarfing"               => 16806,
                         "scarier"                => 6279,
                         "scariest"               => 8145,
                         "scarin"                 => 16805,
                         "scaring"                => 2063,
                         "scarred"                => 5777,
                         "scarring"               => 9936,
                         "scars"                  => 3649,
                         "scarsdale"              => 10820,
                         "scarves"                => 8645,
                         "scary"                  => 1153,
                         "scatter"                => 5887,
                         "scavenger"              => 11169,
                         "scavenging"             => 16804,
                         "scenario"               => 2365,
                         "scenery"                => 4370,
                         "scent"                  => 3230,
                         "scented"                => 6990,
                         "scents"                 => 14879,
                         "scepter"                => 7096,
                         "scepters"               => 14115,
                         "schedule"               => 1139,
                         "schedules"              => 5240,
                         "schematics"             => 8835,
                         "schemed"                => 12933,
                         "schemer"                => 9695,
                         "scheming"               => 4336,
                         "schenkman"              => 11543,
                         "schibetta"              => 5886,
                         "schillinger"            => 4456,
                         "schizo"                 => 14878,
                         "schizoid"               => 15784,
                         "schizophrenic"          => 7870,
                         "schlep"                 => 14877,
                         "schlub"                 => 16803,
                         "schmancy"               => 18086,
                         "schmo"                  => 15783,
                         "schmooze"               => 14876,
                         "schmoozing"             => 13487,
                         "schmuck"                => 5517,
                         "schmucks"               => 14114,
                         "schnapps"               => 6519,
                         "schnauzer"              => 15782,
                         "schnitzel"              => 12932,
                         "schnoz"                 => 14875,
                         "schoolboy"              => 8018,
                         "schooled"               => 8017,
                         "schoolers"              => 14113,
                         "schoolgirl"             => 6209,
                         "schoolwork"             => 6606,
                         "schoolyard"             => 9935,
                         "schotzie"               => 14874,
                         "schreber"               => 18085,
                         "scintillating"          => 13486,
                         "scissor"                => 16802,
                         "scissorhands"           => 18084,
                         "scissors"               => 3184,
                         "scoff"                  => 10501,
                         "scold"                  => 9934,
                         "scolded"                => 16801,
                         "scolding"               => 12931,
                         "scoliosis"              => 11973,
                         "scone"                  => 7575,
                         "scones"                 => 7095,
                         "scooch"                 => 12930,
                         "scoop"                  => 3315,
                         "scooped"                => 11168,
                         "scooping"               => 13485,
                         "scoops"                 => 11167,
                         "scoot"                  => 5033,
                         "scopes"                 => 15781,
                         "scoping"                => 12929,
                         "scorched"               => 9053,
                         "scorcher"               => 14873,
                         "scorching"              => 12456,
                         "scorecard"              => 14112,
                         "scorn"                  => 9459,
                         "scorned"                => 7331,
                         "scotches"               => 16800,
                         "scoundrel"              => 6881,
                         "scoundrels"             => 10819,
                         "scour"                  => 9933,
                         "scoured"                => 12455,
                         "scourge"                => 7452,
                         "scouring"               => 14111,
                         "scowl"                  => 9458,
                         "scowling"               => 14110,
                         "scram"                  => 5666,
                         "scramble"               => 7574,
                         "scrambled"              => 4303,
                         "scrambler"              => 15780,
                         "scrambling"             => 8834,
                         "scrap"                  => 4846,
                         "scrapbook"              => 6774,
                         "scrape"                 => 4189,
                         "scraped"                => 7094,
                         "scrapes"                => 8644,
                         "scraping"               => 6130,
                         "scrapings"              => 12454,
                         "scraps"                 => 6684,
                         "scratch"                => 1818,
                         "scratched"              => 4078,
                         "scratches"              => 5608,
                         "scratching"             => 4206,
                         "scratchy"               => 6350,
                         "scrawny"                => 6068,
                         "screamed"               => 3648,
                         "screamin"               => 9251,
                         "screaming"              => 1319,
                         "screams"                => 4037,
                         "screech"                => 2841,
                         "screeching"             => 9052,
                         "screw"                  => 1033,
                         "screwball"              => 12928,
                         "screwdriver"            => 5239,
                         "screwed"                => 1114,
                         "screwin"                => 10818,
                         "screwing"               => 2437,
                         "screws"                 => 3859,
                         "screwup"                => 8643,
                         "screwups"               => 11542,
                         "scribbled"              => 16799,
                         "scribbling"             => 13484,
                         "scroll"                 => 3327,
                         "scrote"                 => 11541,
                         "scrounge"               => 8470,
                         "scrounging"             => 13483,
                         "scrub"                  => 3788,
                         "scrubbed"               => 8642,
                         "scrubbing"              => 6129,
                         "scrubs"                 => 6683,
                         "scrumptious"            => 9250,
                         "scrunch"                => 11540,
                         "scrunched"              => 18083,
                         "scrunchie"              => 16798,
                         "scruples"               => 6682,
                         "scrutinized"            => 16797,
                         "scrying"                => 9249,
                         "scudder"                => 2301,
                         "scuff"                  => 12927,
                         "scuffle"                => 10500,
                         "scullery"               => 14872,
                         "sculpt"                 => 14109,
                         "scum"                   => 2471,
                         "scumbag"                => 5238,
                         "scumbags"               => 10817,
                         "scummy"                 => 16796,
                         "scurrying"              => 11539,
                         "scurvy"                 => 11972,
                         "scusa"                  => 18082,
                         "scuse"                  => 3456,
                         "scuttlebutt"            => 14108,
                         "scuttling"              => 18081,
                         "scuzzlebutt"            => 10816,
                         "scuzzy"                 => 16795,
                         "seabea"                 => 12926,
                         "seabeas"                => 11166,
                         "seaboard"               => 7330,
                         "seaborn"                => 4743,
                         "seafood"                => 6349,
                         "seahaven"               => 14871,
                         "sealant"                => 18080,
                         "sealed"                 => 2197,
                         "seams"                  => 6067,
                         "seamstress"             => 11165,
                         "seance"                 => 9457,
                         "search"                 => 1057,
                         "searched"               => 3037,
                         "searching"              => 1897,
                         "seared"                 => 13482,
                         "searing"                => 14107,
                         "seascape"               => 12453,
                         "seashells"              => 15779,
                         "seasick"                => 9694,
                         "seasoned"               => 8641,
                         "seatbelt"               => 8144,
                         "seatbelts"              => 9932,
                         "seated"                 => 3208,
                         "sebacio"                => 16794,
                         "secaucus"               => 18079,
                         "secluded"               => 6681,
                         "seclusion"              => 11164,
                         "secondhand"             => 9456,
                         "secondly"               => 4491,
                         "seconds"                => 793,
                         "secrecy"                => 3961,
                         "secretarial"            => 16793,
                         "secretaries"            => 6880,
                         "secretions"             => 14106,
                         "secretive"              => 5237,
                         "secretly"               => 3302,
                         "secrets"                => 1008,
                         "secure"                 => 1643,
                         "securely"               => 11538,
                         "sedate"                 => 6989,
                         "sedated"                => 5100,
                         "sedation"               => 10815,
                         "sedative"               => 4055,
                         "sedatives"              => 9051,
                         "sedley"                 => 9931,
                         "seduce"                 => 2257,
                         "seduced"                => 3977,
                         "seduces"                => 11163,
                         "seducing"               => 5236,
                         "seduction"              => 6014,
                         "seductress"             => 18078,
                         "see"                    => 49,
                         "seedy"                  => 7213,
                         "seein"                  => 5368,
                         "seeing"                 => 434,
                         "seem"                   => 403,
                         "seemed"                 => 788,
                         "seeming"                => 9930,
                         "seems"                  => 395,
                         "seen"                   => 240,
                         "seeping"                => 11537,
                         "seeps"                  => 18077,
                         "seers"                  => 18076,
                         "sees"                   => 983,
                         "seething"               => 14105,
                         "seeya"                  => 6518,
                         "sefelt"                 => 13481,
                         "segretti"               => 11536,
                         "segue"                  => 10814,
                         "seinfelds"              => 18075,
                         "seize"                  => 3809,
                         "seizes"                 => 15778,
                         "seizing"                => 8469,
                         "seizure"                => 4551,
                         "seizures"               => 5776,
                         "selectman"              => 13480,
                         "selfish"                => 1299,
                         "selfishly"              => 10205,
                         "selfishness"            => 6773,
                         "selfless"               => 3960,
                         "selflessly"             => 18074,
                         "selflessness"           => 12925,
                         "sell"                   => 773,
                         "sellin"                 => 8640,
                         "selmak"                 => 11162,
                         "selves"                 => 6605,
                         "selznick"               => 16792,
                         "semanski"               => 18073,
                         "semantics"              => 7869,
                         "semblance"              => 10813,
                         "semen"                  => 5775,
                         "semester"               => 2459,
                         "semiautomatic"          => 16791,
                         "seminar"                => 4369,
                         "semis"                  => 18072,
                         "semite"                 => 16790,
                         "semtex"                 => 9455,
                         "send"                   => 460,
                         "sendin"                 => 18071,
                         "sending"                => 1178,
                         "sendoff"                => 11971,
                         "sends"                  => 2387,
                         "senile"                 => 7329,
                         "senility"               => 16789,
                         "senor"                  => 4742,
                         "senora"                 => 6879,
                         "senores"                => 18070,
                         "senorita"               => 14868,
                         "sensation"              => 4961,
                         "sensational"            => 4806,
                         "sensations"             => 9248,
                         "sense"                  => 424,
                         "sensed"                 => 3547,
                         "senseless"              => 5418,
                         "senses"                 => 2019,
                         "sensible"               => 3767,
                         "sensing"                => 4224,
                         "sensitive"              => 1332,
                         "sensitivity"            => 4188,
                         "sensual"                => 6430,
                         "sensuality"             => 14104,
                         "sensuous"               => 14870,
                         "sentance"               => 14103,
                         "sentence"               => 1374,
                         "sentencing"             => 4276,
                         "sentiment"              => 5320,
                         "sentimental"            => 3195,
                         "sentimentality"         => 9693,
                         "sentiments"             => 7573,
                         "sentinels"              => 10204,
                         "sentries"               => 14102,
                         "seppuku"                => 16788,
                         "sepsis"                 => 18069,
                         "septic"                 => 7212,
                         "septum"                 => 12924,
                         "sequestered"            => 11161,
                         "sequined"               => 15777,
                         "sequins"                => 12452,
                         "serafine"               => 9692,
                         "serenade"               => 10499,
                         "serene"                 => 7093,
                         "sergeant"               => 1829,
                         "serious"                => 377,
                         "seriously"              => 734,
                         "seriousness"            => 8016,
                         "sermon"                 => 6013,
                         "serum"                  => 3455,
                         "servants"               => 3128,
                         "serviceable"            => 18068,
                         "servings"               => 15776,
                         "servitude"              => 12451,
                         "sesterces"              => 14869,
                         "setback"                => 4490,
                         "setbacks"               => 9050,
                         "settin"                 => 10203,
                         "settle"                 => 1063,
                         "settling"               => 3516,
                         "setup"                  => 2449,
                         "seuss"                  => 10498,
                         "seventeen"              => 2114,
                         "seventies"              => 6988,
                         "seventy"                => 1703,
                         "sever"                  => 7328,
                         "severed"                => 5150,
                         "sewed"                  => 8143,
                         "sewer"                  => 3326,
                         "sewers"                 => 5149,
                         "sewing"                 => 4881,
                         "sex"                    => 459,
                         "sexier"                 => 6772,
                         "sexiest"                => 6429,
                         "sexist"                 => 4768,
                         "sexless"                => 12923,
                         "sextant"                => 18067,
                         "sexually"               => 3194,
                         "sha'nauc"               => 18066,
                         "sha're"                 => 12450,
                         "shabbas"                => 16787,
                         "shabbily"               => 16786,
                         "shabby"                 => 6066,
                         "shack"                  => 3496,
                         "shacked"                => 7211,
                         "shacking"               => 5837,
                         "shackle"                => 16785,
                         "shackled"               => 11160,
                         "shackles"               => 9049,
                         "shaddup"                => 14867,
                         "shades"                 => 4767,
                         "shadoe"                 => 13479,
                         "shadowing"              => 13478,
                         "shadows"                => 2055,
                         "shadowy"                => 8468,
                         "shaft"                  => 3485,
                         "shafted"                => 12922,
                         "shafter"                => 18065,
                         "shagged"                => 14866,
                         "shagging"               => 10812,
                         "shake"                  => 1232,
                         "shakedown"              => 9247,
                         "shaken"                 => 3257,
                         "shakers"                => 11970,
                         "shakes"                 => 4427,
                         "shakin"                 => 8142,
                         "shaking"                => 1971,
                         "shaky"                  => 4036,
                         "shall"                  => 593,
                         "shallots"               => 18064,
                         "shallow"                => 2662,
                         "shallows"               => 16784,
                         "shalt"                  => 5064,
                         "sham"                   => 4845,
                         "shambles"               => 7092,
                         "shame"                  => 1150,
                         "shamed"                 => 8303,
                         "shameful"               => 7210,
                         "shameless"              => 5471,
                         "shamelessly"            => 9691,
                         "shaming"                => 16783,
                         "shampoos"               => 18063,
                         "shamu"                  => 12449,
                         "shan't"                 => 8833,
                         "shanghaied"             => 11969,
                         "shangri"                => 10497,
                         "shannen"                => 9454,
                         "shanshu"                => 15775,
                         "shapely"                => 12921,
                         "shapeshifter"           => 13477,
                         "shapetype"              => 16782,
                         "shaping"                => 6604,
                         "shaquille"              => 15774,
                         "shards"                 => 11159,
                         "share"                  => 628,
                         "shareef"                => 10496,
                         "sharifa"                => 18062,
                         "sharing"                => 1592,
                         "sharkbait"              => 8832,
                         "sharking"               => 14865,
                         "sharpen"                => 9453,
                         "sharpened"              => 13476,
                         "sharpener"              => 12920,
                         "sharpening"             => 11968,
                         "sharpens"               => 15773,
                         "sharper"                => 8302,
                         "sharpest"               => 8467,
                         "sharpshooters"          => 14864,
                         "shatner"                => 12919,
                         "shatter"                => 6517,
                         "shattered"              => 3527,
                         "shattering"             => 6065,
                         "shatters"               => 18061,
                         "shavadai"               => 14863,
                         "shave"                  => 2545,
                         "shaves"                 => 12918,
                         "shaving"                => 3808,
                         "shavings"               => 18060,
                         "shawl"                  => 8015,
                         "shawshank"              => 12448,
                         "she'd"                  => 705,
                         "she'll"                 => 482,
                         "she's"                  => 78,
                         "shebang"                => 11967,
                         "shed"                   => 2123,
                         "shedlow"                => 18059,
                         "sheeit"                 => 11158,
                         "sheeny"                 => 16781,
                         "sheepskin"              => 15772,
                         "sheer"                  => 3807,
                         "sheesh"                 => 9048,
                         "sheet"                  => 2201,
                         "sheetrock"              => 12447,
                         "shelbyville"            => 15771,
                         "sheldrake"              => 5715,
                         "shelf"                  => 3160,
                         "shelled"                => 10495,
                         "shellfish"              => 8466,
                         "shelter"                => 2039,
                         "shelve"                 => 15770,
                         "shelves"                => 5607,
                         "shelving"               => 18058,
                         "shenanigans"            => 5836,
                         "shepherds"              => 8014,
                         "sheraton"               => 11966,
                         "sherborne"              => 14862,
                         "sheridan"               => 526,
                         "sheriff"                => 1543,
                         "shhh"                   => 1998,
                         "shhhh"                  => 4527,
                         "shhhhh"                 => 7702,
                         "shhhhhh"                => 10494,
                         "shiatsu"                => 14101,
                         "shielding"              => 9690,
                         "shift"                  => 1401,
                         "shiftless"              => 18057,
                         "shifts"                 => 3245,
                         "shifu"                  => 15769,
                         "shiller"                => 9246,
                         "shimmering"             => 10811,
                         "shimokawa"              => 14861,
                         "shindig"                => 5319,
                         "shine"                  => 2328,
                         "shined"                 => 9929,
                         "shines"                 => 5944,
                         "shining"                => 2781,
                         "shins"                  => 12446,
                         "shiny"                  => 2963,
                         "shipmates"              => 18056,
                         "shipment"               => 3183,
                         "shipped"                => 3526,
                         "shipshape"              => 15768,
                         "shipwrecked"            => 12445,
                         "shirking"               => 12917,
                         "shirt"                  => 979,
                         "shirtless"              => 15767,
                         "shirts"                 => 2497,
                         "shish"                  => 12444,
                         "shit"                   => 378,
                         "shite"                  => 9689,
                         "shitfaced"              => 18055,
                         "shitheads"              => 18054,
                         "shithouse"              => 15766,
                         "shitless"               => 10202,
                         "shitload"               => 8465,
                         "shits"                  => 6680,
                         "shitstorm"              => 16780,
                         "shittin"                => 12443,
                         "shitting"               => 7209,
                         "shivering"              => 6771,
                         "shizzit"                => 18053,
                         "shmancy"                => 18052,
                         "shmoopy"                => 8831,
                         "shock"                  => 1167,
                         "shocked"                => 1805,
                         "shocking"               => 3698,
                         "shockingly"             => 12916,
                         "shocks"                 => 7868,
                         "shoddy"                 => 10493,
                         "shoe"                   => 1372,
                         "shoebox"                => 9047,
                         "shoehorn"               => 15765,
                         "shoelace"               => 11157,
                         "shoelaces"              => 8464,
                         "shoes"                  => 810,
                         "shol'va"                => 13475,
                         "shone"                  => 13474,
                         "shoo"                   => 4399,
                         "shoot"                  => 598,
                         "shooters"               => 5417,
                         "shootin"                => 6516,
                         "shooting"               => 1156,
                         "shoots"                 => 3442,
                         "shop"                   => 901,
                         "shopkeeper"             => 15764,
                         "shopkeepers"            => 18051,
                         "shoplift"               => 14100,
                         "shoplifter"             => 14860,
                         "shoplifters"            => 16779,
                         "shoplifting"            => 5566,
                         "shopped"                => 10810,
                         "shoppers"               => 9452,
                         "shopping"               => 1102,
                         "shortbread"             => 18050,
                         "shortcake"              => 12915,
                         "shortcomings"           => 8639,
                         "shortcut"               => 5665,
                         "shortcuts"              => 9688,
                         "shorted"                => 11156,
                         "shorthand"              => 8301,
                         "shorthanded"            => 12442,
                         "shorting"               => 18049,
                         "shortness"              => 8300,
                         "shorts"                 => 2807,
                         "shortsighted"           => 15763,
                         "shot"                   => 409,
                         "shotguns"               => 8463,
                         "shots"                  => 1398,
                         "should"                 => 91,
                         "should'a"               => 12914,
                         "should've"              => 798,
                         "shoulda"                => 2826,
                         "shoulder"               => 1342,
                         "shoulders"              => 2045,
                         "shouldn't"              => 361,
                         "shouldn't've"           => 14099,
                         "shouldn'ta"             => 16778,
                         "shout"                  => 3048,
                         "shouted"                => 8013,
                         "shouting"               => 3106,
                         "shouts"                 => 11155,
                         "shove"                  => 2182,
                         "shoved"                 => 3325,
                         "shovel"                 => 3697,
                         "shoveled"               => 16777,
                         "shoveling"              => 8830,
                         "shovels"                => 8462,
                         "shoves"                 => 12913,
                         "shoving"                => 4550,
                         "showbiz"                => 10809,
                         "showed"                 => 786,
                         "shower"                 => 955,
                         "showered"               => 6428,
                         "showering"              => 7701,
                         "showgirl"               => 8829,
                         "showin"                 => 9687,
                         "showing"                => 1054,
                         "showmanship"            => 14098,
                         "showoff"                => 15762,
                         "showroom"               => 8461,
                         "showstopper"            => 14859,
                         "showy"                  => 16776,
                         "shrapnel"               => 7327,
                         "shreck"                 => 8299,
                         "shred"                  => 3745,
                         "shredded"               => 6348,
                         "shredding"              => 9686,
                         "shreds"                 => 5148,
                         "shrek"                  => 5279,
                         "shrew"                  => 6603,
                         "shrewd"                 => 7867,
                         "shriek"                 => 12912,
                         "shrieking"              => 10201,
                         "shrieks"                => 18048,
                         "shrill"                 => 9928,
                         "shrimp"                 => 3105,
                         "shrink"                 => 1661,
                         "shrinkage"              => 10492,
                         "shrinking"              => 6878,
                         "shrinks"                => 5664,
                         "shrivel"                => 11535,
                         "shriveled"              => 12441,
                         "shroud"                 => 4920,
                         "shrouded"               => 14097,
                         "shrouds"                => 16775,
                         "shrubberies"            => 14096,
                         "shrubbery"              => 10200,
                         "shrug"                  => 9046,
                         "shrugged"               => 12911,
                         "shrugging"              => 16774,
                         "shrugs"                 => 10199,
                         "shrunk"                 => 6012,
                         "shrunken"               => 10808,
                         "shtick"                 => 12910,
                         "shtud"                  => 18047,
                         "shucks"                 => 7326,
                         "shudder"                => 9451,
                         "shuffle"                => 6347,
                         "shuffleboard"           => 14095,
                         "shuffled"               => 12440,
                         "shuffling"              => 11534,
                         "shugga"                 => 13473,
                         "shunned"                => 10807,
                         "shunning"               => 18046,
                         "shunt"                  => 13472,
                         "shush"                  => 5063,
                         "shushing"               => 13471,
                         "shut"                   => 343,
                         "shuteye"                => 14094,
                         "shuts"                  => 5516,
                         "shutters"               => 7866,
                         "shutting"               => 3148,
                         "shuttles"               => 16773,
                         "shuvanis"               => 15761,
                         "shying"                 => 18045,
                         "shylock"                => 12909,
                         "shyness"                => 15760,
                         "siamese"                => 9450,
                         "sibling"                => 4526,
                         "sicced"                 => 12908,
                         "sicilians"              => 11533,
                         "sick"                   => 389,
                         "sicken"                 => 14858,
                         "sickened"               => 12439,
                         "sickening"              => 8012,
                         "sickens"                => 10806,
                         "sicker"                 => 6515,
                         "sickest"                => 11532,
                         "sickie"                 => 14093,
                         "sickly"                 => 10198,
                         "sickness"               => 2470,
                         "sicko"                  => 6514,
                         "sickos"                 => 13470,
                         "sidarthur"              => 11965,
                         "siddons"                => 14092,
                         "siddown"                => 8460,
                         "sidearm"                => 14091,
                         "sidearms"               => 18044,
                         "sidebar"                => 13469,
                         "sideboard"              => 16772,
                         "sideburns"              => 10491,
                         "sidecar"                => 12907,
                         "sidekicks"              => 14857,
                         "sidelines"              => 5278,
                         "sidetracked"            => 6128,
                         "sidewalk"               => 3766,
                         "sidewalks"              => 10197,
                         "sideways"               => 5663,
                         "siding"                 => 5835,
                         "sidle"                  => 8298,
                         "sidra"                  => 10805,
                         "sieve"                  => 18043,
                         "sifting"                => 11531,
                         "sigfried"               => 14090,
                         "sigh"                   => 4489,
                         "sighing"                => 14856,
                         "sighs"                  => 10804,
                         "sight"                  => 1104,
                         "sighting"               => 5774,
                         "sightings"              => 7325,
                         "sightless"              => 16771,
                         "sights"                 => 3806,
                         "sightseeing"            => 9449,
                         "sigmund"                => 6987,
                         "sign"                   => 471,
                         "signature"              => 1962,
                         "signor"                 => 5367,
                         "signora"                => 6986,
                         "signore"                => 7208,
                         "signorina"              => 18042,
                         "signs"                  => 1480,
                         "siguto"                 => 18041,
                         "silence"                => 1682,
                         "silenced"               => 10490,
                         "silences"               => 12906,
                         "silent"                 => 1588,
                         "silently"               => 9245,
                         "silk"                   => 2590,
                         "silken"                 => 16770,
                         "silks"                  => 16769,
                         "silkwood"               => 16768,
                         "silky"                  => 8638,
                         "silliest"               => 11964,
                         "silliness"              => 12905,
                         "silly"                  => 898,
                         "silverlake"             => 18040,
                         "silverware"             => 6679,
                         "simian"                 => 9448,
                         "simmer"                 => 6985,
                         "simony"                 => 16767,
                         "simpatico"              => 9685,
                         "simpering"              => 14089,
                         "simpler"                => 3679,
                         "simplest"               => 6678,
                         "simpleton"              => 10803,
                         "simpletons"             => 16766,
                         "simplistic"             => 11154,
                         "simulates"              => 15759,
                         "simulator"              => 7865,
                         "sincere"                => 2761,
                         "sincerely"              => 4488,
                         "sincerest"              => 12438,
                         "sincerity"              => 5834,
                         "sindell"                => 16765,
                         "sinewy"                 => 18039,
                         "sing"                   => 887,
                         "singe"                  => 14855,
                         "singed"                 => 12437,
                         "singin"                 => 8297,
                         "singing"                => 1270,
                         "singling"               => 15758,
                         "singularly"             => 18038,
                         "sink"                   => 1843,
                         "sinker"                 => 8637,
                         "sinking"                => 3993,
                         "sinks"                  => 7207,
                         "sinners"                => 7091,
                         "sinning"                => 18037,
                         "sins"                   => 2619,
                         "sinus"                  => 7090,
                         "sinuses"                => 10489,
                         "siphon"                 => 14088,
                         "siphoned"               => 14087,
                         "siphoning"              => 12436,
                         "sipowicz"               => 15757,
                         "sipped"                 => 16764,
                         "sipping"                => 6127,
                         "sir"                    => 202,
                         "sire"                   => 4683,
                         "siree"                  => 12435,
                         "siren"                  => 5318,
                         "sirens"                 => 5885,
                         "sirloin"                => 14854,
                         "sirree"                 => 11153,
                         "sissies"                => 12904,
                         "sista"                  => 18036,
                         "sistah"                 => 16763,
                         "sister"                 => 313,
                         "sisterhood"             => 11963,
                         "sisterly"               => 9927,
                         "sisters"                => 1165,
                         "sistine"                => 13468,
                         "sit"                    => 303,
                         "sitarides"              => 16762,
                         "siteid"                 => 14853,
                         "sits"                   => 2525,
                         "sitter"                 => 2908,
                         "sitters"                => 10802,
                         "sittin"                 => 3787,
                         "sitting"                => 571,
                         "situation"              => 521,
                         "sivapathasundaram"      => 12903,
                         "sixed"                  => 14086,
                         "sixes"                  => 11152,
                         "sixpence"               => 15756,
                         "sixteen"                => 1762,
                         "sixties"                => 5062,
                         "sixty"                  => 1489,
                         "sizable"                => 7324,
                         "sizing"                 => 13467,
                         "sizzling"               => 11151,
                         "skaara"                 => 9684,
                         "skagnetti"              => 18035,
                         "skank"                  => 5235,
                         "skanks"                 => 14085,
                         "skanky"                 => 8296,
                         "skateboards"            => 11150,
                         "skated"                 => 12902,
                         "skates"                 => 5099,
                         "skedaddle"              => 8636,
                         "skeeters"               => 10196,
                         "skeletons"              => 6770,
                         "skeptic"                => 16761,
                         "skeptical"              => 6208,
                         "sketch"                 => 3244,
                         "sketchbook"             => 18034,
                         "sketched"               => 14084,
                         "sketches"               => 3805,
                         "sketching"              => 11149,
                         "sketchy"                => 5565,
                         "skewed"                 => 15755,
                         "skewer"                 => 13466,
                         "skewered"               => 13465,
                         "skidded"                => 12901,
                         "skids"                  => 11148,
                         "skied"                  => 15754,
                         "skies"                  => 4614,
                         "skillfully"             => 18033,
                         "skilosh"                => 14852,
                         "skimmed"                => 11962,
                         "skimming"               => 8459,
                         "skimp"                  => 14851,
                         "skimpy"                 => 10488,
                         "skin"                   => 1019,
                         "skinless"               => 18032,
                         "skinned"                => 6513,
                         "skip"                   => 1534,
                         "skipped"                => 3220,
                         "skipping"               => 4302,
                         "skips"                  => 9683,
                         "skirt"                  => 2544,
                         "skirts"                 => 5317,
                         "skittish"               => 11530,
                         "skivvies"               => 13464,
                         "skokie"                 => 16760,
                         "skulk"                  => 13463,
                         "skulking"               => 9447,
                         "skull"                  => 2310,
                         "skydiving"              => 14083,
                         "skye"                   => 826,
                         "skylight"               => 10487,
                         "skyrocket"              => 15753,
                         "skywire"                => 9682,
                         "slackers"               => 12434,
                         "slacks"                 => 11147,
                         "slam"                   => 2864,
                         "slammed"                => 4008,
                         "slammin"                => 14850,
                         "slamming"               => 5564,
                         "slams"                  => 8828,
                         "slander"                => 6984,
                         "slanderous"             => 14849,
                         "slant"                  => 8827,
                         "slanted"                => 14848,
                         "slap"                   => 2274,
                         "slapped"                => 3525,
                         "slapping"               => 5833,
                         "slaps"                  => 8295,
                         "slash"                  => 4487,
                         "slashed"                => 6677,
                         "slashing"               => 10801,
                         "slaughtered"            => 6676,
                         "slaughterhouse"         => 11146,
                         "slaughtering"           => 12900,
                         "slaved"                 => 11961,
                         "slaving"                => 9244,
                         "slayage"                => 14082,
                         "slayed"                 => 12899,
                         "slayers"                => 5316,
                         "slaying"                => 4581,
                         "slays"                  => 14081,
                         "sleaze"                 => 4710,
                         "sleazebag"              => 12898,
                         "sleazeball"             => 16759,
                         "sleazy"                 => 4035,
                         "sledding"               => 6983,
                         "sledgehammer"           => 8826,
                         "sleds"                  => 14080,
                         "sleek"                  => 12433,
                         "sleep"                  => 364,
                         "sleepin"                => 9045,
                         "sleeping"               => 714,
                         "sleepless"              => 5943,
                         "sleepover"              => 5366,
                         "sleepovers"             => 12432,
                         "sleeps"                 => 3061,
                         "sleepwalk"              => 16758,
                         "sleepwalker"            => 14079,
                         "sleepwalking"           => 6011,
                         "sleepyhead"             => 8825,
                         "sleet"                  => 12431,
                         "sleeve"                 => 3000,
                         "sleeveless"             => 18031,
                         "sleeves"                => 5061,
                         "sleigh"                 => 3876,
                         "sleight"                => 15752,
                         "slept"                  => 846,
                         "sleuthing"              => 18030,
                         "slice"                  => 2654,
                         "sliced"                 => 5884,
                         "slicery"                => 6982,
                         "slices"                 => 5606,
                         "slicing"                => 9926,
                         "slide"                  => 2087,
                         "slides"                 => 3992,
                         "sliding"                => 5773,
                         "slight"                 => 2814,
                         "slighted"               => 16757,
                         "slightest"              => 2618,
                         "slime"                  => 3936,
                         "slimeball"              => 9243,
                         "slimmer"                => 16756,
                         "slimming"               => 13462,
                         "slimy"                  => 4525,
                         "sling"                  => 4709,
                         "slinging"               => 6427,
                         "slings"                 => 12430,
                         "slingshot"              => 11960,
                         "slink"                  => 8141,
                         "slinking"               => 14847,
                         "slip"                   => 1247,
                         "slipped"                => 1685,
                         "slippers"               => 4486,
                         "slippin"                => 18029,
                         "slipping"               => 3207,
                         "slips"                  => 3696,
                         "slit"                   => 4646,
                         "slither"                => 7864,
                         "slithered"              => 10195,
                         "slithering"             => 12897,
                         "slithers"               => 18028,
                         "sloane"                 => 2327,
                         "slobbering"             => 10486,
                         "slobs"                  => 14078,
                         "sloman"                 => 10800,
                         "sloppy"                 => 3515,
                         "sloshed"                => 15751,
                         "slossum"                => 16755,
                         "sloth"                  => 9446,
                         "slots"                  => 5942,
                         "slouch"                 => 11959,
                         "slow"                   => 792,
                         "slowest"                => 12896,
                         "slowing"                => 5032,
                         "slowly"                 => 1731,
                         "slows"                  => 9925,
                         "slugged"                => 10485,
                         "sluggish"               => 10194,
                         "slugs"                  => 8635,
                         "sluman"                 => 18027,
                         "slumber"                => 5315,
                         "slumlord"               => 16754,
                         "slumming"               => 7206,
                         "slump"                  => 9242,
                         "slumped"                => 12895,
                         "slung"                  => 13461,
                         "slurping"               => 11958,
                         "slurring"               => 18026,
                         "slush"                  => 10799,
                         "slushy"                 => 18025,
                         "smack"                  => 2917,
                         "smacked"                => 7205,
                         "smackers"               => 16753,
                         "smacking"               => 9681,
                         "smacks"                 => 11145,
                         "smallish"               => 18024,
                         "smarmy"                 => 9924,
                         "smart"                  => 582,
                         "smarten"                => 18023,
                         "smarter"                => 2059,
                         "smartest"               => 3373,
                         "smarts"                 => 5772,
                         "smash"                  => 3469,
                         "smashed"                => 3193,
                         "smashes"                => 15750,
                         "smear"                  => 4682,
                         "smeared"                => 8140,
                         "smearing"               => 12429,
                         "smears"                 => 12894,
                         "smell"                  => 787,
                         "smelled"                => 2753,
                         "smelling"               => 3678,
                         "smells"                 => 1404,
                         "smelt"                  => 11144,
                         "smidge"                 => 9445,
                         "smidgen"                => 16752,
                         "smila"                  => 14846,
                         "smile"                  => 867,
                         "smiled"                 => 3677,
                         "smilin"                 => 14077,
                         "smiling"                => 1655,
                         "smirk"                  => 6981,
                         "smirking"               => 12428,
                         "smite"                  => 10193,
                         "smithbauer"             => 11529,
                         "smithereens"            => 11143,
                         "smitten"                => 5470,
                         "smoked"                 => 3288,
                         "smokers"                => 10484,
                         "smokescreen"            => 14076,
                         "smoking"                => 1518,
                         "smoldering"             => 11528,
                         "smoochies"              => 18022,
                         "smooching"              => 11957,
                         "smoochy"                => 5469,
                         "smooter"                => 16751,
                         "smoothed"               => 18021,
                         "smoother"               => 9044,
                         "smoothest"              => 15749,
                         "smoothing"              => 9241,
                         "smoothly"               => 4223,
                         "smorgasbord"            => 11956,
                         "smothered"              => 8011,
                         "smothering"             => 10798,
                         "smudged"                => 12427,
                         "smug"                   => 3468,
                         "smuggle"                => 6278,
                         "smuggled"               => 7700,
                         "smuggler"               => 11955,
                         "smugglers"              => 12426,
                         "smuggling"              => 5194,
                         "smugness"               => 15748,
                         "smush"                  => 16750,
                         "smythe"                 => 2793,
                         "snack"                  => 2626,
                         "snacking"               => 12893,
                         "snacks"                 => 4681,
                         "snag"                   => 4708,
                         "snagged"                => 8458,
                         "snagging"               => 16749,
                         "snags"                  => 12425,
                         "snakebite"              => 11954,
                         "snakeskin"              => 16748,
                         "snaking"                => 18020,
                         "snap"                   => 1836,
                         "snapped"                => 2916,
                         "snapping"               => 6675,
                         "snaps"                  => 6010,
                         "snapshots"              => 10192,
                         "snare"                  => 9240,
                         "snarky"                 => 12892,
                         "snarl"                  => 14845,
                         "snarling"               => 12891,
                         "snatched"               => 5468,
                         "snatcher"               => 9043,
                         "snatchers"              => 12890,
                         "snatches"               => 15747,
                         "snatching"              => 10797,
                         "snausages"              => 18019,
                         "snazzy"                 => 11953,
                         "sneak"                  => 1515,
                         "sneaked"                => 8634,
                         "sneakin"                => 11142,
                         "sneaking"               => 2020,
                         "sneaks"                 => 6674,
                         "sneer"                  => 14844,
                         "sneering"               => 18018,
                         "sneeze"                 => 5193,
                         "sneezed"                => 8294,
                         "sneezing"               => 8139,
                         "snickering"             => 14843,
                         "snide"                  => 6877,
                         "sniff"                  => 4426,
                         "sniffed"                => 12424,
                         "sniffin"                => 14842,
                         "sniffing"               => 4054,
                         "sniffles"               => 11952,
                         "sniffling"              => 16747,
                         "sniffs"                 => 14075,
                         "snifter"                => 14841,
                         "snipe"                  => 8457,
                         "snipers"                => 7451,
                         "sniping"                => 14840,
                         "snippy"                 => 9239,
                         "snitch"                 => 4455,
                         "snitched"               => 18017,
                         "snitches"               => 14839,
                         "snitching"              => 18016,
                         "sniveling"              => 9444,
                         "snivelling"             => 16746,
                         "snobby"                 => 9042,
                         "snobs"                  => 9238,
                         "snookums"               => 9443,
                         "snooping"               => 3441,
                         "snooty"                 => 6876,
                         "snooze"                 => 6346,
                         "snore"                  => 5192,
                         "snores"                 => 13460,
                         "snoring"                => 6064,
                         "snorkeling"             => 14838,
                         "snort"                  => 8293,
                         "snorted"                => 14837,
                         "snorting"               => 11951,
                         "snotty"                 => 6426,
                         "snowballed"             => 15746,
                         "snowballing"            => 16745,
                         "snowballs"              => 13459,
                         "snowbank"               => 16744,
                         "snowcone"               => 18015,
                         "snowed"                 => 5365,
                         "snowflakes"             => 13458,
                         "snowing"                => 4766,
                         "snowmen"                => 16743,
                         "snowmobile"             => 12423,
                         "snowmobiles"            => 15745,
                         "snows"                  => 18014,
                         "snowstorm"              => 6980,
                         "snubbed"                => 11950,
                         "snuck"                  => 2813,
                         "snuff"                  => 6875,
                         "snuffed"                => 14074,
                         "snuggled"               => 12422,
                         "snuggling"              => 12889,
                         "snyders"                => 15744,
                         "so"                     => 22,
                         "soak"                   => 4222,
                         "soaked"                 => 4301,
                         "soaking"                => 5147,
                         "soap"                   => 1961,
                         "soapbox"                => 11527,
                         "soaping"                => 18013,
                         "soaps"                  => 7572,
                         "soaring"                => 8292,
                         "soars"                  => 14836,
                         "sobbing"                => 7323,
                         "sober"                  => 2882,
                         "sobered"                => 16742,
                         "sobering"               => 13457,
                         "soberly"                => 16741,
                         "sobriki"                => 18012,
                         "sociable"               => 11949,
                         "socialize"              => 7863,
                         "socialized"             => 15743,
                         "socializing"            => 7089,
                         "sociopath"              => 6769,
                         "sociopathic"            => 15742,
                         "sock"                   => 2648,
                         "socked"                 => 11948,
                         "socket"                 => 7699,
                         "sockets"                => 10796,
                         "socks"                  => 2018,
                         "soda"                   => 1542,
                         "sodas"                  => 5364,
                         "sodding"                => 11526,
                         "sodomized"              => 18011,
                         "sofa"                   => 2724,
                         "sofas"                  => 16740,
                         "soft"                   => 1355,
                         "soften"                 => 5714,
                         "softened"               => 9237,
                         "softener"               => 11525,
                         "softening"              => 12888,
                         "softer"                 => 6425,
                         "softest"                => 15741,
                         "softie"                 => 9442,
                         "softly"                 => 7450,
                         "softness"               => 12887,
                         "softy"                  => 12886,
                         "soggy"                  => 7322,
                         "soiled"                 => 11141,
                         "soiree"                 => 18010,
                         "solarium"               => 10483,
                         "solemn"                 => 6063,
                         "solemnly"               => 9236,
                         "solenoid"               => 13456,
                         "solicit"                => 12885,
                         "solicitation"           => 10482,
                         "soliciting"             => 13455,
                         "solid"                  => 1522,
                         "solidify"               => 14835,
                         "soliloquy"              => 18009,
                         "solitaire"              => 10481,
                         "solitary"               => 3823,
                         "sollozzo"               => 8633,
                         "solve"                  => 1462,
                         "solved"                 => 2344,
                         "solves"                 => 6277,
                         "somber"                 => 12421,
                         "sombrero"               => 9235,
                         "some'in"                => 18008,
                         "somebody"               => 268,
                         "somebody'd"             => 15740,
                         "somebody'll"            => 13454,
                         "someday"                => 1125,
                         "somehow"                => 739,
                         "someone"                => 180,
                         "someone'll"             => 16739,
                         "somepin"                => 16738,
                         "someplace"              => 1032,
                         "someth"                 => 16737,
                         "somethin"               => 1366,
                         "something"              => 66,
                         "something'll"           => 16736,
                         "somethings"             => 14834,
                         "somethng"               => 14073,
                         "sometime"               => 1211,
                         "sometimes"              => 370,
                         "someway"                => 8824,
                         "somewhere"              => 492,
                         "somewheres"             => 12420,
                         "sommes"                 => 14833,
                         "son"                    => 194,
                         "sonar"                  => 7088,
                         "sonnets"                => 10795,
                         "sonny"                  => 368,
                         "sonofabitch"            => 3115,
                         "sonogram"               => 5941,
                         "sonovabitch"            => 12884,
                         "sonrisa"                => 9923,
                         "sonuvabitch"            => 14072,
                         "sookie"                 => 1865,
                         "soon"                   => 256,
                         "sooner"                 => 831,
                         "soonest"                => 16735,
                         "sooo"                   => 4680,
                         "soooo"                  => 11140,
                         "sooth"                  => 18007,
                         "soothe"                 => 8010,
                         "soothes"                => 15739,
                         "soothing"               => 5314,
                         "soothsayer"             => 14832,
                         "sophisticated"          => 2773,
                         "sophistication"         => 10191,
                         "sophomore"              => 3959,
                         "sorbet"                 => 11947,
                         "sorcerers"              => 12419,
                         "sordid"                 => 3899,
                         "sore"                   => 2300,
                         "sorel"                  => 2475,
                         "sorely"                 => 9441,
                         "sores"                  => 7204,
                         "sororities"             => 12883,
                         "sorority"               => 4368,
                         "sorrel"                 => 9234,
                         "sorrier"                => 9233,
                         "sorrow"                 => 4034,
                         "sorrowful"              => 18006,
                         "sorrows"                => 6979,
                         "sorry"                  => 82,
                         "sort"                   => 404,
                         "sorta"                  => 2580,
                         "sorted"                 => 5563,
                         "sorter"                 => 18005,
                         "sorting"                => 6512,
                         "sorts"                  => 2396,
                         "soshi"                  => 18004,
                         "souffle"                => 10480,
                         "soul"                   => 728,
                         "soulless"               => 10794,
                         "soulmates"              => 13453,
                         "souls"                  => 2248,
                         "sound"                  => 435,
                         "sounded"                => 1248,
                         "sounder"                => 9232,
                         "sounding"               => 3127,
                         "soundly"                => 13452,
                         "soundproof"             => 14831,
                         "sounds"                 => 367,
                         "soundstage"             => 15738,
                         "soup"                   => 1389,
                         "soups"                  => 13451,
                         "soupy"                  => 15737,
                         "sour"                   => 3280,
                         "soured"                 => 14071,
                         "sourpuss"               => 15736,
                         "souse"                  => 14830,
                         "soused"                 => 18003,
                         "southey"                => 14070,
                         "southglen"              => 14829,
                         "southie"                => 15735,
                         "southtown"              => 18002,
                         "souvenir"               => 4077,
                         "souvenirs"              => 6768,
                         "souvlaki"               => 15734,
                         "sowing"                 => 12882,
                         "spacerun"               => 16734,
                         "spaceship"              => 5191,
                         "spackle"                => 10190,
                         "spade"                  => 6602,
                         "spades"                 => 5363,
                         "spaghetti"              => 3913,
                         "spandex"                => 6767,
                         "spangled"               => 14069,
                         "spaniard"               => 11524,
                         "spare"                  => 1206,
                         "spared"                 => 4398,
                         "spareribs"              => 12881,
                         "sparing"                => 10793,
                         "spark"                  => 3424,
                         "sparklers"              => 12880,
                         "sparkling"              => 5277,
                         "sparkly"                => 9041,
                         "sparrin"                => 15733,
                         "sparring"               => 8291,
                         "spartacus"              => 16733,
                         "spasm"                  => 7862,
                         "spasms"                 => 11523,
                         "spastic"                => 15732,
                         "spate"                  => 16732,
                         "spatter"                => 14068,
                         "spatula"                => 6424,
                         "spatulas"               => 18001,
                         "spauldings"             => 5883,
                         "speak"                  => 440,
                         "speakeasy"              => 11139,
                         "speakerphone"           => 14828,
                         "speakin"                => 9231,
                         "speaking"               => 753,
                         "speaks"                 => 2306,
                         "spearchucker"           => 18000,
                         "spearmint"              => 14067,
                         "specialise"             => 15731,
                         "speciality"             => 9680,
                         "specialize"             => 6601,
                         "specials"               => 3912,
                         "specialty"              => 3440,
                         "specifics"              => 5031,
                         "specs"                  => 6600,
                         "spect"                  => 17999,
                         "spectacle"              => 5146,
                         "spectacles"             => 14827,
                         "spectacular"            => 3065,
                         "spectacularly"          => 11946,
                         "spectator"              => 6423,
                         "specter"                => 12418,
                         "spectra"                => 2874,
                         "speculate"              => 6511,
                         "speculating"            => 8632,
                         "speech"                 => 1021,
                         "speeches"               => 4114,
                         "speechless"             => 5276,
                         "speedboat"              => 14826,
                         "speedily"               => 15730,
                         "speeding"               => 3935,
                         "speedometer"            => 11138,
                         "speedos"                => 13450,
                         "spell"                  => 789,
                         "spells"                 => 2221,
                         "spencers"               => 11522,
                         "spend"                  => 452,
                         "spender"                => 8456,
                         "spenders"               => 14066,
                         "spendin"                => 17998,
                         "spending"               => 977,
                         "spends"                 => 3206,
                         "sperm"                  => 2924,
                         "spewing"                => 7861,
                         "spews"                  => 17997,
                         "sphincter"              => 14065,
                         "spiced"                 => 17996,
                         "spices"                 => 7203,
                         "spicoli"                => 10792,
                         "spicy"                  => 3804,
                         "spiders"                => 4163,
                         "spied"                  => 10189,
                         "spiel"                  => 11521,
                         "spielberg"              => 5605,
                         "spiked"                 => 6276,
                         "spiking"                => 8455,
                         "spiky"                  => 16731,
                         "spill"                  => 2102,
                         "spilled"                => 2672,
                         "spilling"               => 5145,
                         "spills"                 => 7449,
                         "spilt"                  => 9679,
                         "spin"                   => 1690,
                         "spinach"                => 6126,
                         "spinal"                 => 4367,
                         "spindly"                => 13449,
                         "spine"                  => 3167,
                         "spineless"              => 6978,
                         "spinning"               => 2713,
                         "spins"                  => 7571,
                         "spinster"               => 11137,
                         "spiraling"              => 11136,
                         "spirals"                => 14825,
                         "spirited"               => 4880,
                         "spirits"                => 2170,
                         "spiritually"            => 9678,
                         "spiritus"               => 12879,
                         "spirulina"              => 16730,
                         "spit"                   => 1646,
                         "spite"                  => 2122,
                         "spiteful"               => 6673,
                         "spits"                  => 7570,
                         "spitter"                => 17995,
                         "spittin"                => 16729,
                         "spitting"               => 4133,
                         "spittle"                => 17994,
                         "splashed"               => 9230,
                         "splashing"              => 12417,
                         "splashmore"             => 10479,
                         "splashy"                => 12416,
                         "splat"                  => 10188,
                         "splattered"             => 9677,
                         "splendid"               => 3104,
                         "splendidly"             => 12415,
                         "splendido"              => 16728,
                         "splendor"               => 8454,
                         "splice"                 => 9922,
                         "spliced"                => 10187,
                         "splicing"               => 11520,
                         "splint"                 => 12414,
                         "splintered"             => 17993,
                         "splinters"              => 10186,
                         "splitsville"            => 15729,
                         "splittin"               => 15728,
                         "splitting"              => 3514,
                         "spoil"                  => 1937,
                         "spoiled"                => 2326,
                         "spoiling"               => 5467,
                         "spoils"                 => 6874,
                         "spoilsport"             => 11519,
                         "spoke"                  => 1059,
                         "spoken"                 => 1444,
                         "spokes"                 => 12878,
                         "spokesmen"              => 17992,
                         "sponges"                => 7448,
                         "spongy"                 => 17991,
                         "sponsoring"             => 8138,
                         "spontaneity"            => 7569,
                         "spontaneous"            => 3060,
                         "spontaneously"          => 8453,
                         "spooked"                => 4454,
                         "spooking"               => 16727,
                         "spool"                  => 13448,
                         "spoon"                  => 2840,
                         "spoonful"               => 15727,
                         "spooning"               => 14824,
                         "sporto"                 => 16726,
                         "sportsmanship"          => 12877,
                         "sportswear"             => 15726,
                         "spot"                   => 948,
                         "spotless"               => 8009,
                         "spotlight"              => 4275,
                         "spotlights"             => 14823,
                         "spotted"                => 2395,
                         "spotters"               => 16725,
                         "spotting"               => 6422,
                         "spousal"                => 14064,
                         "spouse"                 => 5940,
                         "spouses"                => 9229,
                         "spout"                  => 9921,
                         "spouting"               => 8137,
                         "sprain"                 => 8136,
                         "sprained"               => 6062,
                         "spramp"                 => 16724,
                         "sprawl"                 => 14063,
                         "sprawled"               => 14822,
                         "spray"                  => 2634,
                         "sprayed"                => 7698,
                         "spraying"               => 8290,
                         "sprays"                 => 15725,
                         "spreader"               => 17990,
                         "spreading"              => 3103,
                         "spreadsheet"            => 16723,
                         "spreadsheets"           => 14821,
                         "spree"                  => 5144,
                         "sprig"                  => 14062,
                         "sprightly"              => 15724,
                         "sprimp"                 => 14820,
                         "springfield"            => 1951,
                         "springing"              => 8823,
                         "springtime"             => 7568,
                         "sprinkled"              => 12876,
                         "sprinkler"              => 8452,
                         "sprinklers"             => 9040,
                         "sprinkles"              => 6510,
                         "sprinkling"             => 17989,
                         "spritz"                 => 14061,
                         "spritzer"               => 15723,
                         "sprouted"               => 13447,
                         "sprouting"              => 14819,
                         "sprouts"                => 6977,
                         "sprung"                 => 4274,
                         "spungeon"               => 15722,
                         "spurt"                  => 15721,
                         "spying"                 => 2423,
                         "squab"                  => 17988,
                         "squabble"               => 12875,
                         "squabbling"             => 17987,
                         "squalid"                => 17986,
                         "squalor"                => 12874,
                         "squander"               => 8631,
                         "squandered"             => 12413,
                         "squandering"            => 17985,
                         "squared"                => 4765,
                         "squarely"               => 13446,
                         "squaring"               => 16722,
                         "squashed"               => 8289,
                         "squashing"              => 16721,
                         "squat"                  => 4132,
                         "squatsie"               => 17984,
                         "squatter"               => 13445,
                         "squatters"              => 11945,
                         "squatting"              => 11944,
                         "squaw"                  => 15720,
                         "squawk"                 => 12873,
                         "squawking"              => 11518,
                         "squeaking"              => 10478,
                         "squeaks"                => 11517,
                         "squeaky"                => 6061,
                         "squeal"                 => 8451,
                         "squealed"               => 14818,
                         "squealing"              => 9440,
                         "squeamish"              => 9676,
                         "squeegee"               => 10185,
                         "squeeze"                => 1874,
                         "squeezed"               => 4805,
                         "squeezes"               => 13444,
                         "squeezing"              => 6060,
                         "squiggle"               => 16720,
                         "squiggly"               => 16719,
                         "squint"                 => 9228,
                         "squinting"              => 14817,
                         "squirm"                 => 6345,
                         "squirming"              => 9439,
                         "squirrels"              => 6509,
                         "squirted"               => 14060,
                         "squished"               => 10184,
                         "squishing"              => 14816,
                         "sshhh"                  => 11943,
                         "sshhhh"                 => 14815,
                         "ssshhh"                 => 15719,
                         "stab"                   => 2469,
                         "stabbed"                => 2486,
                         "stabbing"               => 4485,
                         "stabilize"              => 6344,
                         "stabilized"             => 5098,
                         "stabilizing"            => 11135,
                         "stables"                => 4804,
                         "stabs"                  => 9675,
                         "stace"                  => 9227,
                         "stacked"                => 6672,
                         "stacking"               => 9920,
                         "stacks"                 => 6873,
                         "staedert"               => 16718,
                         "staffer"                => 11942,
                         "staffers"               => 8008,
                         "stagger"                => 12412,
                         "staggering"             => 7087,
                         "staggeringly"           => 15718,
                         "stain"                  => 3495,
                         "stains"                 => 4679,
                         "stairmaster"            => 11941,
                         "stairs"                 => 1417,
                         "stairwell"              => 4879,
                         "stairwells"             => 17983,
                         "stake"                  => 1391,
                         "staked"                 => 6508,
                         "stakeout"               => 5466,
                         "stakeouts"              => 12872,
                         "staking"                => 6872,
                         "stale"                  => 4741,
                         "stalk"                  => 4397,
                         "stalked"                => 5097,
                         "stalkers"               => 10183,
                         "stalking"               => 2343,
                         "stalks"                 => 11940,
                         "stall"                  => 2731,
                         "stalled"                => 6871,
                         "stalling"               => 3314,
                         "stalwart"               => 14059,
                         "stamina"                => 6870,
                         "stammering"             => 16717,
                         "stamp"                  => 1425,
                         "stamped"                => 6343,
                         "stand"                  => 347,
                         "standin"                => 6766,
                         "standing"               => 605,
                         "standoff"               => 9039,
                         "standoffish"            => 14058,
                         "standpoint"             => 8007,
                         "standup"                => 8450,
                         "stankylecartmankennymr" => 14057,
                         "stannart"               => 9438,
                         "stans"                  => 14814,
                         "stanzi"                 => 9674,
                         "stapled"                => 11516,
                         "starboard"              => 5662,
                         "stare"                  => 2288,
                         "stared"                 => 5832,
                         "stares"                 => 6275,
                         "stargates"              => 16716,
                         "stargher"               => 9673,
                         "starin"                 => 9437,
                         "staring"                => 1309,
                         "starlets"               => 15717,
                         "starry"                 => 8630,
                         "starshine"              => 17982,
                         "start"                  => 228,
                         "starters"               => 2589,
                         "startin"                => 5362,
                         "starting"               => 561,
                         "startle"                => 5030,
                         "startled"               => 4033,
                         "startling"              => 8629,
                         "starts"                 => 1006,
                         "starve"                 => 3875,
                         "starved"                => 4053,
                         "starvin"                => 6976,
                         "starving"               => 1773,
                         "stash"                  => 3546,
                         "stashed"                => 3545,
                         "stashing"               => 17981,
                         "stasis"                 => 12411,
                         "stat"                   => 2730,
                         "statement"              => 1210,
                         "stateroom"              => 14813,
                         "stateside"              => 10791,
                         "statesville"            => 3710,
                         "stathis"                => 14056,
                         "stationery"             => 7567,
                         "stats"                  => 5234,
                         "statuary"               => 15716,
                         "stavros"                => 2263,
                         "stay"                   => 169,
                         "stayed"                 => 1064,
                         "stayin"                 => 5562,
                         "staying"                => 649,
                         "stays"                  => 1533,
                         "steadfast"              => 14812,
                         "steadwell"              => 14811,
                         "steady"                 => 1928,
                         "steak"                  => 2144,
                         "steakhouse"             => 14055,
                         "steaks"                 => 5233,
                         "steal"                  => 897,
                         "stealer"                => 13443,
                         "stealin"                => 12871,
                         "stealing"               => 1333,
                         "steals"                 => 4076,
                         "stealthy"               => 11939,
                         "steamed"                => 5661,
                         "steaming"               => 6342,
                         "steamroll"              => 12410,
                         "steamroller"            => 14810,
                         "steamy"                 => 5939,
                         "steckler"               => 8822,
                         "steelheads"             => 14054,
                         "steena"                 => 15715,
                         "steenwyck"              => 16715,
                         "steer"                  => 3403,
                         "steerage"               => 15714,
                         "steered"                => 8449,
                         "steers"                 => 14053,
                         "steffy"                 => 8135,
                         "steinbrenner"           => 5938,
                         "stempel"                => 6421,
                         "stenbeck"               => 1052,
                         "stench"                 => 5660,
                         "steno"                  => 16714,
                         "stenographer"           => 12409,
                         "stens"                  => 14809,
                         "stensland"              => 9436,
                         "step"                   => 537,
                         "stepatech"              => 10790,
                         "stepbrother"            => 14052,
                         "stepdad"                => 7860,
                         "stepdaughter"           => 9226,
                         "stepfather"             => 4102,
                         "stepford"               => 15713,
                         "stephano"               => 17980,
                         "stepladder"             => 14051,
                         "stepmom"                => 10477,
                         "stepmommy"              => 17979,
                         "stepmother"             => 4740,
                         "stepped"                => 1942,
                         "steppin"                => 10789,
                         "stepping"               => 3059,
                         "steps"                  => 1598,
                         "stepson"                => 6765,
                         "stereotype"             => 7321,
                         "stereotyping"           => 17978,
                         "sterile"                => 6059,
                         "sterilize"              => 12870,
                         "sterilized"             => 12869,
                         "sternin"                => 11134,
                         "sternum"                => 14050,
                         "steroid"                => 8628,
                         "steroids"               => 4187,
                         "stethoscope"            => 6671,
                         "stetson"                => 3611,
                         "stevesy"                => 16713,
                         "stew"                   => 4032,
                         "stewardess"             => 6764,
                         "stewardesses"           => 12868,
                         "stewed"                 => 10788,
                         "stewing"                => 17977,
                         "steyne"                 => 14049,
                         "stick"                  => 599,
                         "sticker"                => 5465,
                         "stickers"               => 8288,
                         "stickin"                => 7202,
                         "sticking"               => 1539,
                         "stickup"                => 14808,
                         "stiff"                  => 2760,
                         "stiffed"                => 14048,
                         "stiffer"                => 14807,
                         "stiffs"                 => 9919,
                         "stifle"                 => 13442,
                         "stifling"               => 15712,
                         "stilettos"              => 16712,
                         "still"                  => 106,
                         "stillness"              => 16711,
                         "stillwater"             => 10182,
                         "stilts"                 => 8287,
                         "stimulant"              => 14047,
                         "stimulating"            => 5604,
                         "stings"                 => 6507,
                         "stingy"                 => 11515,
                         "stink"                  => 2083,
                         "stinkin"                => 6506,
                         "stinking"               => 3342,
                         "stinks"                 => 2189,
                         "stipulate"              => 12408,
                         "stipulation"            => 11514,
                         "stir"                   => 2739,
                         "stirred"                => 4707,
                         "stirring"               => 4366,
                         "stirrups"               => 17976,
                         "stirs"                  => 9038,
                         "stitched"               => 8006,
                         "stitches"               => 3898,
                         "stitching"              => 8448,
                         "stockbroker"            => 8447,
                         "stockbrokers"           => 15711,
                         "stocked"                => 6125,
                         "stockholder"            => 10181,
                         "stockholders"           => 6009,
                         "stockings"              => 5096,
                         "stockpile"              => 12867,
                         "stockpiling"            => 14046,
                         "stocky"                 => 13441,
                         "stodgy"                 => 13440,
                         "stogie"                 => 9225,
                         "stoic"                  => 11133,
                         "stoked"                 => 7566,
                         "stole"                  => 876,
                         "stolen"                 => 1331,
                         "stoli"                  => 14806,
                         "stomach"                => 1251,
                         "stomachache"            => 10787,
                         "stomachs"               => 7565,
                         "stomp"                  => 5464,
                         "stomped"                => 6505,
                         "stomping"               => 8134,
                         "stonewall"              => 9224,
                         "stonewalled"            => 16710,
                         "stonewalling"           => 9918,
                         "stood"                  => 1216,
                         "stool"                  => 4844,
                         "stoolie"                => 13439,
                         "stools"                 => 11938,
                         "stoop"                  => 3991,
                         "stooped"                => 11513,
                         "stooping"               => 11937,
                         "stop"                   => 131,
                         "stoplight"              => 17975,
                         "stopped"                => 603,
                         "stopper"                => 14045,
                         "stoppin"                => 12407,
                         "stopping"               => 1432,
                         "stops"                  => 1793,
                         "stopwatch"              => 10180,
                         "store"                  => 704,
                         "storefront"             => 14044,
                         "storeroom"              => 6670,
                         "stormed"                => 5143,
                         "storming"               => 7564,
                         "storybook"              => 7563,
                         "stosh"                  => 10786,
                         "stotch"                 => 15710,
                         "stove"                  => 3647,
                         "stowaway"               => 11132,
                         "stowaways"              => 15709,
                         "stowed"                 => 8133,
                         "straddle"               => 15708,
                         "straddling"             => 15707,
                         "stradling"              => 13438,
                         "straight"               => 494,
                         "straightaway"           => 14805,
                         "straighten"             => 2143,
                         "straightened"           => 3911,
                         "straightener"           => 17974,
                         "straightening"          => 7086,
                         "straightens"            => 14043,
                         "straighter"             => 17973,
                         "straightest"            => 14042,
                         "straightforward"        => 5659,
                         "straights"              => 16709,
                         "strained"               => 5831,
                         "strainer"               => 17972,
                         "straining"              => 14804,
                         "straitjacket"           => 8627,
                         "stranded"               => 3372,
                         "strange"                => 693,
                         "strangely"              => 3610,
                         "strangeness"            => 15706,
                         "strangers"              => 1778,
                         "strangest"              => 4007,
                         "strangle"               => 3279,
                         "strangled"              => 4335,
                         "stranglehold"           => 15705,
                         "strangler"              => 8446,
                         "strangling"             => 7697,
                         "strangulation"          => 11512,
                         "strapless"              => 11936,
                         "strapped"               => 4300,
                         "strapping"              => 8821,
                         "straps"                 => 6504,
                         "strassmans"             => 15704,
                         "strategize"             => 11511,
                         "strategizing"           => 14803,
                         "strattman"              => 9917,
                         "stravanavitch"          => 13437,
                         "straw"                  => 3524,
                         "strawberries"           => 5232,
                         "straws"                 => 5658,
                         "stray"                  => 5029,
                         "straying"               => 17971,
                         "strays"                 => 9223,
                         "streaking"              => 9672,
                         "streamers"              => 9916,
                         "streep"                 => 10179,
                         "streetlight"            => 17970,
                         "streetlights"           => 15703,
                         "streetwalker"           => 14802,
                         "streisand"              => 6669,
                         "strength"               => 1163,
                         "strengthens"            => 14041,
                         "strenuously"            => 16708,
                         "strep"                  => 8132,
                         "stress"                 => 1312,
                         "stressed"               => 2653,
                         "stressful"              => 3544,
                         "stressing"              => 6341,
                         "stretch"                => 1941,
                         "stretcher"              => 7320,
                         "strewn"                 => 11131,
                         "stricken"               => 5603,
                         "strictest"              => 9435,
                         "strictly"               => 2017,
                         "stride"                 => 7696,
                         "strides"                => 11510,
                         "strikes"                => 2553,
                         "stringing"              => 6207,
                         "strings"                => 2139,
                         "stringy"                => 14040,
                         "striped"                => 6869,
                         "striping"               => 16707,
                         "strippers"              => 6058,
                         "stripping"              => 5515,
                         "striptease"             => 13436,
                         "strive"                 => 8286,
                         "strobe"                 => 12866,
                         "stroganoff"             => 17969,
                         "stroke"                 => 1927,
                         "stroked"                => 17968,
                         "strokes"                => 4843,
                         "stroking"               => 9434,
                         "stroll"                 => 3786,
                         "strolled"               => 14039,
                         "strolling"              => 7562,
                         "strolls"                => 12865,
                         "strongbox"              => 13435,
                         "stronger"               => 1228,
                         "strongest"              => 3256,
                         "strowman"               => 17967,
                         "strudel"                => 9433,
                         "struggling"             => 2962,
                         "strumpet"               => 11935,
                         "strung"                 => 3897,
                         "strut"                  => 7859,
                         "strutting"              => 11130,
                         "strychnine"             => 15702,
                         "stubbed"                => 14801,
                         "stubbins"               => 11129,
                         "stubble"                => 14800,
                         "stubborn"               => 1924,
                         "stubbornness"           => 9915,
                         "stubs"                  => 7695,
                         "stuck"                  => 702,
                         "studious"               => 16706,
                         "studs"                  => 8131,
                         "studying"               => 1549,
                         "stuff"                  => 248,
                         "stuffed"                => 2262,
                         "stuffing"               => 3934,
                         "stuffs"                 => 12406,
                         "stuffy"                 => 4989,
                         "stumble"                => 5514,
                         "stumbled"               => 4247,
                         "stumbles"               => 12405,
                         "stumbling"              => 7694,
                         "stumped"                => 7561,
                         "stumper"                => 10785,
                         "stung"                  => 7693,
                         "stunk"                  => 7447,
                         "stunned"                => 3709,
                         "stunning"               => 3229,
                         "stunningly"             => 13434,
                         "stunt"                  => 2360,
                         "stunted"                => 14799,
                         "stunts"                 => 5060,
                         "stupendous"             => 14798,
                         "stupider"               => 8820,
                         "stupidest"              => 4960,
                         "stupidity"              => 4613,
                         "stupidly"               => 11934,
                         "stupor"                 => 11509,
                         "sturdy"                 => 8445,
                         "stutter"                => 6763,
                         "stuttering"             => 11508,
                         "stylings"               => 12864,
                         "stylish"                => 6057,
                         "stylist"                => 9037,
                         "stymied"                => 15701,
                         "styrofoam"              => 12863,
                         "suave"                  => 7858,
                         "subatomic"              => 14797,
                         "subbasement"            => 16705,
                         "subbing"                => 14796,
                         "subconscious"           => 3858,
                         "subconsciously"         => 6975,
                         "subdural"               => 10178,
                         "subhuman"               => 17966,
                         "subid"                  => 5028,
                         "subjecting"             => 14795,
                         "subjugation"            => 15700,
                         "sublet"                 => 11128,
                         "subletting"             => 13433,
                         "sublevel"               => 16704,
                         "sublimating"            => 15699,
                         "subliminal"             => 17965,
                         "submersible"            => 15698,
                         "submissive"             => 14794,
                         "subpoena"               => 4205,
                         "subpoenaed"             => 6206,
                         "subpoenas"              => 10784,
                         "subscribe"              => 9432,
                         "subsequentlyne"         => 9431,
                         "subservient"            => 13432,
                         "subside"                => 14038,
                         "subsided"               => 14793,
                         "subsides"               => 17964,
                         "subsidize"              => 12404,
                         "substantiate"           => 15697,
                         "substantiated"          => 17963,
                         "subterfuge"             => 13431,
                         "subtext"                => 7201,
                         "subtitles"              => 8444,
                         "subtle"                 => 2134,
                         "subtleties"             => 17962,
                         "subtlety"               => 7692,
                         "subtly"                 => 10177,
                         "suburbia"               => 12862,
                         "subvert"                => 15696,
                         "subways"                => 13430,
                         "succeed"                => 2738,
                         "succinct"               => 14792,
                         "succotash"              => 16703,
                         "succubus"               => 5771,
                         "succulent"              => 10783,
                         "succumb"                => 12403,
                         "suckah"                 => 16702,
                         "sucked"                 => 2050,
                         "suckered"               => 8443,
                         "suckin"                 => 10476,
                         "sucking"                => 2512,
                         "suckle"                 => 17961,
                         "sucky"                  => 6974,
                         "suction"                => 4580,
                         "sudden"                 => 884,
                         "suddenly"               => 806,
                         "sueleen"                => 14791,
                         "suffer"                 => 1454,
                         "suffering"              => 1430,
                         "suffers"                => 5275,
                         "suffice"                => 4579,
                         "sufficed"               => 14037,
                         "suffocate"              => 8819,
                         "suffocated"             => 6973,
                         "suffocating"            => 5657,
                         "suffocation"            => 14790,
                         "sugai"                  => 15695,
                         "sugarcoat"              => 13429,
                         "sugared"                => 17960,
                         "sugarless"              => 14036,
                         "sugarplum"              => 11933,
                         "sugary"                 => 15694,
                         "suggest"                => 1079,
                         "suggesting"             => 1585,
                         "suggestion"             => 2034,
                         "suggestions"            => 3036,
                         "suicidal"               => 5561,
                         "suicide"                => 1554,
                         "suicides"               => 8442,
                         "suing"                  => 3182,
                         "suit"                   => 856,
                         "suitcase"               => 2579,
                         "suitcases"              => 5463,
                         "suite"                  => 1544,
                         "suitor"                 => 9036,
                         "suitors"                => 13428,
                         "suits"                  => 1932,
                         "sulfa"                  => 14035,
                         "sulking"                => 7446,
                         "sullied"                => 17959,
                         "sultry"                 => 12861,
                         "sumbitch"               => 12860,
                         "summarily"              => 14789,
                         "summarize"              => 12859,
                         "summation"              => 10475,
                         "summercliff"            => 17958,
                         "summon"                 => 3513,
                         "summoned"               => 4162,
                         "summoning"              => 8285,
                         "summons"                => 6503,
                         "sump'n"                 => 12402,
                         "sumptuous"              => 15693,
                         "sun'll"                 => 14034,
                         "sunbathing"             => 14788,
                         "sunblock"               => 11932,
                         "sunburn"                => 11507,
                         "sunburned"              => 17957,
                         "sundae"                 => 5513,
                         "sundaes"                => 7857,
                         "sundress"               => 16701,
                         "sunflowers"             => 11127,
                         "sunglasses"             => 4645,
                         "sunless"                => 16700,
                         "sunning"                => 16699,
                         "sunnydale"              => 2712,
                         "sunroom"                => 11931,
                         "sunscreen"              => 7319,
                         "sunsets"                => 10782,
                         "sunspots"               => 16698,
                         "sunstroke"              => 13427,
                         "suntac"                 => 17956,
                         "sunup"                  => 14033,
                         "superbowl"              => 6762,
                         "supercilious"           => 17955,
                         "supercollider"          => 14787,
                         "superdad"               => 15692,
                         "superego"               => 16697,
                         "superficial"            => 4221,
                         "superfluous"            => 16696,
                         "superhero"              => 4365,
                         "superheroes"            => 8130,
                         "superhighway"           => 14032,
                         "superiors"              => 5713,
                         "supermarket"            => 4131,
                         "supermodel"             => 6205,
                         "supermodels"            => 14031,
                         "supernatural"           => 3664,
                         "superpower"             => 12858,
                         "superpowers"            => 11930,
                         "superstition"           => 3663,
                         "superstitions"          => 9914,
                         "superstitious"          => 5602,
                         "superstore"             => 17954,
                         "supervillains"          => 16695,
                         "supervise"              => 5601,
                         "supervisor"             => 3588,
                         "superwoman"             => 10781,
                         "supossed"               => 15691,
                         "supper"                 => 2617,
                         "suppertime"             => 16694,
                         "supple"                 => 10474,
                         "supportive"             => 1985,
                         "suppose"                => 565,
                         "supposed"               => 245,
                         "supposedly"             => 2400,
                         "supposing"              => 9671,
                         "supposition"            => 16693,
                         "suppositories"          => 17953,
                         "suppressing"            => 9222,
                         "supremacists"           => 17952,
                         "supremely"              => 12401,
                         "suprise"                => 17951,
                         "sure"                   => 80,
                         "surefire"               => 17950,
                         "surely"                 => 1597,
                         "surfboard"              => 11929,
                         "surfboards"             => 17949,
                         "surfed"                 => 16692,
                         "surgeon"                => 1940,
                         "surgeons"               => 4612,
                         "surgery"                => 996,
                         "surges"                 => 14030,
                         "surgical"               => 3609,
                         "surgically"             => 7691,
                         "surging"                => 12400,
                         "surly"                  => 10473,
                         "surmise"                => 17948,
                         "surprise"               => 509,
                         "surprised"              => 663,
                         "surprises"              => 1734,
                         "surprising"             => 2759,
                         "surprisingly"           => 4644,
                         "surreal"                => 6599,
                         "surrendering"           => 8284,
                         "surrogate"              => 5027,
                         "surround"               => 5142,
                         "surveillance"           => 1779,
                         "survival"               => 2543,
                         "survivalists"           => 17947,
                         "survive"                => 1197,
                         "suslov"                 => 16691,
                         "suspect"                => 1040,
                         "suspected"              => 2406,
                         "suspecting"             => 9913,
                         "suspects"               => 2196,
                         "suspend"                => 6761,
                         "suspenders"             => 10780,
                         "suspending"             => 11506,
                         "suspense"               => 4161,
                         "suspicion"              => 2987,
                         "suspicions"             => 3102,
                         "suspicious"             => 1485,
                         "suspiciously"           => 9430,
                         "sustain"                => 5190,
                         "sustenance"             => 11126,
                         "suture"                 => 9221,
                         "sutures"                => 11125,
                         "suvolte"                => 16690,
                         "svengali"               => 17946,
                         "svenjolly"              => 17945,
                         "svetkoff"               => 15690,
                         "swabs"                  => 10779,
                         "swackhammer"            => 15689,
                         "swaddling"              => 15688,
                         "swagger"                => 14029,
                         "swallowed"              => 3646,
                         "swallowing"             => 8129,
                         "swamp"                  => 3301,
                         "swamped"                => 4484,
                         "swana"                  => 7560,
                         "swans"                  => 6340,
                         "swapping"               => 9035,
                         "swarm"                  => 8283,
                         "swarming"               => 8626,
                         "swarthy"                => 14028,
                         "swat"                   => 4186,
                         "swatches"               => 12399,
                         "swatting"               => 14786,
                         "swayed"                 => 9034,
                         "swaying"                => 12857,
                         "swayzak"                => 9912,
                         "swear"                  => 529,
                         "swearing"               => 4803,
                         "swears"                 => 5231,
                         "sweat"                  => 1587,
                         "sweated"                => 14027,
                         "sweater"                => 1590,
                         "sweaters"               => 4959,
                         "sweatin"                => 10176,
                         "sweating"               => 3219,
                         "sweatpants"             => 13426,
                         "sweats"                 => 6972,
                         "sweatshirt"             => 5937,
                         "sweatshirts"            => 12398,
                         "sweatshop"              => 11928,
                         "sweatshops"             => 15687,
                         "sweaty"                 => 3484,
                         "sweep"                  => 2299,
                         "sweeping"               => 4739,
                         "sweepstakes"            => 10778,
                         "sweet"                  => 422,
                         "sweetbreads"            => 14785,
                         "sweeter"                => 5361,
                         "sweetest"               => 3080,
                         "sweetheart"             => 510,
                         "sweethearts"            => 8005,
                         "sweetie"                => 651,
                         "sweetly"                => 16689,
                         "swelco"                 => 14784,
                         "swell"                  => 2165,
                         "swelled"                => 11124,
                         "swelling"               => 4185,
                         "swells"                 => 12397,
                         "sweltering"             => 16688,
                         "swept"                  => 3512,
                         "swerve"                 => 10777,
                         "swerved"                => 9429,
                         "swerving"               => 15686,
                         "swicker"                => 12396,
                         "swill"                  => 10175,
                         "swilling"               => 15685,
                         "swim"                   => 1556,
                         "swimmin"                => 9911,
                         "swimmingly"             => 11927,
                         "swimsuit"               => 6339,
                         "swimsuits"              => 16687,
                         "swindled"               => 15684,
                         "swine"                  => 6338,
                         "swing"                  => 1521,
                         "swingin"                => 11505,
                         "swings"                 => 3695,
                         "swipe"                  => 7690,
                         "swiped"                 => 7856,
                         "swiping"                => 15683,
                         "swirl"                  => 8818,
                         "swirling"               => 8441,
                         "swirly"                 => 13425,
                         "swish"                  => 9670,
                         "switch"                 => 1258,
                         "switchblade"            => 12395,
                         "switchboard"            => 9428,
                         "switched"               => 1863,
                         "switcheroo"             => 13424,
                         "switching"              => 3645,
                         "switchman"              => 16686,
                         "swivel"                 => 12856,
                         "swizzle"                => 15682,
                         "swollen"                => 4958,
                         "swoon"                  => 9427,
                         "swooning"               => 16685,
                         "swoop"                  => 5462,
                         "swooped"                => 13423,
                         "swooping"               => 15681,
                         "swoops"                 => 11504,
                         "swore"                  => 1868,
                         "sworn"                  => 2287,
                         "swung"                  => 6274,
                         "sycophant"              => 11926,
                         "syllabus"               => 11503,
                         "symbiote"               => 8817,
                         "sympathetic"            => 3467,
                         "sympathies"             => 7855,
                         "sympathize"             => 5360,
                         "sympathy"               => 2111,
                         "symptom"                => 5461,
                         "symptomatic"            => 11925,
                         "symptoms"               => 1980,
                         "synapses"               => 16684,
                         "synch"                  => 16683,
                         "synchronicity"          => 16682,
                         "synchronize"            => 11924,
                         "synthedyne"             => 17944,
                         "syphilis"               => 7200,
                         "syrah"                  => 16681,
                         "syringe"                => 4031,
                         "syringes"               => 14026,
                         "syrup"                  => 3822,
                         "systolic"               => 10776,
                         "szechwan"               => 17943,
                         "szpilman"               => 10472,
                         "t'akaya"                => 14783,
                         "tabby"                  => 2029,
                         "tabithia"               => 17942,
                         "table"                  => 587,
                         "tablecloth"             => 15680,
                         "tablecloths"            => 11923,
                         "tables"                 => 2110,
                         "tablespoon"             => 16680,
                         "tabletops"              => 17941,
                         "tabloid"                => 2986,
                         "tabloids"               => 4273,
                         "tabs"                   => 3958,
                         "tabula"                 => 17940,
                         "tachibana"              => 14025,
                         "tachy"                  => 16679,
                         "tachycardia"            => 14782,
                         "tack"                   => 4842,
                         "tacked"                 => 10775,
                         "tackled"                => 8440,
                         "tacks"                  => 12855,
                         "tacky"                  => 4549,
                         "tacos"                  => 4878,
                         "tactful"                => 16678,
                         "tactic"                 => 4988,
                         "tadpoles"               => 14024,
                         "taffeta"                => 10774,
                         "tagataya"               => 5416,
                         "tagged"                 => 6273,
                         "taggert"                => 1828,
                         "tagging"                => 8128,
                         "tagliati"               => 10471,
                         "tahitian"               => 16677,
                         "tail"                   => 1642,
                         "tailing"                => 6971,
                         "taillight"              => 14023,
                         "tailor"                 => 5460,
                         "tailors"                => 16676,
                         "tails"                  => 3803,
                         "tailspin"               => 15679,
                         "taint"                  => 10174,
                         "tainted"                => 5141,
                         "take"                   => 69,
                         "takeoff"                => 6668,
                         "takeout"                => 4738,
                         "takeovers"              => 9669,
                         "taker"                  => 7854,
                         "takers"                 => 8816,
                         "takes"                  => 518,
                         "taketh"                 => 14022,
                         "takin"                  => 2680,
                         "taking"                 => 293,
                         "talby"                  => 8439,
                         "talcum"                 => 12854,
                         "taldor"                 => 11502,
                         "tale"                   => 2024,
                         "talent"                 => 1344,
                         "talented"               => 2058,
                         "talentless"             => 13422,
                         "talents"                => 3341,
                         "talk"                   => 104,
                         "talkative"              => 8282,
                         "talked"                 => 464,
                         "talker"                 => 5770,
                         "talkie"                 => 8815,
                         "talkies"                => 9426,
                         "talkin"                 => 1456,
                         "talking"                => 150,
                         "talks"                  => 1440,
                         "talky"                  => 9033,
                         "tall"                   => 1383,
                         "taller"                 => 3587,
                         "tallow"                 => 14021,
                         "tamale"                 => 9668,
                         "tamales"                => 16675,
                         "tambourine"             => 13421,
                         "tamed"                  => 14020,
                         "tamer"                  => 17939,
                         "tamper"                 => 9032,
                         "tampered"               => 5274,
                         "tampering"              => 6008,
                         "tampon"                 => 11123,
                         "tampons"                => 8625,
                         "tangible"               => 8127,
                         "tangle"                 => 8281,
                         "tangled"                => 4706,
                         "tangles"                => 17938,
                         "tangling"               => 16674,
                         "tangy"                  => 17937,
                         "tanked"                 => 6502,
                         "tanking"                => 11922,
                         "tanned"                 => 16673,
                         "tanneke"                => 15678,
                         "tanning"                => 8624,
                         "tantamount"             => 17936,
                         "tantrum"                => 6501,
                         "tantrums"               => 9031,
                         "tapas"                  => 16672,
                         "tape"                   => 621,
                         "taped"                  => 3439,
                         "tapes"                  => 2213,
                         "tapeworm"               => 12853,
                         "taping"                 => 4737,
                         "tapioca"                => 12852,
                         "tapped"                 => 3438,
                         "tapping"                => 6272,
                         "tappy"                  => 12851,
                         "tar'd"                  => 17935,
                         "taraka"                 => 12850,
                         "taransky"               => 5769,
                         "tarantula"              => 9667,
                         "tarantulas"             => 16671,
                         "tardiness"              => 12849,
                         "tarmac"                 => 8438,
                         "tarnish"                => 10470,
                         "tarnished"              => 10773,
                         "tarot"                  => 7318,
                         "tarragon"               => 12394,
                         "tarred"                 => 13420,
                         "tartabull"              => 17934,
                         "tartar"                 => 11122,
                         "tartlets"               => 17933,
                         "tarts"                  => 6598,
                         "tarzana"                => 11921,
                         "taser"                  => 14019,
                         "tasking"                => 14018,
                         "tassel"                 => 9425,
                         "tassels"                => 11920,
                         "taste"                  => 935,
                         "tastebuds"              => 17932,
                         "tasted"                 => 3402,
                         "tasteful"               => 6124,
                         "tastefully"             => 14017,
                         "tasteless"              => 9666,
                         "tastes"                 => 2399,
                         "tastic"                 => 14016,
                         "tasting"                => 5230,
                         "tator"                  => 14781,
                         "tattaglia"              => 11919,
                         "tattaglias"             => 15677,
                         "tattered"               => 15676,
                         "tattle"                 => 12848,
                         "tattooed"               => 5882,
                         "tattoos"                => 4524,
                         "tau'ri"                 => 10772,
                         "taunt"                  => 8004,
                         "taunted"                => 12847,
                         "taunting"               => 5768,
                         "tavington"              => 11121,
                         "tawdry"                 => 7853,
                         "taxi"                   => 2181,
                         "taxidermist"            => 14780,
                         "taxidermy"              => 17931,
                         "taxing"                 => 11501,
                         "taxpayers"              => 5830,
                         "teach"                  => 900,
                         "teal'c"                 => 1918,
                         "tear"                   => 1266,
                         "tearful"                => 11500,
                         "tearin"                 => 14015,
                         "tearing"                => 2386,
                         "tears"                  => 1612,
                         "teary"                  => 11918,
                         "tease"                  => 3300,
                         "teased"                 => 7852,
                         "teasing"                => 3079,
                         "teaspoon"               => 12846,
                         "teaspoons"              => 16670,
                         "technicalities"         => 10771,
                         "technicality"           => 5512,
                         "technically"            => 1666,
                         "technologically"        => 10469,
                         "techs"                  => 11917,
                         "tector"                 => 17930,
                         "tedious"                => 6056,
                         "teeming"                => 13419,
                         "teenage"                => 2203,
                         "teenaged"               => 11499,
                         "teenager"               => 2159,
                         "teenagers"              => 2652,
                         "teensy"                 => 8003,
                         "teeny"                  => 3785,
                         "teenybopper"            => 15675,
                         "teetering"              => 16669,
                         "teeth"                  => 1049,
                         "teething"               => 9424,
                         "teevee"                 => 13418,
                         "teldar"                 => 10173,
                         "telegram"               => 4396,
                         "telegrams"              => 8814,
                         "telekinesis"            => 13417,
                         "telekinetic"            => 16668,
                         "telemarketer"           => 14014,
                         "telemarketing"          => 13416,
                         "telemetry"              => 12393,
                         "telepathically"         => 16667,
                         "telepathy"              => 13415,
                         "telephone"              => 1815,
                         "telephoned"             => 14013,
                         "telephones"             => 8437,
                         "telephoto"              => 14012,
                         "teleportation"          => 16666,
                         "teleprompter"           => 12845,
                         "telesave"               => 5359,
                         "telethon"               => 12844,
                         "telex"                  => 15674,
                         "tell"                   => 59,
                         "tell'em"                => 13414,
                         "teller"                 => 4334,
                         "tellers"                => 12392,
                         "tellin"                 => 2661,
                         "telling"                => 259,
                         "tells"                  => 821,
                         "telltale"               => 14011,
                         "telly"                  => 5767,
                         "temper"                 => 2158,
                         "temperamental"          => 8813,
                         "tempered"               => 7445,
                         "tempers"                => 11120,
                         "temping"                => 17929,
                         "temps"                  => 14779,
                         "tempt"                  => 3957,
                         "temptation"             => 4006,
                         "temptations"            => 8623,
                         "tempted"                => 3047,
                         "tempting"               => 3159,
                         "ten"                    => 437,
                         "tenacious"              => 10172,
                         "tenacity"               => 12391,
                         "tenboom"                => 15673,
                         "tend"                   => 1856,
                         "tender"                 => 2923,
                         "tenderness"             => 6970,
                         "tending"                => 6597,
                         "tendonitis"             => 15672,
                         "tendons"                => 16665,
                         "tenement"               => 12843,
                         "tenfold"                => 14010,
                         "tengo"                  => 14009,
                         "tenorman"               => 8280,
                         "tenors"                 => 12390,
                         "tense"                  => 1787,
                         "tension"                => 1926,
                         "tent"                   => 2164,
                         "tenths"                 => 12842,
                         "tents"                  => 7444,
                         "tenuous"                => 12841,
                         "tepid"                  => 15671,
                         "tepui"                  => 17928,
                         "terdlington"            => 17927,
                         "tereza"                 => 10171,
                         "teriyaki"               => 12389,
                         "terminally"             => 9423,
                         "terminate"              => 5189,
                         "termites"               => 5766,
                         "terrace"                => 3287,
                         "terraforming"           => 15670,
                         "terrible"               => 574,
                         "terribly"               => 1426,
                         "terrif"                 => 17926,
                         "terrific"               => 1044,
                         "terrifically"           => 16664,
                         "terrified"              => 1740,
                         "terrifies"              => 8812,
                         "terrify"                => 10468,
                         "terrifying"             => 3299,
                         "terrorists"             => 3262,
                         "terrorize"              => 8622,
                         "terrorized"             => 6969,
                         "terrorizing"            => 7559,
                         "terrors"                => 10467,
                         "tersenadine"            => 17925,
                         "tess"                   => 1018,
                         "tessio"                 => 14778,
                         "testaburger"            => 17924,
                         "tested"                 => 2033,
                         "testicles"              => 8436,
                         "testicular"             => 12388,
                         "testifies"              => 11498,
                         "testify"                => 1501,
                         "testifying"             => 4030,
                         "testikov"               => 15669,
                         "testimony"              => 1724,
                         "testosterone"           => 5459,
                         "tests"                  => 1013,
                         "testy"                  => 6123,
                         "tetanus"                => 8621,
                         "tether"                 => 10770,
                         "tetherball"             => 15668,
                         "tethered"               => 17923,
                         "textbook"               => 5600,
                         "thaddius"               => 12840,
                         "thang"                  => 9910,
                         "thank"                  => 100,
                         "thanked"                => 4075,
                         "thankful"               => 2647,
                         "thankfully"             => 6337,
                         "thanking"               => 2646,
                         "thankless"              => 13413,
                         "thanks"                 => 145,
                         "thanksgiving"           => 1202,
                         "thanksgivings"          => 15667,
                         "that"                   => 4,
                         "that'd"                 => 1484,
                         "that'll"                => 896,
                         "that's"                 => 41,
                         "that've"                => 15666,
                         "thataway"               => 16663,
                         "thatherton"             => 11119,
                         "thatos"                 => 12387,
                         "thats"                  => 7199,
                         "thatta"                 => 14777,
                         "thawed"                 => 10769,
                         "thawing"                => 14776,
                         "theatrics"              => 11118,
                         "thee"                   => 1821,
                         "theft"                  => 3181,
                         "thefts"                 => 15665,
                         "theirs"                 => 2729,
                         "thelwall"               => 16662,
                         "theoretically"          => 6271,
                         "therapist"              => 1841,
                         "therapists"             => 6667,
                         "therapy"                => 1385,
                         "there'd"                => 2598,
                         "there'll"               => 1700,
                         "there're"               => 4764,
                         "there's"                => 90,
                         "there've"               => 7317,
                         "therein"                => 8435,
                         "thereof"                => 7316,
                         "theres"                 => 11497,
                         "thermometer"            => 6270,
                         "thermonuclear"          => 16661,
                         "thermos"                => 8279,
                         "thermostat"             => 7689,
                         "thesaurus"              => 14775,
                         "these'll"               => 12386,
                         "thespian"               => 12839,
                         "thespis"                => 11117,
                         "thesulac"               => 17922,
                         "thetas"                 => 17921,
                         "they'd"                 => 943,
                         "they'll"                => 502,
                         "they're"                => 132,
                         "they've"                => 627,
                         "thick"                  => 1993,
                         "thickening"             => 16660,
                         "thickens"               => 10170,
                         "thicker"                => 6666,
                         "thicket"                => 17920,
                         "thief"                  => 1873,
                         "thieves"                => 3608,
                         "thieving"               => 9909,
                         "thigh"                  => 5188,
                         "thighs"                 => 4705,
                         "thimble"                => 9665,
                         "thin"                   => 1584,
                         "thine"                  => 8620,
                         "thing"                  => 85,
                         "thing'll"               => 15664,
                         "thingie"                => 9422,
                         "thingies"               => 6596,
                         "things"                 => 111,
                         "things'll"              => 8619,
                         "thingy"                 => 4113,
                         "think"                  => 40,
                         "thinkin"                => 2169,
                         "thinking"               => 210,
                         "thinks"                 => 443,
                         "thinner"                => 4184,
                         "thinners"               => 11916,
                         "thinnest"               => 17919,
                         "thinning"               => 10768,
                         "thins"                  => 11915,
                         "thirst"                 => 4425,
                         "thirsty"                => 2309,
                         "thirties"               => 7688,
                         "thirtieth"              => 9030,
                         "thirty"                 => 750,
                         "this"                   => 8,
                         "this'd"                 => 12838,
                         "this'll"                => 2422,
                         "thommo"                 => 15663,
                         "thoracotomy"            => 14774,
                         "thorazine"              => 11496,
                         "thoreau"                => 8811,
                         "thorkel"                => 15662,
                         "thornhart"              => 3523,
                         "thornharts"             => 17918,
                         "thorns"                 => 7315,
                         "thornwood"              => 14008,
                         "thorough"               => 3166,
                         "thoroughly"             => 3802,
                         "thorpey"                => 12837,
                         "those"                  => 141,
                         "thou"                   => 2009,
                         "thought"                => 102,
                         "thoughtful"             => 2332,
                         "thoughtfully"           => 15661,
                         "thoughtfulness"         => 14007,
                         "thoughtless"            => 5415,
                         "thoughts"               => 1117,
                         "thousan"                => 14773,
                         "thousand"               => 617,
                         "thousandth"             => 9421,
                         "thrashing"              => 12385,
                         "thread"                 => 3729,
                         "thready"                => 11914,
                         "threat"                 => 1147,
                         "threaten"               => 1743,
                         "threatened"             => 1253,
                         "threatening"            => 1443,
                         "threats"                => 1854,
                         "threepio"               => 15660,
                         "threes"                 => 9420,
                         "threesome"              => 7687,
                         "threw"                  => 975,
                         "thrifty"                => 17917,
                         "thrill"                 => 2907,
                         "thrilled"               => 1390,
                         "thrilling"              => 5187,
                         "thrills"                => 7314,
                         "thrive"                 => 6055,
                         "thrives"                => 11116,
                         "throat"                 => 1361,
                         "throats"                => 3976,
                         "throbbing"              => 7313,
                         "throes"                 => 17916,
                         "thrombus"               => 17915,
                         "throttle"               => 5458,
                         "throughway"             => 16659,
                         "throw"                  => 493,
                         "throwback"              => 9664,
                         "throwed"                => 16658,
                         "throwers"               => 16657,
                         "throwin"                => 7312,
                         "throwing"               => 1089,
                         "thrown"                 => 1314,
                         "throws"                 => 2651,
                         "thruster"               => 14006,
                         "thrusters"              => 12384,
                         "thrusting"              => 17914,
                         "thrusts"                => 16656,
                         "ththe"                  => 16655,
                         "thug"                   => 4052,
                         "thuggee"                => 17913,
                         "thugs"                  => 4704,
                         "thumb"                  => 2597,
                         "thumbing"               => 12383,
                         "thumbprint"             => 13412,
                         "thump"                  => 6269,
                         "thumping"               => 8434,
                         "thundering"             => 12836,
                         "thunderstorm"           => 10767,
                         "thunk"                  => 9220,
                         "thurgood"               => 8618,
                         "thursday"               => 1627,
                         "thursdays"              => 8810,
                         "thusly"                 => 16654,
                         "thwap"                  => 16653,
                         "thyme"                  => 15659,
                         "thyroid"                => 7851,
                         "thyself"                => 10766,
                         "tibia"                  => 12382,
                         "tick"                   => 2846,
                         "ticked"                 => 3708,
                         "ticker"                 => 8002,
                         "ticket"                 => 1083,
                         "ticketed"               => 15658,
                         "tickets"                => 1073,
                         "ticking"                => 3298,
                         "tickled"                => 9419,
                         "tickles"                => 8001,
                         "ticks"                  => 8126,
                         "tidbit"                 => 9418,
                         "tidbits"                => 15657,
                         "tidings"                => 9029,
                         "tidying"                => 12381,
                         "tied"                   => 1345,
                         "tight"                  => 990,
                         "tighten"                => 5936,
                         "tightened"              => 12835,
                         "tightening"             => 11495,
                         "tightens"               => 15656,
                         "tighter"                => 4395,
                         "tightest"               => 17912,
                         "tightness"              => 15655,
                         "tightrope"              => 14772,
                         "tighty"                 => 15654,
                         "till"                   => 545,
                         "tillinghouse"           => 12380,
                         "tilney"                 => 15653,
                         "timbuktu"               => 9663,
                         "timed"                  => 5765,
                         "timeless"               => 6268,
                         "timer"                  => 3437,
                         "timers"                 => 7558,
                         "timetable"              => 5829,
                         "timetables"             => 17911,
                         "timey"                  => 17910,
                         "timid"                  => 7557,
                         "timin"                  => 17909,
                         "timing"                 => 1292,
                         "timithious"             => 15652,
                         "timmay"                 => 12379,
                         "timmi"                  => 16652,
                         "timmih"                 => 4183,
                         "timmiihh"               => 8809,
                         "timmuh"                 => 15651,
                         "timpani"                => 13411,
                         "tinfoil"                => 14771,
                         "tinga"                  => 7850,
                         "tingles"                => 17908,
                         "tingling"               => 7443,
                         "tingly"                 => 8808,
                         "tiniest"                => 5712,
                         "tinkered"               => 14770,
                         "tinkering"              => 11115,
                         "tinsel"                 => 9028,
                         "tinted"                 => 12834,
                         "tiny"                   => 1271,
                         "tions"                  => 15650,
                         "tipped"                 => 3371,
                         "tippers"                => 16651,
                         "tippin"                 => 5414,
                         "tipping"                => 6500,
                         "tips"                   => 2266,
                         "tipsy"                  => 9027,
                         "tiptoe"                 => 7686,
                         "tiptoeing"              => 12378,
                         "tirade"                 => 9908,
                         "tire"                   => 2496,
                         "tired"                  => 559,
                         "tireless"               => 12377,
                         "tires"                  => 3543,
                         "tiresome"               => 7085,
                         "tiring"                 => 6968,
                         "tizzy"                  => 16650,
                         "to"                     => 3,
                         "to've"                  => 17907,
                         "toad"                   => 4453,
                         "toads"                  => 9662,
                         "toadstool"              => 17906,
                         "toast"                  => 1116,
                         "toasted"                => 6967,
                         "toasters"               => 14005,
                         "toasties"               => 17905,
                         "toasting"               => 7442,
                         "toasts"                 => 10169,
                         "today"                  => 232,
                         "toddies"                => 17904,
                         "toddle"                 => 16649,
                         "toddler"                => 7685,
                         "toddlers"               => 12833,
                         "toddling"               => 17903,
                         "toddy"                  => 5881,
                         "toenails"               => 5764,
                         "toes"                   => 2082,
                         "tofurkey"               => 17902,
                         "togas"                  => 17901,
                         "together"               => 158,
                         "togetherness"           => 8000,
                         "toidy"                  => 17900,
                         "toilet"                 => 1514,
                         "toilets"                => 4877,
                         "toiling"                => 16648,
                         "toity"                  => 13410,
                         "tok'ra"                 => 4299,
                         "token"                  => 3662,
                         "told"                   => 115,
                         "tolerable"              => 12376,
                         "tolerate"               => 3058,
                         "tolerated"              => 7311,
                         "tollan"                 => 13409,
                         "tollans"                => 17899,
                         "tollbooth"              => 17898,
                         "tomarrow"               => 14004,
                         "tombstone"              => 8433,
                         "tomei"                  => 9026,
                         "tomfoolery"             => 14769,
                         "tommorow"               => 13408,
                         "tommorrow"              => 17897,
                         "tomorrow"               => 283,
                         "tomorrows"              => 16647,
                         "tomsk"                  => 16646,
                         "tonane"                 => 7310,
                         "tone"                   => 1862,
                         "toned"                  => 12832,
                         "tongaree"               => 11494,
                         "tongs"                  => 16645,
                         "tongue"                 => 1371,
                         "tongues"                => 5711,
                         "tonic"                  => 4578,
                         "tonics"                 => 16644,
                         "tonight"                => 192,
                         "tonio"                  => 6966,
                         "tons"                   => 2220,
                         "tonsil"                 => 15649,
                         "tonsils"                => 6420,
                         "too"                    => 77,
                         "toodle"                 => 11114,
                         "tool"                   => 1691,
                         "toontown"               => 9219,
                         "tooth"                  => 2238,
                         "toothache"              => 8807,
                         "toothbrush"             => 3363,
                         "toothbrushes"           => 12831,
                         "toothless"              => 14003,
                         "toothpaste"             => 5413,
                         "toothpick"              => 10168,
                         "toothpicks"             => 12375,
                         "tootin"                 => 11113,
                         "toots"                  => 5935,
                         "tooty"                  => 14002,
                         "topanga"                => 6965,
                         "topes"                  => 16643,
                         "topic"                  => 2532,
                         "topless"                => 5710,
                         "topnotch"               => 15648,
                         "topolsky"               => 5186,
                         "toppings"               => 11112,
                         "topple"                 => 15647,
                         "tops"                   => 2706,
                         "topshop"                => 16642,
                         "topside"                => 10466,
                         "topsy"                  => 15646,
                         "torch"                  => 3006,
                         "torched"                => 5763,
                         "torches"                => 7849,
                         "torching"               => 10167,
                         "tore"                   => 2376,
                         "toreador"               => 17896,
                         "torin"                  => 13407,
                         "torment"                => 4364,
                         "tormented"              => 8806,
                         "tormenting"             => 7198,
                         "torn"                   => 1804,
                         "torrance"               => 5828,
                         "torreon"                => 17895,
                         "torrid"                 => 12374,
                         "torso"                  => 9025,
                         "tortilla"               => 17894,
                         "tortillas"              => 15645,
                         "tortious"               => 16641,
                         "tortola"                => 17893,
                         "torture"                => 1698,
                         "tortured"               => 2955,
                         "tortures"               => 11493,
                         "torturing"              => 3078,
                         "torturous"              => 12373,
                         "toscanini"              => 17892,
                         "toss"                   => 1871,
                         "tossed"                 => 2873,
                         "tosses"                 => 10166,
                         "tossin"                 => 16640,
                         "tossing"                => 4074,
                         "totally"                => 453,
                         "toting"                 => 10465,
                         "toto"                   => 3313,
                         "touch"                  => 484,
                         "toucha"                 => 16639,
                         "touche"                 => 7999,
                         "touched"                => 1276,
                         "touches"                => 3046,
                         "touchin"                => 14768,
                         "touching"               => 1713,
                         "touchy"                 => 3857,
                         "tough"                  => 620,
                         "toughen"                => 10464,
                         "tougher"                => 3436,
                         "toughest"               => 5140,
                         "toughie"                => 17891,
                         "tought"                 => 11913,
                         "toula"                  => 6964,
                         "tounge"                 => 15644,
                         "toupee"                 => 7556,
                         "tourelles"              => 16638,
                         "touristy"               => 17890,
                         "tourniquet"             => 14001,
                         "towel"                  => 1831,
                         "towelie"                => 7084,
                         "towels"                 => 2405,
                         "towering"               => 9907,
                         "townhouse"              => 10765,
                         "townie"                 => 8617,
                         "townies"                => 16637,
                         "townsfolk"              => 12372,
                         "townspeople"            => 9024,
                         "toxic"                  => 3136,
                         "toxicology"             => 8805,
                         "toxin"                  => 8432,
                         "toxins"                 => 6419,
                         "toxoplasmosis"          => 15643,
                         "toyed"                  => 10764,
                         "toying"                 => 6122,
                         "toys"                   => 2142,
                         "tp'ed"                  => 15642,
                         "trace"                  => 1712,
                         "traceable"              => 17889,
                         "traced"                 => 3483,
                         "trach"                  => 13406,
                         "trachea"                => 17888,
                         "tracheotomy"            => 14000,
                         "tracing"                => 7197,
                         "tracked"                => 2806,
                         "trackers"               => 16636,
                         "tracking"               => 2121,
                         "tradeoff"               => 13405,
                         "tradin"                 => 16635,
                         "trafficker"             => 14767,
                         "tragedies"              => 8616,
                         "tragedy"                => 1936,
                         "tragic"                 => 2005,
                         "tragically"             => 6121,
                         "trailer"                => 2863,
                         "trainee"                => 7083,
                         "trainin"                => 17887,
                         "trainors"               => 16634,
                         "traipse"                => 13404,
                         "traipsed"               => 17886,
                         "traipsing"              => 8431,
                         "trait"                  => 6120,
                         "traitor"                => 3466,
                         "traitors"               => 7848,
                         "trajectory"             => 6868,
                         "tramell"                => 9661,
                         "tramp"                  => 2243,
                         "tramping"               => 13999,
                         "trampled"               => 9660,
                         "trampling"              => 15641,
                         "trampoline"             => 9906,
                         "tramps"                 => 12371,
                         "trampy"                 => 17885,
                         "trannie"                => 13998,
                         "tranq"                  => 17884,
                         "tranquility"            => 9023,
                         "tranquilizer"           => 6418,
                         "tranquilizers"          => 9218,
                         "transcendent"           => 12370,
                         "transcends"             => 14766,
                         "transcribing"           => 17883,
                         "transcript"             => 6417,
                         "transcripts"            => 5599,
                         "transference"           => 8125,
                         "transfuse"              => 17882,
                         "transfusion"            => 7082,
                         "transfusions"           => 12830,
                         "transgenic"             => 5139,
                         "transgenics"            => 6054,
                         "transgression"          => 11912,
                         "transgressions"         => 15640,
                         "transients"             => 17881,
                         "transitory"             => 17880,
                         "translate"              => 3933,
                         "transparent"            => 4643,
                         "transpired"             => 11911,
                         "transplant"             => 2265,
                         "transplants"            => 13997,
                         "transponder"            => 10763,
                         "transsexual"            => 12829,
                         "transvestite"           => 7555,
                         "transvestites"          => 16633,
                         "trap"                   => 1439,
                         "trapeze"                => 13403,
                         "trapped"                => 1405,
                         "trappers"               => 13996,
                         "trappings"              => 8615,
                         "traps"                  => 4101,
                         "trash"                  => 1245,
                         "trashcan"               => 12369,
                         "trashed"                => 3413,
                         "trashes"                => 15639,
                         "trashing"               => 5095,
                         "trashy"                 => 5313,
                         "trattoria"              => 15638,
                         "trauma"                 => 1987,
                         "traumas"                => 15637,
                         "traumatic"              => 3482,
                         "traumatize"             => 17879,
                         "traumatized"            => 5229,
                         "traumatizing"           => 16632,
                         "traveling"              => 2150,
                         "travers"                => 1382,
                         "travesty"               => 7081,
                         "traviata"               => 13995,
                         "tray"                   => 3101,
                         "traya"                  => 16631,
                         "trays"                  => 6665,
                         "treacherous"            => 6499,
                         "treachery"              => 10165,
                         "tread"                  => 6336,
                         "treading"               => 9217,
                         "treadmill"              => 8278,
                         "treads"                 => 11910,
                         "treadstone"             => 12368,
                         "treasured"              => 9022,
                         "treasures"              => 5762,
                         "treat"                  => 869,
                         "treatable"              => 9021,
                         "treated"                => 1185,
                         "treaters"               => 11909,
                         "treatin"                => 12367,
                         "treating"               => 1583,
                         "treats"                 => 2737,
                         "tree"                   => 893,
                         "treeger"                => 13402,
                         "treehorn"               => 13994,
                         "treehouse"              => 9417,
                         "trellis"                => 11111,
                         "tremble"                => 7441,
                         "trembled"               => 17878,
                         "trembling"              => 5761,
                         "tremendous"             => 3350,
                         "tremendously"           => 7847,
                         "tremoille"              => 14765,
                         "tremont"                => 14764,
                         "tremor"                 => 13401,
                         "tremors"                => 12828,
                         "trenchcoat"             => 17877,
                         "trendy"                 => 6867,
                         "trepkos"                => 13400,
                         "trespass"               => 7080,
                         "trespassed"             => 16630,
                         "trespasser"             => 15636,
                         "trespassers"            => 15635,
                         "trespasses"             => 13993,
                         "trespassing"            => 3765,
                         "triad"                  => 5312,
                         "triads"                 => 13992,
                         "triage"                 => 9416,
                         "trial"                  => 905,
                         "tribbey"                => 11492,
                         "tribbiani"              => 4763,
                         "tribianni"              => 17876,
                         "tribulations"           => 14763,
                         "triceps"                => 16629,
                         "trick"                  => 932,
                         "tricked"                => 2465,
                         "trickery"               => 10762,
                         "trickier"               => 12366,
                         "tricking"               => 7846,
                         "tricks"                 => 1569,
                         "trickster"              => 15634,
                         "tried"                  => 333,
                         "trifecta"               => 14762,
                         "trifle"                 => 7196,
                         "trifled"                => 14761,
                         "trifles"                => 17875,
                         "trifling"               => 15633,
                         "triggers"               => 8430,
                         "trigonometry"           => 14760,
                         "trillion"               => 6595,
                         "trimester"              => 5827,
                         "trimmers"               => 16628,
                         "trimming"               => 9216,
                         "trimmings"              => 12365,
                         "tringle"                => 15632,
                         "trini"                  => 12364,
                         "trinium"                => 11908,
                         "trinkets"               => 10463,
                         "trip"                   => 563,
                         "tripe"                  => 14759,
                         "triplette"              => 13399,
                         "triplicate"             => 11491,
                         "tripped"                => 3401,
                         "trippin"                => 7195,
                         "tripping"               => 4363,
                         "triquetra"              => 16627,
                         "tristin"                => 6416,
                         "trite"                  => 7554,
                         "triumphant"             => 9215,
                         "triumphed"              => 14758,
                         "triumphs"               => 11490,
                         "trivial"                => 5598,
                         "trivialize"             => 17874,
                         "trolling"               => 8804,
                         "trollop"                => 12827,
                         "trolls"                 => 6498,
                         "tropez"                 => 11110,
                         "trophies"               => 6119,
                         "tropicana"              => 16626,
                         "trotting"               => 12363,
                         "troubadour"             => 11907,
                         "troubled"               => 3077,
                         "troublemaker"           => 7684,
                         "troublemakers"          => 12826,
                         "troubles"               => 2320,
                         "troubling"              => 4298,
                         "trouper"                => 13398,
                         "trouser"                => 15631,
                         "trousseau"              => 17873,
                         "trove"                  => 14757,
                         "trowel"                 => 17872,
                         "troxa"                  => 16625,
                         "truant"                 => 14756,
                         "trubshaw"               => 15630,
                         "truce"                  => 3400,
                         "truckasaurus"           => 15629,
                         "truckload"              => 7440,
                         "trucoat"                => 16624,
                         "true"                   => 254,
                         "truer"                  => 14755,
                         "truest"                 => 11489,
                         "truffaut"               => 14754,
                         "truly"                  => 971,
                         "trumped"                => 9214,
                         "trumpets"               => 8124,
                         "trumps"                 => 15628,
                         "trunk"                  => 1759,
                         "trussed"                => 12825,
                         "trust"                  => 285,
                         "trusted"                => 1242,
                         "trusting"               => 2297,
                         "trusts"                 => 3018,
                         "trustworthy"            => 4611,
                         "truth"                  => 251,
                         "truthful"               => 5412,
                         "truthfully"             => 5273,
                         "truths"                 => 5228,
                         "try"                    => 177,
                         "tryed"                  => 17871,
                         "tryin"                  => 2180,
                         "trying"                 => 147,
                         "tryout"                 => 12362,
                         "tryouts"                => 13397,
                         "tryst"                  => 9905,
                         "tsavo"                  => 12824,
                         "tsimshian"              => 14753,
                         "tuatha"                 => 11109,
                         "tubby"                  => 8803,
                         "tuberculoma"            => 14752,
                         "tubers"                 => 16623,
                         "tucked"                 => 3856,
                         "tucking"                => 9020,
                         "tuesdays"               => 8123,
                         "tugging"                => 13991,
                         "tularemia"              => 14751,
                         "tulle"                  => 13396,
                         "tulsa"                  => 4987,
                         "tumble"                 => 6497,
                         "tumbler"                => 11488,
                         "tumblin"                => 17870,
                         "tumbling"               => 7845,
                         "tummy"                  => 5026,
                         "tumnus"                 => 11906,
                         "tumor"                  => 2631,
                         "tuna"                   => 2616,
                         "tune"                   => 2044,
                         "tuned"                  => 3990,
                         "tuney"                  => 15627,
                         "tunic"                  => 12823,
                         "tupperware"             => 9415,
                         "turati"                 => 12822,
                         "turban"                 => 10761,
                         "turbinium"              => 16622,
                         "turbulence"             => 7844,
                         "turds"                  => 11905,
                         "turf"                   => 3694,
                         "turghan"                => 16621,
                         "turkeys"                => 5094,
                         "turkle"                 => 16620,
                         "turlock"                => 13395,
                         "turmoil"                => 5411,
                         "turn"                   => 281,
                         "turnabout"              => 17869,
                         "turnaround"             => 7998,
                         "turncoat"               => 13394,
                         "turndown"               => 14750,
                         "turned"                 => 483,
                         "turners"                => 17868,
                         "turnin"                 => 11108,
                         "turning"                => 952,
                         "turnips"                => 10462,
                         "turnoff"                => 9659,
                         "turns"                  => 827,
                         "turpentine"             => 9414,
                         "turquoise"              => 10164,
                         "turtleneck"             => 10760,
                         "tuscany"                => 3707,
                         "tuscarora"              => 16619,
                         "tushie"                 => 11904,
                         "tushy"                  => 16618,
                         "tussle"                 => 12821,
                         "tutor"                  => 3454,
                         "tutorial"               => 9904,
                         "tutoring"               => 4204,
                         "tutsami"                => 16617,
                         "tutti"                  => 14749,
                         "tuxedos"                => 11903,
                         "tuxes"                  => 12820,
                         "tvmegasite"             => 9213,
                         "twain"                  => 6760,
                         "tweak"                  => 11107,
                         "tweaked"                => 10461,
                         "tweaking"               => 10163,
                         "tweedle"                => 10759,
                         "tweek"                  => 3607,
                         "tween"                  => 12361,
                         "tweeze"                 => 16616,
                         "tweezers"               => 9212,
                         "twelve"                 => 1017,
                         "twenties"               => 4610,
                         "twenty"                 => 508,
                         "twerp"                  => 7079,
                         "twice"                  => 852,
                         "twiddling"              => 17867,
                         "twinge"                 => 8429,
                         "twinges"                => 17866,
                         "twinkies"               => 9019,
                         "twinkling"              => 17865,
                         "twins"                  => 1520,
                         "twirl"                  => 7439,
                         "twirling"               => 9413,
                         "twirly"                 => 17864,
                         "twist"                  => 1955,
                         "twisting"               => 3511,
                         "twists"                 => 6204,
                         "twit"                   => 4841,
                         "twitch"                 => 5826,
                         "twitched"               => 17863,
                         "twitches"               => 17862,
                         "twitching"              => 8277,
                         "twitchy"                => 11487,
                         "twits"                  => 14748,
                         "twosome"                => 14747,
                         "tybalt"                 => 14746,
                         "tying"                  => 4483,
                         "tykes"                  => 14745,
                         "tylenol"                => 11106,
                         "tynacorp"               => 12819,
                         "tyndareus"              => 13393,
                         "typed"                  => 6203,
                         "typewriter"             => 6202,
                         "typewriters"            => 17861,
                         "typhoid"                => 11902,
                         "typing"                 => 4762,
                         "typist"                 => 14744,
                         "tyranny"                => 8122,
                         "tyrants"                => 14743,
                         "udall"                  => 12818,
                         "ughuh"                  => 17860,
                         "uglier"                 => 9658,
                         "uglies"                 => 15626,
                         "ugliest"                => 7683,
                         "ugliness"               => 8121,
                         "ugly"                   => 1101,
                         "uhhh"                   => 3693,
                         "uhhhh"                  => 8276,
                         "uhhhhh"                 => 13990,
                         "uhhhm"                  => 16615,
                         "uhwhy"                  => 17859,
                         "ulcer"                  => 6335,
                         "ulcers"                 => 11105,
                         "ulterior"               => 4703,
                         "ultimatum"              => 4424,
                         "ultimatums"             => 7438,
                         "ultrasound"             => 4423,
                         "ululd"                  => 16614,
                         "umbilical"              => 10162,
                         "umbrellas"              => 9412,
                         "umhmm"                  => 17858,
                         "ummm"                   => 4523,
                         "ummmm"                  => 11104,
                         "umpteen"                => 17857,
                         "umpteenth"              => 15625,
                         "unabomber"              => 11901,
                         "unacceptable"           => 3453,
                         "unaccounted"            => 9657,
                         "unadulterated"          => 9656,
                         "unadvisedly"            => 12817,
                         "unafraid"               => 17856,
                         "unagi"                  => 13989,
                         "unamerican"             => 17855,
                         "unannounced"            => 7078,
                         "unanswered"             => 7309,
                         "unappealing"            => 11900,
                         "unappreciated"          => 11103,
                         "unapproved"             => 17854,
                         "unarmed"                => 5185,
                         "unattached"             => 10460,
                         "unattainable"           => 11102,
                         "unattended"             => 7553,
                         "unattractive"           => 5825,
                         "unauthorized"           => 5059,
                         "unavailable"            => 4609,
                         "unavoidable"            => 7552,
                         "unbalanced"             => 7682,
                         "unbearable"             => 4577,
                         "unbearably"             => 12360,
                         "unbeatable"             => 11486,
                         "unbecoming"             => 7997,
                         "unbelievable"           => 1230,
                         "unbelievably"           => 3676,
                         "unbiased"               => 13988,
                         "unbind"                 => 13987,
                         "unblemished"            => 16613,
                         "unborn"                 => 4802,
                         "unbreakable"            => 12816,
                         "unbridled"              => 9211,
                         "unburden"               => 10161,
                         "unbutton"               => 13986,
                         "unbuttoned"             => 16612,
                         "unbuttoning"            => 17853,
                         "uncalled"               => 8614,
                         "uncanny"                => 5511,
                         "uncaring"               => 12359,
                         "uncas"                  => 17852,
                         "unchallenged"           => 17851,
                         "uncharacteristic"       => 15624,
                         "uncharacteristically"   => 16611,
                         "uncharted"              => 9210,
                         "unchecked"              => 13985,
                         "uncircumcised"          => 17850,
                         "uncivilized"            => 15623,
                         "unclaimed"              => 16610,
                         "uncle"                  => 731,
                         "unclean"                => 9411,
                         "unclench"               => 16609,
                         "uncles"                 => 6866,
                         "unclog"                 => 17849,
                         "uncomfortable"          => 1308,
                         "uncommonly"             => 17848,
                         "uncomplicated"          => 8275,
                         "unconcerned"            => 14742,
                         "unconditional"          => 6201,
                         "unconditionally"        => 9209,
                         "unconfirmed"            => 9655,
                         "unconscionable"         => 8613,
                         "unconscious"            => 1859,
                         "unconsciously"          => 13392,
                         "unconsciousness"        => 13391,
                         "uncontrollable"         => 7551,
                         "uncontrollably"         => 11485,
                         "uncool"                 => 6267,
                         "uncooperative"          => 11484,
                         "uncork"                 => 17847,
                         "uncouth"                => 17846,
                         "uncover"                => 5760,
                         "uncovering"             => 13390,
                         "uncuff"                 => 11899,
                         "uncut"                  => 9018,
                         "undecided"              => 12358,
                         "undeniable"             => 9208,
                         "undeniably"             => 16608,
                         "underage"               => 5272,
                         "underappreciated"       => 17845,
                         "underbelly"             => 9903,
                         "undercover"             => 2325,
                         "undercurrent"           => 15622,
                         "undercut"               => 13389,
                         "underestimate"          => 2683,
                         "underestimated"         => 4548,
                         "underestimates"         => 17844,
                         "underestimating"        => 7437,
                         "underfoot"              => 13984,
                         "undergarment"           => 16607,
                         "undergarments"          => 14741,
                         "undergrad"              => 10758,
                         "underhanded"            => 6266,
                         "underline"              => 15621,
                         "underlined"             => 11101,
                         "underling"              => 17843,
                         "underlings"             => 15620,
                         "underlining"            => 17842,
                         "undermine"              => 4482,
                         "undermines"             => 14740,
                         "undermining"            => 8120,
                         "underneath"             => 1799,
                         "underpaid"              => 11898,
                         "underpants"             => 4840,
                         "underprivileged"        => 10160,
                         "underrated"             => 13983,
                         "undershirt"             => 15619,
                         "understaffed"           => 9902,
                         "understan"              => 15618,
                         "understand"             => 161,
                         "understandable"         => 2736,
                         "understandably"         => 8274,
                         "understanding"          => 1246,
                         "understands"            => 1767,
                         "understated"            => 9410,
                         "understatement"         => 3855,
                         "understood"             => 1256,
                         "understudy"             => 6415,
                         "underwear"              => 1706,
                         "underworld"             => 3956,
                         "underwrite"             => 17841,
                         "undeserving"            => 14739,
                         "undetectable"           => 11100,
                         "undetected"             => 12357,
                         "undies"                 => 9017,
                         "undisciplined"          => 15617,
                         "undiscovered"           => 15616,
                         "undivided"              => 7436,
                         "undo"                   => 2931,
                         "undoing"                => 7996,
                         "undone"                 => 5457,
                         "undoubtedly"            => 5824,
                         "undress"                => 7435,
                         "undressed"              => 5271,
                         "undressing"             => 10159,
                         "undue"                  => 11483,
                         "unduly"                 => 13388,
                         "undying"                => 6496,
                         "unearth"                => 15615,
                         "uneasy"                 => 5880,
                         "uneducated"             => 13387,
                         "unemployable"           => 13386,
                         "unemployed"             => 4029,
                         "unencumbered"           => 15614,
                         "unending"               => 15613,
                         "unequivocal"            => 13982,
                         "unequivocally"          => 12815,
                         "unethical"              => 4957,
                         "uneventful"             => 10158,
                         "unexpected"             => 2315,
                         "unexplainable"          => 9901,
                         "unexplained"            => 8802,
                         "unexplored"             => 16606,
                         "unexpressed"            => 15612,
                         "unfair"                 => 1728,
                         "unfairly"               => 7843,
                         "unfairness"             => 15611,
                         "unfaithful"             => 4333,
                         "unfamiliar"             => 6495,
                         "unfashionable"          => 17840,
                         "unfathomable"           => 12814,
                         "unfeeling"              => 9900,
                         "unfettered"             => 9899,
                         "unfinished"             => 3387,
                         "unfit"                  => 4362,
                         "unflattering"           => 15610,
                         "unfocused"              => 9898,
                         "unfold"                 => 7681,
                         "unfolding"              => 11897,
                         "unfolds"                => 13385,
                         "unforeseen"             => 8428,
                         "unforgettable"          => 6759,
                         "unforgivable"           => 3955,
                         "unforgiving"            => 9016,
                         "unfortunate"            => 2273,
                         "unfortunately"          => 999,
                         "unfounded"              => 8427,
                         "unfreeze"               => 7680,
                         "unfreezing"             => 15609,
                         "unfriendly"             => 11896,
                         "unfulfilled"            => 11099,
                         "unfunny"                => 15608,
                         "unglued"                => 13981,
                         "ungodly"                => 11482,
                         "ungrateful"             => 3452,
                         "unguarded"              => 16605,
                         "unhand"                 => 12813,
                         "unhappily"              => 16604,
                         "unhappiness"            => 6200,
                         "unhappy"                => 1861,
                         "unharmed"               => 7194,
                         "unhealthy"              => 5410,
                         "unheard"                => 7679,
                         "unhinged"               => 12812,
                         "unholy"                 => 6199,
                         "unhook"                 => 8612,
                         "unhooked"               => 15607,
                         "unicorns"               => 9409,
                         "unicycle"               => 15606,
                         "unidentified"           => 5597,
                         "uniform"                => 1739,
                         "uniformed"              => 9654,
                         "uniforms"               => 3349,
                         "unimaginable"           => 9207,
                         "unimaginative"          => 14738,
                         "unimpeachable"          => 17839,
                         "unimportant"            => 6758,
                         "unimpressed"            => 16603,
                         "uninformed"             => 16602,
                         "uninhibited"            => 10459,
                         "uninspired"             => 15605,
                         "uninsured"              => 15604,
                         "unintelligible"         => 14737,
                         "unintentional"          => 13980,
                         "unintentionally"        => 12356,
                         "uninteresting"          => 14736,
                         "uninterrupted"          => 9015,
                         "uninvited"              => 4332,
                         "uninvolved"             => 14735,
                         "unisex"                 => 14734,
                         "universe"               => 1378,
                         "unjust"                 => 9653,
                         "unjustly"               => 13384,
                         "unkind"                 => 9652,
                         "unknowns"               => 16601,
                         "unleaded"               => 15603,
                         "unleash"                => 6664,
                         "unleashed"              => 6198,
                         "unleashing"             => 13979,
                         "unless"                 => 458,
                         "unlikable"              => 15602,
                         "unlikely"               => 3147,
                         "unlisted"               => 8426,
                         "unload"                 => 4452,
                         "unloaded"               => 9408,
                         "unloading"              => 10458,
                         "unlock"                 => 3565,
                         "unlocked"               => 5025,
                         "unlocking"              => 12355,
                         "unlocks"                => 11481,
                         "unlovable"              => 16600,
                         "unloved"                => 10457,
                         "unlucky"                => 5227,
                         "unmade"                 => 17838,
                         "unmarked"               => 7077,
                         "unmask"                 => 13978,
                         "unmentionable"          => 16599,
                         "unmentionables"         => 13383,
                         "unmistakable"           => 11895,
                         "unmitigated"            => 10157,
                         "unnatural"              => 5226,
                         "unnecessarily"          => 9407,
                         "unnecessary"            => 3228,
                         "unnerstand"             => 17837,
                         "unnerve"                => 15601,
                         "unnerved"               => 16598,
                         "unnerving"              => 9651,
                         "unnoticed"              => 9650,
                         "unopened"               => 14733,
                         "unorthodox"             => 6265,
                         "unpack"                 => 4451,
                         "unpacked"               => 7842,
                         "unpacking"              => 6494,
                         "unparalleled"           => 10757,
                         "unplanned"              => 12811,
                         "unpleasant"             => 2899,
                         "unpleasantness"         => 8611,
                         "unplug"                 => 8119,
                         "unplugged"              => 7841,
                         "unpredictability"       => 13977,
                         "unpredictable"          => 3989,
                         "unprepared"             => 6264,
                         "unpretentious"          => 17836,
                         "unprincipled"           => 13382,
                         "unprofessional"         => 5409,
                         "unprotected"            => 6663,
                         "unprovoked"             => 11894,
                         "unpunished"             => 8801,
                         "unqualified"            => 11098,
                         "unquenchable"           => 16597,
                         "unquote"                => 11097,
                         "unravel"                => 6757,
                         "unraveled"              => 14732,
                         "unraveling"             => 11096,
                         "unreachable"            => 11893,
                         "unrealistic"            => 6756,
                         "unreasonable"           => 4073,
                         "unrecognizable"         => 13976,
                         "unreliable"             => 5934,
                         "unremarkable"           => 17835,
                         "unrequited"             => 9649,
                         "unresolved"             => 6007,
                         "unresponsive"           => 8800,
                         "unreturned"             => 17834,
                         "unromantic"             => 13975,
                         "unruly"                 => 11480,
                         "unsaid"                 => 12354,
                         "unsanitary"             => 14731,
                         "unsatisfied"            => 16596,
                         "unsatisfying"           => 15600,
                         "unsavory"               => 8799,
                         "unscathed"              => 9014,
                         "unscheduled"            => 10756,
                         "unscramble"             => 17833,
                         "unscrupulous"           => 11095,
                         "unseal"                 => 15599,
                         "unsealed"               => 12810,
                         "unseasonably"           => 15598,
                         "unseat"                 => 15597,
                         "unsecured"              => 17832,
                         "unseemly"               => 8118,
                         "unseen"                 => 6263,
                         "unselfish"              => 6865,
                         "unsettled"              => 11479,
                         "unsettling"             => 7193,
                         "unshakable"             => 11478,
                         "unsolicited"            => 9897,
                         "unsolved"               => 5933,
                         "unspeakable"            => 5596,
                         "unspeakably"            => 11094,
                         "unspoiled"              => 15596,
                         "unspoken"               => 7550,
                         "unstable"               => 3624,
                         "unstoppable"            => 6414,
                         "unstuck"                => 13381,
                         "unsubstantiated"        => 11093,
                         "unsubtitled"            => 15595,
                         "unsung"                 => 11092,
                         "unsupervised"           => 8610,
                         "unsure"                 => 7678,
                         "unsuspecting"           => 6963,
                         "unsympathetic"          => 13974,
                         "untamed"                => 14730,
                         "untangle"               => 14729,
                         "untangled"              => 17831,
                         "untapped"               => 16595,
                         "untested"               => 9896,
                         "unthinkable"            => 6262,
                         "untie"                  => 3833,
                         "untied"                 => 9013,
                         "untimely"               => 8798,
                         "unto"                   => 3854,
                         "untold"                 => 13973,
                         "untouchable"            => 7549,
                         "untouchables"           => 17830,
                         "untouched"              => 8425,
                         "untoward"               => 11477,
                         "untraceable"            => 8609,
                         "untrained"              => 13380,
                         "untrue"                 => 5759,
                         "untrustworthy"          => 10156,
                         "unturned"               => 17829,
                         "unusual"                => 1616,
                         "unvarnished"            => 17828,
                         "unveil"                 => 10456,
                         "unveiling"              => 7995,
                         "unwanted"               => 5709,
                         "unwarranted"            => 10755,
                         "unwashed"               => 13379,
                         "unwavering"             => 13972,
                         "unwed"                  => 9648,
                         "unwelcome"              => 8117,
                         "unwieldy"               => 16594,
                         "unwind"                 => 5823,
                         "unwise"                 => 8797,
                         "unwitting"              => 14728,
                         "unwittingly"            => 12809,
                         "unworthy"               => 7308,
                         "unwrap"                 => 11091,
                         "unwrapping"             => 16593,
                         "unwritten"              => 11090,
                         "unyielding"             => 17827,
                         "unzip"                  => 13378,
                         "up"                     => 38,
                         "upbeat"                 => 6594,
                         "upbringing"             => 6864,
                         "upchuck"                => 8608,
                         "update"                 => 2915,
                         "upfront"                => 6006,
                         "uphill"                 => 8796,
                         "uphold"                 => 5184,
                         "upholstered"            => 13971,
                         "upholstery"             => 9012,
                         "uplifting"              => 10155,
                         "uplink"                 => 10455,
                         "uploading"              => 16592,
                         "upped"                  => 7192,
                         "uppers"                 => 12808,
                         "upping"                 => 14727,
                         "uppity"                 => 12353,
                         "uproar"                 => 11089,
                         "uproot"                 => 10754,
                         "uprooted"               => 15594,
                         "upscale"                => 7548,
                         "upset"                  => 399,
                         "upsets"                 => 4956,
                         "upsetting"              => 2231,
                         "upshot"                 => 13377,
                         "upside"                 => 2092,
                         "upstage"                => 12352,
                         "upstaged"               => 16591,
                         "upstairs"               => 685,
                         "upstanding"             => 5408,
                         "upstart"                => 15593,
                         "upstate"                => 6413,
                         "uptight"                => 3297,
                         "urethra"                => 16590,
                         "urge"                   => 3180,
                         "urgency"                => 8273,
                         "urgent"                 => 1997,
                         "urgently"               => 11476,
                         "urges"                  => 5225,
                         "urinal"                 => 12807,
                         "urinals"                => 17826,
                         "urinate"                => 11088,
                         "urinating"              => 14726,
                         "urination"              => 15592,
                         "urine"                  => 3896,
                         "urkel"                  => 10753,
                         "urologist"              => 15591,
                         "us'll"                  => 17825,
                         "useless"                => 1909,
                         "usernum"                => 17824,
                         "ushering"               => 15590,
                         "ushers"                 => 11475,
                         "ussher"                 => 14725,
                         "usted"                  => 12806,
                         "usual"                  => 1029,
                         "usurp"                  => 17823,
                         "utensils"               => 10454,
                         "utero"                  => 11474,
                         "uterus"                 => 6412,
                         "utmost"                 => 6197,
                         "uttered"                => 9647,
                         "utterly"                => 3706,
                         "uuuuh"                  => 15589,
                         "vacate"                 => 7307,
                         "vacationing"            => 12805,
                         "vacations"              => 6005,
                         "vaccinated"             => 12804,
                         "vaccine"                => 5224,
                         "vacuumed"               => 11892,
                         "vacuuming"              => 10453,
                         "vacuums"                => 17822,
                         "vadimus"                => 12351,
                         "vagas"                  => 16589,
                         "vaginal"                => 9206,
                         "vaginas"                => 16588,
                         "vague"                  => 3542,
                         "vaguely"                => 4481,
                         "vaguest"                => 13376,
                         "vailsburg"              => 16587,
                         "vain"                   => 4100,
                         "valedictorian"          => 9646,
                         "valentines"             => 5270,
                         "valet"                  => 5223,
                         "valets"                 => 13970,
                         "valiant"                => 5183,
                         "valiantly"              => 17821,
                         "validate"               => 9011,
                         "validates"              => 17820,
                         "valise"                 => 13375,
                         "valium"                 => 5758,
                         "vallens"                => 14724,
                         "valmont"                => 17819,
                         "valor"                  => 9010,
                         "valosky"                => 16586,
                         "valuable"               => 2054,
                         "valuables"              => 8795,
                         "vamanos"                => 12350,
                         "vamoose"                => 12803,
                         "vamos"                  => 12802,
                         "vampira"                => 11473,
                         "vampires"               => 1640,
                         "vamps"                  => 6411,
                         "vancomycin"             => 13374,
                         "vandaley"               => 13373,
                         "vandalism"              => 6410,
                         "vandalized"             => 12801,
                         "vandelay"               => 7994,
                         "vanderhof"              => 17818,
                         "vanish"                 => 4576,
                         "vanished"               => 3386,
                         "vanishes"               => 10752,
                         "vanishing"              => 7547,
                         "vanity"                 => 4246,
                         "vannacutt"              => 14723,
                         "vanquish"               => 2381,
                         "vanquished"             => 4678,
                         "vanquishing"            => 4272,
                         "vanstock"               => 15588,
                         "vapid"                  => 15587,
                         "vaporize"               => 14722,
                         "vaporized"              => 15586,
                         "vapors"                 => 17817,
                         "varcon"                 => 12800,
                         "varicose"               => 12799,
                         "varnish"                => 11891,
                         "varnsen"                => 15585,
                         "vasculitis"             => 13969,
                         "vase"                   => 4130,
                         "vasectomies"            => 17816,
                         "vasectomy"              => 6962,
                         "vasey"                  => 9009,
                         "vaslova"                => 16585,
                         "vastness"               => 17815,
                         "vater"                  => 14721,
                         "vault"                  => 2474,
                         "vayhue"                 => 12349,
                         "vecchio"                => 2066,
                         "veddy"                  => 16584,
                         "veered"                 => 16583,
                         "veering"                => 16582,
                         "vegas"                  => 1255,
                         "vegetable"              => 3100,
                         "vegetables"             => 3423,
                         "vegetarian"             => 4394,
                         "vegetarians"            => 14720,
                         "veggie"                 => 9406,
                         "veggies"                => 11087,
                         "veil"                   => 3764,
                         "veiled"                 => 7434,
                         "veils"                  => 12348,
                         "veins"                  => 3606,
                         "velociraptor"           => 17814,
                         "velour"                 => 17813,
                         "velveteen"              => 17812,
                         "ven't"                  => 17811,
                         "vendettas"              => 12347,
                         "vending"                => 4761,
                         "vendor"                 => 7076,
                         "veneer"                 => 11472,
                         "venereal"               => 16581,
                         "vengeance"              => 2699,
                         "vengeful"               => 6493,
                         "venison"                => 15584,
                         "vent"                   => 3481,
                         "vented"                 => 16580,
                         "ventilate"              => 16579,
                         "ventilated"             => 12798,
                         "ventilator"             => 4450,
                         "venting"                => 9008,
                         "ventricle"              => 11890,
                         "ventriloquism"          => 15583,
                         "ventriloquist"          => 12346,
                         "ventriss"               => 11471,
                         "vents"                  => 7191,
                         "venza"                  => 10452,
                         "veracity"               => 12797,
                         "veranda"                => 13372,
                         "verbal"                 => 3988,
                         "verdad"                 => 13371,
                         "verdict"                => 2670,
                         "verge"                  => 3435,
                         "verger"                 => 11470,
                         "verguenza"              => 17810,
                         "verify"                 => 4393,
                         "verifying"              => 13968,
                         "verily"                 => 14719,
                         "veritable"              => 8424,
                         "vermeer"                => 13967,
                         "vermeil"                => 11469,
                         "vermin"                 => 6118,
                         "vermouth"               => 11468,
                         "versa"                  => 5510,
                         "versed"                 => 10751,
                         "vertes"                 => 14718,
                         "veruca"                 => 13966,
                         "very"                   => 89,
                         "vespers"                => 14717,
                         "vested"                 => 4919,
                         "vestibule"              => 10750,
                         "vestigial"              => 16578,
                         "vests"                  => 10749,
                         "vesuvius"               => 17809,
                         "veterinarian"           => 9007,
                         "veto"                   => 4918,
                         "vetted"                 => 15582,
                         "vial"                   => 3784,
                         "vials"                  => 7840,
                         "vibe"                   => 2798,
                         "vibes"                  => 4331,
                         "vibrating"              => 9006,
                         "vibrations"             => 7075,
                         "vicarious"              => 17808,
                         "vicariously"            => 10451,
                         "vices"                  => 13965,
                         "vichyssoise"            => 17807,
                         "vicious"                => 2430,
                         "viciously"              => 13964,
                         "viciousness"            => 14716,
                         "vicksburg"              => 8607,
                         "vicodin"                => 9895,
                         "vicrum"                 => 15581,
                         "victim"                 => 1159,
                         "victimized"             => 9894,
                         "victimless"             => 13370,
                         "videogames"             => 17806,
                         "videotape"              => 2375,
                         "videotaped"             => 8423,
                         "videotapes"             => 7839,
                         "videotaping"            => 13963,
                         "vigeous"                => 16577,
                         "vigilance"              => 10450,
                         "vigilant"               => 6863,
                         "vigilante"              => 5456,
                         "vigilantes"             => 13962,
                         "viki"                   => 953,
                         "vilandra"               => 7433,
                         "vile"                   => 4072,
                         "villier"                => 16576,
                         "vincennes"              => 8272,
                         "vinceres"               => 16575,
                         "vincey"                 => 10154,
                         "vindaloo"               => 17805,
                         "vindicated"             => 10449,
                         "vindication"            => 11086,
                         "vindictive"             => 3783,
                         "vindictiveness"         => 16574,
                         "vinegar"                => 6261,
                         "violate"                => 5560,
                         "violated"               => 3480,
                         "violates"               => 8794,
                         "violating"              => 5024,
                         "violation"              => 2890,
                         "violent"                => 1916,
                         "violets"                => 10153,
                         "virginal"               => 11467,
                         "virginity"              => 4330,
                         "virgins"                => 5455,
                         "viridiana"              => 12796,
                         "virile"                 => 10748,
                         "virtucon"               => 12795,
                         "virtue"                 => 3801,
                         "virtuous"               => 7838,
                         "virulent"               => 16573,
                         "virus"                  => 1660,
                         "visage"                 => 15580,
                         "visceral"               => 11085,
                         "vishnoor"               => 16572,
                         "visions"                => 2645,
                         "visit"                  => 779,
                         "visitation"             => 2823,
                         "visitin"                => 15579,
                         "visitor"                => 2578,
                         "visor"                  => 15578,
                         "visualize"              => 6662,
                         "visualizing"            => 14715,
                         "vitally"                => 14714,
                         "vitals"                 => 3763,
                         "vitamins"               => 4522,
                         "vitone"                 => 13961,
                         "vittles"                => 17804,
                         "vivacious"              => 15577,
                         "vivant"                 => 15576,
                         "viveca"                 => 15575,
                         "vivica"                 => 15574,
                         "vividly"                => 9405,
                         "vivre"                  => 17803,
                         "viznick"                => 12345,
                         "vizzini"                => 12794,
                         "vocabulary"             => 4986,
                         "vocation"               => 10448,
                         "vodka"                  => 2519,
                         "vogelman"               => 10447,
                         "voice"                  => 636,
                         "voicemail"              => 9645,
                         "voices"                 => 2081,
                         "void"                   => 3278,
                         "voila"                  => 10747,
                         "volant"                 => 11084,
                         "volatile"               => 4917,
                         "voldemort"              => 17802,
                         "volts"                  => 8793,
                         "voluntarily"            => 4449,
                         "volunteered"            => 3340,
                         "volunteering"           => 5023,
                         "voluptuous"             => 13960,
                         "vomit"                  => 4112,
                         "vomited"                => 9644,
                         "vomiting"               => 6492,
                         "vorash"                 => 12793,
                         "vorhees"                => 17801,
                         "vornac"                 => 16571,
                         "vornoff"                => 17800,
                         "votre"                  => 15573,
                         "vouch"                  => 4521,
                         "vouched"                => 12344,
                         "voucher"                => 17799,
                         "vouchers"               => 9893,
                         "vouching"               => 15572,
                         "voula"                  => 14713,
                         "voulez"                 => 13959,
                         "vous"                   => 4520,
                         "vowed"                  => 5454,
                         "vowing"                 => 17798,
                         "vows"                   => 1903,
                         "vroom"                  => 7190,
                         "vrykolaka"              => 14712,
                         "vulgar"                 => 6196,
                         "vulnerability"          => 7189,
                         "vulnerable"             => 1604,
                         "vultures"               => 6004,
                         "vying"                  => 11889,
                         "waaaah"                 => 16570,
                         "waaah"                  => 11888,
                         "waaay"                  => 12343,
                         "wacked"                 => 11466,
                         "wacko"                  => 4702,
                         "wackos"                 => 15571,
                         "wacky"                  => 4028,
                         "wacquiem"               => 14711,
                         "waddya"                 => 16569,
                         "wading"                 => 11465,
                         "wadn't"                 => 12792,
                         "waffles"                => 4329,
                         "wafting"                => 13958,
                         "wage"                   => 3623,
                         "wager"                  => 4361,
                         "wagging"                => 11887,
                         "waging"                 => 10152,
                         "wagon"                  => 2898,
                         "wailing"                => 7546,
                         "waist"                  => 4099,
                         "waistband"              => 15570,
                         "wait"                   => 107,
                         "wait'll"                => 5559,
                         "waitaminute"            => 16568,
                         "waited"                 => 1237,
                         "waiter"                 => 2105,
                         "waitin"                 => 3399,
                         "waiting"                => 350,
                         "waitress"               => 1814,
                         "waitressed"             => 14710,
                         "waitresses"             => 5138,
                         "waitressing"            => 6862,
                         "waitwait"               => 17797,
                         "waive"                  => 8422,
                         "waiving"                => 17796,
                         "wake"                   => 580,
                         "waken"                  => 14709,
                         "wakes"                  => 2394,
                         "wakey"                  => 9643,
                         "waking"                 => 2207,
                         "walk"                   => 335,
                         "walked"                 => 723,
                         "walkie"                 => 6003,
                         "walkin"                 => 3874,
                         "walking"                => 709,
                         "walks"                  => 1423,
                         "wallaby"                => 8116,
                         "wallbanger"             => 17795,
                         "wallet"                 => 1527,
                         "wallets"                => 7188,
                         "wallop"                 => 11464,
                         "wallow"                 => 5757,
                         "wallowing"              => 6053,
                         "wallpaper"              => 5358,
                         "walnuts"                => 9404,
                         "waltons"                => 17794,
                         "waltzed"                => 9403,
                         "waltzes"                => 13957,
                         "waltzing"               => 6861,
                         "wampum"                 => 12791,
                         "wand"                   => 4297,
                         "wandell"                => 16567,
                         "wander"                 => 3324,
                         "wandered"               => 4098,
                         "wandering"              => 2746,
                         "wanders"                => 9205,
                         "wangler"                => 7074,
                         "wango"                  => 14708,
                         "waning"                 => 13369,
                         "wanna"                  => 238,
                         "wannabes"               => 9642,
                         "want"                   => 39,
                         "wanta"                  => 4392,
                         "wanted"                 => 138,
                         "wantin"                 => 11886,
                         "wanting"                => 1110,
                         "wanto"                  => 13368,
                         "wanton"                 => 11083,
                         "wants"                  => 236,
                         "waponi"                 => 15569,
                         "waponis"                => 12790,
                         "warbucks"               => 17793,
                         "wardrobe"               => 2679,
                         "warehouse"              => 1849,
                         "warfarin"               => 12789,
                         "warhead"                => 7677,
                         "warheads"               => 8271,
                         "warlocks"               => 2897,
                         "warm"                   => 850,
                         "warmed"                 => 4296,
                         "warmer"                 => 4160,
                         "warmest"                => 11082,
                         "warming"                => 3564,
                         "warms"                  => 7993,
                         "warmth"                 => 3975,
                         "warn"                   => 1194,
                         "warned"                 => 1488,
                         "warneford"              => 17792,
                         "warning"                => 1096,
                         "warpath"                => 8792,
                         "warped"                 => 4547,
                         "warrant"                => 1580,
                         "warranted"              => 11463,
                         "warrants"               => 5269,
                         "warranty"               => 9402,
                         "warton"                 => 2286,
                         "warts"                  => 7306,
                         "wash"                   => 1330,
                         "washboard"              => 13956,
                         "washcloth"              => 12342,
                         "washed"                 => 2342,
                         "washes"                 => 7837,
                         "washing"                => 2872,
                         "washout"                => 13367,
                         "washroom"               => 8270,
                         "washrooms"              => 16566,
                         "washy"                  => 16565,
                         "waski"                  => 12341,
                         "wasn't"                 => 171,
                         "wasnt"                  => 17791,
                         "wassail"                => 17790,
                         "waste"                  => 841,
                         "wastebasket"            => 14707,
                         "wasted"                 => 1786,
                         "wasteful"               => 12340,
                         "wasteland"              => 9401,
                         "wastin"                 => 10446,
                         "wasting"                => 1306,
                         "watch"                  => 310,
                         "watcha"                 => 12339,
                         "watchdog"               => 9641,
                         "watched"                => 1297,
                         "watchers"               => 8269,
                         "watches"                => 3076,
                         "watchful"               => 11885,
                         "watchin"                => 5137,
                         "watching"               => 539,
                         "watchit"                => 14706,
                         "waterbed"               => 11884,
                         "watered"                => 8791,
                         "watergate"              => 5357,
                         "watering"               => 6260,
                         "watermelons"            => 13955,
                         "waterproof"             => 10445,
                         "waterworks"             => 11883,
                         "watery"                 => 12338,
                         "waturi"                 => 16564,
                         "watusi"                 => 15568,
                         "waunt"                  => 13366,
                         "waved"                  => 5879,
                         "wavered"                => 14705,
                         "wavin"                  => 17789,
                         "waving"                 => 2839,
                         "waxed"                  => 9005,
                         "waxes"                  => 16563,
                         "waxing"                 => 8421,
                         "way"                    => 70,
                         "waylander"              => 17788,
                         "ways"                   => 823,
                         "wayside"                => 16562,
                         "wayward"                => 7545,
                         "wazoo"                  => 10746,
                         "we"                     => 20,
                         "we'd"                   => 534,
                         "we'll"                  => 157,
                         "we're"                  => 76,
                         "we've"                  => 221,
                         "weak"                   => 1241,
                         "weaken"                 => 6755,
                         "weaker"                 => 5656,
                         "weakest"                => 7836,
                         "weakling"               => 12788,
                         "weakness"               => 2563,
                         "weaknesses"             => 5022,
                         "weaning"                => 15567,
                         "weapon"                 => 1252,
                         "wear"                   => 597,
                         "wearin"                 => 5655,
                         "wearing"                => 608,
                         "wears"                  => 2308,
                         "weary"                  => 4736,
                         "weasels"                => 12337,
                         "weasly"                 => 16561,
                         "weathered"              => 11081,
                         "weave"                  => 5654,
                         "webbing"                => 16560,
                         "wedded"                 => 3987,
                         "weddin"                 => 11080,
                         "wedding"                => 342,
                         "weddings"               => 2630,
                         "wedge"                  => 4360,
                         "wedged"                 => 9204,
                         "wedges"                 => 14704,
                         "wedgie"                 => 10151,
                         "wedgies"                => 16559,
                         "wedlock"                => 7187,
                         "wednesday"              => 2080,
                         "wednesdays"             => 8606,
                         "weeding"                => 13954,
                         "weeds"                  => 7186,
                         "week"                   => 382,
                         "weekend"                => 836,
                         "weekends"               => 3179,
                         "weenies"                => 13365,
                         "weensy"                 => 12336,
                         "weeny"                  => 12335,
                         "weep"                   => 4159,
                         "weeping"                => 5311,
                         "weeps"                  => 17787,
                         "weepy"                  => 8420,
                         "weevil"                 => 16558,
                         "weigart"                => 11882,
                         "weigh"                  => 3045,
                         "weighing"               => 4677,
                         "weighs"                 => 4955,
                         "weightless"             => 16557,
                         "weird"                  => 480,
                         "weirded"                => 8268,
                         "weirder"                => 5058,
                         "weirdest"               => 4182,
                         "weirdly"                => 13364,
                         "weirdness"              => 7073,
                         "weirdo"                 => 4295,
                         "weirdoes"               => 15566,
                         "weirdos"                => 8605,
                         "weiskopf"               => 6002,
                         "welcoming"              => 4676,
                         "well"                   => 25,
                         "welles"                 => 5595,
                         "wellll"                 => 16556,
                         "wellstone"              => 14703,
                         "welluh"                 => 17786,
                         "welts"                  => 14702,
                         "wematanye"              => 7185,
                         "wench"                  => 5021,
                         "wendall"                => 12334,
                         "wendigo"                => 9640,
                         "wendle"                 => 11881,
                         "went"                   => 196,
                         "wenus"                  => 15565,
                         "weren't"                => 406,
                         "werewolves"             => 8115,
                         "westbridge"             => 4701,
                         "westerburg"             => 13953,
                         "wetsuit"                => 17785,
                         "wetting"                => 10444,
                         "wewell"                 => 17784,
                         "whack"                  => 2692,
                         "whacked"                => 3135,
                         "whackin"                => 16555,
                         "whacking"               => 9203,
                         "whacks"                 => 17783,
                         "whad'ya"                => 12787,
                         "whadaya"                => 7432,
                         "whadda"                 => 7544,
                         "whaddaya"               => 6961,
                         "whaddya"                => 4642,
                         "whadya"                 => 13363,
                         "whale"                  => 3586,
                         "whammo"                 => 16554,
                         "whammy"                 => 7835,
                         "wharves"                => 15564,
                         "wharvey"                => 14701,
                         "whassup"                => 12786,
                         "what"                   => 7,
                         "what'cha"               => 9004,
                         "what'd"                 => 871,
                         "what'dya"               => 17782,
                         "what'll"                => 2588,
                         "what'm"                 => 9003,
                         "what're"                => 1322,
                         "what's"                 => 83,
                         "what've"                => 4876,
                         "what'ya"                => 11462,
                         "whataya"                => 16553,
                         "whatcha"                => 3146,
                         "whatchamacallit"        => 12785,
                         "whatchya"               => 15563,
                         "whatd'ya"               => 16552,
                         "whatdya"                => 17781,
                         "whatiya"                => 13362,
                         "whatnot"                => 6259,
                         "whato"                  => 17780,
                         "whats"                  => 6960,
                         "whatsa"                 => 10443,
                         "whatsamatter"           => 12784,
                         "whatsoever"             => 2174,
                         "whatta"                 => 3126,
                         "whattaya"               => 9202,
                         "whattya"                => 12783,
                         "whatwhatwhaaat"         => 17779,
                         "whatya"                 => 10745,
                         "whazzup"                => 17778,
                         "wheel"                  => 1478,
                         "wheelbarrow"            => 13952,
                         "wheelchair"             => 2072,
                         "wheelchairs"            => 11461,
                         "wheelies"               => 17777,
                         "wheeling"               => 8419,
                         "wheelman"               => 13951,
                         "wheeze"                 => 16551,
                         "wheezer"                => 13950,
                         "wheezing"               => 16550,
                         "when'd"                 => 6491,
                         "when're"                => 13949,
                         "whence"                 => 7676,
                         "whenever"               => 1003,
                         "where'd"                => 1095,
                         "where're"               => 3782,
                         "where's"                => 366,
                         "where've"               => 4801,
                         "whereabouts"            => 3398,
                         "wherefore"              => 14700,
                         "whereof"                => 16549,
                         "wherever"               => 1234,
                         "whether"                => 681,
                         "whew"                   => 1992,
                         "which'll"               => 11460,
                         "whichever"              => 4916,
                         "whiff"                  => 6117,
                         "whim"                   => 4915,
                         "whimper"                => 11459,
                         "whimpering"             => 11079,
                         "whims"                  => 13361,
                         "whimsical"              => 11078,
                         "whimsy"                 => 12333,
                         "whine"                  => 4051,
                         "whiner"                 => 15562,
                         "whiney"                 => 13948,
                         "whining"                => 3218,
                         "whinny"                 => 17776,
                         "whiny"                  => 6001,
                         "whip"                   => 1412,
                         "whipped"                => 2945,
                         "whipper"                => 12782,
                         "whipping"               => 5594,
                         "whips"                  => 9892,
                         "whirl"                  => 7992,
                         "whirlpool"              => 9639,
                         "whirlwind"              => 7991,
                         "whisk"                  => 6860,
                         "whisked"                => 8790,
                         "whisker"                => 13360,
                         "whisking"               => 12332,
                         "whispered"              => 7305,
                         "whispering"             => 2772,
                         "whispers"               => 7543,
                         "whist"                  => 17775,
                         "whistle"                => 2524,
                         "whistled"               => 17774,
                         "whistles"               => 6409,
                         "whistling"              => 8114,
                         "whit"                   => 4480,
                         "whitelighter"           => 3277,
                         "whitelighters"          => 7184,
                         "whiteness"              => 15561,
                         "whiter"                 => 10744,
                         "whitesnake"             => 16548,
                         "whitest"                => 17773,
                         "whitewash"              => 13947,
                         "whitter"                => 9638,
                         "whittled"               => 14699,
                         "whittlesley"            => 12781,
                         "whittling"              => 16547,
                         "whiz"                   => 4448,
                         "whizz"                  => 17772,
                         "whizzing"               => 17771,
                         "who'd"                  => 1738,
                         "who'll"                 => 3269,
                         "who're"                 => 4641,
                         "who's"                  => 261,
                         "who've"                 => 3563,
                         "whoa"                   => 318,
                         "whoaa"                  => 17770,
                         "whoaaa"                 => 16546,
                         "whoah"                  => 5822,
                         "whodunit"               => 16545,
                         "whoever"                => 941,
                         "whole"                  => 182,
                         "wholeheartedly"         => 11458,
                         "wholesaler"             => 15560,
                         "wholesome"              => 6116,
                         "whomever"               => 6490,
                         "whoo"                   => 1045,
                         "whoomp"                 => 15559,
                         "whooo"                  => 9891,
                         "whoop"                  => 4271,
                         "whoopee"                => 6000,
                         "whoopi"                 => 15558,
                         "whoopie"                => 11457,
                         "whoopin"                => 14698,
                         "whooping"               => 10743,
                         "whoops"                 => 3339,
                         "whoosh"                 => 8789,
                         "whoppers"               => 17769,
                         "whopping"               => 11880,
                         "whorehouse"             => 9890,
                         "whorfin"                => 11077,
                         "whoring"                => 13946,
                         "whupped"                => 15557,
                         "whwhat"                 => 16544,
                         "why"                    => 48,
                         "why'd"                  => 1265,
                         "why're"                 => 6661,
                         "whyn't"                 => 8604,
                         "whyyy"                  => 17768,
                         "wicca"                  => 9889,
                         "wiccaning"              => 15556,
                         "wickedness"             => 11456,
                         "widen"                  => 10742,
                         "widower"                => 7990,
                         "wiedersehen"            => 14697,
                         "wield"                  => 8603,
                         "wielding"               => 9002,
                         "wieners"                => 14696,
                         "wierd"                  => 12780,
                         "wife"                   => 260,
                         "wigand"                 => 5821,
                         "wigged"                 => 8788,
                         "wiggen"                 => 16543,
                         "wigging"                => 9400,
                         "wiggle"                 => 4675,
                         "wiggled"                => 16542,
                         "wiggling"               => 12779,
                         "wiggy"                  => 14695,
                         "wild"                   => 970,
                         "wildebeest"             => 17767,
                         "wildest"                => 5057,
                         "wildflowers"            => 17766,
                         "wildly"                 => 5999,
                         "wildness"               => 13945,
                         "wildwind"               => 3800,
                         "will"                   => 54,
                         "willed"                 => 6859,
                         "willenholly"            => 17765,
                         "willful"                => 7834,
                         "willfully"              => 11076,
                         "willick"                => 17764,
                         "willies"                => 8787,
                         "willin"                 => 12331,
                         "willing"                => 721,
                         "willingly"              => 4181,
                         "willoby"                => 15555,
                         "willona"                => 8113,
                         "willows"                => 7431,
                         "willpower"              => 8418,
                         "willya"                 => 8786,
                         "wilshire"               => 10150,
                         "wilted"                 => 17763,
                         "wilting"                => 17762,
                         "wiluna"                 => 17761,
                         "wimp"                   => 4575,
                         "wimps"                  => 7989,
                         "wimpy"                  => 8417,
                         "winch"                  => 7072,
                         "wind"                   => 986,
                         "windbag"                => 12330,
                         "windbreaker"            => 14694,
                         "winded"                 => 10741,
                         "windermere"             => 16541,
                         "windfall"               => 13359,
                         "windjammer"             => 13358,
                         "windmills"              => 11879,
                         "window"                 => 722,
                         "windowsill"             => 13357,
                         "windowtext"             => 17760,
                         "windpipe"               => 12329,
                         "windshield"             => 4640,
                         "windstorm"              => 17759,
                         "windsurfing"            => 16540,
                         "windthorne"             => 16539,
                         "windward"               => 11075,
                         "wine"                   => 947,
                         "wingding"               => 17758,
                         "winging"                => 10442,
                         "wining"                 => 15554,
                         "wink"                   => 4546,
                         "winked"                 => 13944,
                         "winking"                => 10740,
                         "winks"                  => 11878,
                         "winnebago"              => 7304,
                         "winnin"                 => 13943,
                         "winnings"               => 6660,
                         "winos"                  => 16538,
                         "winthrop"               => 5268,
                         "wintry"                 => 17757,
                         "wipe"                   => 1939,
                         "wiped"                  => 2523,
                         "wiper"                  => 16537,
                         "wipers"                 => 16536,
                         "wipes"                  => 8602,
                         "wiping"                 => 5593,
                         "wire"                   => 1665,
                         "wired"                  => 2889,
                         "wires"                  => 3035,
                         "wiretap"                => 13356,
                         "wiretaps"               => 15553,
                         "wiring"                 => 5020,
                         "wiseass"                => 15552,
                         "wisecracks"             => 12778,
                         "wised"                  => 10149,
                         "wiseguys"               => 14693,
                         "wisely"                 => 5222,
                         "wiser"                  => 4180,
                         "wisest"                 => 8601,
                         "wish"                   => 282,
                         "wished"                 => 2404,
                         "wishes"                 => 1672,
                         "wishful"                => 4574,
                         "wishin"                 => 14692,
                         "wishing"                => 2448,
                         "wisht"                  => 16535,
                         "wishy"                  => 16534,
                         "witch"                  => 818,
                         "witchcraft"             => 3728,
                         "witches"                => 1350,
                         "witching"               => 15551,
                         "witchy"                 => 7430,
                         "withdrawals"            => 11074,
                         "withdraws"              => 16533,
                         "wither"                 => 9001,
                         "withered"               => 11877,
                         "withering"              => 15550,
                         "withheld"               => 7833,
                         "withhold"               => 6195,
                         "withholding"            => 5653,
                         "withnail"               => 9201,
                         "without"                => 235,
                         "withstanding"           => 12777,
                         "witless"                => 10441,
                         "witness"                => 891,
                         "witnesses"              => 1772,
                         "witnessing"             => 7675,
                         "wits"                   => 4328,
                         "witted"                 => 9888,
                         "witter"                 => 2745,
                         "wittle"                 => 12776,
                         "wittlesey"              => 7832,
                         "witty"                  => 3954,
                         "witwer"                 => 11073,
                         "wives"                  => 2079,
                         "wiwith"                 => 16532,
                         "wladek"                 => 8785,
                         "woah"                   => 3017,
                         "wobbling"               => 17756,
                         "wobbly"                 => 9200,
                         "woefully"               => 17755,
                         "wojadubakowski"         => 15549,
                         "woke"                   => 1295,
                         "woken"                  => 6334,
                         "wolchek"                => 14691,
                         "wolek"                  => 5878,
                         "wolfi"                  => 8267,
                         "wolfing"                => 17754,
                         "wolfram"                => 4027,
                         "wollsten"               => 17753,
                         "wolodarsky"             => 16531,
                         "woman"                  => 189,
                         "womanhood"              => 10440,
                         "womanizer"              => 12328,
                         "womanizing"             => 16530,
                         "womanly"                => 11455,
                         "wombosi"                => 12775,
                         "won't"                  => 146,
                         "wonder"                 => 489,
                         "wondered"               => 1889,
                         "wonderfalls"            => 11454,
                         "wonderful"              => 383,
                         "wonderfully"            => 5558,
                         "wonderin"               => 9000,
                         "wondering"              => 632,
                         "wonderland"             => 6858,
                         "wonders"                => 3165,
                         "wondrous"               => 8416,
                         "wonky"                  => 16529,
                         "wont"                   => 2944,
                         "woodchuck"              => 15548,
                         "woodpecker"             => 8415,
                         "woodrell"               => 13355,
                         "woodsboro"              => 9399,
                         "woodshed"               => 15547,
                         "woodsman"               => 13942,
                         "woodsy"                 => 15546,
                         "wooed"                  => 13354,
                         "woof"                   => 3268,
                         "woogyman"               => 12327,
                         "wooing"                 => 10148,
                         "wookiee"                => 14690,
                         "woooo"                  => 10147,
                         "wooooo"                 => 14689,
                         "wooooooo"               => 16528,
                         "woops"                  => 11453,
                         "woosh"                  => 17752,
                         "woozy"                  => 6194,
                         "word"                   => 309,
                         "worded"                 => 13353,
                         "words"                  => 497,
                         "wordsworth"             => 5221,
                         "wore"                   => 1641,
                         "workable"               => 10739,
                         "workaholic"             => 7303,
                         "workday"                => 15545,
                         "worker"                 => 2071,
                         "workiiing"              => 16527,
                         "workin"                 => 3005,
                         "working"                => 291,
                         "workload"               => 8112,
                         "workmanship"            => 13941,
                         "workout"                => 3932,
                         "workup"                 => 8999,
                         "worldly"                => 7542,
                         "worlds"                 => 2859,
                         "worm"                   => 2845,
                         "wormed"                 => 15544,
                         "wormhole"               => 6754,
                         "wormholes"              => 17751,
                         "worming"                => 15543,
                         "worms"                  => 3479,
                         "wormser"                => 14688,
                         "wormtail"               => 17750,
                         "wormy"                  => 17749,
                         "worried"                => 398,
                         "worrier"                => 12326,
                         "worries"                => 1958,
                         "worrisome"              => 16526,
                         "worry"                  => 249,
                         "worryin"                => 14687,
                         "worrying"               => 1338,
                         "worrywart"              => 11452,
                         "worse"                  => 448,
                         "worshiping"             => 17748,
                         "worshipped"             => 6659,
                         "worshipping"            => 8784,
                         "worships"               => 5509,
                         "worst"                  => 689,
                         "worth"                  => 525,
                         "worthiness"             => 17747,
                         "worthless"              => 2511,
                         "worthwhile"             => 4270,
                         "would'a"                => 14686,
                         "would've"               => 638,
                         "woulda"                 => 3397,
                         "wouldn"                 => 9887,
                         "wouldn't"               => 162,
                         "wouldn't've"            => 13940,
                         "wouldn'ta"              => 15542,
                         "wouldst"                => 17746,
                         "wound"                  => 1381,
                         "wounds"                 => 2380,
                         "wow"                    => 323,
                         "wowed"                  => 15541,
                         "wracked"                => 11876,
                         "wracking"               => 10146,
                         "wrangle"                => 12774,
                         "wrangled"               => 17745,
                         "wrap"                   => 1695,
                         "wrapped"                => 1785,
                         "wrapper"                => 7302,
                         "wrappers"               => 11451,
                         "wrapping"               => 3832,
                         "wraps"                  => 4179,
                         "wrath"                  => 4097,
                         "wreak"                  => 6408,
                         "wreaked"                => 10145,
                         "wreaking"               => 8998,
                         "wreaks"                 => 16525,
                         "wreaths"                => 15540,
                         "wreck"                  => 1663,
                         "wrecked"                => 2943,
                         "wrecker"                => 7674,
                         "wrecking"               => 4327,
                         "wrecks"                 => 8414,
                         "wrenched"               => 14685,
                         "wrenching"              => 9886,
                         "wretch"                 => 7988,
                         "wretched"               => 4220,
                         "wriggle"                => 12325,
                         "wring"                  => 6052,
                         "wringer"                => 11072,
                         "wringing"               => 10439,
                         "wrinkle"                => 5756,
                         "wrinkled"               => 6857,
                         "wrinkly"                => 11875,
                         "wrist"                  => 2587,
                         "wrists"                 => 4422,
                         "wristwatch"             => 17744,
                         "write"                  => 602,
                         "writhing"               => 10738,
                         "writin"                 => 11450,
                         "wrong"                  => 149,
                         "wrongdoing"             => 9398,
                         "wronged"                => 6593,
                         "wrongful"               => 7301,
                         "wrongfully"             => 11449,
                         "wrongs"                 => 8111,
                         "wrung"                  => 15539,
                         "wuddya"                 => 10438,
                         "wuss"                   => 4026,
                         "wussies"                => 14684,
                         "wussy"                  => 13352,
                         "wuthering"              => 16524,
                         "wuzzy"                  => 12324,
                         "wwhat"                  => 14683,
                         "wwooww"                 => 17743,
                         "wynant"                 => 5932,
                         "wyndemere"              => 4985,
                         "wyndham"                => 9397,
                         "wynette"                => 15538,
                         "xanax"                  => 9885,
                         "xander"                 => 1321,
                         "xerox"                  => 8110,
                         "xeroxed"                => 17742,
                         "xxxxxx"                 => 10144,
                         "y'all"                  => 2032,
                         "y'are"                  => 16523,
                         "y'ever"                 => 11071,
                         "y'got"                  => 17741,
                         "y'hear"                 => 12773,
                         "y'know"                 => 516,
                         "y'knowwhati'msayin"     => 14682,
                         "y'mean"                 => 16522,
                         "y'see"                  => 7300,
                         "y'understand"           => 15537,
                         "ya'll"                  => 6856,
                         "yaaah"                  => 17740,
                         "yacht"                  => 2281,
                         "yada"                   => 3781,
                         "yadda"                  => 7183,
                         "yahdah"                 => 17739,
                         "yahtzee"                => 16521,
                         "yakking"                => 8783,
                         "yakushova"              => 12323,
                         "yalta"                  => 16520,
                         "yammer"                 => 15536,
                         "yammering"              => 7071,
                         "yamuri"                 => 13939,
                         "yank"                   => 4479,
                         "yanked"                 => 5820,
                         "yankin"                 => 17738,
                         "yanking"                => 6489,
                         "yapping"                => 7429,
                         "yardstick"              => 15535,
                         "yawning"                => 16519,
                         "yawns"                  => 17737,
                         "yeah"                   => 35,
                         "yeahh"                  => 13938,
                         "yeahhh"                 => 11874,
                         "yearbook"               => 3158,
                         "yearbooks"              => 10437,
                         "yearn"                  => 9637,
                         "yearned"                => 16518,
                         "yearning"               => 7673,
                         "yearnings"              => 16517,
                         "yearns"                 => 16516,
                         "yecch"                  => 17736,
                         "yecchh"                 => 17735,
                         "yeesh"                  => 13937,
                         "yeess"                  => 14681,
                         "yelburton"              => 14680,
                         "yell"                   => 1557,
                         "yella"                  => 16515,
                         "yelled"                 => 2838,
                         "yeller"                 => 12322,
                         "yellin"                 => 9396,
                         "yelling"                => 1491,
                         "yellows"                => 13936,
                         "yells"                  => 6488,
                         "yengeese"               => 11873,
                         "yenta"                  => 17734,
                         "yes"                    => 65,
                         "yes'm"                  => 17733,
                         "yeska"                  => 13935,
                         "yesss"                  => 8413,
                         "yesterday"              => 698,
                         "yesterdays"             => 16514,
                         "yet"                    => 239,
                         "yevgeny"                => 13934,
                         "yikes"                  => 4421,
                         "yippee"                 => 7831,
                         "yippie"                 => 16513,
                         "ylang"                  => 17732,
                         "yodel"                  => 12772,
                         "yoga"                   => 4326,
                         "yoghurt"                => 10737,
                         "yogurt"                 => 4984,
                         "yokel"                  => 11070,
                         "yokels"                 => 15534,
                         "yonder"                 => 9395,
                         "yorkers"                => 8600,
                         "yorkin"                 => 11448,
                         "you"                    => 1,
                         "you'd"                  => 231,
                         "you'll"                 => 181,
                         "you'n"                  => 17731,
                         "you're"                 => 29,
                         "you've"                 => 124,
                         "youngsters"             => 8599,
                         "youore"                 => 9884,
                         "your"                   => 19,
                         "youre"                  => 7830,
                         "yours"                  => 362,
                         "yourself"               => 183,
                         "yourselves"             => 1482,
                         "youse"                  => 6051,
                         "youthful"               => 6487,
                         "youuu"                  => 15533,
                         "youve"                  => 16512,
                         "yoyodyne"               => 11872,
                         "yoyou"                  => 10143,
                         "yuck"                   => 3574,
                         "yucky"                  => 9636,
                         "yuletide"               => 11871,
                         "yuppie"                 => 8598,
                         "yuppies"                => 12771,
                         "zach"                   => 1742,
                         "zacks"                  => 15532,
                         "zadir"                  => 9199,
                         "zagat"                  => 17730,
                         "zakamatak"              => 16511,
                         "zamir"                  => 8597,
                         "zander"                 => 1175,
                         "zandt"                  => 7428,
                         "zantopia"               => 14679,
                         "zanuck"                 => 17729,
                         "zapped"                 => 6753,
                         "zapruder"               => 14678,
                         "zatarc"                 => 10436,
                         "zatarcs"                => 15531,
                         "zatunica"               => 13351,
                         "zeitgeist"              => 17728,
                         "zekes"                  => 13350,
                         "zeldy"                  => 13933,
                         "zellary"                => 17727,
                         "zellie"                 => 6407,
                         "zelner"                 => 13932,
                         "zende"                  => 5267,
                         "zendi"                  => 12770,
                         "zephyrs"                => 15530,
                         "zequiel"                => 17726,
                         "zero"                   => 1608,
                         "zeroed"                 => 11870,
                         "zeroes"                 => 8596,
                         "zeroing"                => 13931,
                         "zeros"                  => 8595,
                         "zerzura"                => 14677,
                         "zesty"                  => 14676,
                         "zhivago"                => 11447,
                         "zilch"                  => 9883,
                         "zillion"                => 5356,
                         "zillions"               => 15529,
                         "zinfandel"              => 15528,
                         "zinthar"                => 15527,
                         "ziploc"                 => 16510,
                         "zipped"                 => 8594,
                         "zippers"                => 17725,
                         "zipping"                => 11869,
                         "zippity"                => 11868,
                         "zirconia"               => 17724,
                         "zissou"                 => 7427,
                         "zlotys"                 => 14675,
                         "zoey"                   => 3895,
                         "zolda"                  => 16509,
                         "zombies"                => 4800,
                         "zoning"                 => 6959,
                         "zonked"                 => 11446,
                         "zookeeper"              => 17723,
                         "zooming"                => 11867,
                         "zorin"                  => 15526,
                         "zucchini"               => 17722,
                         "zuwicky"                => 16508,
                         "zzzzzzz"                => 17721,
                       },
);

1;
